@@ -293,7 +293,7 @@ void MediaControl::setState( const MediaItem& rItem )
 
 void MediaControl::implUpdateToolboxes()
 {
-    const bool bValidURL = ( maItem.getURL().getLength() > 0 );
+    const bool bValidURL = ( !maItem.getURL().isEmpty());
 
     maPlayToolBox.EnableItem( AVMEDIA_TOOLBOXITEM_INSERT, bValidURL );
     maPlayToolBox.EnableItem( AVMEDIA_TOOLBOXITEM_PLAY, bValidURL );
@@ -372,7 +372,7 @@ void MediaControl::implUpdateToolboxes()
 
 void MediaControl::implUpdateTimeSlider()
 {
-    if( !maItem.getURL().getLength() || !IsEnabled() )
+    if( maItem.getURL().isEmpty() || !IsEnabled() )
         maTimeSlider.Disable();
     else
     {
@@ -399,7 +399,7 @@ void MediaControl::implUpdateTimeSlider()
 
 void MediaControl::implUpdateVolumeSlider()
 {
-    if( !maItem.getURL().getLength() || !IsEnabled() )
+    if( maItem.getURL().isEmpty() || !IsEnabled() )
         maVolumeSlider.Disable();
     else
     {
@@ -416,7 +416,7 @@ void MediaControl::implUpdateVolumeSlider()
 
 void MediaControl::implUpdateTimeField( double fCurTime )
 {
-    if( maItem.getURL().getLength() > 0 )
+    if( !maItem.getURL().isEmpty() )
     {
         String              aTimeString;
 
@@ -480,7 +480,7 @@ IMPL_LINK( MediaControl, implVolumeHdl, Slider*, p )
 
 // ------------------------------------------------------------------------------
 
-IMPL_LINK( MediaControl, implVolumeEndHdl, Slider*, EMPTYARG )
+IMPL_LINK_NOARG(MediaControl, implVolumeEndHdl)
 {
     return 0;
 }
@@ -603,7 +603,7 @@ IMPL_LINK( MediaControl, implZoomSelectHdl, ListBox*, p )
 
 // ------------------------------------------------------------------------------
 
-IMPL_LINK( MediaControl, implTimeoutHdl, Timer*, EMPTYARG )
+IMPL_LINK_NOARG(MediaControl, implTimeoutHdl)
 {
     update();
     maTimer.Start();
