@@ -395,7 +395,7 @@ void writeNode(
         writeData(handle, RTL_CONSTASCII_STRINGPARAM("<prop oor:name=\""));
         writeAttributeValue(handle, name);
         writeData(handle, RTL_CONSTASCII_STRINGPARAM("\" oor:op=\"fuse\">"));
-        for (NodeMap::iterator i(node->getMembers().begin());
+        for (NodeMap::const_iterator i(node->getMembers().begin());
              i != node->getMembers().end(); ++i)
         {
             writeNode(components, handle, node, i->first, i->second);
@@ -405,7 +405,7 @@ void writeNode(
     case Node::KIND_LOCALIZED_VALUE:
         {
             writeData(handle, RTL_CONSTASCII_STRINGPARAM("<value"));
-            if (name.getLength() != 0) {
+            if (!name.isEmpty()) {
                 writeData(handle, RTL_CONSTASCII_STRINGPARAM(" xml:lang=\""));
                 writeAttributeValue(handle, name);
                 writeData(handle, RTL_CONSTASCII_STRINGPARAM("\""));
@@ -438,18 +438,21 @@ void writeNode(
     case Node::KIND_SET:
         writeData(handle, RTL_CONSTASCII_STRINGPARAM("<node oor:name=\""));
         writeAttributeValue(handle, name);
-        if (node->getTemplateName().getLength() != 0) { // set member
+        if (!node->getTemplateName().isEmpty()) { // set member
             writeData(
                 handle, RTL_CONSTASCII_STRINGPARAM("\" oor:op=\"replace"));
         }
         writeData(handle, RTL_CONSTASCII_STRINGPARAM("\">"));
-        for (NodeMap::iterator i(node->getMembers().begin());
+        for (NodeMap::const_iterator i(node->getMembers().begin());
              i != node->getMembers().end(); ++i)
         {
             writeNode(components, handle, node, i->first, i->second);
         }
         writeData(handle, RTL_CONSTASCII_STRINGPARAM("</node>"));
         break;
+    case Node::KIND_ROOT:
+        assert(false); // this cannot happen
+        break;
     }
 }
 
@@ -474,7 +477,7 @@ void writeModifications(
             switch (parent->kind()) {
             case Node::KIND_LOCALIZED_PROPERTY:
                 writeData(handle, RTL_CONSTASCII_STRINGPARAM("<value"));
-                if (nodeName.getLength() != 0) {
+                if (!nodeName.isEmpty()) {
                     writeData(
                         handle, RTL_CONSTASCII_STRINGPARAM(" xml:lang=\""));
                     writeAttributeValue(handle, nodeName);
@@ -506,7 +509,7 @@ void writeModifications(
                 break;
             }
         }
-        writeData(handle, RTL_CONSTASCII_STRINGPARAM("</item>"));
+        writeData(handle, RTL_CONSTASCII_STRINGPARAM("</item>\n"));
     } else {
         assert(node.is());
         rtl::OUString pathRep(
@@ -570,10 +573,10 @@ void writeModFile(
     writeData(
         tmp.handle,
         RTL_CONSTASCII_STRINGPARAM(
-            "<?xml version=\"1.0\" encoding=\"UTF-8\"?><oor:items"
+            "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<oor:items"
             " xmlns:oor=\"http://openoffice.org/2001/registry\""
             " xmlns:xs=\"http://www.w3.org/2001/XMLSchema\""
-            " xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\">"));
+            " xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\">\n"));
     //TODO: Do not write back information about those removed items that did not
     // come from the .xcs/.xcu files, anyway (but had been added dynamically
     // instead):
@@ -583,10 +586,11 @@ void writeModFile(
     {
         writeModifications(
             components, tmp.handle, rtl::OUString(), rtl::Reference< Node >(),
-            j->first, Data::findNode(Data::NO_LAYER, data.components, j->first),
+            j->first,
+            Data::findNode(Data::NO_LAYER, data.getComponents(), j->first),
             j->second);
     }
-    writeData(tmp.handle, RTL_CONSTASCII_STRINGPARAM("</oor:items>"));
+    writeData(tmp.handle, RTL_CONSTASCII_STRINGPARAM("</oor:items>\n"));
     oslFileError e = osl_closeFile(tmp.handle);
     tmp.closed = true;
     if (e != osl_File_E_None) {
