@@ -258,7 +258,7 @@ void ORowSetValue::setTypeKind(sal_Int32 _eType)
                 break;
             default:
                 (*this) = makeAny();
-                OSL_FAIL("ORowSetValue:operator==(): UNSPUPPORTED TYPE!");
+                OSL_FAIL("ORowSetValue::setTypeKind(): UNSUPPORTED TYPE!");
         }
     }
 
@@ -895,7 +895,7 @@ bool ORowSetValue::operator==(const ORowSetValue& _rRH) const
             break;
         default:
             bRet = false;
-            OSL_FAIL("ORowSetValue::operator==(): UNSPUPPORTED TYPE!");
+            OSL_FAIL("ORowSetValue::operator==(): UNSUPPORTED TYPE!");
             break;
     }
     return bRet;
@@ -1616,100 +1616,6 @@ double ORowSetValue::getDouble()    const
     }
     return nRet;
 }
-// -------------------------------------------------------------------------
-void ORowSetValue::setFromDouble(const double& _rVal,sal_Int32 _nDatatype)
-{
-    RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "dbtools", "Ocke.Janssen@sun.com", "ORowSetValue::setFromDouble" );
-    free();
-
-    m_bNull = sal_False;
-    switch(_nDatatype)
-    {
-        case DataType::CHAR:
-        case DataType::VARCHAR:
-        case DataType::DECIMAL:
-        case DataType::NUMERIC:
-        case DataType::LONGVARCHAR:
-            {
-                ::rtl::OUString aVal = ::rtl::OUString::valueOf(_rVal);
-                m_aValue.m_pString = aVal.pData;
-                rtl_uString_acquire(m_aValue.m_pString);
-            }
-            break;
-        case DataType::BIGINT:
-            if ( m_bSigned )
-            {
-                m_aValue.m_pValue = new sal_Int64((sal_Int64)_rVal);
-                TRACE_ALLOC( sal_Int64 )
-            }
-            else
-            {
-                ::rtl::OUString aVal = ::rtl::OUString::valueOf(_rVal);
-                m_aValue.m_pString = aVal.pData;
-                rtl_uString_acquire(m_aValue.m_pString);
-            }
-            break;
-        case DataType::FLOAT:
-            m_aValue.m_pValue = new float((float)_rVal);
-            TRACE_ALLOC( float )
-            break;
-        case DataType::DOUBLE:
-        case DataType::REAL:
-            m_aValue.m_pValue = new double(_rVal);
-            TRACE_ALLOC( double )
-            break;
-        case DataType::DATE:
-            m_aValue.m_pValue = new Date(dbtools::DBTypeConversion::toDate(_rVal));
-            TRACE_ALLOC( Date )
-            break;
-        case DataType::TIME:
-            m_aValue.m_pValue = new Time(dbtools::DBTypeConversion::toTime(_rVal));
-            TRACE_ALLOC( Time )
-            break;
-        case DataType::TIMESTAMP:
-            m_aValue.m_pValue = new DateTime(dbtools::DBTypeConversion::toDateTime(_rVal));
-            TRACE_ALLOC( DateTime )
-            break;
-        case DataType::BINARY:
-        case DataType::VARBINARY:
-        case DataType::LONGVARBINARY:
-        case DataType::BLOB:
-        case DataType::CLOB:
-            OSL_ASSERT(!"setFromDouble() for this type is not allowed!");
-            break;
-        case DataType::BIT:
-        case DataType::BOOLEAN:
-            m_aValue.m_bBool = _rVal != 0.0;
-            break;
-        case DataType::TINYINT:
-            if ( m_bSigned )
-                m_aValue.m_nInt8 = sal_Int8(_rVal);
-            else
-                m_aValue.m_nInt16 = sal_Int16(_rVal);
-            break;
-        case DataType::SMALLINT:
-            if ( m_bSigned )
-                m_aValue.m_nInt16 = sal_Int16(_rVal);
-            else
-                m_aValue.m_nInt32 = sal_Int32(_rVal);
-            break;
-        case DataType::INTEGER:
-            if ( m_bSigned )
-                m_aValue.m_nInt32 = sal_Int32(_rVal);
-            else
-            {
-                m_aValue.m_pValue = new sal_Int64((sal_Int64)_rVal);
-                TRACE_ALLOC( sal_Int64 )
-            }
-            break;
-            default:
-                {
-                    m_aValue.m_pValue = new Any(_rVal);
-                    break;
-                }
-    }
-    m_eTypeKind = _nDatatype;
-}
 // -----------------------------------------------------------------------------
 Sequence<sal_Int8>  ORowSetValue::getSequence() const
 {
