@@ -49,7 +49,6 @@
 #include "connectivity/sdbcx/VColumn.hxx"
 #include <rtl/ustrbuf.hxx>
 #include <osl/thread.h>
-#include <tools/config.hxx>
 #include <comphelper/sequence.hxx>
 #include <svl/zforlist.hxx>
 #include <rtl/math.hxx>
@@ -156,7 +155,7 @@ CellContentType lcl_GetContentOrResultType( const Reference<XCell>& xCell )
     CellContentType eCellType = xCell->getType();
     if ( eCellType == CellContentType_FORMULA )
     {
-        static const ::rtl::OUString s_sFormulaResultType(RTL_CONSTASCII_USTRINGPARAM("FormulaResultType"));
+        static const ::rtl::OUString s_sFormulaResultType("FormulaResultType");
         Reference<XPropertySet> xProp( xCell, UNO_QUERY );
         try
         {
@@ -275,7 +274,7 @@ void lcl_GetColumnInfo( const Reference<XSpreadsheet>& xSheet, const Reference<X
             sal_Int16 nNumType = NumberFormat::NUMBER;
             try
             {
-                static ::rtl::OUString s_NumberFormat(RTL_CONSTASCII_USTRINGPARAM("NumberFormat"));
+                static ::rtl::OUString s_NumberFormat("NumberFormat");
                 sal_Int32 nKey = 0;
 
                 if ( xProp->getPropertyValue( s_NumberFormat ) >>= nKey )
@@ -477,7 +476,7 @@ void OCalcTable::fillColumns()
         lcl_GetColumnInfo( m_xSheet, m_xFormats, m_nStartCol + i, m_nStartRow, m_bHasHeaders,
                             aColumnName, eType, bCurrency );
 
-        if ( !aColumnName.getLength() )
+        if ( aColumnName.isEmpty() )
             aColumnName = lcl_GetColumnStr( i );
 
         sal_Int32 nPrecision = 0;   //! ...
@@ -487,24 +486,24 @@ void OCalcTable::fillColumns()
         {
             case DataType::VARCHAR:
                 {
-                    static const ::rtl::OUString s_sType(RTL_CONSTASCII_USTRINGPARAM("VARCHAR"));
+                    static const ::rtl::OUString s_sType("VARCHAR");
                     aTypeName = s_sType;
                 }
                 break;
             case DataType::DECIMAL:
-                aTypeName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("DECIMAL"));
+                aTypeName = ::rtl::OUString("DECIMAL");
                 break;
             case DataType::BIT:
-                aTypeName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("BOOL"));
+                aTypeName = ::rtl::OUString("BOOL");
                 break;
             case DataType::DATE:
-                aTypeName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("DATE"));
+                aTypeName = ::rtl::OUString("DATE");
                 break;
             case DataType::TIME:
-                aTypeName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("TIME"));
+                aTypeName = ::rtl::OUString("TIME");
                 break;
             case DataType::TIMESTAMP:
-                aTypeName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("TIMESTAMP"));
+                aTypeName = ::rtl::OUString("TIMESTAMP");
                 break;
             default:
                 OSL_FAIL("missing type name");
@@ -579,7 +578,7 @@ void OCalcTable::construct()
             Reference<XPropertySet> xDocProp( xDoc, UNO_QUERY );
             if ( xDocProp.is() )
             {
-                Reference<XDatabaseRanges> xRanges(xDocProp->getPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("DatabaseRanges")) ),UNO_QUERY);
+                Reference<XDatabaseRanges> xRanges(xDocProp->getPropertyValue( ::rtl::OUString("DatabaseRanges") ),UNO_QUERY);
 
                 if ( xRanges.is() && xRanges->hasByName( m_Name ) )
                 {
@@ -593,7 +592,7 @@ void OCalcTable::construct()
                         sal_Bool bRangeHeader = sal_True;
                         Reference<XPropertySet> xFiltProp( xDBRange->getFilterDescriptor(), UNO_QUERY );
                         if ( xFiltProp.is() )
-                            xFiltProp->getPropertyValue(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ContainsHeader"))) >>= bRangeHeader;
+                            xFiltProp->getPropertyValue(::rtl::OUString("ContainsHeader")) >>= bRangeHeader;
 
                         Reference<XSheetCellRange> xSheetRange( xRefer->getReferredCells(), UNO_QUERY );
                         Reference<XCellRangeAddressable> xAddr( xSheetRange, UNO_QUERY );
@@ -627,7 +626,7 @@ void OCalcTable::construct()
         if (xProp.is())
         {
             ::com::sun::star::util::Date aDateStruct;
-            if ( xProp->getPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("NullDate")) ) >>= aDateStruct )
+            if ( xProp->getPropertyValue( ::rtl::OUString("NullDate") ) >>= aDateStruct )
                 m_aNullDate = ::Date( aDateStruct.Day, aDateStruct.Month, aDateStruct.Year );
         }
     }
@@ -750,7 +749,7 @@ sal_Bool OCalcTable::seekRow(IResultSetHelper::Movement eCursorPosition, sal_Int
 {
     RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "calc", "Ocke.Janssen@sun.com", "OCalcTable::seekRow" );
     // ----------------------------------------------------------
-    // Positionierung vorbereiten:
+    // prepare positioning:
 
     sal_uInt32 nNumberOfRecords = m_nDataRows;
     sal_uInt32 nTempPos = m_nFilePos;
@@ -809,7 +808,7 @@ Error:
                 m_nFilePos = 0;
             break;
         case IResultSetHelper::BOOKMARK:
-            m_nFilePos = nTempPos;   // vorherige Position
+            m_nFilePos = nTempPos;   // previous position
     }
     //  aStatus.Set(SDB_STAT_NO_DATA_FOUND);
     return sal_False;
