@@ -382,12 +382,7 @@ void OPreparedStatement::setFastPropertyValue_NoBroadcast(sal_Int32 nHandle,cons
             OCommonStatement::setFastPropertyValue_NoBroadcast(nHandle,rValue);
     }
 }
-// -----------------------------------------------------------------------------
-void OPreparedStatement::checkParameterIndex(sal_Int32 _parameterIndex)
-{
-    if( !_parameterIndex || _parameterIndex > m_nNumParams)
-        ::dbtools::throwInvalidIndexException(*this);
-}
+
 // -----------------------------------------------------------------------------
 void OPreparedStatement::checkAndResizeParameters(sal_Int32 parameterIndex)
 {
@@ -413,14 +408,14 @@ ORowSetValue& x)
 }
 
 //------------------------------------------------------------------
-sal_uInt32 OPreparedStatement::AddParameter(OSQLParseNode * pParameter, const Reference<XPropertySet>& _xCol)
+size_t OPreparedStatement::AddParameter(OSQLParseNode * pParameter, const Reference<XPropertySet>& _xCol)
 {
     OSL_UNUSED( pParameter );
-    // Nr. of the new added Parameters
-    sal_uInt32 nParameter = m_xParamColumns->get().size()+1;
+    // Count of the newly added Parameters
+    size_t nParameter = m_xParamColumns->get().size()+1;
 
-    OSL_ENSURE(SQL_ISRULE(pParameter,parameter),"OResultSet::AddParameter: Argument ist kein Parameter");
-    OSL_ENSURE(pParameter->count() > 0,"OResultSet: Fehler im Parse Tree");
+    OSL_ENSURE(SQL_ISRULE(pParameter,parameter),"OResultSet::AddParameter: Argument is not a Parameter");
+    OSL_ENSURE(pParameter->count() > 0,"OResultSet: error in parse tree");
 #if OSL_DEBUG_LEVEL > 0
     OSQLParseNode * pMark = pParameter->getChild(0);
     OSL_UNUSED( pMark );
@@ -470,7 +465,7 @@ _pParameter,OSQLParseNode* _pNode,const OSQLTable& _xTable)
     {
         ::rtl::OUString sColumnName,sTableRange;
         m_pSQLIterator->getColumnRange(_pNode,sColumnName,sTableRange);
-        if(sColumnName.getLength())
+        if(!sColumnName.isEmpty())
         {
             Reference<XNameAccess> xNameAccess = _xTable->getColumns();
             if(xNameAccess->hasByName(sColumnName))
@@ -486,7 +481,7 @@ void OPreparedStatement::describeParameter()
 {
     ::std::vector< OSQLParseNode*> aParseNodes;
     scanParameter(m_pParseTree,aParseNodes);
-    if(aParseNodes.size())
+    if(!aParseNodes.empty())
     {
         m_xParamColumns = new OSQLColumns();
         const OSQLTables& xTabs = m_pSQLIterator->getTables();
@@ -506,13 +501,13 @@ aParseNodes.begin();
 // -----------------------------------------------------------------------------
 void OPreparedStatement::scanParameter(OSQLParseNode* pParseNode,::std::vector< OSQLParseNode*>& _rParaNodes)
 {
-    OSL_ENSURE(pParseNode != NULL,"OResultSet: interner Fehler: ungueltiger ParseNode");
+    OSL_ENSURE(pParseNode != NULL,"OResultSet: internal error: invalid ParseNode");
 
     // Parameter Name-Row found?
     if (SQL_ISRULE(pParseNode,parameter))
     {
-        OSL_ENSURE(pParseNode->count() >= 1,"OResultSet: Parse Tree fehlerhaft");
-        OSL_ENSURE(pParseNode->getChild(0)->getNodeType() == SQL_NODE_PUNCTUATION,"OResultSet: Parse Tree fehlerhaft");
+        OSL_ENSURE(pParseNode->count() >= 1,"OResultSet: Faulty Parse Tree");
+        OSL_ENSURE(pParseNode->getChild(0)->getNodeType() == SQL_NODE_PUNCTUATION,"OResultSet: Faulty Parse Tree");
 
         _rParaNodes.push_back(pParseNode);
         // further search isn't necessary
