@@ -46,12 +46,9 @@
 #include <vcl/svapp.hxx>
 #include <vcl/outdev.hxx>
 #include <vcl/virdev.hxx>
-#include <vcl/virdev.hxx>
 #include <vcl/gdimtf.hxx>
 #include <vcl/gradient.hxx>
 
-#include <canvas/canvastools.hxx>
-
 #include <basegfx/range/b2drange.hxx>
 #include <basegfx/point/b2dpoint.hxx>
 #include <basegfx/vector/b2dsize.hxx>
@@ -81,34 +78,6 @@ namespace cppcanvas
             class TransparencyGroupAction : public Action, private ::boost::noncopyable
             {
             public:
-                /** Create new transparency group action.
-
-                    @param rGroupMtf
-                    Metafile that groups all actions to be rendered
-                    transparent
-
-                    @param rParms
-                    Render parameters
-
-                    @param rDstPoint
-                    Left, top edge of destination, in current state
-                    coordinate system
-
-                    @param rDstSize
-                    Size of the transparency group object, in current
-                    state coordinate system.
-
-                    @param nAlpha
-                    Alpha value, must be in the range [0,1]
-                */
-                TransparencyGroupAction( MtfAutoPtr&                    rGroupMtf,
-                                         const Renderer::Parameters&    rParms,
-                                         const ::basegfx::B2DPoint&     rDstPoint,
-                                         const ::basegfx::B2DVector&    rDstSize,
-                                         double                         nAlpha,
-                                         const CanvasSharedPtr&         rCanvas,
-                                         const OutDevState&             rState );
-
                 /** Create new transparency group action.
 
                     @param rGroupMtf
@@ -139,8 +108,8 @@ namespace cppcanvas
                                          const OutDevState&             rState );
 
                 virtual bool render( const ::basegfx::B2DHomMatrix& rTransformation ) const;
-                virtual bool render( const ::basegfx::B2DHomMatrix& rTransformation,
-                                     const Subset&                  rSubset ) const;
+                virtual bool renderSubset( const ::basegfx::B2DHomMatrix& rTransformation,
+                                           const Subset&                  rSubset ) const;
 
                 virtual ::basegfx::B2DRange getBounds( const ::basegfx::B2DHomMatrix& rTransformation ) const;
                 virtual ::basegfx::B2DRange getBounds( const ::basegfx::B2DHomMatrix&   rTransformation,
@@ -183,40 +152,6 @@ namespace cppcanvas
                                                       aLocalTransformation );
             }
 
-            SAL_WNODEPRECATED_DECLARATIONS_PUSH
-            TransparencyGroupAction::TransparencyGroupAction( MtfAutoPtr&                   rGroupMtf,
-                                                              const Renderer::Parameters&   rParms,
-                                                              const ::basegfx::B2DPoint&    rDstPoint,
-                                                              const ::basegfx::B2DVector&   rDstSize,
-                                                              double                        nAlpha,
-                                                              const CanvasSharedPtr&        rCanvas,
-                                                              const OutDevState&            rState ) :
-                mpGroupMtf( rGroupMtf ),
-                mpAlphaGradient(),
-                maParms( rParms ),
-                maDstSize( rDstSize ),
-                mxBufferBitmap(),
-                maLastTransformation(),
-                mpCanvas( rCanvas ),
-                maState(),
-                mnAlpha( nAlpha )
-            {
-                tools::initRenderState(maState,rState);
-                implSetupTransform( maState, rDstPoint );
-
-                // correct clip (which is relative to original transform)
-                tools::modifyClip( maState,
-                                   rState,
-                                   rCanvas,
-                                   rDstPoint,
-                                   NULL,
-                                   NULL );
-
-                maLastSubset.mnSubsetBegin = 0;
-                maLastSubset.mnSubsetEnd = -1;
-            }
-            SAL_WNODEPRECATED_DECLARATIONS_POP
-
             SAL_WNODEPRECATED_DECLARATIONS_PUSH
             TransparencyGroupAction::TransparencyGroupAction( MtfAutoPtr&                   rGroupMtf,
                                                               GradientAutoPtr&              rAlphaGradient,
@@ -258,10 +193,10 @@ namespace cppcanvas
             // into the direction of having a direct GDIMetaFile2XCanvas
             // renderer, and maybe a separate metafile XCanvas
             // implementation.
-            bool TransparencyGroupAction::render( const ::basegfx::B2DHomMatrix&    rTransformation,
-                                                  const Subset&                     rSubset ) const
+            bool TransparencyGroupAction::renderSubset( const ::basegfx::B2DHomMatrix&    rTransformation,
+                                                        const Subset&                     rSubset ) const
             {
-                RTL_LOGFILE_CONTEXT( aLog, "::cppcanvas::internal::TransparencyGroupAction::render()" );
+                RTL_LOGFILE_CONTEXT( aLog, "::cppcanvas::internal::TransparencyGroupAction::renderSubset()" );
                 RTL_LOGFILE_CONTEXT_TRACE1( aLog, "::cppcanvas::internal::TransparencyGroupAction: 0x%X", this );
 
                 // determine overall transformation matrix (render, view,
@@ -279,6 +214,22 @@ namespace cppcanvas
                 aTotalTransform.set( 0, 2, 0.0 );
                 aTotalTransform.set( 1, 2, 0.0 );
 
+                // determine total scaling factor of the
+                // transformation matrix - need to make the bitmap
+                // large enough
+                ::basegfx::B2DTuple aScale;
+                ::basegfx::B2DTuple aTranslate;
+                double              nRotate;
+                double              nShearX;
+                if( !aTotalTransform.decompose( aScale,
+                                                aTranslate,
+                                                nRotate,
+                                                nShearX ) )
+                {
+                    OSL_FAIL( "TransparencyGroupAction::renderSubset(): non-decomposable transformation" );
+                    return false;
+                }
+
                 // if there's no buffer bitmap, or as soon as the
                 // total transformation changes, we've got to
                 // re-render the bitmap
@@ -289,22 +240,6 @@ namespace cppcanvas
                 {
                     DBG_TESTSOLARMUTEX();
 
-                    // determine total scaling factor of the
-                    // transformation matrix - need to make the bitmap
-                    // large enough
-                    ::basegfx::B2DTuple aScale;
-                    ::basegfx::B2DTuple aTranslate;
-                    double              nRotate;
-                    double              nShearX;
-                    if( !aTotalTransform.decompose( aScale,
-                                                    aTranslate,
-                                                    nRotate,
-                                                    nShearX ) )
-                    {
-                        OSL_FAIL( "TransparencyGroupAction::render(): non-decomposable transformation" );
-                        return false;
-                    }
-
                     // output size of metafile
                     ::Size aOutputSizePixel( ::basegfx::fround( aScale.getX() * maDstSize.getX() ),
                                              ::basegfx::fround( aScale.getY() * maDstSize.getY() ) );
@@ -452,12 +387,8 @@ namespace cppcanvas
                 // Translation*Rotation*Shear*Scale. Thus, to neutralize
                 // the contained scaling, we've got to right-multiply with
                 // the inverse.
-                ::basegfx::B2ISize aBmpSize(
-                    ::basegfx::unotools::b2ISizeFromIntegerSize2D( mxBufferBitmap->getSize() ) );
-
                 ::basegfx::B2DHomMatrix aScaleCorrection;
-                aScaleCorrection.scale( (double)maDstSize.getX() / aBmpSize.getX(),
-                                        (double)maDstSize.getY() / aBmpSize.getY() );
+                aScaleCorrection.scale( 1/aScale.getX(), 1/aScale.getY() );
                 aTransform = aTransform * aScaleCorrection;
 
                 rendering::RenderState aLocalState( maState );
@@ -516,7 +447,7 @@ namespace cppcanvas
                 aSubset.mnSubsetBegin = 0;
                 aSubset.mnSubsetEnd   = -1;
 
-                return render( rTransformation, aSubset );
+                return renderSubset( rTransformation, aSubset );
             }
 
             ::basegfx::B2DRange TransparencyGroupAction::getBounds( const ::basegfx::B2DHomMatrix&  rTransformation ) const
@@ -556,25 +487,6 @@ namespace cppcanvas
 
         }
 
-        SAL_WNODEPRECATED_DECLARATIONS_PUSH
-        ActionSharedPtr TransparencyGroupActionFactory::createTransparencyGroupAction( MtfAutoPtr&                  rGroupMtf,
-                                                                                       const Renderer::Parameters&  rParms,
-                                                                                       const ::basegfx::B2DPoint&   rDstPoint,
-                                                                                       const ::basegfx::B2DVector&  rDstSize,
-                                                                                       double                       nAlpha,
-                                                                                       const CanvasSharedPtr&       rCanvas,
-                                                                                       const OutDevState&           rState )
-        {
-            return ActionSharedPtr( new TransparencyGroupAction(rGroupMtf,
-                                                                rParms,
-                                                                rDstPoint,
-                                                                rDstSize,
-                                                                nAlpha,
-                                                                rCanvas,
-                                                                rState ) );
-        }
-        SAL_WNODEPRECATED_DECLARATIONS_POP
-
         SAL_WNODEPRECATED_DECLARATIONS_PUSH
         ActionSharedPtr TransparencyGroupActionFactory::createTransparencyGroupAction( MtfAutoPtr&                  rGroupMtf,
                                                                                        GradientAutoPtr&             rAlphaGradient,
