@@ -130,9 +130,10 @@ struct ImplementationInfo: private boost::noncopyable {
         rtl::OUString const & theName, rtl::OUString const & theLoader,
         rtl::OUString const & theUri, rtl::OUString const & thePrefix,
         css::uno::Reference< css::uno::XComponentContext > const &
-            theAlienContext):
+            theAlienContext,
+        rtl::OUString const & theRdbFile):
         name(theName), loader(theLoader), uri(theUri), prefix(thePrefix),
-        alienContext(theAlienContext)
+        alienContext(theAlienContext), rdbFile(theRdbFile)
     {}
 
     explicit ImplementationInfo(rtl::OUString const & theName): name(theName) {}
@@ -142,6 +143,7 @@ struct ImplementationInfo: private boost::noncopyable {
     rtl::OUString const uri;
     rtl::OUString const prefix;
     css::uno::Reference< css::uno::XComponentContext > const alienContext;
+    rtl::OUString const rdbFile;
     std::vector< rtl::OUString > services;
     std::vector< rtl::OUString > singletons;
 };
@@ -149,12 +151,12 @@ struct ImplementationInfo: private boost::noncopyable {
 struct Implementation: private boost::noncopyable {
     Implementation(
         rtl::OUString const & name, rtl::OUString const & loader,
-        rtl::OUString const & uri,
-        rtl::OUString const & prefix = rtl::OUString(),
-        css::uno::Reference< css::uno::XComponentContext > const &
-            alienContext
-                = css::uno::Reference< css::uno::XComponentContext >()):
-        info(new ImplementationInfo(name, loader, uri, prefix, alienContext)),
+        rtl::OUString const & uri, rtl::OUString const & prefix,
+        css::uno::Reference< css::uno::XComponentContext > const & alienContext,
+        rtl::OUString const & rdbFile):
+        info(
+            new ImplementationInfo(
+                name, loader, uri, prefix, alienContext, rdbFile)),
         loaded(false)
     {}
 
@@ -466,7 +468,7 @@ void Parser::handleImplementation() {
     implementation_.reset(
         new Implementation(
             attrImplementation_, attrLoader_, attrUri_, attrPrefix_,
-            alienContext_));
+            alienContext_, reader_.getUrl()));
     if (!data_->namedImplementations.insert(
             NamedImplementations::value_type(
                 attrImplementation_, implementation_)).
@@ -611,6 +613,7 @@ public:
     Data const & getData() const { return data_; }
 
     void loadImplementation(
+        css::uno::Reference< css::uno::XComponentContext > const & context,
         boost::shared_ptr< ImplementationInfo > const & info,
         css::uno::Reference< css::lang::XSingleComponentFactory > * factory1,
         css::uno::Reference< css::lang::XSingleServiceFactory > * factory2);
@@ -784,6 +787,7 @@ private:
     void removeImplementation(rtl::OUString name);
 
     boost::shared_ptr< Implementation > findServiceImplementation(
+        css::uno::Reference< css::uno::XComponentContext > const & context,
         rtl::OUString const & specifier);
 
     css::uno::Reference< css::uno::XComponentContext > context_;
@@ -834,7 +838,8 @@ private:
     virtual css::uno::Sequence< rtl::OUString > SAL_CALL
     getSupportedServiceNames() throw (css::uno::RuntimeException);
 
-    void loadImplementation();
+    void loadImplementation(
+        css::uno::Reference< css::uno::XComponentContext > const & context);
 
     rtl::Reference< ServiceManager > manager_;
     boost::shared_ptr< ImplementationInfo > info_;
@@ -846,6 +851,7 @@ private:
 };
 
 void ServiceManager::loadImplementation(
+        css::uno::Reference< css::uno::XComponentContext > const & context,
         boost::shared_ptr< ImplementationInfo > const & info,
         css::uno::Reference< css::lang::XSingleComponentFactory > * factory1,
         css::uno::Reference< css::lang::XSingleServiceFactory > * factory2)
@@ -887,8 +893,8 @@ void ServiceManager::loadImplementation(
             smgr = css::uno::Reference< css::lang::XMultiComponentFactory >(
                 ctxt->getServiceManager(), css::uno::UNO_SET_THROW);
         } else {
-            assert(context_.is());
-            ctxt = context_;
+            assert(context.is());
+            ctxt = context;
             smgr = this;
         }
         css::uno::Reference< css::loader::XImplementationLoader > loader(
@@ -982,7 +988,7 @@ ServiceManager::createInstanceWithContext(
     throw (css::uno::Exception, css::uno::RuntimeException)
 {
     boost::shared_ptr< Implementation > impl(
-        findServiceImplementation(aServiceSpecifier));
+        findServiceImplementation(Context, aServiceSpecifier));
     if (impl.get() == 0) {
         return css::uno::Reference< css::uno::XInterface >();
     }
@@ -1005,7 +1011,7 @@ ServiceManager::createInstanceWithArgumentsAndContext(
     throw (css::uno::Exception, css::uno::RuntimeException)
 {
     boost::shared_ptr< Implementation > impl(
-        findServiceImplementation(ServiceSpecifier));
+        findServiceImplementation(Context, ServiceSpecifier));
     if (impl.get() == 0) {
         return css::uno::Reference< css::uno::XInterface >();
     }
@@ -1342,7 +1348,7 @@ void ServiceManager::disposing(css::lang::EventObject const & Source)
 
 void ServiceManager::disposing() {
     std::vector< css::uno::Reference< css::lang::XComponent > > comps;
-    css::uno::Reference< css::lang::XEventListener > listener;
+    Data clear;
     {
         osl::MutexGuard g(rBHelper.rMutex);
         for (DynamicImplementations::const_iterator i(
@@ -1354,10 +1360,10 @@ void ServiceManager::disposing() {
                 comps.push_back(i->second->component);
             }
         }
-        data_.namedImplementations.clear();
-        data_.dynamicImplementations.clear();
-        data_.services.clear();
-        data_.singletons.clear();
+        data_.namedImplementations.swap(clear.namedImplementations);
+        data_.dynamicImplementations.swap(clear.dynamicImplementations);
+        data_.services.swap(clear.services);
+        data_.singletons.swap(clear.singletons);
     }
     for (std::vector<
              css::uno::Reference< css::lang::XComponent > >::const_iterator i(
@@ -1498,7 +1504,9 @@ bool ServiceManager::readLegacyRdbFile(rtl::OUString const & uri) {
         boost::shared_ptr< Implementation > impl(
             new Implementation(
                 name, readLegacyRdbString(uri, implKey, "UNO/ACTIVATOR"),
-                readLegacyRdbString(uri, implKey, "UNO/LOCATION")));
+                readLegacyRdbString(uri, implKey, "UNO/LOCATION"),
+                rtl::OUString(),
+                css::uno::Reference< css::uno::XComponentContext >(), uri));
         if (!data_.namedImplementations.insert(
                 NamedImplementations::value_type(name, impl)).
             second)
@@ -1729,25 +1737,30 @@ void ServiceManager::removeRdbFiles(std::vector< rtl::OUString > const & uris) {
     // The underlying data structures make this function somewhat inefficient,
     // but the assumption is that it is rarely called (and that if it is called,
     // it is called with a uris vector of size one):
-    osl::MutexGuard g(rBHelper.rMutex);
-    for (std::vector< rtl::OUString >::const_iterator i(uris.begin());
-         i != uris.end(); ++i)
+    std::vector< boost::shared_ptr< Implementation > > clear;
     {
-        for (NamedImplementations::iterator j(
-                 data_.namedImplementations.begin());
-             j != data_.namedImplementations.end();)
+        osl::MutexGuard g(rBHelper.rMutex);
+        for (std::vector< rtl::OUString >::const_iterator i(uris.begin());
+             i != uris.end(); ++i)
         {
-            assert(j->second.get() != 0);
-            if (j->second->info->uri == *i) {
-                //TODO: The below leaves data_ in an inconsistent state upon
-                // exceptions:
-                removeFromImplementationMap(
-                    &data_.services, j->second->info->services, j->second);
-                removeFromImplementationMap(
-                    &data_.singletons, j->second->info->singletons, j->second);
-                data_.namedImplementations.erase(j++);
-            } else {
-                ++j;
+            for (NamedImplementations::iterator j(
+                     data_.namedImplementations.begin());
+                 j != data_.namedImplementations.end();)
+            {
+                assert(j->second.get() != 0);
+                if (j->second->info->rdbFile == *i) {
+                    clear.push_back(j->second);
+                    //TODO: The below leaves data_ in an inconsistent state upon
+                    // exceptions:
+                    removeFromImplementationMap(
+                        &data_.services, j->second->info->services, j->second);
+                    removeFromImplementationMap(
+                        &data_.singletons, j->second->info->singletons,
+                        j->second);
+                    data_.namedImplementations.erase(j++);
+                } else {
+                    ++j;
+                }
             }
         }
     }
@@ -1759,6 +1772,7 @@ bool ServiceManager::removeLegacyFactory(
     bool removeListener)
 {
     assert(factoryInfo.is());
+    boost::shared_ptr< Implementation > clear;
     css::uno::Reference< css::lang::XComponent > comp;
     {
         osl::MutexGuard g(rBHelper.rMutex);
@@ -1768,6 +1782,7 @@ bool ServiceManager::removeLegacyFactory(
             return isDisposed();
         }
         assert(i->second.get() != 0);
+        clear = i->second;
         //TODO: The below leaves data_ in an inconsistent state upon exceptions:
         removeFromImplementationMap(
             &data_.services, i->second->info->services, i->second);
@@ -1790,35 +1805,40 @@ bool ServiceManager::removeLegacyFactory(
 void ServiceManager::removeImplementation(rtl::OUString name) {
     // The underlying data structures make this function somewhat inefficient,
     // but the assumption is that it is rarely called:
-    osl::MutexGuard g(rBHelper.rMutex);
-    if (isDisposed()) {
-        return;
-    }
-    NamedImplementations::iterator i(data_.namedImplementations.find(name));
-    if (i == data_.namedImplementations.end()) {
-        throw css::container::NoSuchElementException(
-            "Remove non-inserted implementation " + name,
-            static_cast< cppu::OWeakObject * >(this));
-    }
-    assert(i->second.get() != 0);
-    //TODO: The below leaves data_ in an inconsistent state upon exceptions:
-    removeFromImplementationMap(
-        &data_.services, i->second->info->services, i->second);
-    removeFromImplementationMap(
-        &data_.singletons, i->second->info->singletons, i->second);
-    for (DynamicImplementations::iterator j(
-             data_.dynamicImplementations.begin());
-         j != data_.dynamicImplementations.end(); ++j)
+    boost::shared_ptr< Implementation > clear;
     {
-        if (j->second == i->second) {
-            data_.dynamicImplementations.erase(j);
-            break;
+        osl::MutexGuard g(rBHelper.rMutex);
+        if (isDisposed()) {
+            return;
         }
+        NamedImplementations::iterator i(data_.namedImplementations.find(name));
+        if (i == data_.namedImplementations.end()) {
+            throw css::container::NoSuchElementException(
+                "Remove non-inserted implementation " + name,
+                static_cast< cppu::OWeakObject * >(this));
+        }
+        assert(i->second.get() != 0);
+        clear = i->second;
+        //TODO: The below leaves data_ in an inconsistent state upon exceptions:
+        removeFromImplementationMap(
+            &data_.services, i->second->info->services, i->second);
+        removeFromImplementationMap(
+            &data_.singletons, i->second->info->singletons, i->second);
+        for (DynamicImplementations::iterator j(
+                 data_.dynamicImplementations.begin());
+             j != data_.dynamicImplementations.end(); ++j)
+        {
+            if (j->second == i->second) {
+                data_.dynamicImplementations.erase(j);
+                break;
+            }
+        }
+        data_.namedImplementations.erase(i);
     }
-    data_.namedImplementations.erase(i);
 }
 
 boost::shared_ptr< Implementation > ServiceManager::findServiceImplementation(
+    css::uno::Reference< css::uno::XComponentContext > const & context,
     rtl::OUString const & specifier)
 {
     boost::shared_ptr< Implementation > impl;
@@ -1851,7 +1871,7 @@ boost::shared_ptr< Implementation > ServiceManager::findServiceImplementation(
     if (!loaded) {
         css::uno::Reference< css::lang::XSingleComponentFactory > f1;
         css::uno::Reference< css::lang::XSingleServiceFactory > f2;
-        loadImplementation(impl->info, &f1, &f2);
+        loadImplementation(context, impl->info, &f1, &f2);
         osl::MutexGuard g(rBHelper.rMutex);
         if (!(isDisposed() || impl->loaded)) {
             impl->loaded = true;
@@ -1867,7 +1887,7 @@ FactoryWrapper::createInstanceWithContext(
     css::uno::Reference< css::uno::XComponentContext > const & Context)
     throw (css::uno::Exception, css::uno::RuntimeException)
 {
-    loadImplementation();
+    loadImplementation(Context);
     return factory1_.is()
         ? factory1_->createInstanceWithContext(Context)
         : factory2_->createInstance();
@@ -1879,7 +1899,7 @@ FactoryWrapper::createInstanceWithArgumentsAndContext(
     css::uno::Reference< css::uno::XComponentContext > const & Context)
     throw (css::uno::Exception, css::uno::RuntimeException)
 {
-    loadImplementation();
+    loadImplementation(Context);
     return factory1_.is()
         ? factory1_->createInstanceWithArgumentsAndContext(Arguments, Context)
         : factory2_->createInstanceWithArguments(Arguments);
@@ -1888,7 +1908,7 @@ FactoryWrapper::createInstanceWithArgumentsAndContext(
 css::uno::Reference< css::uno::XInterface > FactoryWrapper::createInstance()
     throw (css::uno::Exception, css::uno::RuntimeException)
 {
-    loadImplementation();
+    loadImplementation(manager_->getContext());
     return factory1_.is()
         ? factory1_->createInstanceWithContext(manager_->getContext())
         : factory2_->createInstance();
@@ -1899,7 +1919,7 @@ FactoryWrapper::createInstanceWithArguments(
     css::uno::Sequence< css::uno::Any > const & Arguments)
     throw (css::uno::Exception, css::uno::RuntimeException)
 {
-    loadImplementation();
+    loadImplementation(manager_->getContext());
     return factory1_.is()
         ? factory1_->createInstanceWithArgumentsAndContext(
             Arguments, manager_->getContext())
@@ -1944,7 +1964,9 @@ css::uno::Sequence< rtl::OUString > FactoryWrapper::getSupportedServiceNames()
     return names;
 }
 
-void FactoryWrapper::loadImplementation() {
+void FactoryWrapper::loadImplementation(
+    css::uno::Reference< css::uno::XComponentContext > const & context)
+{
     {
         osl::MutexGuard g(mutex_);
         if (loaded_) {
@@ -1956,7 +1978,7 @@ void FactoryWrapper::loadImplementation() {
     //TODO: There is a race here, as the relevant service factory can already
     // have been removed and loading can thus fail, as the entity from which to
     // load can disappear once the service factory is removed:
-    manager_->loadImplementation(info_, &f1, &f2);
+    manager_->loadImplementation(context, info_, &f1, &f2);
     if (!(f1.is() || f2.is())) {
         throw css::uno::DeploymentException(
             "Implementation " + info_->name + " does not provide a factory",
