@@ -119,7 +119,7 @@ uno::Any DatabaseDataProvider::queryInterface(uno::Type const & type) throw (uno
 //------------------------------------------------------------------------------
 rtl::OUString DatabaseDataProvider::getImplementationName_Static(  ) throw(uno::RuntimeException)
 {
-    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.chart2.data.DatabaseDataProvider"));
+    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.dbaccess.DatabaseDataProvider"));
 }
 // -----------------------------------------------------------------------------
 // -------------------------------------------------------------------------
@@ -177,21 +177,21 @@ void SAL_CALL DatabaseDataProvider::initialize(const uno::Sequence< uno::Any > &
     const beans::PropertyValue* pArgEnd  = pArgIter + _aArguments.getLength();
     for(;pArgIter != pArgEnd;++pArgIter)
     {
-        if ( pArgIter->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("DataRowSource")) )
+        if ( pArgIter->Name == "DataRowSource" )
         {
             ::com::sun::star::chart::ChartDataRowSource eRowSource = ::com::sun::star::chart::ChartDataRowSource_COLUMNS;
             pArgIter->Value >>= eRowSource;
             if ( eRowSource != ::com::sun::star::chart::ChartDataRowSource_COLUMNS )
                 return sal_False;
         }
-        else if ( pArgIter->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("CellRangeRepresentation")) )
+        else if ( pArgIter->Name == "CellRangeRepresentation" )
         {
             ::rtl::OUString sRange;
             pArgIter->Value >>= sRange;
             if ( !sRange.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("all")) )
                 return sal_False;
         }
-        else if ( pArgIter->Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("FirstCellAsLabel")) )
+        else if ( pArgIter->Name == "FirstCellAsLabel" )
         {
             sal_Bool bFirstCellAsLabel = sal_True;
             pArgIter->Value >>= bFirstCellAsLabel;
@@ -227,7 +227,7 @@ uno::Reference< chart2::data::XDataSource > SAL_CALL DatabaseDataProvider::creat
             aArgs.getOrDefault( "ColumnDescriptions", uno::Sequence< ::rtl::OUString >() );
 
         bool bRet = false;
-        if ( m_Command.getLength() != 0 && m_xActiveConnection.is() )
+        if ( !m_Command.isEmpty() && m_xActiveConnection.is() )
         {
             try
             {
@@ -278,7 +278,7 @@ uno::Sequence< beans::PropertyValue > SAL_CALL DatabaseDataProvider::detectArgum
                 ::rtl::OUString aRole;
                 if  (   xSeqProp.is()
                     &&  ( xSeqProp->getPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Role" ) ) ) >>= aRole )
-                    &&  aRole.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "categories" ) )
+                    &&  aRole == "categories"
                     )
                 {
                     bHasCategories = sal_True;
@@ -308,7 +308,7 @@ uno::Any DatabaseDataProvider::impl_getNumberFormatKey_nothrow(const ::rtl::OUSt
 uno::Reference< chart2::data::XDataSequence > SAL_CALL DatabaseDataProvider::createDataSequenceByRangeRepresentation(const ::rtl::OUString & _sRangeRepresentation) throw (uno::RuntimeException, lang::IllegalArgumentException)
 {
     osl::MutexGuard g(m_aMutex);
-    uno::Reference< chart2::data::XDataSequence > xData = m_xInternal->createDataSequenceByRangeRepresentation(_sRangeRepresentation);;
+    uno::Reference< chart2::data::XDataSequence > xData = m_xInternal->createDataSequenceByRangeRepresentation(_sRangeRepresentation);
     uno::Reference<beans::XPropertySet> xProp(xData,uno::UNO_QUERY);
     const static ::rtl::OUString s_sNumberFormatKey(RTL_CONSTASCII_USTRINGPARAM("NumberFormatKey"));
     if ( xProp.is() && xProp->getPropertySetInfo()->hasPropertyByName(s_sNumberFormatKey) )
@@ -713,7 +713,7 @@ void DatabaseDataProvider::impl_fillInternalDataProvider_throw(sal_Bool _bHasCat
         sal_Int32 nLastNonEmptyColName = aImposedColumnNames.getLength() - 1;
         for ( ; nLastNonEmptyColName >= 0; --nLastNonEmptyColName )
         {
-            if ( aImposedColumnNames[ nLastNonEmptyColName ].getLength() != 0 )
+            if ( !aImposedColumnNames[ nLastNonEmptyColName ].isEmpty() )
                 break;
         }
         aImposedColumnNames.realloc( nLastNonEmptyColName + 1 );
@@ -722,7 +722,7 @@ void DatabaseDataProvider::impl_fillInternalDataProvider_throw(sal_Bool _bHasCat
         // column. This, this results in a ColumnDescriptions array like <"", "col2", "col3">, where you'd expect
         // <"col1", "col2", "col3">.
         // Fix this with some heuristics:
-        if ( ( aImposedColumnNames.getLength() > 0 ) && ( aImposedColumnNames[0].getLength() == 0 ) )
+        if ( ( aImposedColumnNames.getLength() > 0 ) && ( !aImposedColumnNames[0].isEmpty() ) )
         {
             const sal_Int32 nAssumedRowSetColumnIndex = _bHasCategories ? 1 : 0;
             if ( nAssumedRowSetColumnIndex < aRowSetColumnNames.getLength() )
@@ -828,7 +828,7 @@ void DatabaseDataProvider::impl_fillInternalDataProvider_throw(sal_Bool _bHasCat
         {
             aRowLabels.push_back(::rtl::OUString::valueOf(h+1));
             ::std::vector< double > aRow;
-            const sal_Int32 nSize = SAL_N_ELEMENTS(fDefaultData);
+            const sal_Int32 nSize = sizeof(fDefaultData)/sizeof(fDefaultData[0]);
             for (size_t j = 0; j < (aColumns.size()-1); ++j,++k)
             {
                 if ( k >= nSize )
