@@ -72,8 +72,6 @@ public:
     HelpButton          m_aPB_HELP;
     String              m_aQryLabel;
     String              m_sTblLabel;
-    rtl::OUString       m_sCatalog;
-    rtl::OUString       m_sSchema;
     String              m_aName;
     const IObjectNameCheck&
                         m_rObjectNameCheck;
@@ -271,7 +269,7 @@ OSaveAsDlg::OSaveAsDlg( Window * pParent,
                     if ( nPos != COMBOBOX_ENTRY_NOTFOUND )
                         m_pImpl->m_aCatalog.SelectEntryPos(nPos);
 
-                    if ( sSchema.getLength() )
+                    if ( !sSchema.isEmpty() )
                     {
                         nPos = m_pImpl->m_aSchema.GetEntryPos(String(sSchema));
                         if ( nPos != COMBOBOX_ENTRY_NOTFOUND )
