@@ -41,7 +41,10 @@
 #include "uno/current_context.hxx"
 #include "unotools/pathoptions.hxx"
 
+#if !defined(ANDROID) && !defined(IOS)
 #include <l10ntools/compilehelp.hxx>
+#include <l10ntools/HelpIndexer.hxx>
+#endif
 #include <com/sun/star/ucb/XSimpleFileAccess.hpp>
 #include <com/sun/star/util/XMacroExpander.hpp>
 #include <com/sun/star/uri/XUriReferenceFactory.hpp>
@@ -60,29 +63,6 @@ namespace backend {
 namespace help {
 namespace {
 
-// A current context that filters out java-vm.interaction-handler:
-class NonJavaCurrentContext: public cppu::WeakImplHelper1< XCurrentContext > {
-public:
-    NonJavaCurrentContext(Reference< XCurrentContext > const & parent):
-        parent_(parent) {}
-
-    virtual Any SAL_CALL getValueByName(rtl::OUString const & Name)
-        throw (RuntimeException);
-
-private:
-    Reference< XCurrentContext > parent_;
-};
-
-Any NonJavaCurrentContext::getValueByName(rtl::OUString const & Name)
-    throw (RuntimeException)
-{
-    return
-        (Name.equalsAsciiL(
-            RTL_CONSTASCII_STRINGPARAM(JAVA_INTERACTION_HANDLER_NAME))
-         || !parent_.is())
-        ? Any() : parent_->getValueByName(Name);
-}
-
 //==============================================================================
 class BackendImpl : public ::dp_registry::backend::PackageRegistryBackend
 {
@@ -208,7 +188,7 @@ Reference<deployment::XPackage> BackendImpl::bindPackage_(
     Reference<XCommandEnvironment> const & xCmdEnv )
 {
     // we don't support auto detection:
-    if (mediaType_.getLength() == 0)
+    if (mediaType_.isEmpty())
         throw lang::IllegalArgumentException(
             StrCannotDetectMediaType::get() + url,
             static_cast<OWeakObject *>(this), static_cast<sal_Int16>(-1) );
@@ -223,8 +203,7 @@ Reference<deployment::XPackage> BackendImpl::bindPackage_(
             if (!bRemoved)
             {
                 ::ucbhelper::Content ucbContent( url, xCmdEnv );
-                name = ucbContent.getPropertyValue(
-                    StrTitle::get() ).get<OUString>();
+                name = StrTitle::getTitle( ucbContent );
             }
 
             if (subType.EqualsIgnoreCaseAscii(
@@ -404,9 +383,6 @@ beans::Optional< OUString > BackendImpl::PackageImpl::getRegistrationDataURL()
     return beans::Optional<OUString>(true, OUString());
 }
 
-static rtl::OUString aSlash(RTL_CONSTASCII_USTRINGPARAM("/"));
-static rtl::OUString aHelpStr(RTL_CONSTASCII_USTRINGPARAM("help"));
-
 void BackendImpl::implProcessHelp(
     PackageImpl * package, bool doRegisterPackage,
     Reference<ucb::XCommandEnvironment> const & xCmdEnv)
@@ -422,6 +398,7 @@ void BackendImpl::implProcessHelp(
             data.dataUrl = xPackage->getURL();
             if (!package->extensionContainsCompiledHelp())
             {
+#if !defined(ANDROID) && !defined(IOS)
                 const OUString sHelpFolder = createFolder(OUString(), xCmdEnv);
                 data.dataUrl = sHelpFolder;
 
@@ -432,34 +409,12 @@ void BackendImpl::implProcessHelp(
                 if( !xSFA->isFolder( aExpandedHelpURL ) )
                 {
                     rtl::OUString aErrStr = getResourceString( RID_STR_HELPPROCESSING_GENERAL_ERROR );
-                    aErrStr += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "No help folder" ));
+                    aErrStr += rtl::OUString("No help folder" );
                     OWeakObject* oWeakThis = static_cast<OWeakObject *>(this);
                     throw deployment::DeploymentException( rtl::OUString(), oWeakThis,
                                                            makeAny( uno::Exception( aErrStr, oWeakThis ) ) );
                 }
 
-                Reference<XComponentContext> const & xContext = getComponentContext();
-                Reference< script::XInvocation > xInvocation;
-                if( xContext.is() )
-                {
-                    // Ignore the missing JRE scenario on upgrade/first-start
-                    // without horrible end-user warnings that are ignorable,
-                    // and cause grief:
-                    ContextLayer l(
-                        new NonJavaCurrentContext(getCurrentContext()));
-                    try
-                    {
-                        xInvocation = Reference< script::XInvocation >(
-                            xContext->getServiceManager()->createInstanceWithContext(
-                                rtl::OUString(
-                                    RTL_CONSTASCII_USTRINGPARAM("com.sun.star.help.HelpIndexer" )), xContext ) , UNO_QUERY );
-                    }
-                    catch (const Exception &)
-                    {
-                        // i98680: Survive missing lucene
-                    }
-                }
-
                 // Scan languages
                 Sequence< rtl::OUString > aLanguageFolderSeq = xSFA->getFolderContents( aExpandedHelpURL, true );
                 sal_Int32 nLangCount = aLanguageFolderSeq.getLength();
@@ -486,6 +441,9 @@ void BackendImpl::implProcessHelp(
                             &langFolderContent,
                             langFolderDest, xCmdEnv);
 
+                        const OUString aHelpStr("help");
+                        const OUString aSlash("/");
+
                         rtl::OUString aJarFile(
                             makeURL(sHelpFolder, langFolderURLSegment + aSlash + aHelpStr +
                                     OUSTR(".jar")));
@@ -495,9 +453,9 @@ void BackendImpl::implProcessHelp(
                             aJarFile, rtl_UriCharClassPchar,
                             rtl_UriEncodeIgnoreEscapes,
                             RTL_TEXTENCODING_UTF8 );
-                        rtl::OUString aDestBasePath = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "vnd.sun.star.zip://" ));
+                        rtl::OUString aDestBasePath = rtl::OUString("vnd.sun.star.zip://" );
                         aDestBasePath += aEncodedJarFilePath;
-                        aDestBasePath += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "/" ));
+                        aDestBasePath += rtl::OUString("/" );
 
                         sal_Int32 nLenLangFolderURL = aLangURL.getLength() + 1;
 
@@ -539,33 +497,19 @@ void BackendImpl::implProcessHelp(
                             nXhpFileCount, pXhpFiles,
                             langFolderDestExpanded, aErrorInfo );
 
-                        if( bSuccess && xInvocation.is() )
+                        if( bSuccess )
                         {
-                            Sequence<uno::Any> aParamsSeq( 6 );
-
-                            aParamsSeq[0] = uno::makeAny( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "-lang" ) ));
-
                             rtl::OUString aLang;
                             sal_Int32 nLastSlash = aLangURL.lastIndexOf( '/' );
                             if( nLastSlash != -1 )
                                 aLang = aLangURL.copy( nLastSlash + 1 );
                             else
-                                aLang = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "en" ));
-                            aParamsSeq[1] = uno::makeAny( aLang );
+                                aLang = rtl::OUString("en" );
 
-                            aParamsSeq[2] = uno::makeAny( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "-mod" ) ));
-                            aParamsSeq[3] = uno::makeAny( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "help" ) ));
+                            rtl::OUString aMod("help");
 
-                            aParamsSeq[4] = uno::makeAny( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "-zipdir" ) ));
-                            rtl::OUString aSystemPath;
-                            osl::FileBase::getSystemPathFromFileURL(
-                                langFolderDestExpanded, aSystemPath );
-                            aParamsSeq[5] = uno::makeAny( aSystemPath );
-
-                            Sequence< sal_Int16 > aOutParamIndex;
-                            Sequence< uno::Any > aOutParam;
-                            uno::Any aRet = xInvocation->invoke( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "createIndex" )),
-                                                                 aParamsSeq, aOutParamIndex, aOutParam );
+                            HelpIndexer aIndexer(aLang, aMod, langFolderDestExpanded, langFolderDestExpanded);
+                            aIndexer.indexDocuments();
                         }
 
                         if( !bSuccess )
@@ -602,16 +546,16 @@ void BackendImpl::implProcessHelp(
                                     aErrMsg = aErrMsg.copy( 0, nCopy );
                                 }
                                 aErrStr += aErrMsg;
-                                if( nErrStrId == RID_STR_HELPPROCESSING_XMLPARSING_ERROR && aErrorInfo.m_aXMLParsingFile.getLength() )
+                                if( nErrStrId == RID_STR_HELPPROCESSING_XMLPARSING_ERROR && !aErrorInfo.m_aXMLParsingFile.isEmpty() )
                                 {
-                                    aErrStr += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( " in " ));
+                                    aErrStr += rtl::OUString(" in " );
 
                                     rtl::OUString aDecodedFile = rtl::Uri::decode( aErrorInfo.m_aXMLParsingFile,
                                                                                    rtl_UriDecodeWithCharset, RTL_TEXTENCODING_UTF8 );
                                     aErrStr += aDecodedFile;
                                     if( aErrorInfo.m_nXMLParsingLine != -1 )
                                     {
-                                        aErrStr += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( ", line " ));
+                                        aErrStr += rtl::OUString(", line " );
                                         aErrStr += ::rtl::OUString::valueOf( aErrorInfo.m_nXMLParsingLine );
                                     }
                                 }
@@ -623,6 +567,9 @@ void BackendImpl::implProcessHelp(
                         }
                     }
                 }
+#else
+                (void) xCmdEnv;
+#endif
             }
                 //Writing the data entry replaces writing the flag file. If we got to this
                 //point the registration was successful.
@@ -657,7 +604,7 @@ void BackendImpl::implCollectXhpFiles( const rtl::OUString& aDir,
             if( nLastDot != -1 )
             {
                 rtl::OUString aExt = aURL.copy( nLastDot + 1 );
-                if( aExt.equalsIgnoreAsciiCase( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "xhp" )) ) )
+                if( aExt.equalsIgnoreAsciiCase( rtl::OUString("xhp" ) ) )
                     o_rXhpFileVector.push_back( aURL );
             }
         }
@@ -673,15 +620,15 @@ Reference< ucb::XSimpleFileAccess > BackendImpl::getFileAccess( void )
         {
             m_xSFA = Reference< ucb::XSimpleFileAccess >(
                 xContext->getServiceManager()->createInstanceWithContext(
-                    rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.ucb.SimpleFileAccess" )),
+                    rtl::OUString("com.sun.star.ucb.SimpleFileAccess" ),
                     xContext ), UNO_QUERY );
         }
         if( !m_xSFA.is() )
         {
             throw RuntimeException(
-                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                ::rtl::OUString(
                 "dp_registry::backend::help::BackendImpl::getFileAccess(), "
-                "could not instatiate SimpleFileAccess." )),
+                "could not instatiate SimpleFileAccess." ),
                 Reference< XInterface >() );
         }
     }
