@@ -831,21 +831,24 @@ SAL_IMPLEMENT_MAIN_WITH_ARGS( argc, argv )
     if ( pUsePlugin && !strcmp(pUsePlugin, "svp") )
         args->bInhibitSplash = sal_True;
 
-    pPipePath = get_pipe_path( args->pAppPath );
-
-    if ( ( fd = connect_pipe( pPipePath ) ) >= 0 )
+    if ( !args->bInhibitPipe )
     {
-        rtl_uString *pCwdPath = NULL;
-        osl_getProcessWorkingDir( &pCwdPath );
+        pPipePath = get_pipe_path( args->pAppPath );
 
-        bSentArgs = send_args( fd, pCwdPath );
+        if ( ( fd = connect_pipe( pPipePath ) ) >= 0 )
+        {
+            rtl_uString *pCwdPath = NULL;
+            osl_getProcessWorkingDir( &pCwdPath );
 
-        close( fd );
-    }
+            bSentArgs = send_args( fd, pCwdPath );
+
+            close( fd );
+        }
 #if OSL_DEBUG_LEVEL > 1
-    else
-        ustr_debug( "Failed to connect to pipe", pPipePath );
+        else
+            ustr_debug( "Failed to connect to pipe", pPipePath );
 #endif
+    }
 
     if ( !bSentArgs )
     {
@@ -935,7 +938,8 @@ SAL_IMPLEMENT_MAIN_WITH_ARGS( argc, argv )
     }
 
     /* cleanup */
-    rtl_uString_release( pPipePath );
+    if ( pPipePath )
+        rtl_uString_release( pPipePath );
     args_free (args);
 
     return status;
