@@ -34,7 +34,6 @@
 
 #define USE_SVXFONT
 
-#include <svl/ctloptions.hxx>
 #include <svtools/ctrltool.hxx>
 
 #include <editeng/svxfont.hxx>
@@ -98,7 +97,6 @@ using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::linguistic2;
 
-
 DBG_NAME( EditEngine )
 DBG_NAMEEX( EditView )
 
@@ -106,8 +104,6 @@ DBG_NAMEEX( EditView )
 static sal_Bool bDebugPaint = sal_False;
 #endif
 
-SV_IMPL_VARARR( EECharAttribArray, EECharAttrib );
-
 static SfxItemPool* pGlobalPool=0;
 
 // ----------------------------------------------------------------------
@@ -157,6 +153,11 @@ void EditEngine::UndoActionStart( sal_uInt16 nId )
         pImpEditEngine->UndoActionStart( nId );
 }
 
+void EditEngine::UndoActionStart(sal_uInt16 nId, const ESelection& rSel)
+{
+    pImpEditEngine->UndoActionStart(nId, rSel);
+}
+
 void EditEngine::UndoActionEnd( sal_uInt16 nId )
 {
     DBG_CHKTHIS( EditEngine, 0 );
@@ -165,7 +166,7 @@ void EditEngine::UndoActionEnd( sal_uInt16 nId )
         pImpEditEngine->UndoActionEnd( nId );
 }
 
-sal_Bool EditEngine::HasTriedMergeOnLastAddUndo() const
+bool EditEngine::HasTriedMergeOnLastAddUndo() const
 {
     return pImpEditEngine->mbLastTryMerge;
 }
@@ -337,15 +338,17 @@ void EditEngine::Draw( OutputDevice* pOutDev, const Rectangle& rOutRect, const P
         pOutDev->SetClipRegion();
 }
 
-void EditEngine::InsertView( EditView* pEditView, sal_uInt16 nIndex )
+void EditEngine::InsertView(EditView* pEditView, size_t nIndex)
 {
     DBG_CHKTHIS( EditEngine, 0 );
     DBG_CHKOBJ( pEditView, EditView, 0 );
 
-    if ( nIndex > pImpEditEngine->GetEditViews().Count() )
-        nIndex = pImpEditEngine->GetEditViews().Count();
+    if ( nIndex > pImpEditEngine->GetEditViews().size() )
+        nIndex = pImpEditEngine->GetEditViews().size();
+
+    ImpEditEngine::ViewsType& rViews = pImpEditEngine->GetEditViews();
+    rViews.insert(rViews.begin()+nIndex, pEditView);
 
-    pImpEditEngine->GetEditViews().Insert( pEditView, nIndex );
     EditSelection aStartSel;
     aStartSel = pImpEditEngine->GetEditDoc().GetStartPaM();
     pEditView->pImpEditView->SetEditSelection( aStartSel );
@@ -361,13 +364,15 @@ EditView* EditEngine::RemoveView( EditView* pView )
     DBG_CHKOBJ( pView, EditView, 0 );
 
     pView->HideCursor();
-    EditView* pRemoved = 0;
-    sal_uInt16 nPos = pImpEditEngine->GetEditViews().GetPos( pView );
-    DBG_ASSERT( nPos != USHRT_MAX, "RemoveView with invalid index" );
-    if ( nPos != USHRT_MAX )
+    EditView* pRemoved = NULL;
+    ImpEditEngine::ViewsType& rViews = pImpEditEngine->GetEditViews();
+    ImpEditEngine::ViewsType::iterator it = std::find(rViews.begin(), rViews.end(), pView);
+
+    DBG_ASSERT( it != rViews.end(), "RemoveView with invalid index" );
+    if (it != rViews.end())
     {
-        pRemoved = pImpEditEngine->GetEditViews().GetObject( nPos );
-        pImpEditEngine->GetEditViews().Remove( nPos );
+        pRemoved = *it;
+        rViews.erase(it);
         if ( pImpEditEngine->GetActiveView() == pView )
         {
             pImpEditEngine->SetActiveView( 0 );
@@ -379,30 +384,35 @@ EditView* EditEngine::RemoveView( EditView* pView )
     return pRemoved;
 }
 
-EditView* EditEngine::RemoveView( sal_uInt16 nIndex )
+EditView* EditEngine::RemoveView(size_t nIndex)
 {
     DBG_CHKTHIS( EditEngine, 0 );
-    EditView* pView = pImpEditEngine->GetEditViews().GetObject( nIndex );
+    ImpEditEngine::ViewsType& rViews = pImpEditEngine->GetEditViews();
+    if (nIndex >= rViews.size())
+        return NULL;
+
+    EditView* pView = rViews[nIndex];
     if ( pView )
         return RemoveView( pView );
     return NULL;
 }
 
-EditView* EditEngine::GetView( sal_uInt16 nIndex ) const
+EditView* EditEngine::GetView(size_t nIndex) const
 {
     DBG_CHKTHIS( EditEngine, 0 );
-    return pImpEditEngine->GetEditViews().GetObject( nIndex );
+    return pImpEditEngine->GetEditViews()[nIndex];
 }
 
-sal_uInt16 EditEngine::GetViewCount() const
+size_t EditEngine::GetViewCount() const
 {
     DBG_CHKTHIS( EditEngine, 0 );
-    return pImpEditEngine->GetEditViews().Count();
+    return pImpEditEngine->GetEditViews().size();
 }
 
 sal_Bool EditEngine::HasView( EditView* pView ) const
 {
-    return pImpEditEngine->GetEditViews().GetPos( pView ) != USHRT_MAX;
+    ImpEditEngine::ViewsType& rViews = pImpEditEngine->GetEditViews();
+    return std::find(rViews.begin(), rViews.end(), pView) != rViews.end();
 }
 
 EditView* EditEngine::GetActiveView() const
@@ -411,6 +421,11 @@ EditView* EditEngine::GetActiveView() const
     return pImpEditEngine->GetActiveView();
 }
 
+void EditEngine::SetActiveView(EditView* pView)
+{
+    pImpEditEngine->SetActiveView(pView);
+}
+
 void EditEngine::SetDefTab( sal_uInt16 nDefTab )
 {
     DBG_CHKTHIS( EditEngine, 0 );
@@ -433,10 +448,10 @@ void EditEngine::SetPaperSize( const Size& rNewSize )
     sal_Bool bAutoPageSize = pImpEditEngine->GetStatus().AutoPageSize();
     if ( bAutoPageSize || ( aNewSize.Width() != aOldSize.Width() ) )
     {
-        for ( sal_uInt16 nView = 0; nView < pImpEditEngine->aEditViews.Count(); nView++ )
+        for (size_t nView = 0; nView < pImpEditEngine->aEditViews.size(); ++nView)
         {
             EditView* pView = pImpEditEngine->aEditViews[nView];
-             DBG_CHKOBJ( pView, EditView, 0 );
+            DBG_CHKOBJ( pView, EditView, 0 );
             if ( bAutoPageSize )
                 pView->pImpEditView->RecalcOutputArea();
             else if ( pView->pImpEditView->DoAutoSize() )
@@ -451,7 +466,7 @@ void EditEngine::SetPaperSize( const Size& rNewSize )
             // Changing the width has no effect for AutoPageSize, as this is
             // determined by the text width.
             // Optimization first after Vobis delivery was enabled ...
-                pImpEditEngine->FormatFullDoc();
+            pImpEditEngine->FormatFullDoc();
 
             pImpEditEngine->UpdateViews( pImpEditEngine->GetActiveView() );
 
@@ -467,13 +482,13 @@ const Size& EditEngine::GetPaperSize() const
     return pImpEditEngine->GetPaperSize();
 }
 
-void EditEngine::SetVertical( sal_Bool bVertical )
+void EditEngine::SetVertical( bool bVertical )
 {
     DBG_CHKTHIS( EditEngine, 0 );
     pImpEditEngine->SetVertical( bVertical );
 }
 
-sal_Bool EditEngine::IsVertical() const
+bool EditEngine::IsVertical() const
 {
     DBG_CHKTHIS( EditEngine, 0 );
     return pImpEditEngine->IsVertical();
@@ -504,10 +519,15 @@ sal_uInt16 EditEngine::GetScriptType( const ESelection& rSelection ) const
     return pImpEditEngine->GetScriptType( aSel );
 }
 
+LanguageType EditEngine::GetLanguage(const EditPaM& rPaM) const
+{
+    return pImpEditEngine->GetLanguage(rPaM);
+}
+
 LanguageType EditEngine::GetLanguage( sal_uInt16 nPara, sal_uInt16 nPos ) const
 {
     DBG_CHKTHIS( EditEngine, 0 );
-    ContentNode* pNode = pImpEditEngine->GetEditDoc().SaveGetObject( nPara );
+    ContentNode* pNode = pImpEditEngine->GetEditDoc().GetObject( nPara );
     DBG_ASSERT( pNode, "GetLanguage - nPara is invalid!" );
     return pNode ? pImpEditEngine->GetLanguage( EditPaM( pNode, nPos ) ) : LANGUAGE_DONTKNOW;
 }
@@ -519,6 +539,11 @@ void EditEngine::TransliterateText( const ESelection& rSelection, sal_Int32 nTra
     pImpEditEngine->TransliterateText( pImpEditEngine->CreateSel( rSelection ), nTransliterationMode );
 }
 
+EditSelection EditEngine::TransliterateText(const EditSelection& rSelection, sal_Int32 nTransliterationMode)
+{
+    return pImpEditEngine->TransliterateText(rSelection, nTransliterationMode);
+}
+
 void EditEngine::SetAsianCompressionMode( sal_uInt16 n )
 {
     DBG_CHKTHIS( EditView, 0 );
@@ -687,6 +712,318 @@ ESelection EditEngine::GetWord( const ESelection& rSelection, sal_uInt16 nWordTy
     return pE->pImpEditEngine->CreateESel( aSel );
 }
 
+void EditEngine::CursorMoved(ContentNode* pPrevNode)
+{
+    pImpEditEngine->CursorMoved(pPrevNode);
+}
+
+void EditEngine::CheckIdleFormatter()
+{
+    pImpEditEngine->CheckIdleFormatter();
+}
+
+bool EditEngine::IsIdleFormatterActive() const
+{
+    return pImpEditEngine->aIdleFormatter.IsActive();
+}
+
+ParaPortion* EditEngine::FindParaPortion(ContentNode* pNode)
+{
+    return pImpEditEngine->FindParaPortion(pNode);
+}
+
+const ParaPortion* EditEngine::FindParaPortion(ContentNode* pNode) const
+{
+    return pImpEditEngine->FindParaPortion(pNode);
+}
+
+const ParaPortion* EditEngine::GetPrevVisPortion(const ParaPortion* pCurPortion) const
+{
+    return pImpEditEngine->GetPrevVisPortion(pCurPortion);
+}
+
+sal_uInt16 EditEngine::GetScriptType(const EditSelection& rSel) const
+{
+    return pImpEditEngine->GetScriptType(rSel);
+}
+
+void EditEngine::RemoveParaPortion(size_t nNode)
+{
+    pImpEditEngine->GetParaPortions().Remove(nNode);
+}
+
+void EditEngine::SetCallParaInsertedOrDeleted(bool b)
+{
+    pImpEditEngine->SetCallParaInsertedOrDeleted(b);
+}
+
+bool EditEngine::IsCallParaInsertedOrDeleted() const
+{
+    return pImpEditEngine->IsCallParaInsertedOrDeleted();
+}
+
+void EditEngine::AppendDeletedNodeInfo(DeletedNodeInfo* pInfo)
+{
+    pImpEditEngine->aDeletedNodes.push_back(pInfo);
+}
+
+void EditEngine::UpdateSelections()
+{
+    pImpEditEngine->UpdateSelections();
+}
+
+void EditEngine::InsertContent(ContentNode* pNode, sal_uInt16 nPos)
+{
+    pImpEditEngine->InsertContent(pNode, nPos);
+}
+
+EditPaM EditEngine::SplitContent(sal_uInt16 nNode, sal_uInt16 nSepPos)
+{
+    return pImpEditEngine->SplitContent(nNode, nSepPos);
+}
+
+EditPaM EditEngine::ConnectContents(sal_uInt16 nLeftNode, bool bBackward)
+{
+    return pImpEditEngine->ConnectContents(nLeftNode, bBackward);
+}
+
+EditPaM EditEngine::InsertFeature(const EditSelection& rEditSelection, const SfxPoolItem& rItem)
+{
+    return pImpEditEngine->ImpInsertFeature(rEditSelection, rItem);
+}
+
+EditSelection EditEngine::MoveParagraphs(const Range& rParagraphs, sal_uInt16 nNewPos, EditView* pCurView)
+{
+    return pImpEditEngine->MoveParagraphs(rParagraphs, nNewPos, pCurView);
+}
+
+void EditEngine::RemoveCharAttribs(sal_uInt16 nPara, sal_uInt16 nWhich, bool bRemoveFeatures)
+{
+    pImpEditEngine->RemoveCharAttribs(nPara, nWhich, bRemoveFeatures);
+}
+
+void EditEngine::RemoveCharAttribs(const EditSelection& rSel, bool bRemoveParaAttribs, sal_uInt16 nWhich)
+{
+    pImpEditEngine->RemoveCharAttribs(rSel, bRemoveParaAttribs, nWhich);
+}
+
+EditEngine::ViewsType& EditEngine::GetEditViews()
+{
+    return pImpEditEngine->GetEditViews();
+}
+
+const EditEngine::ViewsType& EditEngine::GetEditViews() const
+{
+    return pImpEditEngine->GetEditViews();
+}
+
+void EditEngine::SetUndoMode(bool b)
+{
+    pImpEditEngine->SetUndoMode(b);
+}
+
+void EditEngine::FormatAndUpdate(EditView* pCurView)
+{
+    pImpEditEngine->FormatAndUpdate(pCurView);
+}
+
+bool EditEngine::Undo(EditView* pView)
+{
+    return pImpEditEngine->Undo(pView);
+}
+
+bool EditEngine::Redo(EditView* pView)
+{
+    return pImpEditEngine->Redo(pView);
+}
+
+uno::Reference<datatransfer::XTransferable> EditEngine::CreateTransferable(const EditSelection& rSelection)
+{
+    return pImpEditEngine->CreateTransferable(rSelection);
+}
+
+void EditEngine::ParaAttribsToCharAttribs(ContentNode* pNode)
+{
+    pImpEditEngine->ParaAttribsToCharAttribs(pNode);
+}
+
+EditPaM EditEngine::CreateEditPaM(const EPaM& rEPaM)
+{
+    return pImpEditEngine->CreateEditPaM(rEPaM);
+}
+
+EditPaM EditEngine::ConnectParagraphs(
+        ContentNode* pLeft, ContentNode* pRight, bool bBackward)
+{
+    return pImpEditEngine->ImpConnectParagraphs(pLeft, pRight, bBackward);
+}
+
+EditPaM EditEngine::InsertField(const EditSelection& rEditSelection, const SvxFieldItem& rFld)
+{
+    return pImpEditEngine->InsertField(rEditSelection, rFld);
+}
+
+EditPaM EditEngine::InsertText(const EditSelection& aCurEditSelection, const String& rStr)
+{
+    return pImpEditEngine->InsertText(aCurEditSelection, rStr);
+}
+
+EditSelection EditEngine::InsertText(const EditTextObject& rTextObject, const EditSelection& rSel)
+{
+    return pImpEditEngine->InsertText(rTextObject, rSel);
+}
+
+EditSelection EditEngine::InsertText(
+    uno::Reference<datatransfer::XTransferable >& rxDataObj,
+    const String& rBaseURL, const EditPaM& rPaM, bool bUseSpecial)
+{
+    return pImpEditEngine->InsertText(rxDataObj, rBaseURL, rPaM, bUseSpecial);
+}
+
+EditPaM EditEngine::EndOfWord(const EditPaM& rPaM, sal_Int16 nWordType)
+{
+    return pImpEditEngine->EndOfWord(rPaM, nWordType);
+}
+
+EditPaM EditEngine::GetPaM(const Point& aDocPos, bool bSmart)
+{
+    return pImpEditEngine->GetPaM(aDocPos, bSmart);
+}
+
+EditSelection EditEngine::SelectWord(
+        const EditSelection& rCurSelection, sal_Int16 nWordType, bool bAcceptStartOfWord)
+{
+    return pImpEditEngine->SelectWord(rCurSelection, nWordType, bAcceptStartOfWord);
+}
+
+long EditEngine::GetXPos(
+        const ParaPortion* pParaPortion, const EditLine* pLine, sal_uInt16 nIndex, bool bPreferPortionStart) const
+{
+    return pImpEditEngine->GetXPos(pParaPortion, pLine, nIndex, bPreferPortionStart);
+}
+
+Range EditEngine::GetLineXPosStartEnd(
+        const ParaPortion* pParaPortion, const EditLine* pLine) const
+{
+    return pImpEditEngine->GetLineXPosStartEnd(pParaPortion, pLine);
+}
+
+bool EditEngine::IsFormatted() const
+{
+    return pImpEditEngine->IsFormatted();
+}
+
+EditPaM EditEngine::CursorLeft(const EditPaM& rPaM, sal_uInt16 nCharacterIteratorMode)
+{
+    return pImpEditEngine->CursorLeft(rPaM, nCharacterIteratorMode);
+}
+
+EditPaM EditEngine::CursorRight(const EditPaM& rPaM, sal_uInt16 nCharacterIteratorMode)
+{
+    return pImpEditEngine->CursorRight(rPaM, nCharacterIteratorMode);
+}
+
+sal_uInt16 EditEngine::GetOnePixelInRef() const
+{
+    return pImpEditEngine->nOnePixelInRef;
+}
+
+InternalEditStatus& EditEngine::GetInternalEditStatus()
+{
+    return pImpEditEngine->GetStatus();
+}
+
+EditDoc& EditEngine::GetEditDoc()
+{
+    return pImpEditEngine->GetEditDoc();
+}
+
+const EditDoc& EditEngine::GetEditDoc() const
+{
+    return pImpEditEngine->GetEditDoc();
+}
+
+ParaPortionList& EditEngine::GetParaPortions()
+{
+    return pImpEditEngine->GetParaPortions();
+}
+
+const ParaPortionList& EditEngine::GetParaPortions() const
+{
+    return pImpEditEngine->GetParaPortions();
+}
+
+void EditEngine::SeekCursor(
+        ContentNode* pNode, sal_uInt16 nPos, SvxFont& rFont, OutputDevice* pOut, sal_uInt16 nIgnoreWhich)
+{
+    pImpEditEngine->SeekCursor(pNode, nPos, rFont, pOut, nIgnoreWhich);
+}
+
+EditPaM EditEngine::DeleteSelection(const EditSelection& rSel)
+{
+    return pImpEditEngine->ImpDeleteSelection(rSel);
+}
+
+ESelection EditEngine::CreateESelection(const EditSelection& rSel)
+{
+    return pImpEditEngine->CreateESel(rSel);
+}
+
+EditSelection EditEngine::CreateSelection(const ESelection& rSel)
+{
+    return pImpEditEngine->CreateSel(rSel);
+}
+
+const SfxItemSet& EditEngine::GetBaseParaAttribs(sal_uInt16 nPara) const
+{
+    return pImpEditEngine->GetParaAttribs(nPara);
+}
+
+void EditEngine::SetParaAttribsOnly(sal_uInt16 nPara, const SfxItemSet& rSet)
+{
+    pImpEditEngine->SetParaAttribs(nPara, rSet);
+}
+
+void EditEngine::SetAttribs(const EditSelection& rSel, const SfxItemSet& rSet, sal_uInt8 nSpecial)
+{
+    pImpEditEngine->SetAttribs(rSel, rSet, nSpecial);
+}
+
+String EditEngine::GetSelected(const EditSelection& rSel, const LineEnd eParaSep) const
+{
+    return pImpEditEngine->GetSelected(rSel, eParaSep);
+}
+
+EditPaM EditEngine::DeleteSelected(const EditSelection& rSel)
+{
+    return pImpEditEngine->DeleteSelected(rSel);
+}
+
+void EditEngine::HandleBeginPasteOrDrop(PasteOrDropInfos& rInfos)
+{
+    pImpEditEngine->aBeginPasteOrDropHdl.Call(&rInfos);
+}
+
+void EditEngine::HandleEndPasteOrDrop(PasteOrDropInfos& rInfos)
+{
+    pImpEditEngine->aEndPasteOrDropHdl.Call(&rInfos);
+}
+
+bool EditEngine::HasText() const
+{
+    return pImpEditEngine->ImplHasText();
+}
+
+const EditSelectionEngine& EditEngine::GetSelectionEngine() const
+{
+    return pImpEditEngine->aSelEngine;
+}
+
+void EditEngine::SetInSelectionMode(bool b)
+{
+    pImpEditEngine->bInSelection = b;
+}
+
 sal_Bool EditEngine::PostKeyEvent( const KeyEvent& rKeyEvent, EditView* pEditView, Window* pFrameWin )
 {
     DBG_CHKTHIS( EditEngine, 0 );
@@ -1324,10 +1661,10 @@ EditTextObject* EditEngine::CreateTextObject( sal_uInt16 nPara, sal_uInt16 nPara
 {
     DBG_CHKTHIS( EditEngine, 0 );
     DBG_ASSERT( nPara < pImpEditEngine->GetEditDoc().Count(), "CreateTextObject: Startpara out of Range" );
-    DBG_ASSERT( nPara+nParas-1 < pImpEditEngine->GetEditDoc().Count(), "CreateTextObject: Endpara out of Range" );
+    DBG_ASSERT( nParas <= pImpEditEngine->GetEditDoc().Count() - nPara, "CreateTextObject: Endpara out of Range" );
 
-    ContentNode* pStartNode = pImpEditEngine->GetEditDoc().SaveGetObject( nPara );
-    ContentNode* pEndNode = pImpEditEngine->GetEditDoc().SaveGetObject( nPara+nParas-1 );
+    ContentNode* pStartNode = pImpEditEngine->GetEditDoc().GetObject( nPara );
+    ContentNode* pEndNode = pImpEditEngine->GetEditDoc().GetObject( nPara+nParas-1 );
     DBG_ASSERT( pStartNode, "Start-Paragraph does not exist: CreateTextObject" );
     DBG_ASSERT( pEndNode, "End-Paragraph does not exist: CreateTextObject" );
 
@@ -1348,8 +1685,8 @@ void EditEngine::RemoveParagraph( sal_uInt16 nPara )
     if( pImpEditEngine->GetEditDoc().Count() <= 1 )
         return;
 
-    ContentNode* pNode = pImpEditEngine->GetEditDoc().SaveGetObject( nPara );
-    ParaPortion* pPortion = pImpEditEngine->GetParaPortions().SaveGetObject( nPara );
+    ContentNode* pNode = pImpEditEngine->GetEditDoc().GetObject( nPara );
+    const ParaPortion* pPortion = pImpEditEngine->GetParaPortions().SafeGetObject( nPara );
     DBG_ASSERT( pPortion && pNode, "Paragraph not found: RemoveParagraph" );
     if ( pNode && pPortion )
     {
@@ -1364,7 +1701,7 @@ void EditEngine::RemoveParagraph( sal_uInt16 nPara )
 sal_uInt16 EditEngine::GetTextLen( sal_uInt16 nPara ) const
 {
     DBG_CHKTHIS( EditEngine, 0 );
-    ContentNode* pNode = pImpEditEngine->GetEditDoc().SaveGetObject( nPara );
+    ContentNode* pNode = pImpEditEngine->GetEditDoc().GetObject( nPara );
     DBG_ASSERT( pNode, "Paragraph not found: GetTextLen" );
     if ( pNode )
         return pNode->Len();
@@ -1499,7 +1836,7 @@ const SfxPoolItem& EditEngine::GetParaAttrib( sal_uInt16 nPara, sal_uInt16 nWhic
     return pImpEditEngine->GetParaAttrib( nPara, nWhich );
 }
 
-void EditEngine::GetCharAttribs( sal_uInt16 nPara, EECharAttribArray& rLst ) const
+void EditEngine::GetCharAttribs( sal_uInt16 nPara, std::vector<EECharAttrib>& rLst ) const
 {
     DBG_CHKTHIS( EditEngine, 0 );
     pImpEditEngine->GetCharAttribs( nPara, rLst );
@@ -1539,7 +1876,7 @@ Font EditEngine::GetStandardFont( sal_uInt16 nPara )
 SvxFont EditEngine::GetStandardSvxFont( sal_uInt16 nPara )
 {
     DBG_CHKTHIS( EditEngine, 0 );
-    ContentNode* pNode = pImpEditEngine->GetEditDoc().SaveGetObject( nPara );
+    ContentNode* pNode = pImpEditEngine->GetEditDoc().GetObject( nPara );
     return pNode->GetCharAttribs().GetDefFont();
 }
 
@@ -1561,7 +1898,7 @@ void EditEngine::GetPortions( sal_uInt16 nPara, std::vector<sal_uInt16>& rList )
     if ( !pImpEditEngine->IsFormatted() )
         pImpEditEngine->FormatFullDoc();
 
-    ParaPortion* pParaPortion = pImpEditEngine->GetParaPortions().SaveGetObject( nPara );
+    const ParaPortion* pParaPortion = pImpEditEngine->GetParaPortions().SafeGetObject( nPara );
     if ( pParaPortion )
     {
         sal_uInt16 nEnd = 0;
@@ -1643,8 +1980,8 @@ void EditEngine::SetControlWord( sal_uInt32 nWord )
                 for ( sal_uInt16 n = 0; n < nNodes; n++ )
                 {
                     ContentNode* pNode = pImpEditEngine->GetEditDoc().GetObject( n );
-                    ParaPortion* pPortion = pImpEditEngine->GetParaPortions().GetObject( n );
-                    sal_Bool bWrongs = ( bSpellingChanged || ( nWord & EE_CNTRL_ONLINESPELLING ) ) ? pNode->GetWrongList()->HasWrongs() : sal_False;
+                    const ParaPortion* pPortion = pImpEditEngine->GetParaPortions()[n];
+                    bool bWrongs = ( bSpellingChanged || ( nWord & EE_CNTRL_ONLINESPELLING ) ) ? !pNode->GetWrongList()->empty() : false;
                     if ( bSpellingChanged )
                         pNode->DestroyWrongList();
                     if ( bWrongs )
@@ -1673,13 +2010,13 @@ long EditEngine::GetFirstLineStartX( sal_uInt16 nParagraph )
     DBG_CHKTHIS( EditEngine, 0 );
 
     long nX = 0;
-    ParaPortion* pPPortion = pImpEditEngine->GetParaPortions().SaveGetObject( nParagraph );
+    const ParaPortion* pPPortion = pImpEditEngine->GetParaPortions().SafeGetObject( nParagraph );
     if ( pPPortion )
     {
         DBG_ASSERT( pImpEditEngine->IsFormatted() || !pImpEditEngine->IsFormatting(), "GetFirstLineStartX: Doc not formatted - unable to format!" );
         if ( !pImpEditEngine->IsFormatted() )
             pImpEditEngine->FormatDoc();
-        EditLine* pFirstLine = pPPortion->GetLines()[0];
+        const EditLine* pFirstLine = pPPortion->GetLines()[0];
         nX = pFirstLine->GetStartPosX();
     }
     return nX;
@@ -1699,7 +2036,7 @@ Point EditEngine::GetDocPos( const Point& rPaperPos ) const
 Point EditEngine::GetDocPosTopLeft( sal_uInt16 nParagraph )
 {
     DBG_CHKTHIS( EditEngine, 0 );
-    ParaPortion* pPPortion = pImpEditEngine->GetParaPortions().SaveGetObject( nParagraph );
+    const ParaPortion* pPPortion = pImpEditEngine->GetParaPortions().SafeGetObject( nParagraph );
     DBG_ASSERT( pPPortion, "Paragraph not found: GetWindowPosTopLeft" );
     Point aPoint;
     if ( pPPortion )
@@ -1712,7 +2049,7 @@ Point EditEngine::GetDocPosTopLeft( sal_uInt16 nParagraph )
         if ( pPPortion->GetLines().Count() )
         {
             // Correct it if large Bullet.
-            EditLine* pFirstLine = pPPortion->GetLines()[0];
+            const EditLine* pFirstLine = pPPortion->GetLines()[0];
             aPoint.X() = pFirstLine->GetStartPosX();
         }
         else
@@ -1762,11 +2099,11 @@ sal_Bool EditEngine::IsTextPos( const Point& rPaperPos, sal_uInt16 nBorder )
         EditPaM aPaM = pImpEditEngine->GetPaM( aDocPos, sal_False );
         if ( aPaM.GetNode() )
         {
-            ParaPortion* pParaPortion = pImpEditEngine->FindParaPortion( aPaM.GetNode() );
+            const ParaPortion* pParaPortion = pImpEditEngine->FindParaPortion( aPaM.GetNode() );
             DBG_ASSERT( pParaPortion, "ParaPortion?" );
 
             sal_uInt16 nLine = pParaPortion->GetLineNumber( aPaM.GetIndex() );
-            EditLine* pLine = pParaPortion->GetLines().GetObject( nLine );
+            const EditLine* pLine = pParaPortion->GetLines()[nLine];
             Range aLineXPosStartEnd = pImpEditEngine->GetLineXPosStartEnd( pParaPortion, pLine );
             if ( ( aDocPos.X() >= aLineXPosStartEnd.Min() - nBorder ) &&
                  ( aDocPos.X() <= aLineXPosStartEnd.Max() + nBorder ) )
@@ -1807,7 +2144,7 @@ void EditEngine::QuickMarkInvalid( const ESelection& rSel )
     DBG_ASSERT( rSel.nEndPara < pImpEditEngine->GetEditDoc().Count(), "MarkInvalid: End out of Range!" );
     for ( sal_uInt16 nPara = rSel.nStartPara; nPara <= rSel.nEndPara; nPara++ )
     {
-        ParaPortion* pPortion = pImpEditEngine->GetParaPortions().SaveGetObject( nPara );
+        ParaPortion* pPortion = pImpEditEngine->GetParaPortions().SafeGetObject( nPara );
         if ( pPortion )
             pPortion->MarkSelectionInvalid( 0, pPortion->GetNode()->Len() );
     }
@@ -1836,7 +2173,7 @@ void EditEngine::QuickDelete( const ESelection& rSel )
 void EditEngine::QuickMarkToBeRepainted( sal_uInt16 nPara )
 {
     DBG_CHKTHIS( EditEngine, 0 );
-    ParaPortion* pPortion = pImpEditEngine->GetParaPortions().SaveGetObject( nPara );
+    ParaPortion* pPortion = pImpEditEngine->GetParaPortions().SafeGetObject( nPara );
     if ( pPortion )
         pPortion->SetMustRepaint( sal_True );
 }
@@ -1879,13 +2216,24 @@ void EditEngine::QuickRemoveCharAttribs( sal_uInt16 nPara, sal_uInt16 nWhich )
     pImpEditEngine->RemoveCharAttribs( nPara, nWhich );
 }
 
+void EditEngine::SetStyleSheet(const EditSelection& aSel, SfxStyleSheet* pStyle)
+{
+    pImpEditEngine->SetStyleSheet(aSel, pStyle);
+}
+
 void EditEngine::SetStyleSheet( sal_uInt16 nPara, SfxStyleSheet* pStyle )
 {
     DBG_CHKTHIS( EditEngine, 0 );
     pImpEditEngine->SetStyleSheet( nPara, pStyle );
 }
 
-SfxStyleSheet* EditEngine::GetStyleSheet( sal_uInt16 nPara ) const
+const SfxStyleSheet* EditEngine::GetStyleSheet( sal_uInt16 nPara ) const
+{
+    DBG_CHKTHIS( EditEngine, 0 );
+    return pImpEditEngine->GetStyleSheet( nPara );
+}
+
+SfxStyleSheet* EditEngine::GetStyleSheet( sal_uInt16 nPara )
 {
     DBG_CHKTHIS( EditEngine, 0 );
     return pImpEditEngine->GetStyleSheet( nPara );
@@ -2044,15 +2392,15 @@ sal_Bool EditEngine::ShouldCreateBigTextObject() const
 sal_uInt16 EditEngine::GetFieldCount( sal_uInt16 nPara ) const
 {
     sal_uInt16 nFields = 0;
-    ContentNode* pNode = pImpEditEngine->GetEditDoc().SaveGetObject( nPara );
+    ContentNode* pNode = pImpEditEngine->GetEditDoc().GetObject( nPara );
     if ( pNode )
     {
-        const CharAttribArray& rAttrs = pNode->GetCharAttribs().GetAttribs();
-        for ( sal_uInt16 nAttr = 0; nAttr < rAttrs.Count(); nAttr++ )
+        const CharAttribList::AttribsType& rAttrs = pNode->GetCharAttribs().GetAttribs();
+        CharAttribList::AttribsType::const_iterator it = rAttrs.begin(), itEnd = rAttrs.end();
+        for (; it != itEnd; ++it)
         {
-            EditCharAttrib* pAttr = rAttrs[nAttr];
-            if ( pAttr->Which() == EE_FEATURE_FIELD )
-                nFields++;
+            if (it->Which() == EE_FEATURE_FIELD)
+                ++nFields;
         }
     }
 
@@ -2061,24 +2409,26 @@ sal_uInt16 EditEngine::GetFieldCount( sal_uInt16 nPara ) const
 
 EFieldInfo EditEngine::GetFieldInfo( sal_uInt16 nPara, sal_uInt16 nField ) const
 {
-    ContentNode* pNode = pImpEditEngine->GetEditDoc().SaveGetObject( nPara );
+    ContentNode* pNode = pImpEditEngine->GetEditDoc().GetObject( nPara );
     if ( pNode )
     {
         sal_uInt16 nCurrentField = 0;
-        const CharAttribArray& rAttrs = pNode->GetCharAttribs().GetAttribs();
-        for ( sal_uInt16 nAttr = 0; nAttr < rAttrs.Count(); nAttr++ )
+        const CharAttribList::AttribsType& rAttrs = pNode->GetCharAttribs().GetAttribs();
+        CharAttribList::AttribsType::const_iterator it = rAttrs.begin(), itEnd = rAttrs.end();
+        for (; it != itEnd; ++it)
         {
-            EditCharAttrib* pAttr = rAttrs[nAttr];
-            if ( pAttr->Which() == EE_FEATURE_FIELD )
+            const EditCharAttrib& rAttr = *it;
+            if (rAttr.Which() == EE_FEATURE_FIELD)
             {
                 if ( nCurrentField == nField )
                 {
-                    EFieldInfo aInfo( *(const SvxFieldItem*)pAttr->GetItem(), nPara, pAttr->GetStart() );
-                    aInfo.aCurrentText = ((EditCharAttribField*)pAttr)->GetFieldValue();
+                    const SvxFieldItem* p = static_cast<const SvxFieldItem*>(rAttr.GetItem());
+                    EFieldInfo aInfo(*p, nPara, rAttr.GetStart());
+                    aInfo.aCurrentText = static_cast<const EditCharAttribField&>(rAttr).GetFieldValue();
                     return aInfo;
                 }
 
-                nCurrentField++;
+                ++nCurrentField;
             }
         }
     }
@@ -2086,7 +2436,7 @@ EFieldInfo EditEngine::GetFieldInfo( sal_uInt16 nPara, sal_uInt16 nField ) const
 }
 
 
-sal_Bool EditEngine::UpdateFields()
+bool EditEngine::UpdateFields()
 {
     DBG_CHKTHIS( EditEngine, 0 );
     sal_Bool bChanges = pImpEditEngine->UpdateFields();
@@ -2095,6 +2445,11 @@ sal_Bool EditEngine::UpdateFields()
     return bChanges;
 }
 
+bool EditEngine::UpdateFieldsOnly()
+{
+    return pImpEditEngine->UpdateFields();
+}
+
 void EditEngine::RemoveFields( sal_Bool bKeepFieldText, TypeId aType )
 {
     DBG_CHKTHIS( EditEngine, 0 );
@@ -2106,18 +2461,18 @@ void EditEngine::RemoveFields( sal_Bool bKeepFieldText, TypeId aType )
     for ( sal_uInt16 nPara = 0; nPara < nParas; nPara++  )
     {
         ContentNode* pNode = pImpEditEngine->GetEditDoc().GetObject( nPara );
-        const CharAttribArray& rAttrs = pNode->GetCharAttribs().GetAttribs();
-        for ( sal_uInt16 nAttr = rAttrs.Count(); nAttr; )
+        const CharAttribList::AttribsType& rAttrs = pNode->GetCharAttribs().GetAttribs();
+        for (size_t nAttr = rAttrs.size(); nAttr; )
         {
-            const EditCharAttrib* pAttr = rAttrs[--nAttr];
-            if ( pAttr->Which() == EE_FEATURE_FIELD )
+            const EditCharAttrib& rAttr = rAttrs[--nAttr];
+            if (rAttr.Which() == EE_FEATURE_FIELD)
             {
-                const SvxFieldData* pFldData = ((const SvxFieldItem*)pAttr->GetItem())->GetField();
+                const SvxFieldData* pFldData = static_cast<const SvxFieldItem*>(rAttr.GetItem())->GetField();
                 if ( pFldData && ( !aType || ( pFldData->IsA( aType ) ) ) )
                 {
-                    DBG_ASSERT( pAttr->GetItem()->ISA( SvxFieldItem ), "no field item..." );
-                    EditSelection aSel( EditPaM( pNode, pAttr->GetStart() ), EditPaM( pNode, pAttr->GetEnd() ) );
-                    String aFieldText = ((EditCharAttribField*)pAttr)->GetFieldValue();
+                    DBG_ASSERT( dynamic_cast<const SvxFieldItem*>(rAttr.GetItem()), "no field item..." );
+                    EditSelection aSel( EditPaM(pNode, rAttr.GetStart()), EditPaM(pNode, rAttr.GetEnd()) );
+                    String aFieldText = static_cast<const EditCharAttribField&>(rAttr).GetFieldValue();
                     pImpEditEngine->ImpInsertText( aSel, aFieldText );
                 }
             }
@@ -2132,7 +2487,7 @@ sal_Bool EditEngine::HasOnlineSpellErrors() const
     for ( sal_uInt16 n = 0; n < nNodes; n++ )
     {
         ContentNode* pNode = pImpEditEngine->GetEditDoc().GetObject( n );
-        if ( pNode->GetWrongList() && pNode->GetWrongList()->Count() )
+        if ( pNode->GetWrongList() && !pNode->GetWrongList()->empty() )
             return sal_True;
     }
     return sal_False;
@@ -2172,7 +2527,7 @@ EPosition EditEngine::FindDocPosition( const Point& rDocPos ) const
 Rectangle EditEngine::GetCharacterBounds( const EPosition& rPos ) const
 {
     Rectangle aBounds;
-    ContentNode* pNode = pImpEditEngine->GetEditDoc().SaveGetObject( rPos.nPara );
+    ContentNode* pNode = pImpEditEngine->GetEditDoc().GetObject( rPos.nPara );
 
     // Check against index, not paragraph
     if ( pNode && ( rPos.nIndex < pNode->Len() ) )
@@ -2197,9 +2552,9 @@ ParagraphInfos EditEngine::GetParagraphInfos( sal_uInt16 nPara )
     aInfos.bValid = pImpEditEngine->IsFormatted();
     if ( pImpEditEngine->IsFormatted() )
     {
-        ParaPortion* pParaPortion = pImpEditEngine->GetParaPortions()[nPara];
-        EditLine* pLine = (pParaPortion && pParaPortion->GetLines().Count()) ?
-                pParaPortion->GetLines().GetObject( 0 ) : NULL;
+        const ParaPortion* pParaPortion = pImpEditEngine->GetParaPortions()[nPara];
+        const EditLine* pLine = (pParaPortion && pParaPortion->GetLines().Count()) ?
+                pParaPortion->GetLines()[0] : NULL;
         DBG_ASSERT( pParaPortion && pLine, "GetParagraphInfos - Paragraph out of range" );
         if ( pParaPortion && pLine )
         {
@@ -2322,12 +2677,12 @@ XubString EditEngine::GetUndoComment( sal_uInt16 nId ) const
         case EDITUNDO_DELCONTENT:
         case EDITUNDO_DELETE:
         case EDITUNDO_CUT:
-            aComment = XubString( EditResId( RID_EDITUNDO_DEL ) );
+            aComment = EE_RESSTR(RID_EDITUNDO_DEL);
         break;
         case EDITUNDO_MOVEPARAGRAPHS:
         case EDITUNDO_MOVEPARAS:
         case EDITUNDO_DRAGANDDROP:
-            aComment = XubString( EditResId( RID_EDITUNDO_MOVE ) );
+            aComment = EE_RESSTR(RID_EDITUNDO_MOVE);
         break;
         case EDITUNDO_INSERTFEATURE:
         case EDITUNDO_SPLITPARA:
@@ -2335,29 +2690,29 @@ XubString EditEngine::GetUndoComment( sal_uInt16 nId ) const
         case EDITUNDO_PASTE:
         case EDITUNDO_INSERT:
         case EDITUNDO_READ:
-            aComment = XubString( EditResId( RID_EDITUNDO_INSERT ) );
+            aComment = EE_RESSTR(RID_EDITUNDO_INSERT);
         break;
         case EDITUNDO_SRCHANDREPL:
         case EDITUNDO_REPLACEALL:
-            aComment = XubString( EditResId( RID_EDITUNDO_REPLACE ) );
+            aComment = EE_RESSTR(RID_EDITUNDO_REPLACE);
         break;
         case EDITUNDO_ATTRIBS:
         case EDITUNDO_PARAATTRIBS:
         case EDITUNDO_STRETCH:
-            aComment = XubString( EditResId( RID_EDITUNDO_SETATTRIBS ) );
+            aComment = EE_RESSTR(RID_EDITUNDO_SETATTRIBS);
         break;
         case EDITUNDO_RESETATTRIBS:
-            aComment = XubString( EditResId( RID_EDITUNDO_RESETATTRIBS ) );
+            aComment = EE_RESSTR(RID_EDITUNDO_RESETATTRIBS);
         break;
         case EDITUNDO_STYLESHEET:
-            aComment = XubString( EditResId( RID_EDITUNDO_SETSTYLE ) );
+            aComment = EE_RESSTR(RID_EDITUNDO_SETSTYLE);
         break;
         case EDITUNDO_TRANSLITERATE:
-            aComment = XubString( EditResId( RID_EDITUNDO_TRANSLITERATE ) );
+            aComment = EE_RESSTR(RID_EDITUNDO_TRANSLITERATE);
         break;
         case EDITUNDO_INDENTBLOCK:
         case EDITUNDO_UNINDENTBLOCK:
-            aComment = XubString( EditResId( RID_EDITUNDO_INDENT ) );
+            aComment = EE_RESSTR(RID_EDITUNDO_INDENT);
         break;
     }
     return aComment;
@@ -2560,6 +2915,31 @@ void EditEngine::SetFirstWordCapitalization( sal_Bool bCapitalize )
     pImpEditEngine->SetFirstWordCapitalization( bCapitalize );
 }
 
+bool EditEngine::IsImportHandlerSet() const
+{
+    return pImpEditEngine->aImportHdl.IsSet();
+}
+
+bool EditEngine::IsImportRTFStyleSheetsSet() const
+{
+    return pImpEditEngine->GetStatus().DoImportRTFStyleSheets();
+}
+
+void EditEngine::CallImportHandler(ImportInfo& rInfo)
+{
+    pImpEditEngine->aImportHdl.Call(&rInfo);
+}
+
+EditPaM EditEngine::InsertParaBreak(
+        const EditSelection& rEditSelection, bool bKeepEndingAttribs)
+{
+    return pImpEditEngine->ImpInsertParaBreak(rEditSelection, bKeepEndingAttribs);
+}
+
+EditPaM EditEngine::InsertLineBreak(const EditSelection& rEditSelection)
+{
+    return pImpEditEngine->InsertLineBreak(rEditSelection);
+}
 
 EFieldInfo::EFieldInfo()
 {
