@@ -93,6 +93,7 @@
 #define BRACELEFT   '{'
 #define BRACERIGHT  '}'
 
+using namespace ::com::sun::star;
 using namespace editeng;
 
 // Some helper functions
@@ -1468,49 +1469,49 @@ void SvxRTFParser::ReadBorderAttr( int nToken, SfxItemSet& rSet,
             }
 
         case RTF_BRDRDOT:       // dotted border
-            aBrd.SetStyle( DOTTED );
+            aBrd.SetBorderLineStyle(table::BorderLineStyle::DOTTED);
             break;
         case RTF_BRDRDASH:      // dashed border
-            aBrd.SetStyle( DASHED );
+            aBrd.SetBorderLineStyle(table::BorderLineStyle::DASHED);
             break;
         case RTF_BRDRHAIR:      // hairline border
             {
-                aBrd.SetStyle( SOLID );
+                aBrd.SetBorderLineStyle( table::BorderLineStyle::SOLID);
                 aBrd.SetWidth( DEF_LINE_WIDTH_0 );
             }
             break;
         case RTF_BRDRDB:        // Double border
-            aBrd.SetStyle( DOUBLE );
+            aBrd.SetBorderLineStyle(table::BorderLineStyle::DOUBLE);
             break;
         case RTF_BRDRINSET:     // inset border
-            aBrd.SetStyle( INSET );
+            aBrd.SetBorderLineStyle(table::BorderLineStyle::INSET);
             break;
         case RTF_BRDROUTSET:    // outset border
-            aBrd.SetStyle( OUTSET );
+            aBrd.SetBorderLineStyle(table::BorderLineStyle::OUTSET);
             break;
         case RTF_BRDRTNTHSG:    // ThinThick Small gap
-            aBrd.SetStyle( THINTHICK_SMALLGAP );
+            aBrd.SetBorderLineStyle(table::BorderLineStyle::THINTHICK_SMALLGAP);
             break;
         case RTF_BRDRTNTHMG:    // ThinThick Medium gap
-            aBrd.SetStyle( THINTHICK_MEDIUMGAP );
+            aBrd.SetBorderLineStyle(table::BorderLineStyle::THINTHICK_MEDIUMGAP);
             break;
         case RTF_BRDRTNTHLG:    // ThinThick Large gap
-            aBrd.SetStyle( THINTHICK_LARGEGAP );
+            aBrd.SetBorderLineStyle(table::BorderLineStyle::THINTHICK_LARGEGAP);
             break;
         case RTF_BRDRTHTNSG:    // ThickThin Small gap
-            aBrd.SetStyle( THICKTHIN_SMALLGAP );
+            aBrd.SetBorderLineStyle(table::BorderLineStyle::THICKTHIN_SMALLGAP);
             break;
         case RTF_BRDRTHTNMG:    // ThickThin Medium gap
-            aBrd.SetStyle( THICKTHIN_MEDIUMGAP );
+            aBrd.SetBorderLineStyle(table::BorderLineStyle::THICKTHIN_MEDIUMGAP);
             break;
         case RTF_BRDRTHTNLG:    // ThickThin Large gap
-            aBrd.SetStyle( THICKTHIN_LARGEGAP );
+            aBrd.SetBorderLineStyle(table::BorderLineStyle::THICKTHIN_LARGEGAP);
             break;
         case RTF_BRDREMBOSS:    // Embossed border
-            aBrd.SetStyle( EMBOSSED );
+            aBrd.SetBorderLineStyle(table::BorderLineStyle::EMBOSSED);
             break;
         case RTF_BRDRENGRAVE:   // Engraved border
-            aBrd.SetStyle( ENGRAVED );
+            aBrd.SetBorderLineStyle(table::BorderLineStyle::ENGRAVED);
             break;
 
         case RTF_BRDRS:         // single thickness border
