@@ -103,10 +103,10 @@ void OCommonEmbeddedObject::Deactivate()
         try {
             xClientSite->saveObject();
         }
-        catch( embed::ObjectSaveVetoException& )
+        catch( const embed::ObjectSaveVetoException& )
         {
         }
-        catch( uno::Exception& e )
+        catch( const uno::Exception& e )
         {
             throw embed::StorageWrappedTargetException(
                 ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "The client could not store the object!" )),
@@ -144,7 +144,7 @@ void OCommonEmbeddedObject::StateChangeNotification_Impl( sal_Bool bBeforeChange
                     else
                         ((embed::XStateChangeListener*)pIterator.next())->stateChanged( aSource, nOldState, nNewState );
                 }
-                catch( uno::Exception& )
+                catch( const uno::Exception& )
                 {
                     // even if the listener complains ignore it for now
                    }
@@ -329,7 +329,7 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
 
                         aModuleName = xManager->identify( xContDoc );
                     }
-                    catch( uno::Exception& )
+                    catch( const uno::Exception& )
                     {}
 
                     // if currently another object is UIactive it will be deactivated; usually this will activate the LM of
@@ -481,7 +481,7 @@ void SAL_CALL OCommonEmbeddedObject::changeState( sal_Int32 nNewState )
 
                 SwitchStateTo_Impl( nNewState );
             }
-            catch( uno::Exception& )
+            catch( const uno::Exception& )
             {
                 if ( nOldState != m_nObjectState )
                     // notify listeners that the object has changed the state
@@ -496,8 +496,7 @@ void SAL_CALL OCommonEmbeddedObject::changeState( sal_Int32 nNewState )
 
         // let the object window be shown
         if ( nNewState == embed::EmbedStates::UI_ACTIVE || nNewState == embed::EmbedStates::INPLACE_ACTIVE )
-            PostEvent_Impl( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "OnVisAreaChanged" ) ),
-                                        uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
+            PostEvent_Impl( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "OnVisAreaChanged" ) ) );
     }
 }
 
@@ -555,7 +554,7 @@ void SAL_CALL OCommonEmbeddedObject::doVerb( sal_Int32 nVerbID )
     {
         nNewState = ConvertVerbToState_Impl( nVerbID );
     }
-    catch( uno::Exception& )
+    catch( const uno::Exception& )
     {}
 
     if ( nNewState == -1 )
@@ -635,8 +634,7 @@ void SAL_CALL OCommonEmbeddedObject::update()
         throw embed::WrongStateException( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "The object has no persistence!\n" )),
                                         uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
 
-    PostEvent_Impl( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "OnVisAreaChanged" ) ),
-                                        uno::Reference< uno::XInterface >( static_cast< ::cppu::OWeakObject* >(this) ) );
+    PostEvent_Impl( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "OnVisAreaChanged" ) ) );
 }
 
 //----------------------------------------------
