@@ -29,7 +29,6 @@
 
 
 #include <osl/mutex.hxx>
-#include <tools/urlobj.hxx>
 #include <tools/diagnose_ex.h>
 #include <cppuhelper/weak.hxx>
 #include <svl/itemprop.hxx>
@@ -54,6 +53,7 @@
 #include <com/sun/star/text/BibliographyDataField.hpp>
 #include <com/sun/star/form/XLoadListener.hpp>
 #include <com/sun/star/frame/XLayoutManager.hpp>
+#include <com/sun/star/uno/XAggregation.hpp>
 #include <toolkit/awt/vclxwindow.hxx>
 #include <vcl/window.hxx>
 #include <vcl/edit.hxx>
@@ -243,13 +243,34 @@ void BibliographyLoader::cancel(void) throw (::com::sun::star::uno::RuntimeExcep
 }
 
 // -----------------------------------------------------------------------
+namespace
+{
+    // lp#527938, debian#602953, fdo#33266, i#105408
+    static bool lcl_isBaseAvailable()
+    {
+        try
+        {
+            Reference< XMultiServiceFactory >  xMgr = comphelper::getProcessServiceFactory();
+            Reference< XAggregation > xAggregate = Reference< XAggregation >( xMgr->createInstance(C2U("com.sun.star.sdb.RowSet")), UNO_QUERY);
+            return xAggregate.is();
+        }
+        catch(...)
+        {
+            return false;
+        }
+    }
+}
 void BibliographyLoader::load(const Reference< XFrame > & rFrame, const rtl::OUString& rURL,
         const Sequence< PropertyValue >& rArgs,
         const Reference< XLoadEventListener > & rListener) throw (::com::sun::star::uno::RuntimeException)
 {
-    //!
+    // lp#527938, debian#602953, fdo#33266, i#105408
+    // make sure we actually can instanciate services from base first
+    if(!lcl_isBaseAvailable())
+        return;
 
     SolarMutexGuard aGuard;
+    
     m_pBibMod = OpenBibModul();
 
     String aURLStr( rURL );
@@ -281,7 +302,7 @@ void BibliographyLoader::loadView(const Reference< XFrame > & rFrame, const rtl:
     m_xDatMan = m_pDatMan;
     BibDBDescriptor aBibDesc = BibModul::GetConfig()->GetBibliographyURL();
 
-    if(!aBibDesc.sDataSource.getLength())
+    if(aBibDesc.sDataSource.isEmpty())
     {
         DBChangeDialogConfig_Impl aConfig;
         const Sequence<OUString> aSources = aConfig.GetDataSourceNames();
@@ -338,7 +359,7 @@ void BibliographyLoader::loadView(const Reference< XFrame > & rFrame, const rtl:
             Any a = xPropSet->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "LayoutManager" )));
             a >>= xLayoutManager;
         }
-        catch ( uno::Exception& )
+        catch ( const uno::Exception& )
         {
         }
     }
@@ -532,7 +553,7 @@ Sequence< rtl::OUString > BibliographyLoader::getElementNames(void) throw ( Runt
             do
             {
                 rtl::OUString sTemp = xIdColumn->getString();
-                if (sTemp.getLength() && !xIdColumn->wasNull())
+                if (!sTemp.isEmpty() && !xIdColumn->wasNull())
                 {
                     int nLen = aRet.getLength();
                     if(nLen == nRealNameCount)
