@@ -28,7 +28,6 @@
 
 #include <osl/mutex.hxx>
 #include <tools/diagnose_ex.h>
-#include <tools/urlobj.hxx>
 #include <comphelper/processfactory.hxx>
 #include <com/sun/star/io/XPersistObject.hpp>
 #include <com/sun/star/sdbc/ResultSetType.hpp>
@@ -126,7 +125,6 @@ Reference< XConnection > getConnection(const ::rtl::OUString& _rURL)
     if (xDataSource.is())
     {
         // need user/pwd for this
-        ::rtl::OUString sUser, sPwd;
         Reference< XPropertySet >  xDataSourceProps(xDataSource, UNO_QUERY);
         Reference< XCompletedConnection > xComplConn(xDataSource, UNO_QUERY);
         try
@@ -292,7 +290,7 @@ class MappingDialog_Impl : public ModalDialog
 
 
 
-    DECL_LINK(OkHdl, OKButton*);
+    DECL_LINK(OkHdl, void *);
     DECL_LINK(ListBoxSelectHdl, ListBox*);
 
 public:
@@ -520,7 +518,7 @@ IMPL_LINK(MappingDialog_Impl, ListBoxSelectHdl, ListBox*, pListBox)
     return 0;
 }
 
-IMPL_LINK(MappingDialog_Impl, OkHdl, OKButton*, EMPTYARG)
+IMPL_LINK_NOARG(MappingDialog_Impl, OkHdl)
 {
     if(bModified)
     {
@@ -922,7 +920,7 @@ Reference< XForm >  BibDataManager::createDatabaseForm(BibDBDescriptor& rDesc)
             if(aTableNameSeq.getLength() > 0)
             {
                 const ::rtl::OUString* pTableNames = aTableNameSeq.getConstArray();
-                if(rDesc.sTableOrQuery.getLength())
+                if(!rDesc.sTableOrQuery.isEmpty())
                     aActiveDataTable = rDesc.sTableOrQuery;
                 else
                 {
@@ -1045,7 +1043,7 @@ Sequence< ::rtl::OUString > BibDataManager::getQueryFields()
 {
     BibConfig* pConfig = BibModul::GetConfig();
     ::rtl::OUString aFieldString = pConfig->getQueryField();
-    if(!aFieldString.getLength())
+    if(aFieldString.isEmpty())
     {
         Sequence< ::rtl::OUString > aSeq = getQueryFields();
         const ::rtl::OUString* pFields = aSeq.getConstArray();
@@ -1063,7 +1061,7 @@ void BibDataManager::startQueryWith(const ::rtl::OUString& rQuery)
     pConfig->setQueryText( rQuery );
 
     ::rtl::OUString aQueryString;
-    if(rQuery.getLength()>0)
+    if(!rQuery.isEmpty())
     {
         aQueryString=aQuoteChar;
         aQueryString+=getQueryField();
@@ -1080,7 +1078,6 @@ void BibDataManager::startQueryWith(const ::rtl::OUString& rQuery)
 
 void BibDataManager::setActiveDataSource(const ::rtl::OUString& rURL)
 {
-    ::rtl::OUString uTable;
     ::rtl::OUString sTmp(aDataSourceURL);
     aDataSourceURL = rURL;
 
@@ -1538,7 +1535,7 @@ void BibDataManager::SetMeAsUidListener()
             }
         }
 
-        if(theFieldName.getLength()>0)
+        if(!theFieldName.isEmpty())
         {
             Reference< XPropertySet >  xPropSet;
             Any aElement;
@@ -1582,7 +1579,7 @@ void BibDataManager::RemoveMeAsUidListener()
             }
         }
 
-        if(theFieldName.getLength()>0)
+        if(!theFieldName.isEmpty())
         {
             Reference< XPropertySet >  xPropSet;
             Any aElement;
@@ -1634,7 +1631,7 @@ void BibDataManager::DispatchDBChangeDialog()
 
 const ::rtl::OUString& BibDataManager::GetIdentifierMapping()
 {
-    if(!sIdentifierMapping.getLength())
+    if(sIdentifierMapping.isEmpty())
     {
         BibConfig* pConfig = BibModul::GetConfig();
         BibDBDescriptor aDesc;
