@@ -47,8 +47,10 @@
 
 #define _WINDOWS
 
+#ifdef _MSC_VER
 #pragma warning (push,1)
 #pragma warning (disable:4668)
+#endif
 
 #include <windows.h>
 #include <direct.h>
@@ -57,7 +59,9 @@
 #include <sys/types.h>
 #include <fcntl.h>
 
+#ifdef _MSC_VER
 #pragma warning (pop)
+#endif
 
 #endif //end of WNT
 
@@ -78,8 +82,16 @@
 
 #include "nsp_func.hxx"
 
+#include "npsdk/plugin.h"
+
 #include <comphelper/documentconstants.hxx>
 
+#ifdef _MSC_VER
+#define NP_DLLPUBLIC
+#else
+#define NP_DLLPUBLIC SAL_DLLPUBLIC_EXPORT
+#endif
+
 /***********************************************************************
  *
  * Implementations of plugin API functions
@@ -87,7 +99,7 @@
  ***********************************************************************/
 
 static NSP_Mute_Obj send_lock = NSP_New_Mute_Obj();
-static NSP_PIPE_FD write_fd = 0;
+static NSP_PIPE_FD write_fd = (NSP_PIPE_FD)-1;
 
 
 long int NSP_WriteToPipe(NSP_PIPE_FD fp, void* buf, unsigned long int len)
@@ -361,6 +373,10 @@ MIMETYPE_OASIS_OPENDOCUMENT_PRESENTATION_ASCII ":odp:OpenDocument Presentation;"
 MIMETYPE_OASIS_OPENDOCUMENT_PRESENTATION_TEMPLATE_ASCII ":otp:OpenDocument Presentation Template;"
 MIMETYPE_OASIS_OPENDOCUMENT_FORMULA_ASCII ":odf:OpenDocument Formula;" );
 
+NP_DLLPUBLIC
+#ifndef HAVE_NON_CONST_NPP_GETMIMEDESCRIPTION
+const
+#endif
 char*
 NPP_GetMIMEDescription(void)
 {
@@ -369,9 +385,7 @@ NPP_GetMIMEDescription(void)
 }
 
 #ifdef UNIX
-NPError
-// I am not actually sure wrt this, it ast least compiles with external
-// npapi.h now...
+NP_DLLPUBLIC NPError
 NPP_GetValue(NPP /*instance*/, NPPVariable variable, void *value)
 {
     NPError err = NPERR_NO_ERROR;
@@ -412,7 +426,7 @@ NPP_Initialize(void)
 }
 
 #ifdef OJI
-jref
+NP_DLLPUBLIC jref
 NPP_GetJavaClass()
 {
     return NULL;
@@ -435,7 +449,7 @@ NPP_Shutdown(void)
 #endif
 }
 
-NPError
+NP_DLLPUBLIC NPError NP_LOADDS
 NPP_New(NPMIMEType pluginType,
     NPP instance,
     uint16_t mode,
@@ -487,7 +501,7 @@ NPP_New(NPMIMEType pluginType,
     return NPERR_NO_ERROR;
 }
 
-NPError
+NP_DLLPUBLIC NPError NP_LOADDS
 NPP_Destroy(NPP instance, NPSavedData** /*save*/)
 {
     debug_fprintf(NSP_LOG_APPEND, "print by Nsplugin, enter NPP_Destroy.\n");
@@ -532,7 +546,7 @@ NPP_Destroy(NPP instance, NPSavedData** /*save*/)
 }
 
 
-NPError
+NP_DLLPUBLIC NPError NP_LOADDS
 NPP_SetWindow(NPP instance, NPWindow* window)
 {
     PluginInstance* This;
@@ -626,7 +640,7 @@ NPP_SetWindow(NPP instance, NPWindow* window)
 }
 
 
-NPError
+NP_DLLPUBLIC NPError NP_LOADDS
 NPP_NewStream(NPP instance,
           NPMIMEType /*type*/,
           NPStream* /*stream*/,
@@ -648,21 +662,21 @@ int32_t STREAMBUFSIZE = 0X0FFFFFFF;
  * mode so we can take any size stream in our
  * write call (since we ignore it) */
 
-int32_t
+NP_DLLPUBLIC int32_t NP_LOADDS
 NPP_WriteReady(NPP /*instance*/, NPStream* /*stream*/)
 {
     return STREAMBUFSIZE;
 }
 
 
-int32_t
+NP_DLLPUBLIC int32_t NP_LOADDS
 NPP_Write(NPP /*instance*/, NPStream* /*stream*/, int32_t /*offset*/, int32_t len, void* /*buffer*/)
 {
     return len;     /* The number of bytes accepted */
 }
 
 
-NPError
+NP_DLLPUBLIC NPError NP_LOADDS
 NPP_DestroyStream(NPP instance, NPStream* /*stream*/, NPError /*reason*/)
 {
     if (instance == NULL)
@@ -671,7 +685,7 @@ NPP_DestroyStream(NPP instance, NPStream* /*stream*/, NPError /*reason*/)
 }
 
 // save fname to another file with the original file name
-void
+NP_DLLPUBLIC void NP_LOADDS
 NPP_StreamAsFile(NPP instance, NPStream *stream, const char* fname)
 {
     debug_fprintf(NSP_LOG_APPEND, "Into Stream\n");
@@ -734,7 +748,7 @@ NPP_StreamAsFile(NPP instance, NPStream *stream, const char* fname)
         if(0 != strcmp(fname, localPathNew)) {
 
 #ifdef WNT
-        if(NULL == CopyFile(fname, localPathNew, FALSE))
+        if(FALSE == CopyFile(fname, localPathNew, FALSE))
             return;
 #endif //end of WNT
 
@@ -753,7 +767,7 @@ NPP_StreamAsFile(NPP instance, NPStream *stream, const char* fname)
             return;
         }
         char buffer[NPP_BUFFER_SIZE] = {0};
-        int ret;
+        ssize_t ret;
         while(0 <= (ret = read(fdSrc, buffer, NPP_BUFFER_SIZE)))
         {
             if (0 == ret)
@@ -764,7 +778,13 @@ NPP_StreamAsFile(NPP instance, NPStream *stream, const char* fname)
 
                     break;
             }
-            write(fdDst, buffer, ret);
+            ssize_t written_bytes = write(fdDst, buffer, ret);
+            if (written_bytes != ret)
+            {
+                debug_fprintf(NSP_LOG_APPEND, "NPP_StreamAsFile:short write to %s. error: %s \n",
+                    localPathNew, strerror(errno));
+                return;
+            }
         }
         close(fdSrc);
         close(fdDst);
@@ -812,14 +832,14 @@ NPP_StreamAsFile(NPP instance, NPStream *stream, const char* fname)
         debug_fprintf(NSP_LOG_APPEND, "NPP_StreamAsFile send SO_SET_WINDOW return failure \n");
 }
 
-void
+NP_DLLPUBLIC void NP_LOADDS
 NPP_URLNotify(NPP /*instance*/, const char* /*url*/,
                 NPReason /*reason*/, void* /*notifyData*/)
 {
 }
 
 
-void
+NP_DLLPUBLIC void NP_LOADDS
 NPP_Print(NPP instance, NPPrint* printInfo)
 {
     if(printInfo == NULL)
