@@ -42,7 +42,9 @@
 #include <com/sun/star/lang/XSingleServiceFactory.hpp>
 #include <com/sun/star/loader/XImplementationLoader.hpp>
 #include <com/sun/star/loader/CannotActivateFactoryException.hpp>
+#include <com/sun/star/plugin/PluginManager.hpp>
 
+#include <comphelper/componentcontext.hxx>
 #include <plugin/impl.hxx>
 #include <tools/fsys.hxx>
 #include <ucbhelper/content.hxx>
@@ -119,6 +121,7 @@ XPlugin_Impl::XPlugin_Impl( const uno::Reference< com::sun::star::lang::XMultiSe
         PluginControl_Impl(),
         m_xSMgr( rSMgr ),
         m_pPluginComm( NULL ),
+        m_pSysPlugData( CreateSysPlugData() ),
         m_aEncoding( osl_getThreadTextEncoding() ),
         m_pArgv( NULL ),
         m_pArgn( NULL ),
@@ -131,14 +134,13 @@ XPlugin_Impl::XPlugin_Impl( const uno::Reference< com::sun::star::lang::XMultiSe
 {
     memset( &m_aInstance, 0, sizeof( m_aInstance ) );
     memset( &m_aNPWindow, 0, sizeof( m_aNPWindow ) );
-    memset( &m_aSysPlugData, 0, sizeof( m_aSysPlugData ) );
 
     m_xModel = new PluginModel();
     uno::Reference< com::sun::star::beans::XPropertySet >  xPS( m_xModel, UNO_QUERY );
     xPS->addPropertyChangeListener( OUString(), this );
 
-    Guard< Mutex > aGuard( PluginManager::get().getPluginMutex() );
-    PluginManager::get().getPlugins().push_back( this );
+    Guard< Mutex > aGuard( ::PluginManager::get().getPluginMutex() );
+    ::PluginManager::get().getPlugins().push_back( this );
 }
 
 void XPlugin_Impl::destroyInstance()
@@ -198,11 +200,11 @@ IMPL_LINK( XPlugin_Impl, secondLevelDispose, XPlugin_Impl*, /*pThis*/ )
 
     // may have become undisposable between PostUserEvent and here
     // or may have disposed and receive a second UserEvent
-    std::list<XPlugin_Impl*>& rList = PluginManager::get().getPlugins();
+    std::list<XPlugin_Impl*>& rList = ::PluginManager::get().getPlugins();
     std::list<XPlugin_Impl*>::iterator iter;
 
     {
-        Guard< Mutex > aPluginGuard( PluginManager::get().getPluginMutex() );
+        Guard< Mutex > aPluginGuard( ::PluginManager::get().getPluginMutex() );
         for( iter = rList.begin(); iter != rList.end(); ++iter )
         {
             if( *iter == this )
@@ -222,7 +224,7 @@ IMPL_LINK( XPlugin_Impl, secondLevelDispose, XPlugin_Impl*, /*pThis*/ )
     uno::Reference< com::sun::star::beans::XPropertySet >  xPS( m_xModel, UNO_QUERY );
     xPS->removePropertyChangeListener( OUString(), this );
     {
-        Guard< Mutex > aPluginGuard( PluginManager::get().getPluginMutex() );
+        Guard< Mutex > aPluginGuard( ::PluginManager::get().getPluginMutex() );
         rList.remove( this );
     }
     m_aNPWindow.window = NULL;
@@ -325,15 +327,15 @@ void XPlugin_Impl::handleSpecialArgs()
             try
             {
                 uno::Reference< XPropertySet > xProp( m_xModel, UNO_QUERY );
-                Any aProp = xProp->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "URL" ) ) );
+                Any aProp = xProp->getPropertyValue( OUString(  "URL"  ) );
                 aProp >>= aURL;
             }
-            catch( UnknownPropertyException )
+            catch(const UnknownPropertyException &)
             {
             }
         }
 
-        if( aURL.getLength() )
+        if( !aURL.isEmpty() )
         {
             // set new args, old args need not be freed as there were none set
             m_nArgs = 6;
@@ -395,15 +397,15 @@ void XPlugin_Impl::handleSpecialArgs()
             try
             {
                 uno::Reference< XPropertySet > xProp( m_xModel, UNO_QUERY );
-                Any aProp = xProp->getPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "URL" ) ) );
+                Any aProp = xProp->getPropertyValue( OUString(  "URL"  ) );
                 aProp >>= aURL;
             }
-            catch( UnknownPropertyException )
+            catch(const UnknownPropertyException &)
             {
             }
         }
 
-        if( aURL.getLength() )
+        if( !aURL.isEmpty() )
         {
             // SRC
             prependArg( "SRC", OUStringToOString( aURL, m_aEncoding ).getStr() );
@@ -446,7 +448,7 @@ void XPlugin_Impl::modelChanged()
     destroyInstance();
 
     m_aDescription = fitDescription( getCreationURL() );
-    if( !m_aDescription.Mimetype.getLength() )
+    if( m_aDescription.Mimetype.isEmpty() )
     {
         m_nProvidingState = PROVIDING_NONE;
         return;
@@ -468,7 +470,7 @@ OUString XPlugin_Impl::getCreationURL()
     uno::Reference< com::sun::star::beans::XPropertySet >  xPS( m_xModel, UNO_QUERY );
     if( xPS.is() )
     {
-        Any aValue = xPS->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("URL")) );
+        Any aValue = xPS->getPropertyValue( OUString("URL") );
         aValue >>= aRet;
     }
     return aRet;
@@ -484,7 +486,7 @@ sal_Bool XPlugin_Impl::setModel( const uno::Reference< com::sun::star::awt::XCon
     if( ! xPS.is() )
         return sal_False;
 
-    if( getCreationURL().getLength() )
+    if( !getCreationURL().isEmpty() )
     {
         m_xModel = Model;
         modelChanged();
@@ -512,8 +514,8 @@ void XPlugin_Impl::loadPlugin()
     Guard< Mutex > aGuard( m_aMutex );
 
     std::list<PluginComm*>::iterator iter;
-    for( iter = PluginManager::get().getPluginComms().begin();
-         iter != PluginManager::get().getPluginComms().end(); ++iter )
+    for( iter = ::PluginManager::get().getPluginComms().begin();
+         iter != ::PluginManager::get().getPluginComms().end(); ++iter )
     {
         if( OStringToOUString( (*iter)->getLibName(), m_aEncoding ) == m_aDescription.PluginName )
         {
@@ -523,11 +525,14 @@ void XPlugin_Impl::loadPlugin()
     }
     const SystemEnvData* pEnvData = getSysChildSysData();
 #if defined( UNX ) && !(defined(QUARTZ))
-    XSync( (Display*)pEnvData->pDisplay, False );
+    if (pEnvData->pDisplay) // headless?
+    {
+        XSync( (Display*)pEnvData->pDisplay, False );
+    }
 #endif
     if( ! getPluginComm() )
     {
-        if( m_aDescription.PluginName.getLength() )
+        if( !m_aDescription.PluginName.isEmpty() )
         {
 #if defined QUARTZ
             PluginComm* pComm = new MacPluginComm( m_aDescription.Mimetype,
@@ -566,10 +571,17 @@ void XPlugin_Impl::loadPlugin()
                  NULL );
 #ifdef QUARTZ
     // m_aNPWindow is set up in the MacPluginComm from the view
-    m_aSysPlugData.m_pParentView = pEnvData->pView;
+    SetSysPlugDataParentView(*pEnvData);
 #elif defined( UNX )
-    XSync( (Display*)pEnvData->pDisplay, False );
-    m_aNPWindow.window      = (void*)pEnvData->aWindow;
+    if (pEnvData->pDisplay) // headless?
+    {
+        XSync( (Display*)pEnvData->pDisplay, False );
+        m_aNPWindow.window  = (void*)pEnvData->aWindow;
+    }
+    else
+    {
+        m_aNPWindow.window  = NULL;
+    }
     m_aNPWindow.ws_info     = NULL;
 #else
     m_aNPWindow.window = (void*)pEnvData->hWnd;
@@ -656,9 +668,9 @@ sal_Bool XPlugin_Impl::provideNewStream(const OUString& mimetype,
         {
             try
             {
-                xPS->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("URL")), aAny );
+                xPS->setPropertyValue( OUString("URL"), aAny );
                 aAny <<= mimetype;
-                xPS->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("TYPE")), aAny );
+                xPS->setPropertyValue( OUString("TYPE"), aAny );
             }
             catch(...)
             {
@@ -668,14 +680,14 @@ sal_Bool XPlugin_Impl::provideNewStream(const OUString& mimetype,
     m_nProvidingState = PROVIDING_NOW;
 
     OString aMIME;
-    if( mimetype.getLength() )
+    if( !mimetype.isEmpty() )
         aMIME = OUStringToOString( mimetype, m_aEncoding );
     else
         aMIME = OUStringToOString( m_aDescription.Mimetype, m_aEncoding );
 
     OString aURL  = OUStringToOString( url, m_aEncoding );
 
-    // check wether there is a notifylistener for this stream
+    // check whether there is a notifylistener for this stream
     // this means that the strema is created from the plugin
     // via NPN_GetURLNotify or NPN_PostURLNotify
     std::list<PluginEventListener*>::iterator iter;
@@ -693,7 +705,7 @@ sal_Bool XPlugin_Impl::provideNewStream(const OUString& mimetype,
     if( ! m_pPluginComm )
     {
         loadPlugin();
-        if( m_aLastGetUrl.getLength() && m_aLastGetUrl == aURL )
+        if( !m_aLastGetUrl.isEmpty() && m_aLastGetUrl == aURL )
         {
             // plugin is pulling data, don't push the same stream;
             // this complicated method could have been avoided if
@@ -706,7 +718,7 @@ sal_Bool XPlugin_Impl::provideNewStream(const OUString& mimetype,
      if( ! m_pPluginComm )
         return sal_False;
 
-     if( ! url.getLength() )
+     if(  url.isEmpty() )
          // this is valid if the plugin is supposed to
          // pull data (via e.g. NPN_GetURL)
          return sal_True;
@@ -720,7 +732,7 @@ sal_Bool XPlugin_Impl::provideNewStream(const OUString& mimetype,
              {
                  Any aAny;
                  aAny <<= m_aDescription.Mimetype;
-                 xPS->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("TYPE")), aAny );
+                 xPS->setPropertyValue( OUString("TYPE"), aAny );
              }
              catch(...)
              {
@@ -751,7 +763,7 @@ sal_Bool XPlugin_Impl::provideNewStream(const OUString& mimetype,
     fprintf( stderr,
              "new stream \"%s\" of MIMEType \"%s\"\n"
              "for plugin \"%s\"\n"
-             "seekable = %s, length = %"SAL_PRIdINT32"\n",
+             "seekable = %s, length = %" SAL_PRIdINT32 "\n",
              aURL.getStr(), aMIME.getStr(), getPluginComm()->getLibName().getStr(),
              isfile ? "true" : "false", length );
 
@@ -862,7 +874,7 @@ void XPlugin_Impl::setPosSize( sal_Int32 nX_, sal_Int32 nY_, sal_Int32 nWidth_,
     Guard< Mutex > aGuard( m_aMutex );
 
 #if OSL_DEBUG_LEVEL > 1
-    fprintf( stderr, "XPlugin_Impl::setPosSize( %"SAL_PRIdINT32", %"SAL_PRIdINT32", %"SAL_PRIdINT32", %"SAL_PRIdINT32", %d )\n",
+    fprintf( stderr, "XPlugin_Impl::setPosSize( %" SAL_PRIdINT32 ", %" SAL_PRIdINT32 ", %" SAL_PRIdINT32 ", %" SAL_PRIdINT32 ", %d )\n",
              nX_, nY_, nWidth_, nHeight_, nFlags );
 #endif
 
@@ -883,12 +895,7 @@ void XPlugin_Impl::setPosSize( sal_Int32 nX_, sal_Int32 nY_, sal_Int32 nWidth_,
 
 PluginDescription XPlugin_Impl::fitDescription( const OUString& rURL )
 {
-    uno::Reference< XPluginManager >  xPMgr( m_xSMgr->createInstance( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.plugin.PluginManager")) ), UNO_QUERY );
-    if( !xPMgr.is() )
-    {
-        m_nProvidingState = PROVIDING_NONE;
-        return PluginDescription();
-    }
+    uno::Reference< XPluginManager >  xPMgr( plugin::PluginManager::create(comphelper::ComponentContext(m_xSMgr).getUNOContext()) );
 
     Sequence< PluginDescription > aDescrs = xPMgr->getPluginDescriptions();
     const PluginDescription* pDescrs = aDescrs.getConstArray();
@@ -907,9 +914,9 @@ PluginDescription XPlugin_Impl::fitDescription( const OUString& rURL )
     }
 
     int nPos = rURL.lastIndexOf( (sal_Unicode)'.' );
-    OUString aExt = rURL.copy( nPos ).toAsciiLowerCase();
     if( nPos != -1 )
     {
+        OUString const aExt = rURL.copy( nPos ).toAsciiLowerCase();
         for( int i = 0; i < aDescrs.getLength(); i++ )
         {
             OUString aThisExt = pDescrs[ i ].Extension.toAsciiLowerCase();
@@ -1037,7 +1044,7 @@ void PluginInputStream::load()
                                );
         m_pContent->openStream( static_cast< XOutputStream* >( this ) );
     }
-    catch( com::sun::star::uno::Exception )
+    catch(const com::sun::star::uno::Exception &)
     {
     }
 }
@@ -1133,7 +1140,7 @@ PluginOutputStream::PluginOutputStream( XPlugin_Impl* pPlugin,
                                         sal_uInt32 len,
                                         sal_uInt32 lastmod ) :
         PluginStream( pPlugin, url, len, lastmod ),
-        m_xStream( pPlugin->getServiceManager()->createInstance( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.io.DataOutputStream")) ), UNO_QUERY )
+        m_xStream( pPlugin->getServiceManager()->createInstance( OUString("com.sun.star.io.DataOutputStream") ), UNO_QUERY )
 {
     Guard< Mutex > aGuard( m_pPlugin->getMutex() );
 
