@@ -38,11 +38,10 @@
 #include <math.h>
 #include <sal/macros.h>
 #include <rtl/strbuf.hxx>
-#include <comphelper/string.hxx>
 
 ResId SaneResId( sal_uInt32 nID )
 {
-    static ResMgr* pResMgr = ResMgr::CreateResMgr( "san" );
+    static ResMgr* pResMgr = ResMgr::CreateResMgr( "scn" );
     return ResId( nID, *pResMgr );
 }
 
@@ -1212,20 +1211,18 @@ sal_Bool SaneDlg::LoadState()
             if( nOption == -1 )
                 continue;
 
-            using comphelper::string::matchL;
-
-            if (matchL(aValue, RTL_CONSTASCII_USTRINGPARAM("BOOL=")))
+            if (aValue.matchL(RTL_CONSTASCII_STRINGPARAM("BOOL=")))
             {
                 aValue = aValue.copy(RTL_CONSTASCII_LENGTH("BOOL="));
                 sal_Bool aBOOL = (sal_Bool)aValue.toInt32();
                 mrSane.SetOptionValue( nOption, aBOOL );
             }
-            else if (matchL(aValue, RTL_CONSTASCII_USTRINGPARAM("STRING=")))
+            else if (aValue.matchL(RTL_CONSTASCII_STRINGPARAM("STRING=")))
             {
                 aValue = aValue.copy(RTL_CONSTASCII_LENGTH("STRING="));
                 mrSane.SetOptionValue(nOption,rtl::OStringToOUString(aValue, osl_getThreadTextEncoding()) );
             }
-            else if (matchL(aValue, RTL_CONSTASCII_USTRINGPARAM("NUMERIC=")))
+            else if (aValue.matchL(RTL_CONSTASCII_STRINGPARAM("NUMERIC=")))
             {
                 aValue = aValue.copy(RTL_CONSTASCII_LENGTH("NUMERIC="));
 
