@@ -352,7 +352,7 @@ void Writer::Impl_writeGradientEx( const PolyPolygon& rPolyPoly, const Gradient&
         PolyPolygon aPolyPolygon( rPolyPoly );
         map( aPolyPolygon );
 
-        if( (rGradient.GetStyle() == GRADIENT_LINEAR && rGradient.GetAngle() == 900) || (rGradient.GetStyle() == GRADIENT_RADIAL)  )
+        if( (rGradient.GetStyle() == GradientStyle_LINEAR && rGradient.GetAngle() == 900) || (rGradient.GetStyle() == GradientStyle_RADIAL)  )
         {
             const Rectangle aBoundRect( aPolyPolygon.GetBoundRect() );
 
@@ -407,15 +407,13 @@ FlashFont& Writer::Impl_getFont( const Font& rFont )
     FontMap::iterator aIter( maFonts.begin() );
     const FontMap::iterator aEnd( maFonts.end() );
 
-    while( aIter != aEnd )
+    for(; aIter != aEnd; ++aIter)
     {
         const Font tempFont = (*aIter)->getFont();
         if( compare_fonts_for_me(tempFont, rFont) )
         {
             return **aIter;
         }
-
-        aIter++;
     }
 
     FlashFont* pFont = new FlashFont( rFont, createID() );
