@@ -113,6 +113,7 @@ PDFExport::PDFExport( const Reference< XComponent >& rxSrcDoc,
                                               //already used for i59651 (PDF/A-1)
     mbUseTransitionEffects      ( sal_True ),
     mbExportBookmarks           ( sal_True ),
+    mbExportHiddenSlides        ( sal_False ),
     mnOpenBookmarkLevels        ( -1 ),
     mbUseLosslessCompression    ( sal_False ),
     mbReduceImageResolution     ( sal_False ),
@@ -183,11 +184,11 @@ sal_Bool PDFExport::ExportSelection( vcl::PDFWriter& rPDFWriter,
 
         for( sal_Int32 nData = 0, nDataCount = rRenderOptions.getLength(); nData < nDataCount; ++nData )
         {
-            if( rRenderOptions[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "IsFirstPage" ) ) )
+            if ( rRenderOptions[ nData ].Name == "IsFirstPage" )
                 pFirstPage = &rRenderOptions[ nData ].Value;
-            else if( rRenderOptions[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "IsLastPage" ) ) )
+            else if ( rRenderOptions[ nData ].Name == "IsLastPage" )
                 pLastPage = &rRenderOptions[ nData ].Value;
-            else if( rRenderOptions[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "ExportNotesPages" ) ) )
+            else if ( rRenderOptions[ nData ].Name == "ExportNotesPages" )
                 rRenderOptions[ nData ].Value >>= bExportNotesPages;
         }
 
@@ -210,7 +211,7 @@ sal_Bool PDFExport::ExportSelection( vcl::PDFWriter& rPDFWriter,
 
                     for( sal_Int32 nProperty = 0, nPropertyCount = aRenderer.getLength(); nProperty < nPropertyCount; ++nProperty )
                     {
-                        if( aRenderer[ nProperty ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "PageSize" ) ) )
+                        if ( aRenderer[ nProperty ].Name == "PageSize" )
                             aRenderer[ nProperty].Value >>= aPageSize;
                     }
 
@@ -263,7 +264,7 @@ sal_Bool PDFExport::ExportSelection( vcl::PDFWriter& rPDFWriter,
             }
         }
     }
-    catch( RuntimeException )
+    catch(const RuntimeException &)
     {
     }
     return bRet;
@@ -307,7 +308,7 @@ void PDFExportStreamDoc::write( const Reference< XOutputStream >& xStream )
             xStore->storeToURL( OUString( RTL_CONSTASCII_USTRINGPARAM( "private:stream" ) ),
                                 aArgs );
         }
-        catch( IOException& )
+        catch( const IOException& )
         {
         }
     }
@@ -325,7 +326,7 @@ static OUString getMimetypeForDocument( const Reference< XMultiServiceFactory >&
     if( xModuleManager.is() && xStore.is() )
     {
         OUString aDocServiceName = xModuleManager->identify( Reference< XInterface >( xStore, uno::UNO_QUERY ) );
-        if ( aDocServiceName.getLength() )
+        if ( !aDocServiceName.isEmpty() )
         {
             // get the actual filter name
             OUString aFilterName;
@@ -349,7 +350,7 @@ static OUString getMimetypeForDocument( const Reference< XMultiServiceFactory >&
             if ( xApplConfig.is() )
             {
                 xApplConfig->getByName( OUString( RTL_CONSTASCII_USTRINGPARAM( "ooSetupFactoryActualFilter" ) ) ) >>= aFilterName;
-                if( aFilterName.getLength() )
+                if( !aFilterName.isEmpty() )
                 {
                     // find the related type name
                     OUString aTypeName;
@@ -360,10 +361,10 @@ static OUString getMimetypeForDocument( const Reference< XMultiServiceFactory >&
                     Sequence< beans::PropertyValue > aFilterData;
                     xFilterFactory->getByName( aFilterName ) >>= aFilterData;
                     for ( sal_Int32 nInd = 0; nInd < aFilterData.getLength(); nInd++ )
-                        if ( aFilterData[nInd].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "Type" ) ) )
+                        if ( aFilterData[nInd].Name == "Type" )
                             aFilterData[nInd].Value >>= aTypeName;
 
-                    if ( aTypeName.getLength() )
+                    if ( !aTypeName.isEmpty() )
                     {
                         // find the mediatype
                         Reference< container::XNameAccess > xTypeDetection(
@@ -373,7 +374,7 @@ static OUString getMimetypeForDocument( const Reference< XMultiServiceFactory >&
                         Sequence< beans::PropertyValue > aTypeData;
                         xTypeDetection->getByName( aTypeName ) >>= aTypeData;
                         for ( sal_Int32 nInd = 0; nInd < aTypeData.getLength(); nInd++ )
-                            if ( aTypeData[nInd].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "MediaType" ) ) )
+                            if ( aTypeData[nInd].Name == "MediaType" )
                                 aTypeData[nInd].Value >>= aDocMimetype;
                     }
                 }
@@ -386,14 +387,13 @@ static OUString getMimetypeForDocument( const Reference< XMultiServiceFactory >&
 sal_Bool PDFExport::Export( const OUString& rFile, const Sequence< PropertyValue >& rFilterData )
 {
     INetURLObject   aURL( rFile );
-    OUString        aFile;
     sal_Bool        bRet = sal_False;
 
     std::set< PDFWriter::ErrorCode > aErrors;
 
     if( aURL.GetProtocol() != INET_PROT_FILE )
     {
-        String aTmp;
+        rtl::OUString aTmp;
 
         if( ::utl::LocalFileHelper::ConvertPhysicalNameToURL( rFile, aTmp ) )
             aURL = INetURLObject(aTmp);
@@ -452,105 +452,107 @@ sal_Bool PDFExport::Export( const OUString& rFile, const Sequence< PropertyValue
 
             for( sal_Int32 nData = 0, nDataCount = rFilterData.getLength(); nData < nDataCount; ++nData )
             {
-                if( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "PageRange" ) ) )
+                if ( rFilterData[ nData ].Name == "PageRange" )
                     rFilterData[ nData ].Value >>= aPageRange;
-                else if( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "Selection" ) ) )
+                else if ( rFilterData[ nData ].Name == "Selection" )
                     rFilterData[ nData ].Value >>= aSelection;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "UseLosslessCompression" ) ) )
+                else if ( rFilterData[ nData ].Name == "UseLosslessCompression" )
                     rFilterData[ nData ].Value >>= mbUseLosslessCompression;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "Quality" ) ) )
+                else if ( rFilterData[ nData ].Name == "Quality" )
                     rFilterData[ nData ].Value >>= mnQuality;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "ReduceImageResolution" ) ) )
+                else if ( rFilterData[ nData ].Name == "ReduceImageResolution" )
                     rFilterData[ nData ].Value >>= mbReduceImageResolution;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "IsSkipEmptyPages" ) ) )
+                else if ( rFilterData[ nData ].Name == "IsSkipEmptyPages" )
                     rFilterData[ nData ].Value >>= mbSkipEmptyPages;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "MaxImageResolution" ) ) )
+                else if ( rFilterData[ nData ].Name == "MaxImageResolution" )
                     rFilterData[ nData ].Value >>= mnMaxImageResolution;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "UseTaggedPDF" ) ) )
+                else if ( rFilterData[ nData ].Name == "UseTaggedPDF" )
                     rFilterData[ nData ].Value >>= mbUseTaggedPDF;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "SelectPdfVersion" ) ) )
+                else if ( rFilterData[ nData ].Name == "SelectPdfVersion" )
                     rFilterData[ nData ].Value >>= mnPDFTypeSelection;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "ExportNotes" ) ) )
+                else if ( rFilterData[ nData ].Name == "ExportNotes" )
                     rFilterData[ nData ].Value >>= mbExportNotes;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "ExportNotesPages" ) ) )
+                else if ( rFilterData[ nData ].Name == "ExportNotesPages" )
                     rFilterData[ nData ].Value >>= mbExportNotesPages;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "EmbedStandardFonts" ) ) )
+                else if ( rFilterData[ nData ].Name == "EmbedStandardFonts" )
                     rFilterData[ nData ].Value >>= mbEmbedStandardFonts;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "UseTransitionEffects" ) ) )
+                else if ( rFilterData[ nData ].Name == "UseTransitionEffects" )
                     rFilterData[ nData ].Value >>= mbUseTransitionEffects;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "ExportFormFields" ) ) )
+                else if ( rFilterData[ nData ].Name == "ExportFormFields" )
                     rFilterData[ nData ].Value >>= mbExportFormFields;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "FormsType" ) ) )
+                else if ( rFilterData[ nData ].Name == "FormsType" )
                     rFilterData[ nData ].Value >>= mnFormsFormat;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "AllowDuplicateFieldNames" ) ) )
+                else if ( rFilterData[ nData ].Name == "AllowDuplicateFieldNames" )
                     rFilterData[ nData ].Value >>= mbAllowDuplicateFieldNames;
 //viewer properties
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "HideViewerToolbar" ) ) )
+                else if ( rFilterData[ nData ].Name == "HideViewerToolbar" )
                     rFilterData[ nData ].Value >>= mbHideViewerToolbar;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "HideViewerMenubar" ) ) )
+                else if ( rFilterData[ nData ].Name == "HideViewerMenubar" )
                     rFilterData[ nData ].Value >>= mbHideViewerMenubar;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "HideViewerWindowControls" ) ) )
+                else if ( rFilterData[ nData ].Name == "HideViewerWindowControls" )
                     rFilterData[ nData ].Value >>= mbHideViewerWindowControls;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "ResizeWindowToInitialPage" ) ) )
+                else if ( rFilterData[ nData ].Name == "ResizeWindowToInitialPage" )
                     rFilterData[ nData ].Value >>= mbFitWindow;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "CenterWindow" ) ) )
+                else if ( rFilterData[ nData ].Name == "CenterWindow" )
                     rFilterData[ nData ].Value >>= mbCenterWindow;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "OpenInFullScreenMode" ) ) )
+                else if ( rFilterData[ nData ].Name == "OpenInFullScreenMode" )
                     rFilterData[ nData ].Value >>= mbOpenInFullScreenMode;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "DisplayPDFDocumentTitle" ) ) )
+                else if ( rFilterData[ nData ].Name == "DisplayPDFDocumentTitle" )
                     rFilterData[ nData ].Value >>= mbDisplayPDFDocumentTitle;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "InitialView" ) ) )
+                else if ( rFilterData[ nData ].Name == "InitialView" )
                     rFilterData[ nData ].Value >>= mnPDFDocumentMode;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "Magnification" ) ) )
+                else if ( rFilterData[ nData ].Name == "Magnification" )
                     rFilterData[ nData ].Value >>= mnPDFDocumentAction;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "Zoom" ) ) )
+                else if ( rFilterData[ nData ].Name == "Zoom" )
                     rFilterData[ nData ].Value >>= mnZoom;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "InitialPage" ) ) )
+                else if ( rFilterData[ nData ].Name == "InitialPage" )
                     rFilterData[ nData ].Value >>= mnInitialPage;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "PageLayout" ) ) )
+                else if ( rFilterData[ nData ].Name == "PageLayout" )
                     rFilterData[ nData ].Value >>= mnPDFPageLayout;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "FirstPageOnLeft" ) ) )
+                else if ( rFilterData[ nData ].Name == "FirstPageOnLeft" )
                     rFilterData[ nData ].Value >>= aContext.FirstPageLeft;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "IsAddStream" ) ) )
+                else if ( rFilterData[ nData ].Name == "IsAddStream" )
                     rFilterData[ nData ].Value >>= mbAddStream;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "Watermark" ) ) )
+                else if ( rFilterData[ nData ].Name == "Watermark" )
                 {
                     maWatermark = rFilterData[ nData ].Value;
                     mbWatermark = sal_True;
                 }
 //now all the security related properties...
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "EncryptFile" ) ) )
+                else if ( rFilterData[ nData ].Name == "EncryptFile" )
                     rFilterData[ nData ].Value >>= mbEncrypt;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "DocumentOpenPassword" ) ) )
+                else if ( rFilterData[ nData ].Name == "DocumentOpenPassword" )
                     rFilterData[ nData ].Value >>= aOpenPassword;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "RestrictPermissions" ) ) )
+                else if ( rFilterData[ nData ].Name == "RestrictPermissions" )
                     rFilterData[ nData ].Value >>= mbRestrictPermissions;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "PermissionPassword" ) ) )
+                else if ( rFilterData[ nData ].Name == "PermissionPassword" )
                     rFilterData[ nData ].Value >>= aPermissionPassword;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "PreparedPasswords" ) ) )
+                else if ( rFilterData[ nData ].Name == "PreparedPasswords" )
                     rFilterData[ nData ].Value >>= xEnc;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "PreparedPermissionPassword" ) ) )
+                else if ( rFilterData[ nData ].Name == "PreparedPermissionPassword" )
                     rFilterData[ nData ].Value >>= aPreparedPermissionPassword;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "Printing" ) ) )
+                else if ( rFilterData[ nData ].Name == "Printing" )
                     rFilterData[ nData ].Value >>= mnPrintAllowed;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "Changes" ) ) )
+                else if ( rFilterData[ nData ].Name == "Changes" )
                     rFilterData[ nData ].Value >>= mnChangesAllowed;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "EnableCopyingOfContent" ) ) )
+                else if ( rFilterData[ nData ].Name == "EnableCopyingOfContent" )
                     rFilterData[ nData ].Value >>= mbCanCopyOrExtract;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "EnableTextAccessForAccessibilityTools" ) ) )
+                else if ( rFilterData[ nData ].Name == "EnableTextAccessForAccessibilityTools" )
                     rFilterData[ nData ].Value >>= mbCanExtractForAccessibility;
 //--->i56629 links extra (relative links and other related stuff)
-                 else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "ExportLinksRelativeFsys" ) ) )
+                 else if ( rFilterData[ nData ].Name == "ExportLinksRelativeFsys" )
                      rFilterData[ nData ].Value >>= mbExportRelativeFsysLinks;
-                 else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "PDFViewSelection" ) ) )
+                 else if ( rFilterData[ nData ].Name == "PDFViewSelection" )
                      rFilterData[ nData ].Value >>= mnDefaultLinkAction;
-                 else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "ConvertOOoTargetToPDFTarget" ) ) )
+                 else if ( rFilterData[ nData ].Name == "ConvertOOoTargetToPDFTarget" )
                      rFilterData[ nData ].Value >>= mbConvertOOoTargetToPDFTarget;
-                  else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "ExportBookmarksToPDFDestination" ) ) )
+                  else if ( rFilterData[ nData ].Name == "ExportBookmarksToPDFDestination" )
                       rFilterData[ nData ].Value >>= mbExportBmkToDest;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "ExportBookmarks" ) ) )
+                else if ( rFilterData[ nData ].Name == "ExportBookmarks" )
                     rFilterData[ nData ].Value >>= mbExportBookmarks;
-                else if ( rFilterData[ nData ].Name == OUString( RTL_CONSTASCII_USTRINGPARAM( "OpenBookmarkLevels" ) ) )
+                else if ( rFilterData[ nData ].Name == "ExportHiddenSlides" )
+                    rFilterData[ nData ].Value >>= mbExportHiddenSlides;
+                else if ( rFilterData[ nData ].Name == "OpenBookmarkLevels" )
                     rFilterData[ nData ].Value >>= mnOpenBookmarkLevels;
             }
             aContext.URL        = aURL.GetMainURL(INetURLObject::DECODE_TO_IURI);
@@ -658,7 +660,7 @@ sal_Bool PDFExport::Export( const OUString& rFile, const Sequence< PropertyValue
 
 //set check for permission change password
 // if not enabled and no permission password, force permissions to default as if PDF where without encryption
-                if( mbRestrictPermissions && (xEnc.is() || aPermissionPassword.getLength() > 0) )
+                if( mbRestrictPermissions && (xEnc.is() || !aPermissionPassword.isEmpty()) )
                 {
                     mbEncrypt = sal_True;
 //permission set as desired, done after
@@ -710,7 +712,7 @@ sal_Bool PDFExport::Export( const OUString& rFile, const Sequence< PropertyValue
                 aContext.Encryption.CanExtractForAccessibility  = mbCanExtractForAccessibility;
                 if( mbEncrypt && ! xEnc.is() )
                     xEnc = PDFWriter::InitEncryption( aPermissionPassword, aOpenPassword, aContext.Encryption.Security128bit );
-                if( mbEncrypt && aPermissionPassword.getLength() && ! aPreparedPermissionPassword.getLength() )
+                if( mbEncrypt && !aPermissionPassword.isEmpty() && ! aPreparedPermissionPassword.getLength() )
                     aPreparedPermissionPassword = comphelper::OStorageHelper::CreatePackageEncryptionData( aPermissionPassword );
             }
             // after this point we don't need the legacy clear passwords anymore
@@ -809,6 +811,7 @@ sal_Bool PDFExport::Export( const OUString& rFile, const Sequence< PropertyValue
                 pPDFExtOutDevData->SetFormsFormat( mnFormsFormat );
                 pPDFExtOutDevData->SetIsExportFormFields( mbExportFormFields );
                 pPDFExtOutDevData->SetIsExportBookmarks( mbExportBookmarks );
+                pPDFExtOutDevData->SetIsExportHiddenSlides( mbExportHiddenSlides );
                 pPDFExtOutDevData->SetIsLosslessCompression( mbUseLosslessCompression );
                 pPDFExtOutDevData->SetIsReduceImageResolution( mbReduceImageResolution );
                 pPDFExtOutDevData->SetIsExportNamedDestinations( mbExportBmkToDest );
@@ -828,7 +831,7 @@ sal_Bool PDFExport::Export( const OUString& rFile, const Sequence< PropertyValue
                 aRenderOptions[ 5 ].Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "PageRange" ) );
                 aRenderOptions[ 5 ].Value <<= aPageRange;
 
-                if( aPageRange.getLength() || !aSelection.hasValue() )
+                if( !aPageRange.isEmpty() || !aSelection.hasValue() )
                 {
                     aSelection = Any();
                     aSelection <<= mxSrcDoc;
@@ -866,7 +869,7 @@ sal_Bool PDFExport::Export( const OUString& rFile, const Sequence< PropertyValue
                         bSecondPassForImpressNotes = sal_True;      // the export notes checkbox needs to be disabled
                 }
 
-                if( !aPageRange.getLength() )
+                if( aPageRange.isEmpty() )
                 {
                     aPageRange = OUStringBuffer()
                         .append( static_cast< sal_Int32 >( 1 ) )
@@ -903,7 +906,7 @@ sal_Bool PDFExport::Export( const OUString& rFile, const Sequence< PropertyValue
 
                 // if during the export the doc locale was set copy it to PDF writer
                 const com::sun::star::lang::Locale& rLoc( pPDFExtOutDevData->GetDocumentLocale() );
-                if( rLoc.Language.getLength() )
+                if( !rLoc.Language.isEmpty() )
                     pPDFWriter->SetDocumentLocale( rLoc );
 
                 if( bRet )
