@@ -112,7 +112,7 @@ namespace svt
             createPicker();
 
         // set the title
-        if ( m_aTitle.getLength() > 0 )
+        if ( !m_aTitle.isEmpty() )
             getDialog()->SetText( m_aTitle );
     }
 
@@ -218,7 +218,7 @@ namespace svt
             if ( m_pDlg )
             {
                 // synchronize the help id of the dialog with out help URL property
-                if ( m_sHelpURL.getLength() )
+                if ( !m_sHelpURL.isEmpty() )
                 {   // somebody already set the help URL while we had no dialog yet
                     OControlAccess::setHelpURL( m_pDlg, m_sHelpURL, sal_False );
                 }
@@ -401,7 +401,7 @@ namespace svt
     }
 
     //---------------------------------------------------------------------
-    IMPL_LINK( OCommonPicker, OnCancelPicker, void*, EMPTYARG )
+    IMPL_LINK_NOARG(OCommonPicker, OnCancelPicker)
     {
         // By definition, the solar mutex is locked when we arrive here. Note that this
         // is important, as for instance the consistency of m_pDlg depends on this mutex.
@@ -445,7 +445,7 @@ namespace svt
         {
             if ( *pArgument >>= aPropArg )
             {
-                if ( aPropArg.Name.getLength() <= 0)
+                if ( aPropArg.Name.isEmpty())
                     continue;
 
                 sSettingName = aPropArg.Name;
@@ -453,7 +453,7 @@ namespace svt
             }
             else if ( *pArgument >>= aPairArg )
             {
-                if ( aPairArg.Name.getLength() <= 0)
+                if ( aPairArg.Name.isEmpty())
                     continue;
 
                 sSettingName = aPairArg.Name;
@@ -488,7 +488,7 @@ namespace svt
     sal_Bool OCommonPicker::implHandleInitializationArgument( const ::rtl::OUString& _rName, const Any& _rValue ) SAL_THROW( ( Exception, RuntimeException ) )
     {
         sal_Bool bKnown = sal_True;
-        if ( _rName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "ParentWindow" ) ) )
+        if ( _rName == "ParentWindow" )
         {
             m_xDialogParent.clear();
             OSL_VERIFY( _rValue >>= m_xDialogParent );
