@@ -26,6 +26,9 @@
  *
  ************************************************************************/
 
+#if defined _WIN32_WINNT
+#   undef _WIN32_WINNT
+#endif
 #define _WIN32_WINNT 0x0500
 
 
@@ -58,7 +61,7 @@ namespace /* private */
     const size_t MAX_FILETITLE_BUFF_SIZE = 32000;
     const size_t MAX_FILTER_BUFF_SIZE    = 4096;
 
-    const LPTSTR CURRENT_INSTANCE = TEXT("CurrInst");
+    const LPCTSTR CURRENT_INSTANCE = TEXT("CurrInst");
 
     //------------------------------------------
     // find an appropriate parent window
