@@ -125,7 +125,7 @@ static const sal_Int32  RESOURCEURL_PREFIX_SIZE = 17;
 static sal_Int16 RetrieveTypeFromResourceURL( const rtl::OUString& aResourceURL )
 {
 
-    if (( aResourceURL.indexOf( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( RESOURCEURL_PREFIX ))) == 0 ) &&
+    if (( aResourceURL.indexOf( rtl::OUString( RESOURCEURL_PREFIX )) == 0 ) &&
         ( aResourceURL.getLength() > RESOURCEURL_PREFIX_SIZE ))
     {
         rtl::OUString aTmpStr     = aResourceURL.copy( RESOURCEURL_PREFIX_SIZE );
@@ -146,7 +146,7 @@ static sal_Int16 RetrieveTypeFromResourceURL( const rtl::OUString& aResourceURL
 
 static rtl::OUString RetrieveNameFromResourceURL( const rtl::OUString& aResourceURL )
 {
-    if (( aResourceURL.indexOf( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( RESOURCEURL_PREFIX ))) == 0 ) &&
+    if (( aResourceURL.indexOf( rtl::OUString( RESOURCEURL_PREFIX )) == 0 ) &&
         ( aResourceURL.getLength() > RESOURCEURL_PREFIX_SIZE ))
     {
         sal_Int32 nIndex = aResourceURL.lastIndexOf( '/' );
@@ -215,8 +215,8 @@ void UIConfigurationManager::impl_preloadUIElementTypeList( sal_Int16 nElementTy
                     rtl::OUString aExtension( aUIElementNames[n].copy( nIndex+1 ));
                     rtl::OUString aUIElementName( aUIElementNames[n].copy( 0, nIndex ));
 
-                    if (( aUIElementName.getLength() > 0 ) &&
-                        ( aExtension.equalsIgnoreAsciiCaseAsciiL( "xml", 3 )))
+                    if (!aUIElementName.isEmpty() &&
+                        ( aExtension.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("xml"))))
                     {
                         aUIElementData.aResourceURL = aResURLPrefix + aUIElementName;
                         aUIElementData.aName        = aUIElementNames[n];
@@ -240,7 +240,7 @@ void UIConfigurationManager::impl_requestUIElementData( sal_Int16 nElementType,
     UIElementType& rElementTypeData = m_aUIElements[nElementType];
 
     Reference< XStorage > xElementTypeStorage = rElementTypeData.xStorage;
-    if ( xElementTypeStorage.is() && aUIElementData.aName.getLength() )
+    if ( xElementTypeStorage.is() && !aUIElementData.aName.isEmpty() )
     {
         try
         {
@@ -267,7 +267,7 @@ void UIConfigurationManager::impl_requestUIElementData( sal_Int16 nElementType,
                                 aUIElementData.xSettings = Reference< XIndexAccess >( static_cast< OWeakObject * >( new ConstItemContainer( xContainer, sal_True ) ), UNO_QUERY );
                             return;
                         }
-                        catch ( ::com::sun::star::lang::WrappedTargetException& )
+                        catch ( const ::com::sun::star::lang::WrappedTargetException& )
                         {
                         }
                     }
@@ -288,7 +288,7 @@ void UIConfigurationManager::impl_requestUIElementData( sal_Int16 nElementType,
                             aUIElementData.xSettings = Reference< XIndexAccess >( static_cast< OWeakObject * >( new ConstItemContainer( pRootItemContainer, sal_True ) ), UNO_QUERY );
                             return;
                         }
-                        catch ( ::com::sun::star::lang::WrappedTargetException& )
+                        catch ( const ::com::sun::star::lang::WrappedTargetException& )
                         {
                         }
 
@@ -305,7 +305,7 @@ void UIConfigurationManager::impl_requestUIElementData( sal_Int16 nElementType,
                             aUIElementData.xSettings = Reference< XIndexAccess >( static_cast< OWeakObject * >( new ConstItemContainer( pRootItemContainer, sal_True ) ), UNO_QUERY );
                             return;
                         }
-                        catch ( ::com::sun::star::lang::WrappedTargetException& )
+                        catch ( const ::com::sun::star::lang::WrappedTargetException& )
                         {
                         }
 
@@ -319,16 +319,16 @@ void UIConfigurationManager::impl_requestUIElementData( sal_Int16 nElementType,
                 }
             }
         }
-        catch ( ::com::sun::star::embed::InvalidStorageException& )
+        catch ( const ::com::sun::star::embed::InvalidStorageException& )
         {
         }
-        catch ( ::com::sun::star::lang::IllegalArgumentException& )
+        catch ( const ::com::sun::star::lang::IllegalArgumentException& )
         {
         }
-        catch ( ::com::sun::star::io::IOException& )
+        catch ( const ::com::sun::star::io::IOException& )
         {
         }
-        catch ( ::com::sun::star::embed::StorageWrappedTargetException& )
+        catch ( const ::com::sun::star::embed::StorageWrappedTargetException& )
         {
         }
     }
@@ -393,7 +393,7 @@ void UIConfigurationManager::impl_storeElementTypeData( Reference< XStorage >& x
                                 MenuConfiguration aMenuCfg( m_xServiceManager );
                                 aMenuCfg.StoreMenuBarConfigurationToXML( rElement.xSettings, xOutputStream );
                             }
-                            catch ( ::com::sun::star::lang::WrappedTargetException& )
+                            catch ( const ::com::sun::star::lang::WrappedTargetException& )
                             {
                             }
                         }
@@ -405,7 +405,7 @@ void UIConfigurationManager::impl_storeElementTypeData( Reference< XStorage >& x
                             {
                                 ToolBoxConfiguration::StoreToolBox( m_xServiceManager, xOutputStream, rElement.xSettings );
                             }
-                            catch ( ::com::sun::star::lang::WrappedTargetException& )
+                            catch ( const ::com::sun::star::lang::WrappedTargetException& )
                             {
                             }
                         }
@@ -417,7 +417,7 @@ void UIConfigurationManager::impl_storeElementTypeData( Reference< XStorage >& x
                             {
                                 StatusBarConfiguration::StoreStatusBar( m_xServiceManager, xOutputStream, rElement.xSettings );
                             }
-                            catch ( ::com::sun::star::lang::WrappedTargetException& )
+                            catch ( const ::com::sun::star::lang::WrappedTargetException& )
                             {
                             }
                         }
@@ -563,19 +563,19 @@ void UIConfigurationManager::impl_Initialize()
             {
                 xElementTypeStorage = m_xDocConfigStorage->openStorageElement( rtl::OUString::createFromAscii( UIELEMENTTYPENAMES[i] ), nModes );
             }
-            catch ( com::sun::star::container::NoSuchElementException& )
+            catch ( const com::sun::star::container::NoSuchElementException& )
             {
             }
-            catch ( ::com::sun::star::embed::InvalidStorageException& )
+            catch ( const ::com::sun::star::embed::InvalidStorageException& )
             {
             }
-            catch ( ::com::sun::star::lang::IllegalArgumentException& )
+            catch ( const ::com::sun::star::lang::IllegalArgumentException& )
             {
             }
-            catch ( ::com::sun::star::io::IOException& )
+            catch ( const ::com::sun::star::io::IOException& )
             {
             }
-            catch ( ::com::sun::star::embed::StorageWrappedTargetException& )
+            catch ( const ::com::sun::star::embed::StorageWrappedTargetException& )
             {
             }
 
@@ -601,9 +601,9 @@ UIConfigurationManager::UIConfigurationManager( com::sun::star::uno::Reference<
     , m_bModified( false )
     , m_bConfigRead( false )
     , m_bDisposed( false )
-    , m_aXMLPostfix( RTL_CONSTASCII_USTRINGPARAM( ".xml" ))
-    , m_aPropUIName( RTL_CONSTASCII_USTRINGPARAM( "UIName" ))
-    , m_aPropResourceURL( RTL_CONSTASCII_USTRINGPARAM( "ResourceURL" ))
+    , m_aXMLPostfix( ".xml" )
+    , m_aPropUIName( "UIName" )
+    , m_aPropResourceURL( "ResourceURL" )
     , m_xServiceManager( xServiceManager )
     , m_aListenerContainer( m_aLock.getShareableOslMutex() )
 {
@@ -631,7 +631,7 @@ void SAL_CALL UIConfigurationManager::dispose() throw (::com::sun::star::uno::Ru
             if ( m_xImageManager.is() )
                 m_xImageManager->dispose();
         }
-        catch ( Exception& )
+        catch ( const Exception& )
         {
         }
 
@@ -755,16 +755,16 @@ void SAL_CALL UIConfigurationManager::reset() throw (::com::sun::star::uno::Runt
             for ( sal_uInt32 k = 0; k < aRemoveEventNotifyContainer.size(); k++ )
                 implts_notifyContainerListener( aRemoveEventNotifyContainer[k], NotifyOp_Remove );
         }
-        catch ( ::com::sun::star::lang::IllegalArgumentException& )
+        catch ( const ::com::sun::star::lang::IllegalArgumentException& )
         {
         }
-        catch ( ::com::sun::star::container::NoSuchElementException& )
+        catch ( const ::com::sun::star::container::NoSuchElementException& )
         {
         }
-        catch ( ::com::sun::star::embed::InvalidStorageException& )
+        catch ( const ::com::sun::star::embed::InvalidStorageException& )
         {
         }
-        catch ( ::com::sun::star::embed::StorageWrappedTargetException& )
+        catch ( const ::com::sun::star::embed::StorageWrappedTargetException& )
         {
         }
     }
@@ -1072,10 +1072,10 @@ Reference< XInterface > SAL_CALL UIConfigurationManager::getImageManager() throw
 
         Sequence< Any > aPropSeq( 2 );
         PropertyValue aPropValue;
-        aPropValue.Name  = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "UserConfigStorage" ));
+        aPropValue.Name  = rtl::OUString( "UserConfigStorage" );
         aPropValue.Value = makeAny( m_xDocConfigStorage );
         aPropSeq[0] = makeAny( aPropValue );
-        aPropValue.Name  = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ModuleIdentifier" ));
+        aPropValue.Name  = rtl::OUString( "ModuleIdentifier" );
         aPropValue.Value = makeAny( m_aModuleIdentifier );
         aPropSeq[1] = makeAny( aPropValue );
 
@@ -1103,7 +1103,7 @@ Reference< XInterface > SAL_CALL UIConfigurationManager::getShortCutManager() th
     Reference< XInitialization > xInit      (xAccConfig, UNO_QUERY_THROW);
 
     PropertyValue aProp;
-    aProp.Name    = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("DocumentRoot"));
+    aProp.Name    = ::rtl::OUString("DocumentRoot");
     aProp.Value <<= xDocumentRoot;
 
     Sequence< Any > lArgs(1);
@@ -1142,7 +1142,7 @@ void SAL_CALL UIConfigurationManager::setStorage( const Reference< XStorage >& S
             if ( xComponent.is() )
                 xComponent->dispose();
         }
-        catch ( Exception& )
+        catch ( const Exception& )
         {
         }
     }
@@ -1170,14 +1170,14 @@ void SAL_CALL UIConfigurationManager::setStorage( const Reference< XStorage >& S
             try
             {
                 long nOpenMode = 0;
-                Any a = xPropSet->getPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "OpenMode" )));
+                Any a = xPropSet->getPropertyValue( rtl::OUString( "OpenMode" ));
                 if ( a >>= nOpenMode )
                     m_bReadOnly = !( nOpenMode & ElementModes::WRITE );
             }
-            catch ( com::sun::star::beans::UnknownPropertyException& )
+            catch ( const com::sun::star::beans::UnknownPropertyException& )
             {
             }
-            catch ( com::sun::star::lang::WrappedTargetException& )
+            catch ( const com::sun::star::lang::WrappedTargetException& )
             {
             }
         }
@@ -1217,7 +1217,7 @@ void SAL_CALL UIConfigurationManager::reload() throw (::com::sun::star::uno::Exc
                 if ( rDocElementType.bModified )
                     impl_reloadElementTypeData( rDocElementType, aRemoveNotifyContainer, aReplaceNotifyContainer );
             }
-            catch ( Exception& )
+            catch ( const Exception& )
             {
                 throw IOException();
             }
@@ -1256,7 +1256,7 @@ void SAL_CALL UIConfigurationManager::store() throw (::com::sun::star::uno::Exce
                 if ( rElementType.bModified && xStorage.is() )
                     impl_storeElementTypeData( xStorage, rElementType );
             }
-            catch ( Exception& )
+            catch ( const Exception& )
             {
                 throw IOException();
             }
@@ -1290,7 +1290,7 @@ void SAL_CALL UIConfigurationManager::storeToStorage( const Reference< XStorage
                 if ( rElementType.bModified && xElementTypeStorage.is() )
                     impl_storeElementTypeData( xElementTypeStorage, rElementType, false ); // store data to storage, but don't reset modify flag!
             }
-            catch ( Exception& )
+            catch ( const Exception& )
             {
                 throw IOException();
             }
@@ -1339,7 +1339,7 @@ void UIConfigurationManager::implts_notifyContainerListener( const Configuration
                         break;
                 }
             }
-            catch( css::uno::RuntimeException& )
+            catch( const css::uno::RuntimeException& )
             {
                 pIterator.remove();
             }
