@@ -64,13 +64,11 @@
 #include <vcl/svapp.hxx>
 #include <vcl/i18nhelp.hxx>
 #include <vcl/image.hxx>
-#include <tools/urlobj.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <toolkit/unohlp.hxx>
 #include <vcl/window.hxx>
 #include <svtools/menuoptions.hxx>
 #include <unotools/cmdoptions.hxx>
-#include <dispatch/uieventloghelper.hxx>
 #include <rtl/logfile.hxx>
 #include <svtools/miscopt.hxx>
 
@@ -121,8 +119,6 @@ sal_Bool CompareToolBarEntry( const ToolBarEntry& aOne, const ToolBarEntry& aTwo
 
     if ( nComp < 0 )
         return sal_True;
-    else if ( nComp > 0 )
-        return sal_False;
     else
         return sal_False;
 }
@@ -134,9 +130,9 @@ Reference< XLayoutManager > getLayoutManagerFromFrame( const Reference< XFrame >
 
     try
     {
-        xPropSet->getPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "LayoutManager" ))) >>= xLayoutManager;
+        xPropSet->getPropertyValue( rtl::OUString( "LayoutManager" )) >>= xLayoutManager;
     }
-    catch ( UnknownPropertyException& )
+    catch ( const UnknownPropertyException& )
     {
     }
 
@@ -159,8 +155,8 @@ DEFINE_INIT_SERVICE                     (   ToolbarsMenuController, {} )
 
 ToolbarsMenuController::ToolbarsMenuController( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory >& xServiceManager ) :
     svt::PopupMenuControllerBase( xServiceManager ),
-    m_aPropUIName( RTL_CONSTASCII_USTRINGPARAM( "UIName" )),
-    m_aPropResourceURL( RTL_CONSTASCII_USTRINGPARAM( "ResourceURL" )),
+    m_aPropUIName( "UIName" ),
+    m_aPropResourceURL( "ResourceURL" ),
     m_bModuleIdentified( sal_False ),
     m_bResetActive( sal_False ),
     m_aIntlWrapper( xServiceManager, Application::GetSettings().GetLocale() )
@@ -177,7 +173,7 @@ void ToolbarsMenuController::addCommand(
     sal_uInt16        nItemId    = m_xPopupMenu->getItemCount()+1;
 
     rtl::OUString aLabel;
-    if ( rLabel.getLength() == 0 )
+    if ( rLabel.isEmpty() )
         aLabel = getUINameFromCommand( rCommandURL );
     else
         aLabel = rLabel;
@@ -186,7 +182,7 @@ void ToolbarsMenuController::addCommand(
     Reference< awt::XMenuExtended > xMenuExtended( m_xPopupMenu, UNO_QUERY );
     xMenuExtended->setCommand( nItemId, rCommandURL );
 
-    bool bInternal = ( rCommandURL.indexOf( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( STATIC_INTERNAL_CMD_PART ))) == 0);
+    bool bInternal = ( rCommandURL.indexOf( rtl::OUString( STATIC_INTERNAL_CMD_PART )) == 0);
     if ( !bInternal )
     {
         if ( !getDispatchFromCommandURL( rCommandURL ).is() )
@@ -250,7 +246,7 @@ rtl::OUString ToolbarsMenuController::getUINameFromCommand( const rtl::OUString&
                                                                 UNO_QUERY );
             xNameAccess->getByName( m_aModuleIdentifier ) >>= m_xUICommandDescription;
         }
-        catch ( Exception& )
+        catch ( const Exception& )
         {
         }
     }
@@ -265,7 +261,7 @@ rtl::OUString ToolbarsMenuController::getUINameFromCommand( const rtl::OUString&
             {
                 for ( sal_Int32 i = 0; i < aPropSeq.getLength(); i++ )
                 {
-                    if ( aPropSeq[i].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "Label" ) ))
+                    if ( aPropSeq[i].Name == "Label" )
                     {
                         aPropSeq[i].Value >>= aStr;
                         break;
@@ -274,7 +270,7 @@ rtl::OUString ToolbarsMenuController::getUINameFromCommand( const rtl::OUString&
             }
             aLabel = aStr;
         }
-        catch ( Exception& )
+        catch ( const Exception& )
         {
         }
     }
@@ -298,7 +294,7 @@ static void fillHashMap( const Sequence< Sequence< ::com::sun::star::beans::Prop
                 pProperties[j].Value >>= aUIName;
         }
 
-        if ( aResourceURL.getLength() > 0 &&
+        if ( !aResourceURL.isEmpty() &&
              rHashMap.find( aResourceURL ) == rHashMap.end() )
             rHashMap.insert( ToolbarHashMap::value_type( aResourceURL, aUIName ));
     }
@@ -319,11 +315,11 @@ Sequence< Sequence< com::sun::star::beans::PropertyValue > > ToolbarsMenuControl
             {
                 rtl::OUString   aResName;
                 sal_Int16       nType( -1 );
-                xPropSet->getPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Type" ))) >>= nType;
-                xPropSet->getPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ResourceURL" ))) >>= aResName;
+                xPropSet->getPropertyValue( rtl::OUString( "Type" )) >>= nType;
+                xPropSet->getPropertyValue( rtl::OUString( "ResourceURL" )) >>= aResName;
 
                 if (( nType == ::com::sun::star::ui::UIElementType::TOOLBAR ) &&
-                    ( aResName.getLength() > 0 ))
+                    !aResName.isEmpty() )
                 {
                     ToolBarInfo aToolBarInfo;
 
@@ -338,7 +334,7 @@ Sequence< Sequence< com::sun::star::beans::PropertyValue > > ToolbarsMenuControl
                     aToolBarArray.push_back( aToolBarInfo );
                 }
             }
-            catch ( Exception& )
+            catch ( const Exception& )
             {
             }
         }
@@ -400,7 +396,7 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
         }
 
         std::vector< ToolBarEntry > aSortedTbs;
-        rtl::OUString               aStaticCmdPart( RTL_CONSTASCII_USTRINGPARAM( STATIC_CMD_PART ));
+        rtl::OUString               aStaticCmdPart( STATIC_CMD_PART );
 
         Sequence< Sequence< com::sun::star::beans::PropertyValue > > aSeqFrameToolBars = getLayoutManagerToolbars( xLayoutManager );
         fillHashMap( aSeqFrameToolBars, aToolbarHashMap );
@@ -412,7 +408,7 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
             sal_Bool      bHideFromMenu( sal_False );
             sal_Bool      bContextSensitive( sal_False );
             sal_Bool      bVisible( sal_False );
-            if ( aUIName.getLength() == 0 &&
+            if ( aUIName.isEmpty() &&
                  m_xPersistentWindowState.is() )
             {
                 try
@@ -435,7 +431,7 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
                         }
                     }
                 }
-                catch ( Exception& )
+                catch ( const Exception& )
                 {
                 }
 
@@ -445,7 +441,7 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
 
             }
 
-            if (( aUIName.getLength() > 0 ) && ( !bHideFromMenu ))
+            if ( !aUIName.isEmpty() && !bHideFromMenu )
             {
                 ToolBarEntry aTbEntry;
                 aTbEntry.aUIName = aUIName;
@@ -455,7 +451,7 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
                 aTbEntry.pCollatorWrapper = m_aIntlWrapper.getCaseCollator();
                 aSortedTbs.push_back( aTbEntry );
             }
-            pIter++;
+            ++pIter;
         }
 
         // sort toolbars
@@ -503,21 +499,21 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
         {
             if ( m_aModuleIdentifier.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.drawing.DrawingDocument" ) ) ||
                  m_aModuleIdentifier.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.presentation.PresentationDocument" ) ))
-                addCommand( m_xPopupMenu, rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( CMD_COLORBAR )), aEmptyString );
-            else if ( m_aModuleIdentifier.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.sheet.SpreadsheetDocument" ) ))
-                addCommand( m_xPopupMenu, rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( CMD_INPUTLINEBAR )), aEmptyString );
+                addCommand( m_xPopupMenu, rtl::OUString( CMD_COLORBAR ), aEmptyString );
+            else if ( m_aModuleIdentifier == "com.sun.star.sheet.SpreadsheetDocument" )
+                addCommand( m_xPopupMenu, rtl::OUString( CMD_INPUTLINEBAR ), aEmptyString );
             else
-                addCommand( m_xPopupMenu, rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( CMD_FORMULABAR )), aEmptyString );
+                addCommand( m_xPopupMenu, rtl::OUString( CMD_FORMULABAR ), aEmptyString );
         }
 
         sal_Bool          bAddCommand( sal_True );
         SvtCommandOptions aCmdOptions;
-        rtl::OUString     aConfigureToolbar( RTL_CONSTASCII_USTRINGPARAM( CONFIGURE_TOOLBARS ));
+        rtl::OUString     aConfigureToolbar( CONFIGURE_TOOLBARS );
 
         if ( aCmdOptions.HasEntries( SvtCommandOptions::CMDOPTION_DISABLED ))
         {
             if ( aCmdOptions.Lookup( SvtCommandOptions::CMDOPTION_DISABLED,
-                                     rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( CONFIGURE_TOOLBARS_CMD ))))
+                                     rtl::OUString( CONFIGURE_TOOLBARS_CMD )))
                 bAddCommand = sal_False;
         }
 
@@ -545,7 +541,7 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
         }
 
         String aLabelStr = String( FwkResId( STR_RESTORE_TOOLBARS ));
-        rtl::OUString aRestoreCmd( RTL_CONSTASCII_USTRINGPARAM( CMD_RESTOREVISIBILITY ));
+        rtl::OUString aRestoreCmd( CMD_RESTOREVISIBILITY );
         addCommand( m_xPopupMenu, aRestoreCmd, aLabelStr );
     }
 }
@@ -642,7 +638,7 @@ void SAL_CALL ToolbarsMenuController::select( const css::awt::MenuEvent& rEvent
             PopupMenu* pVCLPopupMenu = (PopupMenu *)pPopupMenu->GetMenu();
 
             rtl::OUString aCmd( pVCLPopupMenu->GetItemCommand( rEvent.MenuId ));
-            if ( aCmd.indexOf( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( STATIC_INTERNAL_CMD_PART ))) == 0 )
+            if ( aCmd.indexOf( rtl::OUString( STATIC_INTERNAL_CMD_PART )) == 0 )
             {
                 // Command to restore the visibility of all context sensitive toolbars
                 Reference< XNameReplace > xNameReplace( xPersistentWindowState, UNO_QUERY );
@@ -686,7 +682,7 @@ void SAL_CALL ToolbarsMenuController::select( const css::awt::MenuEvent& rEvent
                                     }
                                 }
                             }
-                            catch ( NoSuchElementException& )
+                            catch ( const NoSuchElementException& )
                             {
                             }
                         }
@@ -701,12 +697,12 @@ void SAL_CALL ToolbarsMenuController::select( const css::awt::MenuEvent& rEvent
                                 {
                                     try
                                     {
-                                        xPropSet->setPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "RefreshContextToolbarVisibility" )), makeAny( sal_True ));
+                                        xPropSet->setPropertyValue( rtl::OUString( "RefreshContextToolbarVisibility" ), makeAny( sal_True ));
                                     }
-                                    catch ( RuntimeException& )
+                                    catch ( const RuntimeException& )
                                     {
                                     }
-                                    catch ( Exception& )
+                                    catch ( const Exception& )
                                     {
                                     }
                                 }
@@ -714,16 +710,16 @@ void SAL_CALL ToolbarsMenuController::select( const css::awt::MenuEvent& rEvent
                             RefreshToolbars( xFrame );
                         }
                     }
-                    catch ( RuntimeException& )
+                    catch ( const RuntimeException& )
                     {
                         throw;
                     }
-                    catch ( Exception& )
+                    catch ( const Exception& )
                     {
                     }
                 }
             }
-            else if ( aCmd.indexOf( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( STATIC_CMD_PART ))) < 0 )
+            else if ( aCmd.indexOf( rtl::OUString( STATIC_CMD_PART )) < 0 )
             {
                 URL                     aTargetURL;
                 Sequence<PropertyValue> aArgs;
@@ -740,8 +736,6 @@ void SAL_CALL ToolbarsMenuController::select( const css::awt::MenuEvent& rEvent
                     pExecuteInfo->xDispatch     = xDispatch;
                     pExecuteInfo->aTargetURL    = aTargetURL;
                     pExecuteInfo->aArgs         = aArgs;
-                    if(::comphelper::UiEventsLogger::isEnabled()) //#i88653#
-                        UiEventLogHelper(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ToolbarsMenuController"))).log(m_xServiceManager, m_xFrame, aTargetURL, aArgs);
                     Application::PostUserEvent( STATIC_LINK(0, ToolbarsMenuController, ExecuteHdl_Impl), pExecuteInfo );
                 }
             }
@@ -793,7 +787,7 @@ void SAL_CALL ToolbarsMenuController::activate( const css::awt::MenuEvent& ) thr
     const sal_uInt32 nCount = aCmdVector.size();
     for ( sal_uInt32 i = 0; i < nCount; i++ )
     {
-        bool bInternal = ( aCmdVector[i].indexOf( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( STATIC_INTERNAL_CMD_PART ))) == 0);
+        bool bInternal = ( aCmdVector[i].indexOf( rtl::OUString( STATIC_INTERNAL_CMD_PART )) == 0);
 
         if ( !bInternal )
         {
@@ -803,8 +797,8 @@ void SAL_CALL ToolbarsMenuController::activate( const css::awt::MenuEvent& ) thr
             Reference< XDispatch > xDispatch = xDispatchProvider->queryDispatch( aTargetURL, ::rtl::OUString(), 0 );
             if ( xDispatch.is() )
             {
-                xDispatch->addStatusListener( SAL_STATIC_CAST( XStatusListener*, this ), aTargetURL );
-                xDispatch->removeStatusListener( SAL_STATIC_CAST( XStatusListener*, this ), aTargetURL );
+                xDispatch->addStatusListener( (static_cast< XStatusListener* >(this)), aTargetURL );
+                xDispatch->removeStatusListener( (static_cast< XStatusListener* >(this)), aTargetURL );
             }
         }
         else if ( aCmdVector[i].equalsAscii( CMD_RESTOREVISIBILITY ))
@@ -881,7 +875,7 @@ void SAL_CALL ToolbarsMenuController::initialize( const Sequence< Any >& aArgume
                     }
                     m_aModuleIdentifier = aModuleIdentifier;
                 }
-                catch ( Exception& )
+                catch ( const Exception& )
                 {
                 }
             }
@@ -901,7 +895,7 @@ IMPL_STATIC_LINK_NOINSTANCE( ToolbarsMenuController, ExecuteHdl_Impl, ExecuteInf
             pExecuteInfo->xDispatch->dispatch( pExecuteInfo->aTargetURL, pExecuteInfo->aArgs );
         }
     }
-    catch ( Exception& )
+    catch ( const Exception& )
     {
     }
 
