@@ -71,7 +71,7 @@
 
 #define CCLASS_ALL
 #include <characterclassificationImpl.hxx>
-#include <scripttypedetector.hxx>
+#include <unoscripttypedetector.hxx>
 #include <cclass_unicode.hxx>
 
 #define COLLATOR_ALL
@@ -91,7 +91,7 @@
 #define IMPL_CREATEINSTANCE( ImplName ) \
     ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >   \
         SAL_CALL ImplName##_CreateInstance(                                 \
-            const ::com::sun::star::uno::Reference<                         \
+            SAL_UNUSED_PARAMETER const ::com::sun::star::uno::Reference<    \
                     ::com::sun::star::lang::XMultiServiceFactory >& )       \
 {                                                                           \
     return ::com::sun::star::uno::Reference <                               \
@@ -157,7 +157,7 @@ IMPL_CREATEINSTANCE( Collator_Unicode )
 IMPL_CREATEINSTANCE_MSF( CharacterClassificationImpl )
 IMPL_CREATEINSTANCE_MSF( cclass_Unicode )
 IMPL_CREATEINSTANCE_MSF( TransliterationImpl )
-IMPL_CREATEINSTANCE( ScriptTypeDetector )
+IMPL_CREATEINSTANCE( UnoScriptTypeDetector )
 
 IMPL_CREATEINSTANCE_MSF( InputSequenceCheckerImpl )
 IMPL_CREATEINSTANCE( InputSequenceChecker_th )
@@ -388,7 +388,7 @@ static const struct InstancesArray {
         &Collator_Unicode_CreateInstance },
     {   "com.sun.star.i18n.ScriptTypeDetector",
         "com.sun.star.i18n.ScriptTypeDetector",
-        &ScriptTypeDetector_CreateInstance },
+        &UnoScriptTypeDetector_CreateInstance },
     {   "com.sun.star.i18n.CharacterClassification",
         "com.sun.star.i18n.CharacterClassification",
         &CharacterClassificationImpl_CreateInstance },
@@ -574,7 +574,7 @@ static const struct InstancesArray {
 extern "C"
 {
 
-SAL_DLLPUBLIC_EXPORT void* SAL_CALL i18npool_component_getFactory( const sal_Char* sImplementationName, void* _pServiceManager, void* /*_pRegistryKey*/ )
+SAL_DLLPUBLIC_EXPORT void* SAL_CALL i18npool_component_getFactory( const sal_Char* sImplementationName, void* _pServiceManager, SAL_UNUSED_PARAMETER void* /*_pRegistryKey*/ )
 {
     void* pRet = NULL;
 
@@ -592,7 +592,8 @@ SAL_DLLPUBLIC_EXPORT void* SAL_CALL i18npool_component_getFactory( const sal_Cha
             aServiceNames.getArray()[0] =
                 ::rtl::OUString::createFromAscii( pArr->pServiceNm );
             xFactory = ::cppu::createSingleFactory(
-                    pServiceManager, aServiceNames.getArray()[0],
+                    pServiceManager,
+                    ::rtl::OUString::createFromAscii( pArr->pImplementationNm ),
                     *pArr->pFn, aServiceNames );
             break;
         }
