@@ -133,23 +133,23 @@ void PPTShape::addShape(
     try
     {
         rtl::OUString sServiceName( msServiceName );
-        if( sServiceName.getLength() )
+        if( !sServiceName.isEmpty() )
         {
             oox::drawingml::TextListStylePtr aMasterTextListStyle;
             Reference< lang::XMultiServiceFactory > xServiceFact( rFilterBase.getModel(), UNO_QUERY_THROW );
             sal_Bool bClearText = sal_False;
 
-            if ( sServiceName != OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.drawing.GraphicObjectShape")) &&
-                 sServiceName != OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.drawing.OLE2Shape")) )
+            if ( sServiceName !=  "com.sun.star.drawing.GraphicObjectShape"  &&
+                 sServiceName !=  "com.sun.star.drawing.OLE2Shape" )
             {
-                const rtl::OUString sOutlinerShapeService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.OutlinerShape" ) );
+                const rtl::OUString sOutlinerShapeService( "com.sun.star.presentation.OutlinerShape"  );
                 OSL_TRACE("has master: %p", rSlidePersist.getMasterPersist().get());
                 switch( mnSubType )
                 {
                     case XML_ctrTitle :
                     case XML_title :
                     {
-                        const rtl::OUString sTitleShapeService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.TitleTextShape" ) );
+                        const rtl::OUString sTitleShapeService( "com.sun.star.presentation.TitleTextShape"  );
                         sServiceName = sTitleShapeService;
                         aMasterTextListStyle = rSlidePersist.getMasterPersist().get() ? rSlidePersist.getMasterPersist()->getTitleTextStyle() : rSlidePersist.getTitleTextStyle();
                     }
@@ -159,7 +159,7 @@ void PPTShape::addShape(
                         if ( ( meShapeLocation == Master ) || ( meShapeLocation == Layout ) )
                             sServiceName = rtl::OUString();
                         else {
-                            const rtl::OUString sTitleShapeService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.SubtitleShape" ) );
+                            const rtl::OUString sTitleShapeService( "com.sun.star.presentation.SubtitleShape"  );
                             sServiceName = sTitleShapeService;
                             aMasterTextListStyle = rSlidePersist.getMasterPersist().get() ? rSlidePersist.getMasterPersist()->getTitleTextStyle() : rSlidePersist.getTitleTextStyle();
                         }
@@ -173,7 +173,7 @@ void PPTShape::addShape(
                     break;
                     case XML_body :
                     {
-                        const rtl::OUString sNotesShapeService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.NotesShape" ) );
+                        const rtl::OUString sNotesShapeService( "com.sun.star.presentation.NotesShape"  );
                         if ( rSlidePersist.isNotesPage() )
                         {
                             sServiceName = sNotesShapeService;
@@ -188,35 +188,35 @@ void PPTShape::addShape(
                     break;
                     case XML_dt :
                     {
-                        const rtl::OUString sDateTimeShapeService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.DateTimeShape" ) );
+                        const rtl::OUString sDateTimeShapeService( "com.sun.star.presentation.DateTimeShape"  );
                         sServiceName = sDateTimeShapeService;
                         bClearText = sal_True;
                     }
                     break;
                     case XML_hdr :
                     {
-                        const rtl::OUString sHeaderShapeService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.HeaderShape" ) );
+                        const rtl::OUString sHeaderShapeService( "com.sun.star.presentation.HeaderShape"  );
                         sServiceName = sHeaderShapeService;
                         bClearText = sal_True;
                     }
                     break;
                     case XML_ftr :
                     {
-                        const rtl::OUString sFooterShapeService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.FooterShape" ) );
+                        const rtl::OUString sFooterShapeService( "com.sun.star.presentation.FooterShape"  );
                         sServiceName = sFooterShapeService;
                         bClearText = sal_True;
                     }
                     break;
                     case XML_sldNum :
                     {
-                        const rtl::OUString sSlideNumberShapeService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.SlideNumberShape" ) );
+                        const rtl::OUString sSlideNumberShapeService( "com.sun.star.presentation.SlideNumberShape"  );
                         sServiceName = sSlideNumberShapeService;
                         bClearText = sal_True;
                     }
                     break;
                     case XML_sldImg :
                     {
-                        const rtl::OUString sPageShapeService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.PageShape" ) );
+                        const rtl::OUString sPageShapeService( "com.sun.star.presentation.PageShape"  );
                         sServiceName = sPageShapeService;
                     }
                     break;
@@ -224,7 +224,7 @@ void PPTShape::addShape(
                         if ( meShapeLocation == Layout )
                             sServiceName = sOutlinerShapeService;
                         else {
-                            const rtl::OUString sChartService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.ChartShape" ) );
+                            const rtl::OUString sChartService( "com.sun.star.presentation.ChartShape"  );
                             sServiceName = sChartService;
                         }
                     break;
@@ -232,7 +232,7 @@ void PPTShape::addShape(
                         if ( meShapeLocation == Layout )
                             sServiceName = sOutlinerShapeService;
                         else {
-                            const rtl::OUString sTableService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.TableShape" ) );
+                            const rtl::OUString sTableService( "com.sun.star.presentation.TableShape"  );
                             sServiceName = sTableService;
                         }
                     break;
@@ -240,7 +240,7 @@ void PPTShape::addShape(
                         if ( meShapeLocation == Layout )
                             sServiceName = sOutlinerShapeService;
                         else {
-                            const rtl::OUString sGraphicObjectService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.GraphicObjectShape" ) );
+                            const rtl::OUString sGraphicObjectService( "com.sun.star.presentation.GraphicObjectShape"  );
                             sServiceName = sGraphicObjectService;
                         }
                     break;
@@ -248,7 +248,7 @@ void PPTShape::addShape(
                         if ( meShapeLocation == Layout )
                             sServiceName = sOutlinerShapeService;
                         else {
-                            const rtl::OUString sMediaService( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.MediaShape" ) );
+                            const rtl::OUString sMediaService( "com.sun.star.presentation.MediaShape"  );
                             sServiceName = sMediaService;
                         }
                     break;
@@ -262,10 +262,10 @@ void PPTShape::addShape(
             OSL_TRACE("shape service: %s", rtl::OUStringToOString(sServiceName, RTL_TEXTENCODING_UTF8 ).getStr());
 
             // use placeholder index if possible
-            if( mnSubType && getSubTypeIndex() && getSubTypeIndex() != -1 && rSlidePersist.getMasterPersist().get() ) {
-                oox::drawingml::ShapePtr pPlaceholder = PPTShape::findPlaceholderByIndex( getSubTypeIndex(), rSlidePersist.getMasterPersist()->getShapes()->getChildren() );
+            if( mnSubType && getSubTypeIndex().has() && rSlidePersist.getMasterPersist().get() ) {
+                oox::drawingml::ShapePtr pPlaceholder = PPTShape::findPlaceholderByIndex( getSubTypeIndex().get(), rSlidePersist.getMasterPersist()->getShapes()->getChildren() );
                 if( pPlaceholder.get()) {
-                    OSL_TRACE("found placeholder with index: %d and type: %s", getSubTypeIndex(), lclDebugSubType( mnSubType ));
+                    OSL_TRACE("found placeholder with index: %d and type: %s", getSubTypeIndex().get(), lclDebugSubType( mnSubType ));
                 }
                 if( pPlaceholder.get() ) {
                     PPTShape* pPPTPlaceholder = dynamic_cast< PPTShape* >( pPlaceholder.get() );
@@ -290,7 +290,7 @@ void PPTShape::addShape(
                         OSL_TRACE("placeholder has parent placeholder: %s type: %s index: %d",
                                   rtl::OUStringToOString( pPPTPlaceholder->mpPlaceholder->getId(), RTL_TEXTENCODING_UTF8 ).getStr(),
                                   lclDebugSubType( pPPTPlaceholder->mpPlaceholder->getSubType() ),
-                                  pPPTPlaceholder->mpPlaceholder->getSubTypeIndex() );
+                                  pPPTPlaceholder->mpPlaceholder->getSubTypeIndex().get() );
                         OSL_TRACE("has textbody %d", pPPTPlaceholder->mpPlaceholder->getTextBody() != NULL );
                         TextListStylePtr pPlaceholderStyle = getSubTypeTextListStyle( rSlidePersist, pPPTPlaceholder->mpPlaceholder->getSubType() );
                         if( pPPTPlaceholder->mpPlaceholder->getTextBody() )
@@ -306,11 +306,24 @@ void PPTShape::addShape(
                 OSL_TRACE("placeholder id: %s", pPlaceholder.get() ? rtl::OUStringToOString(pPlaceholder->getId(), RTL_TEXTENCODING_UTF8 ).getStr() : "not found");
             }
 
-            if ( sServiceName.getLength() )
+            if ( !sServiceName.isEmpty() )
             {
-            // use style from master slide for placeholders only, otherwise use slide's style, which might be the default style from presentation
                 if ( !aMasterTextListStyle.get() )
-                    aMasterTextListStyle = ( mnSubType && rSlidePersist.getMasterPersist().get() ) ? rSlidePersist.getMasterPersist()->getOtherTextStyle() : rSlidePersist.getOtherTextStyle();
+                {
+                    bool isOther = !getTextBody().get() && !sServiceName.equalsAscii("com.sun.star.drawing.GroupShape");
+                    TextListStylePtr aSlideStyle = isOther ? rSlidePersist.getOtherTextStyle() : rSlidePersist.getDefaultTextStyle();
+                    // Combine from MasterSlide details as well.
+                    if( rSlidePersist.getMasterPersist().get() )
+                    {
+                        aMasterTextListStyle = isOther ? rSlidePersist.getMasterPersist()->getOtherTextStyle() : rSlidePersist.getMasterPersist()->getDefaultTextStyle();
+                        if( aSlideStyle.get() )
+                            aMasterTextListStyle->apply( *aSlideStyle.get() );
+                    }
+                    else
+                    {
+                        aMasterTextListStyle = aSlideStyle;
+                    }
+                }
 
             if( aMasterTextListStyle.get() && getTextBody().get() ) {
                 TextListStylePtr aCombinedTextListStyle (new TextListStyle());
@@ -318,14 +331,14 @@ void PPTShape::addShape(
                 aCombinedTextListStyle->apply( *aMasterTextListStyle.get() );
 
                 if( mpPlaceholder.get() && mpPlaceholder->getTextBody().get() )
-                aCombinedTextListStyle->apply( mpPlaceholder->getTextBody()->getTextListStyle() );
+                    aCombinedTextListStyle->apply( mpPlaceholder->getTextBody()->getTextListStyle() );
                 aCombinedTextListStyle->apply( getTextBody()->getTextListStyle() );
 
                 setMasterTextListStyle( aCombinedTextListStyle );
             } else
                 setMasterTextListStyle( aMasterTextListStyle );
 
-            Reference< XShape > xShape( createAndInsert( rFilterBase, sServiceName, pTheme, rxShapes, pShapeRect, bClearText, aTransformation ) );
+            Reference< XShape > xShape( createAndInsert( rFilterBase, sServiceName, pTheme, rxShapes, pShapeRect, bClearText, mpPlaceholder.get() != NULL, aTransformation ) );
                 if ( !rSlidePersist.isMasterPage() && rSlidePersist.getPage().is() && ( (sal_Int32)mnSubType == XML_title ) )
                  {
                     try
@@ -333,7 +346,7 @@ void PPTShape::addShape(
                         rtl::OUString aTitleText;
                         Reference< XTextRange > xText( xShape, UNO_QUERY_THROW );
                         aTitleText = xText->getString();
-                        if ( aTitleText.getLength() && ( aTitleText.getLength() < 64 ) )    // just a magic value, but we don't want to set slide names which are too long
+                        if ( !aTitleText.isEmpty() && ( aTitleText.getLength() < 64 ) )    // just a magic value, but we don't want to set slide names which are too long
                         {
                             Reference< container::XNamed > xName( rSlidePersist.getPage(), UNO_QUERY_THROW );
                             xName->setName( aTitleText );
@@ -344,7 +357,7 @@ void PPTShape::addShape(
 
                     }
                 }
-                if( pShapeMap && msId.getLength() )
+                if( pShapeMap && !msId.isEmpty() )
                 {
                     (*pShapeMap)[ msId ] = shared_from_this();
                 }
@@ -361,9 +374,9 @@ void PPTShape::addShape(
     }
 }
 
-void PPTShape::applyShapeReference( const oox::drawingml::Shape& rReferencedShape )
+void PPTShape::applyShapeReference( const oox::drawingml::Shape& rReferencedShape, bool bUseText )
 {
-    Shape::applyShapeReference( rReferencedShape );
+    Shape::applyShapeReference( rReferencedShape, bUseText );
 }
 
 oox::drawingml::ShapePtr PPTShape::findPlaceholder( const sal_Int32 nMasterPlaceholder, std::vector< oox::drawingml::ShapePtr >& rShapes )
@@ -390,13 +403,10 @@ oox::drawingml::ShapePtr PPTShape::findPlaceholderByIndex( const sal_Int32 nIdx,
 {
     oox::drawingml::ShapePtr aShapePtr;
 
-    if( nIdx == -1)
-        return aShapePtr;
-
     std::vector< oox::drawingml::ShapePtr >::reverse_iterator aRevIter( rShapes.rbegin() );
     while( aRevIter != rShapes.rend() )
     {
-        if ( (*aRevIter)->getSubTypeIndex() == nIdx )
+        if ( (*aRevIter)->getSubTypeIndex().has() && (*aRevIter)->getSubTypeIndex().get() == nIdx )
         {
             aShapePtr = *aRevIter;
             break;
@@ -410,13 +420,6 @@ oox::drawingml::ShapePtr PPTShape::findPlaceholderByIndex( const sal_Int32 nIdx,
     return aShapePtr;
 }
 
-// if nFirstPlaceholder can't be found, it will be searched for nSecondPlaceholder
-oox::drawingml::ShapePtr PPTShape::findPlaceholder( sal_Int32 nFirstPlaceholder, sal_Int32 nSecondPlaceholder, std::vector< oox::drawingml::ShapePtr >& rShapes )
-{
-    oox::drawingml::ShapePtr pPlaceholder = findPlaceholder( nFirstPlaceholder, rShapes );
-    return !nSecondPlaceholder || pPlaceholder.get() ? pPlaceholder : findPlaceholder( nSecondPlaceholder, rShapes );
-}
-
 } }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
