@@ -36,9 +36,9 @@
 #include "vcl/msgbox.hxx"
 #include "vcl/strhelper.hxx"
 
+#include <tools/config.hxx>
 #include <osl/thread.h>
 #include <rtl/strbuf.hxx>
-#include <comphelper/string.hxx>
 #include <boost/unordered_set.hpp>
 
 using namespace psp;
@@ -95,11 +95,11 @@ void APChooseDevicePage::fill( PrinterInfo& rInfo )
 {
     if( m_aPDFBtn.IsChecked() )
     {
-        rInfo.m_aFeatures = OUString(RTL_CONSTASCII_USTRINGPARAM("pdf="));
+        rInfo.m_aFeatures = OUString("pdf=");
     }
     else if( m_aFaxBtn.IsChecked() )
     {
-        rInfo.m_aFeatures = OUString(RTL_CONSTASCII_USTRINGPARAM("fax"));
+        rInfo.m_aFeatures = OUString("fax");
     }
     else
         rInfo.m_aFeatures = OUString();
@@ -165,7 +165,7 @@ void APChooseDriverPage::updateDrivers( bool bRefresh, const rtl::OUString& rSel
     for( std::list< rtl::OUString >::const_iterator it = aDrivers.begin(); it != aDrivers.end(); ++it )
     {
         rtl::OUString aDriver( psp::PPDParser::getPPDPrinterName( *it ) );
-        if( aDriver.getLength() )
+        if( !aDriver.isEmpty() )
         {
             int nPos = m_aDriverBox.InsertEntry( aDriver );
             m_aDriverBox.SetEntryData( nPos, new String( *it ) );
@@ -284,7 +284,7 @@ IMPL_LINK( APChooseDriverPage, ClickBtnHdl, PushButton*, pButton )
                     aDir.append( sal_Unicode( '/' ) );
                     aDir.appendAscii( PRINTER_PPDDIR );
                     rtl::OUString aPPDDir( aDir.makeStringAndClear() );
-                    FindFiles( aPPDDir, aFiles, String( RTL_CONSTASCII_USTRINGPARAM( "PS;PPD;PS.GZ;PPD.GZ" ) ), true );
+                    FindFiles( aPPDDir, aFiles, String(  "PS;PPD;PS.GZ;PPD.GZ"  ), true );
                     for( file = aFiles.begin(); file != aFiles.end(); ++file )
                     {
                         String aFile( aPPDDir );
@@ -497,17 +497,15 @@ APOldPrinterPage::APOldPrinterPage( AddPrinterDialog* pParent )
 
     // read defaults
     aConfig.SetGroup( "Xprinter,PostScript" );
-    ByteString aDefPageSize( aConfig.ReadKey( "PageSize" ) );
-    ByteString aDefOrientation( aConfig.ReadKey( "Orientation" ) );
-    ByteString aDefMarginLeft( aConfig.ReadKey( "MarginLeft" ) );
-    ByteString aDefMarginRight( aConfig.ReadKey( "MarginRight" ) );
-    ByteString aDefMarginTop( aConfig.ReadKey( "MarginTop" ) );
-    ByteString aDefMarginBottom( aConfig.ReadKey( "MarginBottom" ) );
-    ByteString aDefScale( aConfig.ReadKey( "Scale" ) );
-    ByteString aDefCopies( aConfig.ReadKey( "Copies" ) );
-    ByteString aDefDPI( aConfig.ReadKey( "DPI" ) );
-
-    using comphelper::string::getToken;
+    rtl::OString aDefPageSize( aConfig.ReadKey( "PageSize" ) );
+    rtl::OString aDefOrientation( aConfig.ReadKey( "Orientation" ) );
+    rtl::OString aDefMarginLeft( aConfig.ReadKey( "MarginLeft" ) );
+    rtl::OString aDefMarginRight( aConfig.ReadKey( "MarginRight" ) );
+    rtl::OString aDefMarginTop( aConfig.ReadKey( "MarginTop" ) );
+    rtl::OString aDefMarginBottom( aConfig.ReadKey( "MarginBottom" ) );
+    rtl::OString aDefScale( aConfig.ReadKey( "Scale" ) );
+    rtl::OString aDefCopies( aConfig.ReadKey( "Copies" ) );
+    rtl::OString aDefDPI( aConfig.ReadKey( "DPI" ) );
 
     aConfig.SetGroup( "devices" );
     int nDevices = aConfig.GetKeyCount();
@@ -516,9 +514,9 @@ APOldPrinterPage::APOldPrinterPage( AddPrinterDialog* pParent )
         aConfig.SetGroup( "devices" );
         rtl::OString aPrinter(aConfig.GetKeyName(nKey));
         rtl::OString aValue(aConfig.ReadKey(aPrinter));
-        rtl::OString aPort(getToken(aValue, 1, ','));
-        rtl::OString aDriver(getToken(aValue, 0, ' '));
-        rtl::OString aPS( getToken(getToken(aValue, 0, ','), 1, ' ') );
+        rtl::OString aPort(aValue.getToken(1, ','));
+        rtl::OString aDriver(aValue.getToken(0, ' '));
+        rtl::OString aPS( aValue.getToken(0, ',').getToken(1, ' ') );
         rtl::OString aNewDriver(aDriver);
         if( aDriver.equalsL(RTL_CONSTASCII_STRINGPARAM("GENERIC")))
             aNewDriver = rtl::OString(RTL_CONSTASCII_STRINGPARAM("SGENPRT"));
@@ -530,8 +528,8 @@ APOldPrinterPage::APOldPrinterPage( AddPrinterDialog* pParent )
         if( pParser == NULL )
         {
             String aText( PaResId( RID_TXT_DRIVERDOESNOTEXIST ) );
-            aText.SearchAndReplace( String( RTL_CONSTASCII_USTRINGPARAM( "%s1" ) ), rtl::OStringToOUString(aPrinter, aEncoding) );
-            aText.SearchAndReplace( String( RTL_CONSTASCII_USTRINGPARAM( "%s2" ) ), rtl::OStringToOUString(aDriver, aEncoding) );
+            aText.SearchAndReplace( String(  "%s1"  ), rtl::OStringToOUString(aPrinter, aEncoding) );
+            aText.SearchAndReplace( String(  "%s2"  ), rtl::OStringToOUString(aDriver, aEncoding) );
             InfoBox aBox( this, aText );
             aBox.Execute();
             continue;
@@ -539,11 +537,11 @@ APOldPrinterPage::APOldPrinterPage( AddPrinterDialog* pParent )
 
         // read the command
         aConfig.SetGroup( "ports" );
-        ByteString aCommand( aConfig.ReadKey( aPort ) );
-        if( ! aCommand.Len() )
+        rtl::OString aCommand( aConfig.ReadKey( aPort ) );
+        if (aCommand.isEmpty())
         {
             String aText( PaResId( RID_TXT_PRINTERWITHOUTCOMMAND ) );
-            aText.SearchAndReplace( String( RTL_CONSTASCII_USTRINGPARAM( "%s" ) ), rtl::OStringToOUString(aPrinter, aEncoding) );
+            aText.SearchAndReplace( String(  "%s"  ), rtl::OStringToOUString(aPrinter, aEncoding) );
             InfoBox aBox( this, aText );
             aBox.Execute();
             continue;
@@ -567,11 +565,11 @@ APOldPrinterPage::APOldPrinterPage( AddPrinterDialog* pParent )
 
         aValue = aConfig.ReadKey( "PageSize", aDefPageSize );
         int nLeft, nRight, nTop, nBottom;
-        if( aValue.getLength() &&
+        if( !aValue.isEmpty() &&
             aInfo.m_pParser->getMargins( rtl::OStringToOUString(aValue, aEncoding),
                                          nLeft, nRight, nTop, nBottom ) )
         {
-            const PPDKey* pKey = aInfo.m_pParser->getKey( String( RTL_CONSTASCII_USTRINGPARAM( "PageSize" ) ) );
+            const PPDKey* pKey = aInfo.m_pParser->getKey( String(  "PageSize"  ) );
             const PPDValue* pValue = pKey ? pKey->getValue( rtl::OStringToOUString(aValue, aEncoding) ) : NULL;
             if( pKey && pValue )
                 aInfo.m_aContext.setValue( pKey, pValue );
@@ -602,23 +600,22 @@ APOldPrinterPage::APOldPrinterPage( AddPrinterDialog* pParent )
 
         aValue = aConfig.ReadKey( "Orientation", aDefOrientation );
         if (!aValue.isEmpty())
-            aInfo.m_eOrientation = aValue.equalsIgnoreAsciiCase( "landscape" ) == COMPARE_EQUAL ? orientation::Landscape : orientation::Portrait;
+            aInfo.m_eOrientation = aValue.equalsIgnoreAsciiCaseL(RTL_CONSTASCII_STRINGPARAM("landscape")) ? orientation::Landscape : orientation::Portrait;
         int nGroupKeys = aConfig.GetKeyCount();
         for( int nPPDKey = 0; nPPDKey < nGroupKeys; nPPDKey++ )
         {
-            ByteString aPPDKey( aConfig.GetKeyName( nPPDKey ) );
+            rtl::OString aPPDKey( aConfig.GetKeyName( nPPDKey ) );
             // ignore page region
             // there are some ppd keys in old Xpdefaults that
             // should never have been writte because they are defaults
             // PageRegion leads to problems in conjunction
             // with a not matching PageSize
-            if( aPPDKey.CompareTo( "PPD_", 4 ) == COMPARE_EQUAL &&
-                aPPDKey != "PPD_PageRegion"
-                )
+            if (aPPDKey.matchL(RTL_CONSTASCII_STRINGPARAM("PPD_")) &&
+                !aPPDKey.equalsL(RTL_CONSTASCII_STRINGPARAM("PPD_PageRegion")))
             {
                 aValue = aConfig.ReadKey( nPPDKey );
-                aPPDKey.Erase( 0, 4 );
-                const PPDKey* pKey = aInfo.m_pParser->getKey( String( aPPDKey, RTL_TEXTENCODING_ISO_8859_1 ) );
+                aPPDKey = aPPDKey.copy(4);
+                const PPDKey* pKey = aInfo.m_pParser->getKey( rtl::OStringToOUString(aPPDKey, RTL_TEXTENCODING_ISO_8859_1) );
                 const PPDValue* pValue = pKey ? ( aValue.equalsL(RTL_CONSTASCII_STRINGPARAM("*nil")) ? NULL : pKey->getValue(rtl::OStringToOUString(aValue, RTL_TEXTENCODING_ISO_8859_1)) ) : NULL;
                 if( pKey )
                     aInfo.m_aContext.setValue( pKey, pValue, true );
@@ -655,7 +652,7 @@ void APOldPrinterPage::addOldPrinters()
         if( ! rManager.addPrinter( pInfo->m_aPrinterName, pInfo->m_aDriverName ) )
         {
             String aText( PaResId( RID_TXT_PRINTERADDFAILED ) );
-            aText.SearchAndReplace( String( RTL_CONSTASCII_USTRINGPARAM( "%s" ) ), pInfo->m_aPrinterName );
+            aText.SearchAndReplace( String(  "%s"  ), pInfo->m_aPrinterName );
                 ErrorBox aBox( this, WB_OK | WB_DEF_OK, aText );
                 aBox.Execute();
                 continue;
@@ -701,7 +698,7 @@ void APFaxDriverPage::fill( PrinterInfo& rInfo )
 {
     if( isDefault() )
     {
-        rInfo.m_aDriverName = OUString(RTL_CONSTASCII_USTRINGPARAM("SGENPRT"));
+        rInfo.m_aDriverName = OUString("SGENPRT");
     }
 }
 
@@ -734,9 +731,9 @@ bool APPdfDriverPage::check()
 void APPdfDriverPage::fill( PrinterInfo& rInfo )
 {
     if( isDefault() )
-        rInfo.m_aDriverName = OUString(RTL_CONSTASCII_USTRINGPARAM("SGENPRT"));
+        rInfo.m_aDriverName = OUString("SGENPRT");
     else if( isDist() )
-        rInfo.m_aDriverName = OUString(RTL_CONSTASCII_USTRINGPARAM("ADISTILL"));
+        rInfo.m_aDriverName = OUString("ADISTILL");
 }
 
 //--------------------------------------------------------------------
@@ -1022,13 +1019,13 @@ void AddPrinterDialog::addPrinter()
             }
             else if( m_pChooseDevicePage->isFax() )
             {
-                aInfo.m_aFeatures = OUString(RTL_CONSTASCII_USTRINGPARAM("fax="));
+                aInfo.m_aFeatures = OUString("fax=");
                 if( m_pFaxNamePage->isFaxSwallow() )
-                    aInfo.m_aFeatures += OUString(RTL_CONSTASCII_USTRINGPARAM("swallow"));
+                    aInfo.m_aFeatures += OUString("swallow");
             }
             else if( m_pChooseDevicePage->isPDF() )
             {
-                OUString aPdf( RTL_CONSTASCII_USTRINGPARAM("pdf=") );
+                OUString aPdf( "pdf=" );
                 aPdf += m_pPdfCommandPage->getPdfDir();
                 aInfo.m_aFeatures = aPdf;
             }
@@ -1077,7 +1074,7 @@ String AddPrinterDialog::uniquePrinterName( const String& rBase )
 
     PrinterInfoManager& rManager( PrinterInfoManager::get() );
 
-    int nVersion = 1;
+    sal_Int32 nVersion = 1;
     list< OUString > aPrinterList;
     rManager.listPrinters( aPrinterList );
     boost::unordered_set< OUString, OUStringHash > aPrinters;
@@ -1087,7 +1084,7 @@ String AddPrinterDialog::uniquePrinterName( const String& rBase )
     {
         aResult = rBase;
         aResult.AppendAscii( "_" );
-        aResult += String::CreateFromInt32( nVersion++ );
+        aResult += rtl::OUString::valueOf(nVersion++);
     }
 
     return aResult;
@@ -1096,40 +1093,40 @@ String AddPrinterDialog::uniquePrinterName( const String& rBase )
 String AddPrinterDialog::getOldPrinterLocation()
 {
     static const char* pHome = getenv( "HOME" );
-    String aRet;
-    ByteString aFileName;
+    rtl::OString aFileName;
 
     rtl_TextEncoding aEncoding = osl_getThreadTextEncoding();
     if( pHome )
     {
-        aFileName = pHome;
-        aFileName.Append( "/.Xpdefaults" );
-        if( access( aFileName.GetBuffer(), F_OK ) )
+        aFileName = rtl::OStringBuffer().append(pHome).
+            append(RTL_CONSTASCII_STRINGPARAM("/.Xpdefaults")).
+            makeStringAndClear();
+        if (access(aFileName.getStr(), F_OK))
         {
-            aFileName = pHome;
-            aFileName.Append( "/.sversionrc" );
-            Config aSVer( String( aFileName, aEncoding ) );
+            aFileName = rtl::OStringBuffer().append(pHome).
+                append(RTL_CONSTASCII_STRINGPARAM("/.sversionrc")).
+                makeStringAndClear();
+            Config aSVer(rtl::OStringToOUString(aFileName, aEncoding));
             aSVer.SetGroup( "Versions" );
             aFileName = aSVer.ReadKey( "StarOffice 5.2" );
-            if( aFileName.Len() )
-                aFileName.Append( "/share/xp3/Xpdefaults" );
+            if (!aFileName.isEmpty())
+                aFileName = aFileName + rtl::OString(RTL_CONSTASCII_STRINGPARAM("/share/xp3/Xpdefaults"));
             else if(
-                    (aFileName = aSVer.ReadKey( "StarOffice 5.1" ) ).Len()
+                    (aFileName = aSVer.ReadKey( "StarOffice 5.1" ) ).getLength()
                     ||
-                    (aFileName = aSVer.ReadKey( "StarOffice 5.0" ) ).Len()
+                    (aFileName = aSVer.ReadKey( "StarOffice 5.0" ) ).getLength()
                     ||
-                    (aFileName = aSVer.ReadKey( "StarOffice 4.0" ) ).Len()
+                    (aFileName = aSVer.ReadKey( "StarOffice 4.0" ) ).getLength()
                     )
             {
-                aFileName.Append( "/xp3/Xpdefaults" );
+                aFileName = aFileName + rtl::OString(RTL_CONSTASCII_STRINGPARAM("/xp3/Xpdefaults"));
             }
-            if( aFileName.Len() && access( aFileName.GetBuffer(), F_OK ) )
-                aFileName.Erase();
+            if (!aFileName.isEmpty() && access(aFileName.getStr(), F_OK))
+                aFileName = rtl::OString();
         }
     }
-    if( aFileName.Len() )
-        aRet = String( aFileName, aEncoding );
-    return aRet;
+
+    return !aFileName.isEmpty() ? rtl::OStringToOUString(aFileName, aEncoding) : rtl::OUString();
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
