@@ -147,7 +147,7 @@ PropBrw::PropBrw(const Reference< XMultiServiceFactory >&   _xORB,Window* pParen
                 ::cppu::ContextEntry_Init( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ActiveConnection" ) ), makeAny( m_pDesignView->getController().getConnection() ) ),
             };
             m_xInspectorContext.set(
-                ::cppu::createComponentContext( aHandlerContextInfo, SAL_N_ELEMENTS( aHandlerContextInfo ),
+                ::cppu::createComponentContext( aHandlerContextInfo, sizeof( aHandlerContextInfo ) / sizeof( aHandlerContextInfo[0] ),
                 xOwnContext ) );
             // create a property browser controller
             bool bEnableHelpSection = lcl_shouldEnableHelpSection( m_xORB );
@@ -173,7 +173,6 @@ PropBrw::PropBrw(const Reference< XMultiServiceFactory >&   _xORB,Window* pParen
                     uno::Reference< uno::XInterface > xDefaultHelpProvider( inspection::DefaultHelpProvider::create( m_xInspectorContext, xInspectorUI ) );
                 }
             }
-            xFactoryProperties->setPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "DefaultContext" ) ) ,makeAny(xOwnContext));
         }
         catch (Exception&)
         {
@@ -182,9 +181,6 @@ PropBrw::PropBrw(const Reference< XMultiServiceFactory >&   _xORB,Window* pParen
             {
                 ::comphelper::disposeComponent(m_xBrowserController);
                 ::comphelper::disposeComponent(m_xBrowserComponentWindow);
-                Reference< XPropertySet > xFactoryProperties( m_xORB, UNO_QUERY_THROW );
-                if ( xOwnContext.is() )
-                    xFactoryProperties->setPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "DefaultContext" ) ) ,makeAny(xOwnContext));
             }
             catch(Exception&) { }
             m_xBrowserController.clear();
@@ -218,7 +214,7 @@ PropBrw::~PropBrw()
             const ::rtl::OUString pProps[] = { ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ContextDocument" ) )
                                             ,  ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "DialogParentWindow" ) )
                                             , ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ActiveConnection" ) )};
-            for (size_t i = 0; i < SAL_N_ELEMENTS(pProps); ++i)
+            for (size_t i = 0; i < sizeof(pProps)/sizeof(pProps[0]); ++i)
                 xName->removeByName(pProps[i]);
         }
     }
@@ -262,7 +258,7 @@ void PropBrw::implDetachController()
             OSL_VERIFY( m_xBrowserController->getViewData() >>= sCurrentPage );
         }
 
-        if ( !sCurrentPage.getLength() )
+        if ( sCurrentPage.isEmpty() )
             sCurrentPage = m_sLastActivePage;
     }
     catch( const Exception& )
@@ -509,7 +505,7 @@ void PropBrw::Update( OSectionView* pNewView )
             m_bInitialStateChange = sal_False;
             // and additionally, we want to show the page which was active during
             // our previous incarnation
-            if ( m_sLastActivePage.getLength() && m_xBrowserController.is() )
+            if ( !m_sLastActivePage.isEmpty() && m_xBrowserController.is() )
             {
                 try
                 {
