@@ -688,7 +688,7 @@ SAL_CALL osl_createFileHandleFromOSHandle (
         pImpl->m_state |= FileHandle_Impl::STATE_SEEKABLE;
 
         /* init current size */
-        LARGE_INTEGER uSize = { 0, 0 };
+        LARGE_INTEGER uSize = { { 0, 0 } };
         (void) ::GetFileSizeEx(hFile, &uSize);
         pImpl->m_size = (sal::static_int_cast<sal_uInt64>(uSize.HighPart) << 32) + uSize.LowPart;
     }
@@ -765,6 +765,22 @@ SAL_CALL osl_syncFile(oslFileHandle Handle)
     return osl_File_E_None;
 }
 
+//#############################################
+oslFileError
+SAL_CALL osl_getFileOSHandle(
+    oslFileHandle  Handle,
+    sal_IntPtr    *piFileHandle )
+{
+    FileHandle_Impl* pImpl = static_cast<FileHandle_Impl*>(Handle);
+
+    if (0 == pImpl || !IsValidHandle(pImpl->m_hFile))
+        return osl_File_E_INVAL;
+
+    *piFileHandle = (sal_IntPtr) pImpl->m_hFile;
+
+    return osl_File_E_None;
+}
+
 //#############################################
 oslFileError
 SAL_CALL osl_closeFile(oslFileHandle Handle)
@@ -860,8 +876,6 @@ SAL_CALL osl_mapFile(
         if (nSize > 0)
         {
             c ^= pData[0];
-            pData += nSize;
-            nSize -= nSize;
         }
     }
     return osl_File_E_None;
@@ -880,6 +894,13 @@ SAL_CALL osl_unmapFile(void* pAddr, sal_uInt64 /* uLength */)
     return osl_File_E_None;
 }
 
+//#############################################
+oslFileError
+SAL_CALL osl_unmapMappedFile(oslFileHandle /* Handle */, void* pAddr, sal_uInt64 uLength)
+{
+    return osl_unmapFile( pAddr, uLength );
+}
+
 //#############################################
 oslFileError
 SAL_CALL osl_readLine(
