@@ -27,12 +27,13 @@
  ************************************************************************/
 #include <string.h>
 
+#include <algorithm>
+
 #include <sal/types.h>
 
 #include <rtl/textenc.h>
 #include <rtl/tencinfo.h>
 
-
 #include <com/sun/star/io/XInputStream.hpp>
 
 using namespace ::com::sun::star::uno;
@@ -54,8 +55,9 @@ sal_Int32 XMLFile2UTFConverter::readAndConvert( Sequence<sal_Int8> &seq , sal_In
         throw NotConnectedException();
     }
     if( ! m_bStarted ) {
-        nMaxToRead = Max( 512 , nMaxToRead );   // it should be possible to find the encoding attribute
-                                                 // within the first 512 bytes == 128 chars in UCS-4
+        // it should be possible to find the encoding attribute
+        // within the first 512 bytes == 128 chars in UCS-4
+        nMaxToRead = ::std::max( sal_Int32(512) , nMaxToRead );
     }
 
     sal_Int32 nRead;
@@ -93,7 +95,7 @@ sal_Int32 XMLFile2UTFConverter::readAndConvert( Sequence<sal_Int8> &seq , sal_In
                   // read more !
                   continue;
                 }
-                if( scanForEncoding( seq ) || m_sEncoding.getLength() ) {
+                if( scanForEncoding( seq ) || !m_sEncoding.isEmpty() ) {
                     // initialize decoding
                     initializeDecoding();
                 }
@@ -340,7 +342,7 @@ sal_Bool XMLFile2UTFConverter::scanForEncoding( Sequence< sal_Int8 > &seq )
 void XMLFile2UTFConverter::initializeDecoding()
 {
 
-    if( m_sEncoding.getLength() )
+    if( !m_sEncoding.isEmpty() )
     {
         rtl_TextEncoding encoding = rtl_getTextEncodingFromMimeCharset( m_sEncoding.getStr() );
         if( encoding != RTL_TEXTENCODING_UTF8 )
