@@ -57,6 +57,24 @@ ScFormatEntry::ScFormatEntry(ScDocument* pDoc):
 {
 }
 
+bool ScFormatEntry::operator==( const ScFormatEntry& r ) const
+{
+    if(GetType() != r.GetType())
+        return false;
+
+    switch(GetType())
+    {
+        case condformat::CONDITION:
+            return static_cast<const ScCondFormatEntry&>(*this) == static_cast<const ScCondFormatEntry&>(r);
+        default:
+            // TODO: implement also this case
+            // actually return false for these cases is not that bad
+            // as soon as databar and color scale are tested we need
+            // to think about the range
+            return false;
+    }
+}
+
 bool lcl_HasRelRef( ScDocument* pDoc, ScTokenArray* pFormula, sal_uInt16 nRecursion = 0 )
 {
     if (pFormula)
@@ -753,8 +771,21 @@ static bool lcl_IsDuplicate( ScDocument *pDoc, double nArg, const String& rStr,
         const ScRange *aRange = rRanges[i];
         SCROW nRow = aRange->aEnd.Row();
         SCCOL nCol = aRange->aEnd.Col();
-        for( SCROW r = aRange->aStart.Row(); r <= nRow; r++ )
-            for( SCCOL c = aRange->aStart.Col(); c <= nCol; c++ )
+        SCCOL nColStart = aRange->aStart.Col();
+        SCROW nRowStart = aRange->aStart.Row();
+        SCTAB nTab = aRange->aStart.Tab();
+
+        // temporary fix to workaorund slow duplicate entry
+        // conditions, prevent to use a whole row
+        if(nRow == MAXROW)
+        {
+            bool bShrunk = false;
+            pDoc->ShrinkToUsedDataArea(bShrunk, nTab, nColStart, nRowStart,
+                                            nCol, nRow, false);
+        }
+
+        for( SCROW r = nRowStart; r <= nRow; r++ )
+            for( SCCOL c = nColStart; c <= nCol; c++ )
             {
                 double nVal = 0.0;
                 ScBaseCell *pCell = NULL;
@@ -1126,7 +1157,7 @@ void ScConditionEntry::SourceChanged( const ScAddress& rChanged )
                         ScRange aPaint( nCol1,nRow1,nTab1, nCol2,nRow2,nTab2 );
 
                         //  kein Paint, wenn es nur die Zelle selber ist
-                        if ( aPaint.aStart != rChanged || aPaint.aEnd != rChanged )
+                        if ( aPaint.IsValid() && (aPaint.aStart != rChanged || aPaint.aEnd != rChanged ))
                             DataChanged( &aPaint );
                     }
                 }
@@ -1289,8 +1320,6 @@ int ScCondFormatEntry::operator== ( const ScCondFormatEntry& r ) const
 {
     return ScConditionEntry::operator==( r ) &&
             aStyleName == r.aStyleName;
-
-    //  Range wird nicht verglichen
 }
 
 ScCondFormatEntry::~ScCondFormatEntry()
@@ -1356,13 +1385,14 @@ bool ScConditionalFormat::EqualEntries( const ScConditionalFormat& r ) const
 
     //! auf gleiche Eintraege in anderer Reihenfolge testen ???
 
-    /*
-    for (sal_uInt16 i=0; i<nEntryCount; i++)
-        if ( ! (*ppEntries[i] == *r.ppEntries[i]) )
+    for (sal_uInt16 i=0; i<size(); i++)
+        if ( ! (maEntries == r.maEntries ) )
             return false;
-    */
 
-    return maRanges == r.maRanges;
+    // right now don't check for same range
+    // we only use this method to merge same conditional formats from
+    // old ODF data structure
+    return true;
 }
 
 void ScConditionalFormat::AddRange( const ScRangeList& rRanges )
@@ -1522,6 +1552,12 @@ void ScConditionalFormat::UpdateReference( UpdateRefMode eUpdateRefMode,
         itr->UpdateReference(eUpdateRefMode, rRange, nDx, nDy, nDz);
 }
 
+void ScConditionalFormat::DeleteArea( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2 )
+{
+    SCTAB nTab = maRanges[0]->aStart.Tab();
+    maRanges.DeleteArea( nCol1, nRow1, nTab, nCol2, nRow2, nTab );
+}
+
 void ScConditionalFormat::RenameCellStyle(const String& rOld, const String& rNew)
 {
     for(CondFormatContainer::iterator itr = maEntries.begin(); itr != maEntries.end(); ++itr)
@@ -1650,6 +1686,19 @@ void ScConditionalFormatList::UpdateReference( UpdateRefMode eUpdateRefMode,
 {
     for( iterator itr = begin(); itr != end(); ++itr)
         itr->UpdateReference( eUpdateRefMode, rRange, nDx, nDy, nDz );
+
+    if( eUpdateRefMode == URM_INSDEL )
+    {
+        // need to check which must be deleted
+        iterator itr = begin();
+        while(itr != end())
+        {
+            if(itr->GetRange().empty())
+                maConditionalFormats.erase(itr++);
+            else
+                ++itr;
+        }
+    }
 }
 
 void ScConditionalFormatList::RenameCellStyle( const String& rOld, const String& rNew )
@@ -1664,6 +1713,34 @@ void ScConditionalFormatList::UpdateMoveTab( SCTAB nOldPos, SCTAB nNewPos )
         itr->UpdateMoveTab( nOldPos, nNewPos );
 }
 
+bool ScConditionalFormatList::CheckAllEntries()
+{
+    bool bValid = true;
+    //
+    // need to check which must be deleted
+    iterator itr = begin();
+    while(itr != end())
+    {
+        if(itr->GetRange().empty())
+        {
+            bValid = false;
+            maConditionalFormats.erase(itr++);
+        }
+        else
+            ++itr;
+    }
+
+    return bValid;
+}
+
+void ScConditionalFormatList::DeleteArea( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2 )
+{
+    for( iterator itr = begin(); itr != end(); ++itr)
+        itr->DeleteArea( nCol1, nRow1, nCol2, nRow2 );
+
+    CheckAllEntries();
+}
+
 void ScConditionalFormatList::SourceChanged( const ScAddress& rAddr )
 {
     for( iterator itr = begin(); itr != end(); ++itr)
