@@ -73,6 +73,7 @@ ScDPCache::ScDPCache(ScDocument* pDoc) :
     mpDoc( pDoc ),
     mnColumnCount ( 0 ),
     maEmptyRows(0, MAXROW, true),
+    mnDataSize(-1),
     mbDisposing(false)
 {
 }
@@ -278,11 +279,11 @@ struct LessByDataIndex : std::binary_function<Bucket, Bucket, bool>
     }
 };
 
-struct EqualByValue : std::binary_function<Bucket, Bucket, bool>
+struct EqualByOrderIndex : std::binary_function<Bucket, Bucket, bool>
 {
     bool operator() (const Bucket& left, const Bucket& right) const
     {
-        return left.maValue.IsCaseInsEqual(right.maValue);
+        return left.mnOrderIndex == right.mnOrderIndex;
     }
 };
 
@@ -358,7 +359,7 @@ void processBuckets(std::vector<Bucket>& aBuckets, ScDPCache::Field& rField)
 
     // Unique by value.
     std::vector<Bucket>::iterator itUniqueEnd =
-        std::unique(aBuckets.begin(), aBuckets.end(), EqualByValue());
+        std::unique(aBuckets.begin(), aBuckets.end(), EqualByOrderIndex());
 
     // Copy the unique values into items.
     std::vector<Bucket>::iterator itBeg = aBuckets.begin();
@@ -751,7 +752,21 @@ public:
 
 void ScDPCache::PostInit()
 {
+    OSL_ENSURE(!maFields.empty(), "Cache not initialized!");
+
     maEmptyRows.build_tree();
+    typedef mdds::flat_segment_tree<SCROW, bool>::const_reverse_iterator itr_type;
+    itr_type it = maEmptyRows.rbegin();
+    OSL_ENSURE(it != maEmptyRows.rend(), "corrupt flat_segment_tree instance!");
+    mnDataSize = maFields[0].maData.size();
+    ++it; // Skip the first position.
+    OSL_ENSURE(it != maEmptyRows.rend(), "buggy version of flat_segment_tree is used.");
+    if (it->second)
+    {
+        SCROW nLastNonEmpty = it->first - 1;
+        if (nLastNonEmpty+1 < mnDataSize)
+            mnDataSize = nLastNonEmpty+1;
+    }
 }
 
 void ScDPCache::Clear()
@@ -850,6 +865,12 @@ SCROW ScDPCache::GetRowCount() const
     return maFields[0].maData.size();
 }
 
+SCROW ScDPCache::GetDataSize() const
+{
+    OSL_ENSURE(mnDataSize <= GetRowCount(), "Data size should never be larger than the row count.");
+    return mnDataSize >= 0 ? mnDataSize : 0;
+}
+
 const ScDPCache::ItemsType& ScDPCache::GetDimMemberValues(SCCOL nDim) const
 {
     OSL_ENSURE( nDim>=0 && nDim < mnColumnCount ," nDim < mnColumnCount ");
