@@ -172,7 +172,7 @@ SfxPoolItem* ScPatternAttr::Create( SvStream& rStream, sal_uInt16 /* nVersion */
     {
         short   eFamDummy;
         pStr = new String;
-        rStream.ReadByteString( *pStr, rStream.GetStreamCharSet() );
+        *pStr = rStream.ReadUniOrByteString( rStream.GetStreamCharSet() );
         rStream >> eFamDummy; // wg. altem Dateiformat
     }
     else
@@ -194,11 +194,11 @@ SvStream& ScPatternAttr::Store(SvStream& rStream, sal_uInt16 /* nItemVersion */)
     rStream << (sal_Bool)sal_True;
 
     if ( pStyle )
-        rStream.WriteByteString( pStyle->GetName(), rStream.GetStreamCharSet() );
+        rStream.WriteUniOrByteString( pStyle->GetName(), rStream.GetStreamCharSet() );
     else if ( pName )                   // wenn Style geloescht ist/war
-        rStream.WriteByteString( *pName, rStream.GetStreamCharSet() );
+        rStream.WriteUniOrByteString( *pName, rStream.GetStreamCharSet() );
     else
-        rStream.WriteByteString( ScGlobal::GetRscString(STR_STYLENAME_STANDARD),
+        rStream.WriteUniOrByteString( ScGlobal::GetRscString(STR_STYLENAME_STANDARD),
                                     rStream.GetStreamCharSet() );
 
     rStream << (short)SFX_STYLE_FAMILY_PARA;  // wg. altem Dateiformat
@@ -970,9 +970,12 @@ SfxStyleSheetBase* lcl_CopyStyleToPool
              rSrcSet.GetItemState( ATTR_VALUE_FORMAT, false, &pSrcItem ) == SFX_ITEM_SET )
         {
             sal_uLong nOldFormat = static_cast<const SfxUInt32Item*>(pSrcItem)->GetValue();
-            sal_uInt32* pNewFormat = static_cast<sal_uInt32*>(pFormatExchangeList->Get( nOldFormat ));
-            if (pNewFormat)
-                rDestSet.Put( SfxUInt32Item( ATTR_VALUE_FORMAT, *pNewFormat ) );
+            SvNumberFormatterIndexTable::const_iterator it = pFormatExchangeList->find(nOldFormat);
+            if (it != pFormatExchangeList->end())
+            {
+                sal_uInt32 nNewFormat = it->second;
+                rDestSet.Put( SfxUInt32Item( ATTR_VALUE_FORMAT, nNewFormat ) );
+            }
         }
 
         // ggF. abgeleitete Styles erzeugen, wenn nicht vorhanden:
@@ -1023,39 +1026,7 @@ ScPatternAttr* ScPatternAttr::PutInPool( ScDocument* pDestDoc, ScDocument* pSrcD
         {
             SfxPoolItem* pNewItem = NULL;
 
-            if ( nAttrId == ATTR_CONDITIONAL )
-            {
-                //  Bedingte Formate ins neue Dokument kopieren
-
-                sal_uLong nNewIndex = 0;
-                ScConditionalFormatList* pSrcList = pSrcDoc->GetCondFormList();
-                if ( pSrcList )
-                {
-                    sal_uLong nOldIndex = ((const SfxUInt32Item*)pSrcItem)->GetValue();
-                    const ScConditionalFormat* pOldData = pSrcList->GetFormat( nOldIndex );
-                    if ( pOldData )
-                    {
-                        nNewIndex = pDestDoc->AddCondFormat( *pOldData );
-
-                        //  zugehoerige Styles auch mitkopieren
-                        //! nur wenn Format bei Add neu angelegt
-
-                        ScStyleSheetPool* pSrcSPool = pSrcDoc->GetStyleSheetPool();
-                        ScStyleSheetPool* pDestSPool = pDestDoc->GetStyleSheetPool();
-                        const SvNumberFormatterIndexTable* pFormatExchangeList = pDestDoc->GetFormatExchangeList();
-                        sal_uInt16 nStlCnt = pOldData->Count();
-                        for (sal_uInt16 i=0; i<nStlCnt; i++)
-                        {
-                            String aName = pOldData->GetEntry(i)->GetStyle();
-                            SfxStyleSheetBase* pSrcStl =
-                                pSrcDoc->GetStyleSheetPool()->Find(aName, SFX_STYLE_FAMILY_PARA);
-                            lcl_CopyStyleToPool( pSrcStl, pSrcSPool, pDestSPool, pFormatExchangeList );
-                        }
-                    }
-                }
-                pNewItem = new SfxUInt32Item( ATTR_CONDITIONAL, nNewIndex );
-            }
-            else if ( nAttrId == ATTR_VALIDDATA )
+            if ( nAttrId == ATTR_VALIDDATA )
             {
                 //  Gueltigkeit ins neue Dokument kopieren
 
@@ -1075,9 +1046,12 @@ ScPatternAttr* ScPatternAttr::PutInPool( ScDocument* pDestDoc, ScDocument* pSrcD
                 //  Zahlformate nach Exchange-Liste
 
                 sal_uLong nOldFormat = ((const SfxUInt32Item*)pSrcItem)->GetValue();
-                sal_uInt32* pNewFormat = static_cast<sal_uInt32*>(pDestDoc->GetFormatExchangeList()->Get(nOldFormat));
-                if (pNewFormat)
-                    pNewItem = new SfxUInt32Item( ATTR_VALUE_FORMAT, (sal_uInt32) (*pNewFormat) );
+                SvNumberFormatterIndexTable::const_iterator it = pDestDoc->GetFormatExchangeList()->find(nOldFormat);
+                if (it != pDestDoc->GetFormatExchangeList()->end())
+                {
+                    sal_uInt32 nNewFormat = it->second;
+                    pNewItem = new SfxUInt32Item( ATTR_VALUE_FORMAT, nNewFormat );
+                }
             }
 
             if ( pNewItem )
