@@ -50,6 +50,9 @@
 #include <svl/inethist.hxx>
 #include <unotools/syslocale.hxx>
 
+#include <com/sun/star/text/textfield/Type.hpp>
+#include <com/sun/star/document/XDocumentProperties.hpp>
+
 #include "editutil.hxx"
 #include "global.hxx"
 #include "attrib.hxx"
@@ -60,6 +63,8 @@
 #include "inputopt.hxx"
 #include "compiler.hxx"
 
+using namespace com::sun::star;
+
 // STATIC DATA -----------------------------------------------------------
 
 //  Delimiters zusaetzlich zu EditEngine-Default:
@@ -648,22 +653,31 @@ String ScHeaderEditEngine::CalcFieldValue( const SvxFieldItem& rField,
                                     sal_uInt16 /* nPara */, sal_uInt16 /* nPos */,
                                     Color*& /* rTxtColor */, Color*& /* rFldColor */ )
 {
-    String aRet;
     const SvxFieldData* pFieldData = rField.GetField();
-    if ( pFieldData )
+    if (!pFieldData)
+        return rtl::OUString("?");
+
+    rtl::OUString aRet;
+    sal_Int32 nClsId = pFieldData->GetClassId();
+    switch (nClsId)
     {
-        TypeId aType = pFieldData->Type();
-        if (aType == TYPE(SvxPageField))
+        case text::textfield::Type::PAGE:
             aRet = lcl_GetNumStr( aData.nPageNo,aData.eNumType );
-        else if (aType == TYPE(SvxPagesField))
+        break;
+        case text::textfield::Type::PAGES:
             aRet = lcl_GetNumStr( aData.nTotalPages,aData.eNumType );
-        else if (aType == TYPE(SvxTimeField))
+        break;
+        case text::textfield::Type::EXTENDED_TIME:
+        case text::textfield::Type::TIME:
+            // For now, time field in the header / footer is always dynamic.
             aRet = ScGlobal::pLocaleData->getTime(aData.aTime);
-        else if (aType == TYPE(SvxFileField))
+        break;
+        case text::textfield::Type::DOCINFO_TITLE:
             aRet = aData.aTitle;
-        else if (aType == TYPE(SvxExtFileField))
+        break;
+        case text::textfield::Type::EXTENDED_FILE:
         {
-            switch ( ((const SvxExtFileField*)pFieldData)->GetFormat() )
+            switch (static_cast<const SvxExtFileField*>(pFieldData)->GetFormat())
             {
                 case SVXFILEFORMAT_FULLPATH :
                     aRet = aData.aLongDocName;
@@ -672,19 +686,15 @@ String ScHeaderEditEngine::CalcFieldValue( const SvxFieldItem& rField,
                     aRet = aData.aShortDocName;
             }
         }
-        else if (aType == TYPE(SvxTableField))
+        break;
+        case text::textfield::Type::TABLE:
             aRet = aData.aTabName;
-        else if (aType == TYPE(SvxDateField))
+        break;
+        case text::textfield::Type::DATE:
             aRet = ScGlobal::pLocaleData->getDate(aData.aDate);
-        else
-        {
-            aRet = '?';
-        }
-    }
-    else
-    {
-        OSL_FAIL("FieldData ist 0");
-        aRet = '?';
+        break;
+        default:
+            aRet = "?";
     }
 
     return aRet;
@@ -696,11 +706,11 @@ String ScHeaderEditEngine::CalcFieldValue( const SvxFieldItem& rField,
 //
 //------------------------------------------------------------------------
 
-ScFieldEditEngine::ScFieldEditEngine( SfxItemPool* pEnginePoolP,
-            SfxItemPool* pTextObjectPool, sal_Bool bDeleteEnginePoolP )
-        :
+ScFieldEditEngine::ScFieldEditEngine(
+    ScDocument* pDoc, SfxItemPool* pEnginePoolP,
+    SfxItemPool* pTextObjectPool, bool bDeleteEnginePoolP) :
         ScEditEngineDefaulter( pEnginePoolP, bDeleteEnginePoolP ),
-        bExecuteURL( sal_True )
+        mpDoc(pDoc), bExecuteURL(true)
 {
     if ( pTextObjectPool )
         SetEditTextObjectPool( pTextObjectPool );
@@ -713,41 +723,76 @@ String ScFieldEditEngine::CalcFieldValue( const SvxFieldItem& rField,
                                     sal_uInt16 /* nPara */, sal_uInt16 /* nPos */,
                                     Color*& rTxtColor, Color*& /* rFldColor */ )
 {
-    String aRet;
+    rtl::OUString aRet;
     const SvxFieldData* pFieldData = rField.GetField();
 
-    if ( pFieldData )
+    if (!pFieldData)
+        return rtl::OUString(" ");
+
+    sal_uInt16 nClsId = pFieldData->GetClassId();
+    switch (nClsId)
     {
-        TypeId aType = pFieldData->Type();
-
-        if (aType == TYPE(SvxURLField))
+        case text::textfield::Type::URL:
         {
-            String aURL = ((const SvxURLField*)pFieldData)->GetURL();
+            const SvxURLField* pField = static_cast<const SvxURLField*>(pFieldData);
+            rtl::OUString aURL = pField->GetURL();
 
-            switch ( ((const SvxURLField*)pFieldData)->GetFormat() )
+            switch (pField->GetFormat())
             {
                 case SVXURLFORMAT_APPDEFAULT: //!!! einstellbar an App???
                 case SVXURLFORMAT_REPR:
-                    aRet = ((const SvxURLField*)pFieldData)->GetRepresentation();
-                    break;
-
+                    aRet = pField->GetRepresentation();
+                break;
                 case SVXURLFORMAT_URL:
                     aRet = aURL;
-                    break;
+                break;
+                default:
+                    ;
             }
 
             svtools::ColorConfigEntry eEntry =
-                INetURLHistory::GetOrCreate()->QueryUrl( aURL ) ? svtools::LINKSVISITED : svtools::LINKS;
+                INetURLHistory::GetOrCreate()->QueryUrl(String(aURL)) ? svtools::LINKSVISITED : svtools::LINKS;
             rTxtColor = new Color( SC_MOD()->GetColorConfig().GetColorValue(eEntry).nColor );
         }
-        else
+        break;
+        case text::textfield::Type::EXTENDED_TIME:
         {
-            aRet = '?';
+            const SvxExtTimeField* pField = static_cast<const SvxExtTimeField*>(pFieldData);
+            if (mpDoc)
+                aRet = pField->GetFormatted(*mpDoc->GetFormatTable(), ScGlobal::eLnge);
         }
+        break;
+        case text::textfield::Type::DATE:
+        {
+            Date aDate(Date::SYSTEM);
+            aRet = ScGlobal::pLocaleData->getDate(aDate);
+        }
+        break;
+        case text::textfield::Type::DOCINFO_TITLE:
+        {
+            SfxObjectShell* pDocShell = mpDoc->GetDocumentShell();
+            aRet = pDocShell->getDocProperties()->getTitle();
+            if (aRet.isEmpty())
+                aRet = pDocShell->GetTitle();
+        }
+        break;
+        case text::textfield::Type::TABLE:
+        {
+            const SvxTableField* pField = static_cast<const SvxTableField*>(pFieldData);
+            SCTAB nTab = pField->GetTab();
+            rtl::OUString aName;
+            if (mpDoc->GetName(nTab, aName))
+                aRet = aName;
+            else
+                aRet = "?";
+        }
+        break;
+        default:
+            aRet = "?";
     }
 
-    if (!aRet.Len())        // leer ist baeh
-        aRet = ' ';         // Space ist Default der Editengine
+    if (aRet.isEmpty())        // leer ist baeh
+        aRet = " ";         // Space ist Default der Editengine
 
     return aRet;
 }
