@@ -26,12 +26,8 @@
  *
  ************************************************************************/
 
-
-
-
-// INCLUDE ---------------------------------------------------------------
-
 #include "scitems.hxx"
+#include <comphelper/string.hxx>
 #include <editeng/eeitem.hxx>
 
 #include <rtl/tencinfo.h>
@@ -55,9 +51,6 @@
 #include <sfx2/objsh.hxx>
 #include <svl/stritem.hxx>
 #include <svl/urihelper.hxx>
-#ifndef _SVSTDARR_STRINGSSORTDTOR
-#define _SVSTDARR_STRINGSSORTDTOR
-#endif
 #include <svl/svstdarr.hxx>
 #include <svl/zforlist.hxx>
 #include <svtools/htmlkywd.hxx>
@@ -70,7 +63,6 @@
 #include "filter.hxx"
 #include "global.hxx"
 #include "document.hxx"
-#include "scitems.hxx"
 #include "attrib.hxx"
 #include "patattr.hxx"
 #include "stlpool.hxx"
@@ -100,7 +92,9 @@
 #include <com/sun/star/document/XDocumentPropertiesSupplier.hpp>
 #include <rtl/strbuf.hxx>
 
+
 using ::editeng::SvxBorderLine;
+using namespace ::com::sun::star;
 
 //========================================================================
 
@@ -156,7 +150,7 @@ const sal_Char ScHTMLExport::sIndentSource[nIndentMax+1] =
 //========================================================================
 
 FltError ScFormatFilterPluginImpl::ScExportHTML( SvStream& rStrm, const String& rBaseURL, ScDocument* pDoc,
-        const ScRange& rRange, const CharSet /*eNach*/, sal_Bool bAll,
+        const ScRange& rRange, const CharSet /*eNach*/, bool bAll,
         const String& rStreamPath, String& rNonConvertibleChars )
 {
     ScHTMLExport aEx( rStrm, rBaseURL, pDoc, rRange, bAll, rStreamPath );
@@ -375,7 +369,7 @@ void ScHTMLExport::WriteHeader()
         OUT_LF();
 
         //----------------------------------------------------------
-        if (xDocProps->getPrintedBy().getLength())
+        if (!xDocProps->getPrintedBy().isEmpty())
         {
             OUT_COMMENT( GLOBSTR( STR_DOC_INFO ) );
             String aStrOut( GLOBSTR( STR_DOC_PRINTED ) );
@@ -396,7 +390,7 @@ void ScHTMLExport::WriteHeader()
         << OOO_STRING_SVTOOLS_HTML_thead << "," << OOO_STRING_SVTOOLS_HTML_tbody << "," << OOO_STRING_SVTOOLS_HTML_tfoot << ","
         << OOO_STRING_SVTOOLS_HTML_tablerow << "," << OOO_STRING_SVTOOLS_HTML_tableheader << ","
         << OOO_STRING_SVTOOLS_HTML_tabledata << "," << OOO_STRING_SVTOOLS_HTML_parabreak << " { " << sFontFamily;
-    xub_StrLen nFonts = aHTMLStyle.aFontFamilyName.GetTokenCount( ';' );
+    xub_StrLen nFonts = comphelper::string::getTokenCount(aHTMLStyle.aFontFamilyName, ';');
     if ( nFonts == 1 )
     {
         rStrm << '\"';
@@ -528,36 +522,36 @@ rtl::OString ScHTMLExport::BorderToStyle(const char* pBorderName,
             std::max(int(nWidth / TWIPS_PER_PIXEL), 1) : 0;
         aOut.append(static_cast<sal_Int32>(nPxWidth)).
             append(RTL_CONSTASCII_STRINGPARAM("px "));
-        switch ( pLine->GetStyle() )
+        switch (pLine->GetBorderLineStyle())
         {
-            case ::editeng::SOLID:
+            case table::BorderLineStyle::SOLID:
                 aOut.append(RTL_CONSTASCII_STRINGPARAM("solid"));
                 break;
-            case ::editeng::DOTTED:
+            case table::BorderLineStyle::DOTTED:
                 aOut.append(RTL_CONSTASCII_STRINGPARAM("dotted"));
                 break;
-            case ::editeng::DASHED:
+            case table::BorderLineStyle::DASHED:
                 aOut.append(RTL_CONSTASCII_STRINGPARAM("dashed"));
                 break;
-            case ::editeng::DOUBLE:
-            case ::editeng::THINTHICK_SMALLGAP:
-            case ::editeng::THINTHICK_MEDIUMGAP:
-            case ::editeng::THINTHICK_LARGEGAP:
-            case ::editeng::THICKTHIN_SMALLGAP:
-            case ::editeng::THICKTHIN_MEDIUMGAP:
-            case ::editeng::THICKTHIN_LARGEGAP:
+            case table::BorderLineStyle::DOUBLE:
+            case table::BorderLineStyle::THINTHICK_SMALLGAP:
+            case table::BorderLineStyle::THINTHICK_MEDIUMGAP:
+            case table::BorderLineStyle::THINTHICK_LARGEGAP:
+            case table::BorderLineStyle::THICKTHIN_SMALLGAP:
+            case table::BorderLineStyle::THICKTHIN_MEDIUMGAP:
+            case table::BorderLineStyle::THICKTHIN_LARGEGAP:
                 aOut.append(RTL_CONSTASCII_STRINGPARAM("double"));
                 break;
-            case ::editeng::EMBOSSED:
+            case table::BorderLineStyle::EMBOSSED:
                 aOut.append(RTL_CONSTASCII_STRINGPARAM("ridge"));
                 break;
-            case ::editeng::ENGRAVED:
+            case table::BorderLineStyle::ENGRAVED:
                 aOut.append(RTL_CONSTASCII_STRINGPARAM("groove"));
                 break;
-            case ::editeng::OUTSET:
+            case table::BorderLineStyle::OUTSET:
                 aOut.append(RTL_CONSTASCII_STRINGPARAM("outset"));
                 break;
-            case ::editeng::INSET:
+            case table::BorderLineStyle::INSET:
                 aOut.append(RTL_CONSTASCII_STRINGPARAM("inset"));
                 break;
             default:
@@ -1124,7 +1118,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
         {
             aStr.append(' ').append(OOO_STRING_SVTOOLS_HTML_O_face).
                 append(RTL_CONSTASCII_STRINGPARAM("=\""));
-            xub_StrLen nFonts = rFontItem.GetFamilyName().GetTokenCount( ';' );
+            xub_StrLen nFonts = comphelper::string::getTokenCount(rFontItem.GetFamilyName(), ';');
             if ( nFonts == 1 )
             {
                 rtl::OString aTmpStr = HTMLOutFuncs::ConvertStringToHTML(
@@ -1336,8 +1330,7 @@ sal_Bool ScHTMLExport::CopyLocalFileToINet( String& rFileNm,
         }
         else
         {
-            SfxMedium aMedium( aDest, STREAM_WRITE | STREAM_SHARE_DENYNONE,
-                                false );
+            SfxMedium aMedium( aDest, STREAM_WRITE | STREAM_SHARE_DENYNONE );
 
             {
                 SvFileStream aCpy( aMedium.GetPhysicalName(), STREAM_WRITE );
