@@ -72,6 +72,13 @@ SvXMLImportContext* ScXMLConditionalFormatsContext::CreateChildContext( sal_uInt
 
 void ScXMLConditionalFormatsContext::EndElement()
 {
+    ScDocument* pDoc = GetScImport().GetDocument();
+
+    SCTAB nTab = GetScImport().GetTables().GetCurrentSheet();
+    ScConditionalFormatList* pCondFormatList = pDoc->GetCondFormList(nTab);
+    bool bDeleted = !pCondFormatList->CheckAllEntries();
+
+    SAL_WARN_IF(bDeleted, "sc", "conditional formats have been deleted because they contained empty range info");
 }
 
 ScXMLConditionalFormatContext::ScXMLConditionalFormatContext( ScXMLImport& rImport, sal_uInt16 nPrfx,
@@ -313,7 +320,7 @@ void GetConditionData(const rtl::OUString& rValue, ScConditionMode& eMode, rtl::
     else if(rValue.indexOf("between") == 0)
     {
         const sal_Unicode* pStr = rValue.getStr();
-        const sal_Unicode* pStart = pStr + 7;
+        const sal_Unicode* pStart = pStr + 8;
         const sal_Unicode* pEnd = pStr + rValue.getLength();
         rExpr1 = ScXMLConditionHelper::getExpression( pStart, pEnd, ',');
         rExpr2 = ScXMLConditionHelper::getExpression( pStart, pEnd, ')');
