@@ -67,8 +67,6 @@
 
 #include <memory>
 
-#define SC_ENABLEUSERSORTLIST   "EnableUserSortList"
-#define SC_USERSORTLISTINDEX    "UserSortListIndex"
 #define SC_USERLIST             "UserList"
 
 using namespace com::sun::star;
@@ -370,11 +368,11 @@ ScDBData* ScXMLDatabaseRangeContext::ConvertToDBData(const OUString& rName)
         ScSortDescriptor::FillSortParam(aParam, aSortSequence);
 
         SCCOLROW nStartPos = aParam.bByRow ? maRange.aStart.Col() : maRange.aStart.Row();
-        for (size_t i = 0; i < MAXSORT; ++i)
+        for (size_t i = 0; i < aParam.GetSortKeyCount(); ++i)
         {
-            if (!aParam.bDoSort[i])
+            if (!aParam.maKeyState[i].bDoSort)
                 break;
-            aParam.nField[i] += nStartPos;
+            aParam.maKeyState[i].nField += nStartPos;
         }
 
         pData->SetSortParam(aParam);
@@ -567,7 +565,7 @@ SvXMLImportContext *ScXMLSourceSQLContext::CreateChildContext( sal_uInt16 nPrefi
 
     if ( nPrefix == XML_NAMESPACE_FORM )
     {
-        if (IsXMLToken(rLName, XML_CONNECTION_RESOURCE) && (sDBName.getLength() == 0))
+        if (IsXMLToken(rLName, XML_CONNECTION_RESOURCE) && sDBName.isEmpty())
         {
             pContext = new ScXMLConResContext( GetScImport(), nPrefix,
                                                           rLName, xAttrList, pDatabaseRangeContext);
@@ -582,7 +580,7 @@ SvXMLImportContext *ScXMLSourceSQLContext::CreateChildContext( sal_uInt16 nPrefi
 
 void ScXMLSourceSQLContext::EndElement()
 {
-    if (sDBName.getLength())
+    if (!sDBName.isEmpty())
         pDatabaseRangeContext->SetDatabaseName(sDBName);
 }
 
@@ -635,7 +633,7 @@ SvXMLImportContext *ScXMLSourceTableContext::CreateChildContext( sal_uInt16 nPre
 
     if ( nPrefix == XML_NAMESPACE_FORM )
     {
-        if (IsXMLToken(rLName, XML_CONNECTION_RESOURCE) && (sDBName.getLength() == 0))
+        if (IsXMLToken(rLName, XML_CONNECTION_RESOURCE) && sDBName.isEmpty())
         {
             pContext = new ScXMLConResContext( GetScImport(), nPrefix,
                                                           rLName, xAttrList, pDatabaseRangeContext);
@@ -650,7 +648,7 @@ SvXMLImportContext *ScXMLSourceTableContext::CreateChildContext( sal_uInt16 nPre
 
 void ScXMLSourceTableContext::EndElement()
 {
-    if (sDBName.getLength())
+    if (!sDBName.isEmpty())
         pDatabaseRangeContext->SetDatabaseName(sDBName);
 }
 
@@ -703,7 +701,7 @@ SvXMLImportContext *ScXMLSourceQueryContext::CreateChildContext( sal_uInt16 nPre
 
     if ( nPrefix == XML_NAMESPACE_FORM )
     {
-        if (IsXMLToken(rLName, XML_CONNECTION_RESOURCE) && (sDBName.getLength() == 0))
+        if (IsXMLToken(rLName, XML_CONNECTION_RESOURCE) && sDBName.isEmpty())
         {
             pContext = new ScXMLConResContext( GetScImport(), nPrefix,
                                                           rLName, xAttrList, pDatabaseRangeContext);
@@ -718,7 +716,7 @@ SvXMLImportContext *ScXMLSourceQueryContext::CreateChildContext( sal_uInt16 nPre
 
 void ScXMLSourceQueryContext::EndElement()
 {
-    if (sDBName.getLength())
+    if (!sDBName.isEmpty())
         pDatabaseRangeContext->SetDatabaseName(sDBName);
 }
 
@@ -747,7 +745,7 @@ ScXMLConResContext::ScXMLConResContext( ScXMLImport& rImport,
                 sConRes = sValue;
         }
     }
-    if (sConRes.getLength())
+    if (!sConRes.isEmpty())
         pDatabaseRangeContext->SetConnectionRessource(sConRes);
 }
 
