@@ -1329,12 +1329,6 @@ bool ScDBDocFunc::DataPilotUpdate( ScDPObject* pOldObj, const ScDPObject* pNewOb
             }
             if ( pDestObj )
             {
-                // create new database connection for "refresh"
-                // (and re-read column entry collections)
-                // so all changes take effect
-                if ( pNewObj == pOldObj && pDestObj->IsImportData() )
-                    pDestObj->ClearTableData();
-
                 pDestObj->ReloadGroupTableData();
                 pDestObj->InvalidateData();             // before getting the new output area
 
@@ -1478,7 +1472,8 @@ sal_uLong ScDBDocFunc::RefreshPivotTables(ScDPObject* pDPObj, bool bApi)
     for (; it != itEnd; ++it)
     {
         ScDPObject* pObj = *it;
-        pObj->SyncAllDimensionMembers();
+        if (!pObj->SyncAllDimensionMembers())
+            continue;
 
         // This action is intentionally not undoable since it modifies cache.
         DataPilotUpdate(pObj, pObj, false, bApi);
