@@ -53,7 +53,6 @@
 #include "scmod.hxx"
 #include "attrib.hxx"
 #include "zforauto.hxx"
-#include "scitems.hxx"
 #include "global.hxx"
 #include "globstr.hrc"
 #include "autoform.hxx"
@@ -452,7 +451,7 @@ void ScAutoFmtPreview::Init()
 
 //------------------------------------------------------------------------
 
-void ScAutoFmtPreview::CalcCellArray( sal_Bool bFitWidthP )
+void ScAutoFmtPreview::CalcCellArray( bool bFitWidthP )
 {
     maArray.SetXOffset( 2 );
     maArray.SetAllColWidths( bFitWidthP ? mnDataColWidth2 : mnDataColWidth1 );
