@@ -40,7 +40,6 @@
 #include <com/sun/star/lang/XUnoTunnel.hpp>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/string.hxx>
-#include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
 #include <com/sun/star/io/XInputStream.hpp>
 #include <com/sun/star/task/XInteractionHandler.hpp>
@@ -50,9 +49,6 @@
 #include <com/sun/star/ucb/XContent.hpp>
 #include <com/sun/star/packages/zip/ZipIOException.hpp>
 
-
-#include <framework/interaction.hxx>
-
 #include <toolkit/helper/vclunohelper.hxx>
 #include <ucbhelper/simpleinteractionrequest.hxx>
 
@@ -197,7 +193,7 @@ static sal_Bool lcl_MayBeDBase( SvStream& rStream )
     rStream.Seek(STREAM_SEEK_TO_BEGIN);
     rStream >> nMark;
     bool bValidMark = false;
-    for (size_t i=0; i < SAL_N_ELEMENTS(nValidMarks) && !bValidMark; ++i)
+    for (size_t i=0; i < sizeof(nValidMarks)/sizeof(nValidMarks[0]) && !bValidMark; ++i)
     {
         if (nValidMarks[i] == nMark)
             bValidMark = true;
@@ -273,22 +269,22 @@ static sal_Bool lcl_MayBeDBase( SvStream& rStream )
     for( sal_Int32 nProperty=0; nProperty<nPropertyCount; ++nProperty )
     {
         // extract properties
-        if( lDescriptor[nProperty].Name == OUString(RTL_CONSTASCII_USTRINGPARAM("URL")) )
+        if ( lDescriptor[nProperty].Name == "URL" )
         {
             lDescriptor[nProperty].Value >>= sTemp;
             aURL = sTemp;
         }
-        else if( !aURL.Len() && lDescriptor[nProperty].Name == OUString(RTL_CONSTASCII_USTRINGPARAM("FileName")) )
+        else if( !aURL.Len() && lDescriptor[nProperty].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("FileName")) )
         {
             lDescriptor[nProperty].Value >>= sTemp;
             aURL = sTemp;
         }
-        else if( lDescriptor[nProperty].Name == OUString(RTL_CONSTASCII_USTRINGPARAM("TypeName")) )
+        else if ( lDescriptor[nProperty].Name == "TypeName" )
         {
             lDescriptor[nProperty].Value >>= sTemp;
             aTypeName = sTemp;
         }
-        else if( lDescriptor[nProperty].Name == OUString(RTL_CONSTASCII_USTRINGPARAM("FilterName")) )
+        else if ( lDescriptor[nProperty].Name == "FilterName" )
         {
             lDescriptor[nProperty].Value >>= sTemp;
             aPreselectedFilterName = sTemp;
@@ -297,22 +293,22 @@ static sal_Bool lcl_MayBeDBase( SvStream& rStream )
             // remember index of property to get access to it later
             nIndexOfFilterName = nProperty;
         }
-        else if( lDescriptor[nProperty].Name == OUString(RTL_CONSTASCII_USTRINGPARAM("InputStream")) )
+        else if ( lDescriptor[nProperty].Name == "InputStream" )
             nIndexOfInputStream = nProperty;
-        else if( lDescriptor[nProperty].Name == OUString(RTL_CONSTASCII_USTRINGPARAM("ReadOnly")) )
+        else if ( lDescriptor[nProperty].Name == "ReadOnly" )
             nIndexOfReadOnlyFlag = nProperty;
-        else if( lDescriptor[nProperty].Name == OUString(RTL_CONSTASCII_USTRINGPARAM("UCBContent")) )
+        else if ( lDescriptor[nProperty].Name == "UCBContent" )
             nIndexOfContent = nProperty;
-        else if( lDescriptor[nProperty].Name == OUString(RTL_CONSTASCII_USTRINGPARAM("AsTemplate")) )
+        else if ( lDescriptor[nProperty].Name == "AsTemplate" )
         {
             lDescriptor[nProperty].Value >>= bOpenAsTemplate;
             nIndexOfTemplateFlag = nProperty;
         }
-        else if( lDescriptor[nProperty].Name == OUString(RTL_CONSTASCII_USTRINGPARAM("InteractionHandler")) )
+        else if ( lDescriptor[nProperty].Name == "InteractionHandler" )
             lDescriptor[nProperty].Value >>= xInteraction;
-        else if( lDescriptor[nProperty].Name == OUString(RTL_CONSTASCII_USTRINGPARAM("RepairPackage")) )
+        else if ( lDescriptor[nProperty].Name == "RepairPackage" )
             lDescriptor[nProperty].Value >>= bRepairPackage;
-        else if( lDescriptor[nProperty].Name == OUString(RTL_CONSTASCII_USTRINGPARAM("DocumentTitle")) )
+        else if ( lDescriptor[nProperty].Name == "DocumentTitle" )
             nIndexOfDocumentTitle = nProperty;
     }
 
@@ -345,7 +341,7 @@ static sal_Bool lcl_MayBeDBase( SvStream& rStream )
             pFilter = aMatcher.GetFilter4EA( aTypeName );
 
         // ctor of SfxMedium uses owner transition of ItemSet
-        SfxMedium aMedium( aURL, bWasReadOnly ? STREAM_STD_READ : STREAM_STD_READWRITE, false, NULL, pSet );
+        SfxMedium aMedium( aURL, bWasReadOnly ? STREAM_STD_READ : STREAM_STD_READWRITE, NULL, pSet );
         aMedium.UseInteractionHandler( sal_True );
 
         sal_Bool bIsStorage = aMedium.IsStorage();
@@ -445,17 +441,27 @@ static sal_Bool lcl_MayBeDBase( SvStream& rStream )
             }
             else
             {
-                bool bIsXLS = false;
                 SvStream* pStream = aMedium.GetInStream();
                 const SfxFilter* pPreselectedFilter = pFilter;
-                if ( pPreselectedFilter && ( ( pPreselectedFilter->GetName().SearchAscii("Excel") != STRING_NOTFOUND ) ||
-                    ( !aPreselectedFilterName.Len() && pPreselectedFilter->GetFilterName().EqualsAscii( pFilterAscii ) ) ) )
-                    bIsXLS = true;
+                bool bCsvSelected = (pPreselectedFilter &&
+                        pPreselectedFilter->GetFilterName().EqualsAscii( pFilterAscii ));
+                bool bExcelSelected = (pPreselectedFilter &&
+                        (pPreselectedFilter->GetName().SearchAscii("Excel") != STRING_NOTFOUND));
+                bool bIsXLS = (bExcelSelected || (bCsvSelected && !aPreselectedFilterName.Len()));
                 pFilter = 0;
                 if ( pStream )
                 {
-                    SotStorageRef aStorage = new SotStorage ( pStream, false );
-                    if ( !aStorage->GetError() )
+                    pStream->Seek( STREAM_SEEK_TO_END);
+                    sal_Size nSize = pStream->Tell();
+                    pStream->Seek( 0);
+                    // Do not attempt to create an SotStorage on a
+                    // 0-length stream as that would create the compound
+                    // document header on the stream and effectively write to
+                    // disk!
+                    SotStorageRef aStorage;
+                    if (nSize > 0)
+                        aStorage = new SotStorage ( pStream, false );
+                    if ( aStorage.Is() && !aStorage->GetError() )
                     {
                         // Excel-5: detect through contained streams
                         // there are some "excel" formats from 3rd party vendors that need to be distinguished
@@ -526,7 +532,7 @@ static sal_Bool lcl_MayBeDBase( SvStream& rStream )
                             }
                         }
                     }
-                    else
+                    else if (nSize > 0)
                     {
                         SvStream &rStr = *pStream;
 
@@ -644,7 +650,7 @@ static sal_Bool lcl_MayBeDBase( SvStream& rStream )
                             pLotus2,
                             pQPro
                             };
-                        const sal_uInt16 nFilterCount = SAL_N_ELEMENTS(ppFilterPatterns);
+                        const sal_uInt16 nFilterCount = sizeof (ppFilterPatterns) / sizeof (ppFilterPatterns[0]);
 
                         static const sal_Char* const pFilterName[] =     // zugehoerige Filter
                             {
@@ -671,9 +677,15 @@ static sal_Bool lcl_MayBeDBase( SvStream& rStream )
 
                         for ( nFilter = 0 ; nFilter < nFilterCount ; nFilter++ )
                         {
+                            pSearch = ppFilterPatterns[ nFilter ];
+                            if (bCsvSelected && pSearch == pSylk)
+                                // SYLK 4 characters is really too weak to
+                                // override preselected CSV, already ID;Name
+                                // would trigger that. fdo#48347
+                                continue;
+
                             rStr.Seek( 0 ); // am Anfang war alles Uebel...
                             rStr >> nAkt;
-                            pSearch = ppFilterPatterns[ nFilter ];
                             bSync = sal_True;
                             while( !rStr.IsEof() && bSync )
                             {
@@ -735,14 +747,16 @@ static sal_Bool lcl_MayBeDBase( SvStream& rStream )
                             // get file header
                             rStr.Seek( 0 );
                             const sal_Size nTrySize = 80;
-                            ByteString aHeader = read_uInt8s_AsOString(rStr, nTrySize);
+                            rtl::OString aHeader = read_uInt8s_ToOString(rStr, nTrySize);
 
-                            if ( aHeader.CompareTo( "{\\rtf", 5 ) == COMPARE_EQUAL )
+                            bool bMaybeHtml = HTMLParser::IsHTMLFormat( aHeader.getStr());
+
+                            if ( aHeader.copy(0, 5).equalsL("{\\rtf", 5) )
                             {
                                 // test for RTF
                                 pFilter = aMatcher.GetFilter4FilterName( String::CreateFromAscii(pFilterRtf) );
                             }
-                            else if ( bIsXLS && bMaybeText )
+                            else if ( bIsXLS && (bMaybeText && !bMaybeHtml) )
                             {
                                 aHeader = comphelper::string::stripStart(aHeader, ' ');
                                 // Detect Excel 2003 XML here only if XLS was preselected.
@@ -754,9 +768,9 @@ static sal_Bool lcl_MayBeDBase( SvStream& rStream )
                             }
                             else if ( pPreselectedFilter->GetName().EqualsAscii(pFilterDBase) && lcl_MayBeDBase( rStr ) )
                                 pFilter = pPreselectedFilter;
-                            else if ( pPreselectedFilter->GetFilterName().EqualsAscii(pFilterAscii) && bMaybeText )
+                            else if ( bCsvSelected && bMaybeText )
                                 pFilter = pPreselectedFilter;
-                            else if ( HTMLParser::IsHTMLFormat( aHeader.GetBuffer() ) )
+                            else if ( bMaybeHtml )
                             {
                                 // test for HTML
 
@@ -780,6 +794,13 @@ static sal_Bool lcl_MayBeDBase( SvStream& rStream )
                             }
                         }
                     }
+                    else
+                    {
+                        // 0-length stream, preselected Text/CSV is ok, user
+                        // may want to write to that file later.
+                        if ( bCsvSelected )
+                            pFilter = pPreselectedFilter;
+                    }
                 }
             }
         }
@@ -841,7 +862,7 @@ static sal_Bool lcl_MayBeDBase( SvStream& rStream )
             lDescriptor[nIndexOfTemplateFlag].Value <<= bOpenAsTemplate;
     }
 
-    if ( aDocumentTitle.getLength() )
+    if ( !aDocumentTitle.isEmpty() )
     {
         // the title was set here
         if ( nIndexOfDocumentTitle == -1 )
@@ -875,19 +896,17 @@ static sal_Bool lcl_MayBeDBase( SvStream& rStream )
     return aTypeName;
 }
 
-SFX_IMPL_SINGLEFACTORY( ScFilterDetect )
-
 /* XServiceInfo */
-UNOOUSTRING SAL_CALL ScFilterDetect::getImplementationName() throw( UNORUNTIMEEXCEPTION )
+rtl::OUString SAL_CALL ScFilterDetect::getImplementationName() throw( UNORUNTIMEEXCEPTION )
 {
     return impl_getStaticImplementationName();
 }
                                                                                                                                 \
 /* XServiceInfo */
-sal_Bool SAL_CALL ScFilterDetect::supportsService( const UNOOUSTRING& sServiceName ) throw( UNORUNTIMEEXCEPTION )
+sal_Bool SAL_CALL ScFilterDetect::supportsService( const rtl::OUString& sServiceName ) throw( UNORUNTIMEEXCEPTION )
 {
-    UNOSEQUENCE< UNOOUSTRING >  seqServiceNames(getSupportedServiceNames());
-    const UNOOUSTRING*          pArray          =   seqServiceNames.getConstArray();
+    UNOSEQUENCE< rtl::OUString > seqServiceNames(getSupportedServiceNames());
+    const rtl::OUString*         pArray          = seqServiceNames.getConstArray();
     for ( sal_Int32 nCounter=0; nCounter<seqServiceNames.getLength(); nCounter++ )
     {
         if ( pArray[nCounter] == sServiceName )
@@ -899,23 +918,23 @@ sal_Bool SAL_CALL ScFilterDetect::supportsService( const UNOOUSTRING& sServiceNa
 }
 
 /* XServiceInfo */
-UNOSEQUENCE< UNOOUSTRING > SAL_CALL ScFilterDetect::getSupportedServiceNames() throw( UNORUNTIMEEXCEPTION )
+UNOSEQUENCE< rtl::OUString > SAL_CALL ScFilterDetect::getSupportedServiceNames() throw( UNORUNTIMEEXCEPTION )
 {
     return impl_getStaticSupportedServiceNames();
 }
 
 /* Helper for XServiceInfo */
-UNOSEQUENCE< UNOOUSTRING > ScFilterDetect::impl_getStaticSupportedServiceNames()
+UNOSEQUENCE< rtl::OUString > ScFilterDetect::impl_getStaticSupportedServiceNames()
 {
-    UNOSEQUENCE< UNOOUSTRING > seqServiceNames( 1 );
-    seqServiceNames.getArray() [0] = UNOOUSTRING(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.frame.ExtendedTypeDetection"  ));
+    UNOSEQUENCE< rtl::OUString > seqServiceNames( 1 );
+    seqServiceNames.getArray() [0] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.frame.ExtendedTypeDetection"  ));
     return seqServiceNames ;
 }
 
 /* Helper for XServiceInfo */
-UNOOUSTRING ScFilterDetect::impl_getStaticImplementationName()
+OUString ScFilterDetect::impl_getStaticImplementationName()
 {
-    return UNOOUSTRING(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.calc.FormatDetector" ));
+    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.calc.FormatDetector" ));
 }
 
 /* Helper for registry */
