@@ -388,7 +388,7 @@ MotionPathTag::MotionPathTag( CustomAnimationPane& rPane, ::sd::View& rView, con
     }
 
     XDash aDash( XDASH_RECT, 1, 80, 1, 80, 80);
-    String aEmpty( RTL_CONSTASCII_USTRINGPARAM("?") );
+    rtl::OUString aEmpty( "?" );
     mpPathObj->SetMergedItem( XLineDashItem( aEmpty, aDash ) );
     mpPathObj->SetMergedItem( XLineStyleItem( XLINE_DASH ) );
     mpPathObj->SetMergedItem( XLineColorItem(aEmpty, ::Color(COL_GRAY)) );
@@ -431,7 +431,7 @@ MotionPathTag::~MotionPathTag()
 
 void MotionPathTag::updatePathAttributes()
 {
-    String aEmpty( RTL_CONSTASCII_USTRINGPARAM("?") );
+    rtl::OUString aEmpty( "?" );
 
     ::basegfx::B2DPolygon aCandidate;
     if( mxPolyPoly.count() )
@@ -526,7 +526,7 @@ bool MotionPathTag::MouseButtonDown( const MouseEvent& rMEvt, SmartHdl& rHdl )
                 if(bNewObj)
                     aPt = mrView.GetSnapPos(aPt,mrView.GetSdrPageView());
 
-                sal_Bool bClosed0(mpPathObj->IsClosedObj());
+                bool bClosed0(mpPathObj->IsClosedObj());
 
                 sal_uInt32 nInsPointNum = mpPathObj->NbcInsPointOld(aPt, bNewObj, sal_True);
 
