@@ -72,7 +72,6 @@
 #include "glob.hrc"
 #include "sdmod.hxx"
 #include "sdxfer.hxx"
-#include "FrameView.hxx"
 #include "ViewShellHint.hxx"
 #include "AccessibleSlideSorterView.hxx"
 #include "AccessibleSlideSorterObject.hxx"
@@ -86,7 +85,6 @@
 #include <sfx2/request.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/dispatch.hxx>
-#include <tools/link.hxx>
 #include <vcl/svapp.hxx>
 
 #include <com/sun/star/lang/XComponent.hpp>
@@ -189,9 +187,8 @@ SlideSorterController::~SlideSorterController (void)
         if (xComponent.is())
             xComponent->dispose();
     }
-    catch( uno::Exception& e )
+    catch( uno::Exception& )
     {
-        (void)e;
         OSL_FAIL( "sd::SlideSorterController::~SlideSorterController(), exception caught!" );
     }
 
