@@ -140,7 +140,7 @@ SlideSorterViewShell::SlideSorterViewShell (
         mpFrameView = new FrameView(GetDoc());
     GetFrameView()->Connect();
 
-    SetName (String (RTL_CONSTASCII_USTRINGPARAM("SlideSorterViewShell")));
+    SetName (rtl::OUString("SlideSorterViewShell"));
 
     pParentWindow->SetStyle(pParentWindow->GetStyle() | WB_DIALOGCONTROL);
 }
@@ -165,9 +165,8 @@ SlideSorterViewShell::~SlideSorterViewShell (void)
                 xComponent->dispose();
         }
     }
-    catch( ::com::sun::star::uno::Exception& e )
+    catch( ::com::sun::star::uno::Exception& )
     {
-        (void)e;
         OSL_FAIL("sd::SlideSorterViewShell::~SlideSorterViewShell(), exception caught!" );
     }
     GetFrameView()->Disconnect();
@@ -187,7 +186,7 @@ void SlideSorterViewShell::Initialize (void)
         mpScrollBarBox);
     mpView = &mpSlideSorter->GetView();
 
-    ViewShell::doShow();
+    doShow();
 
     SetPool( &GetDoc()->GetPool() );
     SetUndoManager( GetDoc()->GetDocSh()->GetUndoManager() );
@@ -237,7 +236,7 @@ SlideSorterViewShell* SlideSorterViewShell::GetSlideSorter (ViewShellBase& rBase
     {
         ::boost::shared_ptr<FrameworkHelper> pFrameworkHelper (FrameworkHelper::Instance(rBase));
         if (pFrameworkHelper->IsValid())
-            for (int i=0; pViewShell==NULL && aPaneURLs[i].getLength()>0; ++i)
+            for (int i=0; pViewShell==NULL && !aPaneURLs[i].isEmpty(); ++i)
             {
                 pViewShell = dynamic_cast<SlideSorterViewShell*>(
                     pFrameworkHelper->GetViewShell(aPaneURLs[i]).get());
