@@ -956,7 +956,7 @@ void SlideSorterView::UpdatePageUnderMouse (
     const bool bAnimate)
 {
     // Update the page under the mouse.
-    SetPageUnderMouse(rpDescriptor, bAnimate, rMousePosition);
+    SetPageUnderMouse(rpDescriptor, bAnimate);
 
     // Tell the button bar about the new mouse position.
     SharedSdWindow pWindow (mrSlideSorter.GetContentWindow());
@@ -984,8 +984,7 @@ void SlideSorterView::UpdatePageUnderMouse (
 
 void SlideSorterView::SetPageUnderMouse (
     const model::SharedPageDescriptor& rpDescriptor,
-    const bool bAnimate,
-    const Point& rMousePosition)
+    const bool bAnimate)
 {
     if (mpPageUnderMouse != rpDescriptor)
     {
@@ -995,7 +994,7 @@ void SlideSorterView::SetPageUnderMouse (
         mpPageUnderMouse = rpDescriptor;
 
         if (mpPageUnderMouse)
-            SetState(mpPageUnderMouse, PageDescriptor::ST_MouseOver, true, bAnimate, rMousePosition);
+            SetState(mpPageUnderMouse, PageDescriptor::ST_MouseOver, true, bAnimate);
 
         // Change the quick help text to display the name of the page under
         // the mouse.
@@ -1010,8 +1009,7 @@ bool SlideSorterView::SetState (
     const model::SharedPageDescriptor& rpDescriptor,
     const PageDescriptor::State eState,
     const bool bStateValue,
-    const bool bAnimate,
-    const Point& rMousePosition)
+    const bool bAnimate)
 {
     model::SharedPageDescriptor pDescriptor (rpDescriptor);
     if ( ! pDescriptor)
@@ -1039,11 +1037,7 @@ bool SlideSorterView::SetState (
         if (eState == PageDescriptor::ST_MouseOver)
         {
             if (bStateValue)
-            {
-                if (bAnimate)
-                    GetButtonBar().UpdateButtonPosition(rpDescriptor, rMousePosition);
                 GetButtonBar().RequestFadeIn(rpDescriptor, bAnimate);
-            }
             else
                 GetButtonBar().RequestFadeOut(rpDescriptor, bAnimate);
         }
