@@ -71,11 +71,6 @@ using ::rtl::OUString;
 namespace sd {
 
 namespace {
-    OUString A2S (const char* pString)
-    {
-        return OUString::createFromAscii(pString);
-    }
-
 
 
     /** Convenience class to extract values from the sequence of properties
@@ -222,7 +217,7 @@ namespace {
             if (nContent == 1) // range
             {
                 OUString sValue = mrProperties.getStringValue("PageRange");
-                return sValue.getLength() ? sValue : sFullRange;
+                return sValue.isEmpty() ? sFullRange : sValue;
             }
 
             if (nContent == 2 && // selection
@@ -261,7 +256,7 @@ namespace {
             const bool bDefaultValue = false) const
         {
             OUString sValue( mrProperties.getStringValue( pName ) );
-            if (sValue.getLength())
+            if (!sValue.isEmpty())
                 return sValue.equalsAscii(pValue);
             else
                 return bDefaultValue;
@@ -412,72 +407,70 @@ namespace {
                                            aOpt.GetModuleName( mbImpress ? SvtModuleOptions::E_SIMPRESS : SvtModuleOptions::E_SDRAW ) );
             AddDialogControl( vcl::PrinterOptionsHelper::getGroupControlOpt(
                                 aAppGroupname,
-                                rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:TabPage:AppPage" ) )
+                                ".HelpID:vcl:PrintDialog:TabPage:AppPage"
                                 ) );
 
             uno::Sequence< rtl::OUString > aHelpIds;
             if( mbImpress )
             {
                 vcl::PrinterOptionsHelper::UIControlOptions aPrintOpt;
-                aPrintOpt.maGroupHint = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "JobPage" ) );
+                aPrintOpt.maGroupHint = "JobPage" ;
                 AddDialogControl( vcl::PrinterOptionsHelper::getSubgroupControlOpt(
                                     String( SdResId(_STR_IMPRESS_PRINT_UI_PRINT_GROUP) ),
-                                    rtl::OUString(),
+                                    "",
                                     aPrintOpt )
                                     );
 
                 aHelpIds.realloc( 1 );
-                aHelpIds[0] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:PageContentType:ListBox" ) );
+                aHelpIds[0] = ".HelpID:vcl:PrintDialog:PageContentType:ListBox" ;
                 AddDialogControl( vcl::PrinterOptionsHelper::getChoiceControlOpt(
                                     String( SdResId( _STR_IMPRESS_PRINT_UI_CONTENT ) ),
                                     aHelpIds,
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( "PageContentType" ) ),
+                                    "PageContentType" ,
                                     CreateChoice(_STR_IMPRESS_PRINT_UI_CONTENT_CHOICES),
                                     0,
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( "List" ) )
+                                    "List"
                                     )
                                 );
 
-                aHelpIds[0] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:SlidesPerPage:ListBox" ) );
-                vcl::PrinterOptionsHelper::UIControlOptions
-                    aContentOpt( OUString( RTL_CONSTASCII_USTRINGPARAM( "PageContentType" ) ), 1 );
+                aHelpIds[0] = ".HelpID:vcl:PrintDialog:SlidesPerPage:ListBox" ;
+                vcl::PrinterOptionsHelper::UIControlOptions aContentOpt( "PageContentType" , 1 );
                 AddDialogControl( vcl::PrinterOptionsHelper::getChoiceControlOpt(
                                     String( SdResId( _STR_IMPRESS_PRINT_UI_SLIDESPERPAGE ) ),
                                     aHelpIds,
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( "SlidesPerPage" ) ),
+                                    "SlidesPerPage" ,
                                     GetSlidesPerPageSequence(),
                                     0,
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( "List" ) ),
+                                    "List",
                                     Sequence< sal_Bool >(),
                                     aContentOpt
                                     )
                                 );
 
-                aHelpIds[0] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:SlidesPerPageOrder:ListBox" ) );
-                vcl::PrinterOptionsHelper::UIControlOptions
-                    aSlidesPerPageOpt( OUString( RTL_CONSTASCII_USTRINGPARAM( "SlidesPerPage" ) ), -1, sal_True );
+                aHelpIds[0] = ".HelpID:vcl:PrintDialog:SlidesPerPageOrder:ListBox" ;
+                vcl::PrinterOptionsHelper::UIControlOptions aSlidesPerPageOpt( "SlidesPerPage" , -1, sal_True );
                 AddDialogControl( vcl::PrinterOptionsHelper::getChoiceControlOpt(
                                     String( SdResId( _STR_IMPRESS_PRINT_UI_ORDER ) ),
                                     aHelpIds,
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( "SlidesPerPageOrder" ) ),
+                                    "SlidesPerPageOrder" ,
                                     CreateChoice(_STR_IMPRESS_PRINT_UI_ORDER_CHOICES),
                                     0,
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( "List" ) ),
+                                    "List" ,
                                     Sequence< sal_Bool >(),
                                     aSlidesPerPageOpt )
                                 );
             }
 
             AddDialogControl( vcl::PrinterOptionsHelper::getSubgroupControlOpt(
-                               String( SdResId(_STR_IMPRESS_PRINT_UI_INCLUDE_CONTENT) ), rtl::OUString() ) );
+                               String( SdResId(_STR_IMPRESS_PRINT_UI_INCLUDE_CONTENT) ), "" ) );
 
 
             if( mbImpress )
             {
                 AddDialogControl( vcl::PrinterOptionsHelper::getBoolControlOpt(
                                     String( SdResId(_STR_IMPRESS_PRINT_UI_IS_PRINT_NAME) ),
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:IsPrintName:CheckBox" ) ),
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( "IsPrintName" ) ),
+                                    ".HelpID:vcl:PrintDialog:IsPrintName:CheckBox" ,
+                                    "IsPrintName" ,
                                     sal_False
                                     )
                                 );
@@ -486,8 +479,8 @@ namespace {
             {
                 AddDialogControl( vcl::PrinterOptionsHelper::getBoolControlOpt(
                                     String( SdResId(_STR_DRAW_PRINT_UI_IS_PRINT_NAME) ),
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:IsPrintName:CheckBox" ) ),
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( "IsPrintName" ) ),
+                                    ".HelpID:vcl:PrintDialog:IsPrintName:CheckBox" ,
+                                    "IsPrintName" ,
                                     sal_False
                                     )
                                 );
@@ -495,8 +488,8 @@ namespace {
 
             AddDialogControl( vcl::PrinterOptionsHelper::getBoolControlOpt(
                                 String( SdResId(_STR_IMPRESS_PRINT_UI_IS_PRINT_DATE) ),
-                                OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:IsPrintDateTime:CheckBox" ) ),
-                                OUString( RTL_CONSTASCII_USTRINGPARAM( "IsPrintDateTime" ) ),
+                                ".HelpID:vcl:PrintDialog:IsPrintDateTime:CheckBox" ,
+                                "IsPrintDateTime" ,
                                 sal_False
                                 )
                             );
@@ -505,49 +498,48 @@ namespace {
             {
                 AddDialogControl( vcl::PrinterOptionsHelper::getBoolControlOpt(
                                     String( SdResId(_STR_IMPRESS_PRINT_UI_IS_PRINT_HIDDEN) ),
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:IsPrintHidden:CheckBox" ) ),
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( "IsPrintHidden" ) ),
+                                    ".HelpID:vcl:PrintDialog:IsPrintHidden:CheckBox" ,
+                                    "IsPrintHidden" ,
                                     sal_False
                                     )
                                 );
             }
 
             AddDialogControl( vcl::PrinterOptionsHelper::getSubgroupControlOpt(
-                               String( SdResId(_STR_IMPRESS_PRINT_UI_QUALITY) ), rtl::OUString() ) );
+                               String( SdResId(_STR_IMPRESS_PRINT_UI_QUALITY) ), "" ) );
 
             aHelpIds.realloc( 3 );
-            aHelpIds[0] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:Quality:RadioButton:0" ) );
-            aHelpIds[1] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:Quality:RadioButton:1" ) );
-            aHelpIds[2] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:Quality:RadioButton:2" ) );
+            aHelpIds[0] = ".HelpID:vcl:PrintDialog:Quality:RadioButton:0" ;
+            aHelpIds[1] = ".HelpID:vcl:PrintDialog:Quality:RadioButton:1" ;
+            aHelpIds[2] = ".HelpID:vcl:PrintDialog:Quality:RadioButton:2" ;
             AddDialogControl( vcl::PrinterOptionsHelper::getChoiceControlOpt(
-                                rtl::OUString(),
+                                "",
                                 aHelpIds,
-                                OUString( RTL_CONSTASCII_USTRINGPARAM( "Quality" ) ),
+                                "Quality" ,
                                 CreateChoice(_STR_IMPRESS_PRINT_UI_QUALITY_CHOICES),
                                 0
                                 )
                             );
 
             AddDialogControl( vcl::PrinterOptionsHelper::getSubgroupControlOpt(
-                               String( SdResId(_STR_IMPRESS_PRINT_UI_PAGE_OPTIONS) ), rtl::OUString() ) );
+                               String( SdResId(_STR_IMPRESS_PRINT_UI_PAGE_OPTIONS) ), "" ) );
 
             aHelpIds.realloc( 4 );
-            aHelpIds[0] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:PageOptions:RadioButton:0" ) );
-            aHelpIds[1] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:PageOptions:RadioButton:1" ) );
-            aHelpIds[2] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:PageOptions:RadioButton:2" ) );
-            aHelpIds[3] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:PageOptions:RadioButton:3" ) );
+            aHelpIds[0] = ".HelpID:vcl:PrintDialog:PageOptions:RadioButton:0" ;
+            aHelpIds[1] = ".HelpID:vcl:PrintDialog:PageOptions:RadioButton:1" ;
+            aHelpIds[2] = ".HelpID:vcl:PrintDialog:PageOptions:RadioButton:2" ;
+            aHelpIds[3] = ".HelpID:vcl:PrintDialog:PageOptions:RadioButton:3" ;
             if( mbImpress )
             {
                 // FIXME: additional dependency on PrintProspect = false
-                vcl::PrinterOptionsHelper::UIControlOptions
-                    aPageOptionsOpt( OUString( RTL_CONSTASCII_USTRINGPARAM( "PageContentType" ) ), 0 );
+                vcl::PrinterOptionsHelper::UIControlOptions aPageOptionsOpt( "PageContentType" , 0 );
                 AddDialogControl( vcl::PrinterOptionsHelper::getChoiceControlOpt(
-                                    rtl::OUString(),
+                                    "",
                                     aHelpIds,
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( "PageOptions" ) ),
+                                    "PageOptions" ,
                                     CreateChoice(_STR_IMPRESS_PRINT_UI_PAGE_OPTIONS_CHOICES),
                                     0,
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( "Radio" ) ),
+                                    "Radio" ,
                                     Sequence< sal_Bool >(),
                                     aPageOptionsOpt
                                     )
@@ -555,15 +547,14 @@ namespace {
             }
             else
             {
-                vcl::PrinterOptionsHelper::UIControlOptions
-                    aPageOptionsOpt( OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintProspect" ) ), sal_False );
+                vcl::PrinterOptionsHelper::UIControlOptions aPageOptionsOpt( "PrintProspect" , sal_False );
                 AddDialogControl( vcl::PrinterOptionsHelper::getChoiceControlOpt(
-                                    rtl::OUString(),
+                                    "",
                                     aHelpIds,
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( "PageOptions" ) ),
+                                    "PageOptions" ,
                                     CreateChoice(_STR_IMPRESS_PRINT_UI_PAGE_OPTIONS_CHOICES_DRAW),
                                     0,
-                                    OUString( RTL_CONSTASCII_USTRINGPARAM( "Radio" ) ),
+                                    "Radio" ,
                                     Sequence< sal_Bool >(),
                                     aPageOptionsOpt
                                     )
@@ -571,33 +562,33 @@ namespace {
             }
 
             vcl::PrinterOptionsHelper::UIControlOptions aBrochureOpt;
-            aBrochureOpt.maGroupHint = OUString( RTL_CONSTASCII_USTRINGPARAM( "LayoutPage" ) );
+            aBrochureOpt.maGroupHint = "LayoutPage" ;
             AddDialogControl( vcl::PrinterOptionsHelper::getSubgroupControlOpt(
-                               String( SdResId(_STR_IMPRESS_PRINT_UI_PAGE_SIDES) ), rtl::OUString(),
+                               String( SdResId(_STR_IMPRESS_PRINT_UI_PAGE_SIDES) ), "",
                                aBrochureOpt ) );
 
             // brochure printing
             AddDialogControl( vcl::PrinterOptionsHelper::getBoolControlOpt(
                                 String( SdResId(_STR_IMPRESS_PRINT_UI_BROCHURE) ),
-                                rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:PrintProspect:CheckBox" ) ),
-                                OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintProspect" ) ),
+                                ".HelpID:vcl:PrintDialog:PrintProspect:CheckBox" ,
+                                "PrintProspect" ,
                                 sal_False,
                                 aBrochureOpt
                                 )
                             );
 
             vcl::PrinterOptionsHelper::UIControlOptions
-                aIncludeOpt( OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintProspect" ) ), -1, sal_False );
-            aIncludeOpt.maGroupHint = OUString( RTL_CONSTASCII_USTRINGPARAM( "LayoutPage" ) );
+                aIncludeOpt( "PrintProspect" , -1, sal_False );
+            aIncludeOpt.maGroupHint =  "LayoutPage" ;
             aHelpIds.realloc( 1 );
-            aHelpIds[0] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:PrintProspectInclude:ListBox" ) );
+            aHelpIds[0] = ".HelpID:vcl:PrintDialog:PrintProspectInclude:ListBox" ;
             AddDialogControl( vcl::PrinterOptionsHelper::getChoiceControlOpt(
                                 String( SdResId(_STR_IMPRESS_PRINT_UI_BROCHURE_INCLUDE) ),
                                 aHelpIds,
-                                OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintProspectInclude" ) ),
+                                "PrintProspectInclude" ,
                                 CreateChoice(_STR_IMPRESS_PRINT_UI_BROCHURE_INCLUDE_LIST),
                                 0,
-                                OUString( RTL_CONSTASCII_USTRINGPARAM( "List" ) ),
+                                "List" ,
                                 Sequence< sal_Bool >(),
                                 aIncludeOpt
                                 )
@@ -605,11 +596,11 @@ namespace {
 
             // paper tray (on options page)
             vcl::PrinterOptionsHelper::UIControlOptions aPaperTrayOpt;
-            aPaperTrayOpt.maGroupHint = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "OptionsPageOptGroup" ) );
+            aPaperTrayOpt.maGroupHint = "OptionsPageOptGroup" ;
             AddDialogControl( vcl::PrinterOptionsHelper::getBoolControlOpt(
                                 String( SdResId(_STR_IMPRESS_PRINT_UI_PAPER_TRAY) ),
-                                rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:PrintPaperFromSetup:CheckBox" ) ),
-                                OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintPaperFromSetup" ) ),
+                                ".HelpID:vcl:PrintDialog:PrintPaperFromSetup:CheckBox" ,
+                                "PrintPaperFromSetup" ,
                                 sal_False,
                                 aPaperTrayOpt
                                 )
@@ -617,20 +608,20 @@ namespace {
             // print range selection
             vcl::PrinterOptionsHelper::UIControlOptions aPrintRangeOpt;
             aPrintRangeOpt.mbInternalOnly = sal_True;
-            aPrintRangeOpt.maGroupHint = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "PrintRange" ) );
+            aPrintRangeOpt.maGroupHint = "PrintRange" ;
             AddDialogControl( vcl::PrinterOptionsHelper::getSubgroupControlOpt(
                                 String( SdResId( _STR_IMPRESS_PRINT_UI_PAGE_RANGE ) ),
-                                rtl::OUString(),
+                                "",
                                 aPrintRangeOpt )
                              );
 
             // create a choice for the content to create
-            rtl::OUString aPrintRangeName( RTL_CONSTASCII_USTRINGPARAM( "PrintContent" ) );
+            rtl::OUString aPrintRangeName( "PrintContent" );
             aHelpIds.realloc( 3 );
-            aHelpIds[0] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:PrintContent:RadioButton:0" ) );
-            aHelpIds[1] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:PrintContent:RadioButton:1" ) );
-            aHelpIds[2] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:PrintContent:RadioButton:2" ) );
-            AddDialogControl( vcl::PrinterOptionsHelper::getChoiceControlOpt( rtl::OUString(),
+            aHelpIds[0] = ".HelpID:vcl:PrintDialog:PrintContent:RadioButton:0" ;
+            aHelpIds[1] = ".HelpID:vcl:PrintDialog:PrintContent:RadioButton:1" ;
+            aHelpIds[2] = ".HelpID:vcl:PrintDialog:PrintContent:RadioButton:2" ;
+            AddDialogControl( vcl::PrinterOptionsHelper::getChoiceControlOpt( "",
                                 aHelpIds,
                                 aPrintRangeName,
                                 CreateChoice(mbImpress
@@ -640,10 +631,10 @@ namespace {
                             );
             // create a an Edit dependent on "Pages" selected
             vcl::PrinterOptionsHelper::UIControlOptions aPageRangeOpt( aPrintRangeName, 1, sal_True );
-            AddDialogControl( vcl::PrinterOptionsHelper::getEditControlOpt( rtl::OUString(),
-                                rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".HelpID:vcl:PrintDialog:PageRange:Edit" ) ),
-                                rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "PageRange" ) ),
-                                rtl::OUString(),
+            AddDialogControl( vcl::PrinterOptionsHelper::getEditControlOpt( "",
+                                ".HelpID:vcl:PrintDialog:PageRange:Edit" ,
+                                "PageRange" ,
+                                "",
                                 aPageRangeOpt )
                             );
 
@@ -905,7 +896,7 @@ namespace {
             const sal_uLong nDrawMode,
             const Orientation eOrientation,
             const sal_uInt16 nPaperTray)
-            : PrinterPage(ePageKind, rMapMode, bPrintMarkedOnly, ::rtl::OUString(),
+            : PrinterPage(ePageKind, rMapMode, bPrintMarkedOnly, "",
                 Point(), nDrawMode, eOrientation, nPaperTray),
               mnFirstPageIndex(nFirstPageIndex),
               mnSecondPageIndex(nSecondPageIndex),
@@ -1001,7 +992,7 @@ namespace {
             SdPage& rHandoutPage (*rDocument.GetSdPage(0, PK_HANDOUT));
 
             Reference< com::sun::star::beans::XPropertySet > xHandoutPage( rHandoutPage.getUnoPage(), UNO_QUERY );
-            const rtl::OUString sPageNumber( RTL_CONSTASCII_USTRINGPARAM( "Number" ) );
+            const rtl::OUString sPageNumber( "Number" );
 
             // Collect the page objects of the handout master.
             std::vector<SdrPageObj*> aHandoutPageObjects;
@@ -1251,7 +1242,7 @@ public:
 
         // The RenderDevice property is handled specially: its value is
         // stored in mpPrinter instead of being retrieved on demand.
-        Any aDev( getValue( OUString( RTL_CONSTASCII_USTRINGPARAM( "RenderDevice" ) ) ) );
+        Any aDev( getValue( "RenderDevice" ) );
         Reference<awt::XDevice> xRenderDevice;
 
         if (aDev >>= xRenderDevice)
@@ -1301,14 +1292,14 @@ public:
 
         css::uno::Sequence<css::beans::PropertyValue> aProperties (3);
 
-        aProperties[0].Name = A2S("ExtraPrintUIOptions");
+        aProperties[0].Name = "ExtraPrintUIOptions";
         aProperties[0].Value <<= m_aUIProperties;
 
-        aProperties[1].Name = A2S("PageSize");
+        aProperties[1].Name = "PageSize";
         aProperties[1].Value <<= maPrintSize;
 
         // FIXME: is this always true ?
-        aProperties[2].Name = A2S("PageIncludesNonprintableArea");
+        aProperties[2].Name = "PageIncludesNonprintableArea";
         aProperties[2].Value = makeAny( sal_True );
 
         return aProperties;
@@ -2010,10 +2001,10 @@ private:
             if (mpOptions->IsPrintPageName())
             {
                 rInfo.msPageString = pPage->GetName();
-                rInfo.msPageString += ::rtl::OUString(sal_Unicode(' '));
+                rInfo.msPageString += rtl::OUString(sal_Unicode(' '));
             }
             else
-                rInfo.msPageString = ::rtl::OUString();
+                rInfo.msPageString = "";
             rInfo.msPageString += rInfo.msTimeDate;
 
             long aPageWidth   = aPageSize.Width() - pPage->GetLftBorder() - pPage->GetRgtBorder();
