@@ -26,7 +26,6 @@
  *
  ************************************************************************/
 
-
 #include "PresenterSlideShowView.hxx"
 
 #include "PresenterCanvasHelper.hxx"
@@ -54,7 +53,7 @@ using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::drawing::framework;
 using ::rtl::OUString;
 
-#define A2S(pString) (::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(pString)))
+#define A2S(pString) (::rtl::OUString(pString))
 
 namespace sdext { namespace presenter {
 
@@ -101,8 +100,6 @@ PresenterSlideShowView::PresenterSlideShowView (
     }
 }
 
-
-
 void PresenterSlideShowView::LateInit (void)
 {
     mxSlideShow = Reference<presentation::XSlideShow> (
@@ -114,7 +111,7 @@ void PresenterSlideShowView::LateInit (void)
     Reference<lang::XMultiComponentFactory> xFactory (
         mxComponentContext->getServiceManager(), UNO_QUERY_THROW);
     mxPresenterHelper.set (xFactory->createInstanceWithContext(
-                   OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Draw.PresenterHelper")),
+                   OUString("com.sun.star.comp.Draw.PresenterHelper"),
                    mxComponentContext),
                UNO_QUERY_THROW);
 
@@ -168,17 +165,7 @@ void PresenterSlideShowView::LateInit (void)
     // Add the new slide show view to the slide show.
     if (mxSlideShow.is() && ! mbIsViewAdded)
     {
-        Reference<presentation::XSlideShowView> xView (this);
-        mxSlideShow->addView(xView);
-        // Prevent embeded sounds being played twice at the same time by
-        // disabling sound for the new slide show view.
-        beans::PropertyValue aProperty;
-        aProperty.Name = A2S("IsSoundEnabled");
-        Sequence<Any> aValues (2);
-        aValues[0] <<= xView;
-        aValues[1] <<= sal_False;
-        aProperty.Value <<= aValues;
-        mxSlideShow->setProperty(aProperty);
+        impl_addAndConfigureView();
         mbIsViewAdded = true;
     }
 
@@ -197,16 +184,10 @@ void PresenterSlideShowView::LateInit (void)
         >>= msClickToExitPresentationTitle;
 }
 
-
-
-
 PresenterSlideShowView::~PresenterSlideShowView (void)
 {
 }
 
-
-
-
 void PresenterSlideShowView::disposing (void)
 {
     // Tell all listeners that we are disposed.
@@ -279,9 +260,6 @@ void PresenterSlideShowView::disposing (void)
     mxCurrentSlide = NULL;
 }
 
-
-
-
 //----- XDrawView -------------------------------------------------------------
 
 void SAL_CALL PresenterSlideShowView::setCurrentPage (
@@ -327,18 +305,12 @@ void SAL_CALL PresenterSlideShowView::setCurrentPage (
     }
 }
 
-
-
-
 css::uno::Reference<css::drawing::XDrawPage> SAL_CALL PresenterSlideShowView::getCurrentPage (void)
     throw (css::uno::RuntimeException)
 {
     return mxCurrentSlide;
 }
 
-
-
-
 //----- CachablePresenterView -------------------------------------------------
 
 void PresenterSlideShowView::ReleaseView (void)
@@ -350,9 +322,6 @@ void PresenterSlideShowView::ReleaseView (void)
     }
 }
 
-
-
-
 //----- XSlideShowView --------------------------------------------------------
 
 Reference<rendering::XSpriteCanvas> SAL_CALL PresenterSlideShowView::getCanvas (void)
@@ -363,9 +332,6 @@ Reference<rendering::XSpriteCanvas> SAL_CALL PresenterSlideShowView::getCanvas (
     return Reference<rendering::XSpriteCanvas>(mxViewCanvas, UNO_QUERY);
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::clear (void)
     throw (RuntimeException)
 {
@@ -384,7 +350,7 @@ void SAL_CALL PresenterSlideShowView::clear (void)
         rendering::ViewState aViewState (
             geometry::AffineMatrix2D(1,0,0, 0,1,0),
             NULL);
-        double aColor[3] = {0,0,0};
+        double aColor[4] = {0,0,0,0};
         rendering::RenderState aRenderState(
             geometry::AffineMatrix2D(1,0,0, 0,1,0),
             NULL,
@@ -394,9 +360,6 @@ void SAL_CALL PresenterSlideShowView::clear (void)
     }
 }
 
-
-
-
 geometry::AffineMatrix2D SAL_CALL PresenterSlideShowView::getTransformation (void)
     throw (RuntimeException)
 {
@@ -424,9 +387,6 @@ geometry::AffineMatrix2D SAL_CALL PresenterSlideShowView::getTransformation (voi
     }
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::addTransformationChangedListener(
     const Reference<util::XModifyListener>& rxListener)
     throw (RuntimeException)
@@ -437,9 +397,6 @@ void SAL_CALL PresenterSlideShowView::addTransformationChangedListener(
         rxListener);
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::removeTransformationChangedListener(
     const Reference<util::XModifyListener>& rxListener)
     throw (RuntimeException)
@@ -450,9 +407,6 @@ void SAL_CALL PresenterSlideShowView::removeTransformationChangedListener(
         rxListener);
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::addPaintListener(
     const Reference<awt::XPaintListener>& rxListener)
     throw (RuntimeException)
@@ -463,9 +417,6 @@ void SAL_CALL PresenterSlideShowView::addPaintListener(
         rxListener);
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::removePaintListener(
     const Reference<awt::XPaintListener>& rxListener)
     throw (RuntimeException)
@@ -476,9 +427,6 @@ void SAL_CALL PresenterSlideShowView::removePaintListener(
         rxListener);
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::addMouseListener(
     const Reference<awt::XMouseListener>& rxListener)
     throw (RuntimeException)
@@ -489,9 +437,6 @@ void SAL_CALL PresenterSlideShowView::addMouseListener(
         rxListener);
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::removeMouseListener(
     const Reference<awt::XMouseListener>& rxListener)
     throw (RuntimeException)
@@ -502,9 +447,6 @@ void SAL_CALL PresenterSlideShowView::removeMouseListener(
         rxListener);
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::addMouseMotionListener(
     const Reference<awt::XMouseMotionListener>& rxListener)
     throw (RuntimeException)
@@ -515,9 +457,6 @@ void SAL_CALL PresenterSlideShowView::addMouseMotionListener(
         rxListener);
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::removeMouseMotionListener(
     const Reference<awt::XMouseMotionListener>& rxListener)
     throw (RuntimeException)
@@ -528,9 +467,6 @@ void SAL_CALL PresenterSlideShowView::removeMouseMotionListener(
         rxListener);
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::setMouseCursor(::sal_Int16 nPointerShape)
     throw (RuntimeException)
 {
@@ -543,7 +479,7 @@ void SAL_CALL PresenterSlideShowView::setMouseCursor(::sal_Int16 nPointerShape)
             mxComponentContext, UNO_QUERY);
         if (xFactory.is())
             mxPointer = Reference<awt::XPointer>(
-                xFactory->createInstance(OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.Pointer"))),
+                xFactory->createInstance(OUString("com.sun.star.awt.Pointer")),
                 UNO_QUERY);
     }
 
@@ -557,8 +493,6 @@ void SAL_CALL PresenterSlideShowView::setMouseCursor(::sal_Int16 nPointerShape)
     }
 }
 
-
-
 awt::Rectangle SAL_CALL PresenterSlideShowView::getCanvasArea(  ) throw (RuntimeException)
 {
     if( mxViewWindow.is() && mxTopPane.is() )
@@ -571,8 +505,6 @@ awt::Rectangle SAL_CALL PresenterSlideShowView::getCanvasArea(  ) throw (Runtime
     return aRectangle;
 }
 
-
-
 //----- lang::XEventListener --------------------------------------------------
 
 void SAL_CALL PresenterSlideShowView::disposing (const lang::EventObject& rEvent)
@@ -584,9 +516,6 @@ void SAL_CALL PresenterSlideShowView::disposing (const lang::EventObject& rEvent
         mxSlideShow = NULL;
 }
 
-
-
-
 //----- XPaintListener --------------------------------------------------------
 
 void SAL_CALL PresenterSlideShowView::windowPaint (const awt::PaintEvent& rEvent)
@@ -608,9 +537,6 @@ void SAL_CALL PresenterSlideShowView::windowPaint (const awt::PaintEvent& rEvent
         PaintInnerWindow(rEvent);
 }
 
-
-
-
 //----- XMouseListener --------------------------------------------------------
 
 void SAL_CALL PresenterSlideShowView::mousePressed (const awt::MouseEvent& rEvent)
@@ -633,9 +559,6 @@ void SAL_CALL PresenterSlideShowView::mousePressed (const awt::MouseEvent& rEven
             mpPresenterController->HandleMouseClick(rEvent);
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::mouseReleased (const awt::MouseEvent& rEvent)
     throw (RuntimeException)
 {
@@ -649,9 +572,6 @@ void SAL_CALL PresenterSlideShowView::mouseReleased (const awt::MouseEvent& rEve
     }
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::mouseEntered (const awt::MouseEvent& rEvent)
     throw (RuntimeException)
 {
@@ -665,9 +585,6 @@ void SAL_CALL PresenterSlideShowView::mouseEntered (const awt::MouseEvent& rEven
     }
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::mouseExited (const awt::MouseEvent& rEvent)
     throw (RuntimeException)
 {
@@ -681,9 +598,6 @@ void SAL_CALL PresenterSlideShowView::mouseExited (const awt::MouseEvent& rEvent
     }
 }
 
-
-
-
 //----- XMouseMotionListener --------------------------------------------------
 
 void SAL_CALL PresenterSlideShowView::mouseDragged (const awt::MouseEvent& rEvent)
@@ -699,9 +613,6 @@ void SAL_CALL PresenterSlideShowView::mouseDragged (const awt::MouseEvent& rEven
     }
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::mouseMoved (const awt::MouseEvent& rEvent)
     throw (RuntimeException)
 {
@@ -715,9 +626,6 @@ void SAL_CALL PresenterSlideShowView::mouseMoved (const awt::MouseEvent& rEvent)
     }
 }
 
-
-
-
 //----- XWindowListener -------------------------------------------------------
 
 void SAL_CALL PresenterSlideShowView::windowResized (const awt::WindowEvent& rEvent)
@@ -731,10 +639,6 @@ void SAL_CALL PresenterSlideShowView::windowResized (const awt::WindowEvent& rEv
     Resize();
 }
 
-
-
-
-
 void SAL_CALL PresenterSlideShowView::windowMoved (const awt::WindowEvent& rEvent)
     throw (RuntimeException)
 {
@@ -743,9 +647,6 @@ void SAL_CALL PresenterSlideShowView::windowMoved (const awt::WindowEvent& rEven
         mbIsForcedPaintPending = true;
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::windowShown (const lang::EventObject& rEvent)
     throw (RuntimeException)
 {
@@ -753,18 +654,12 @@ void SAL_CALL PresenterSlideShowView::windowShown (const lang::EventObject& rEve
     Resize();
 }
 
-
-
-
 void SAL_CALL PresenterSlideShowView::windowHidden (const lang::EventObject& rEvent)
     throw (RuntimeException)
 {
     (void)rEvent;
 }
 
-
-
-
 //----- XView -----------------------------------------------------------------
 
 Reference<XResourceId> SAL_CALL PresenterSlideShowView::getResourceId (void)
@@ -773,32 +668,23 @@ Reference<XResourceId> SAL_CALL PresenterSlideShowView::getResourceId (void)
     return mxViewId;
 }
 
-
-
-
 sal_Bool SAL_CALL PresenterSlideShowView::isAnchorOnly (void)
     throw (RuntimeException)
 {
     return false;
 }
 
-
-
-
 //----- CachablePresenterView -------------------------------------------------
 
 void PresenterSlideShowView::ActivatePresenterView (void)
 {
     if (mxSlideShow.is() && ! mbIsViewAdded)
     {
-        mxSlideShow->addView(this);
+        impl_addAndConfigureView();
         mbIsViewAdded = true;
     }
 }
 
-
-
-
 void PresenterSlideShowView::DeactivatePresenterView (void)
 {
     if (mxSlideShow.is() && mbIsViewAdded)
@@ -808,9 +694,6 @@ void PresenterSlideShowView::DeactivatePresenterView (void)
     }
 }
 
-
-
-
 //-----------------------------------------------------------------------------
 
 void PresenterSlideShowView::PaintOuterWindow (const awt::Rectangle& rRepaintBox)
@@ -873,9 +756,6 @@ void PresenterSlideShowView::PaintOuterWindow (const awt::Rectangle& rRepaintBox
     }
 }
 
-
-
-
 void PresenterSlideShowView::PaintEndSlide (const awt::Rectangle& rRepaintBox)
 {
     if ( ! mxCanvas.is())
@@ -931,9 +811,6 @@ void PresenterSlideShowView::PaintEndSlide (const awt::Rectangle& rRepaintBox)
         mxSpriteCanvas->updateScreen(sal_True);
 }
 
-
-
-
 void PresenterSlideShowView::PaintInnerWindow (const awt::PaintEvent& rEvent)
 {
     // Forward window paint to listeners.
@@ -956,9 +833,6 @@ void PresenterSlideShowView::PaintInnerWindow (const awt::PaintEvent& rEvent)
         mxSpriteCanvas->updateScreen(sal_True);
 }
 
-
-
-
 Reference<awt::XWindow> PresenterSlideShowView::CreateViewWindow (
     const Reference<awt::XWindow>& rxParentWindow) const
 {
@@ -971,7 +845,7 @@ Reference<awt::XWindow> PresenterSlideShowView::CreateViewWindow (
 
         Reference<awt::XToolkit> xToolkit (
             xFactory->createInstanceWithContext(
-                OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.awt.Toolkit")),
+                OUString("com.sun.star.awt.Toolkit"),
                 mxComponentContext),
             UNO_QUERY_THROW);
         awt::WindowDescriptor aWindowDescriptor (
@@ -1001,9 +875,6 @@ Reference<awt::XWindow> PresenterSlideShowView::CreateViewWindow (
     return xViewWindow;
 }
 
-
-
-
 Reference<rendering::XCanvas> PresenterSlideShowView::CreateViewCanvas (
     const Reference<awt::XWindow>& rxViewWindow) const
 {
@@ -1016,9 +887,6 @@ Reference<rendering::XCanvas> PresenterSlideShowView::CreateViewCanvas (
         rxViewWindow);
 }
 
-
-
-
 void PresenterSlideShowView::Resize (void)
 {
     if ( ! mxWindow.is() || ! mxViewWindow.is())
@@ -1075,21 +943,15 @@ void PresenterSlideShowView::Resize (void)
         mbIsForcedPaintPending = true;
 }
 
-
-
-
 void PresenterSlideShowView::ForceRepaint (void)
 {
     if (mxSlideShow.is() && mbIsViewAdded)
     {
         mxSlideShow->removeView(this);
-        mxSlideShow->addView(this);
+        impl_addAndConfigureView();
     }
 }
 
-
-
-
 void PresenterSlideShowView::CreateBackgroundPolygons (void)
 {
     const awt::Rectangle aWindowBox (mxWindow->getPosSize());
@@ -1137,20 +999,31 @@ void PresenterSlideShowView::CreateBackgroundPolygons (void)
     }
 }
 
-
-
-
 void PresenterSlideShowView::ThrowIfDisposed (void)
     throw (::com::sun::star::lang::DisposedException)
 {
     if (rBHelper.bDisposed || rBHelper.bInDispose)
     {
         throw lang::DisposedException (
-            OUString(RTL_CONSTASCII_USTRINGPARAM("PresenterSlideShowView object has already been disposed")),
+            OUString("PresenterSlideShowView object has already been disposed"),
             static_cast<uno::XWeak*>(this));
     }
 }
 
+void PresenterSlideShowView::impl_addAndConfigureView()
+{
+    Reference<presentation::XSlideShowView> xView (this);
+    mxSlideShow->addView(xView);
+    // Prevent embeded sounds being played twice at the same time by
+    // disabling sound for the new slide show view.
+    beans::PropertyValue aProperty;
+    aProperty.Name = A2S("IsSoundEnabled");
+    Sequence<Any> aValues (2);
+    aValues[0] <<= xView;
+    aValues[1] <<= sal_False;
+    aProperty.Value <<= aValues;
+    mxSlideShow->setProperty(aProperty);
+}
 
 } } // end of namespace ::sd::presenter
 
