@@ -102,6 +102,7 @@
 #include <sfxlocal.hrc>
 #include <rtl/oustringostreaminserter.hxx>
 #include <rtl/strbuf.hxx>
+
 #ifdef UNX
 #include <errno.h>
 #include <sys/stat.h>
@@ -123,7 +124,7 @@ using namespace ::cppu;
 
 #define IODLG_CONFIGNAME        String(DEFINE_CONST_UNICODE("FilePicker_Save"))
 #define IMPGRF_CONFIGNAME       String(DEFINE_CONST_UNICODE("FilePicker_Graph"))
-#define USERITEM_NAME           ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "UserItem" ))
+#define USERITEM_NAME           ::rtl::OUString("UserItem" )
 
 //-----------------------------------------------------------------------------
 
@@ -132,9 +133,9 @@ namespace sfx2
 
 const OUString* GetLastFilterConfigId( FileDialogHelper::Context _eContext )
 {
-    static const OUString aSD_EXPORT_IDENTIFIER( RTL_CONSTASCII_USTRINGPARAM( "SdExportLastFilter" ) );
-    static const OUString aSI_EXPORT_IDENTIFIER( RTL_CONSTASCII_USTRINGPARAM( "SiExportLastFilter" ) );
-    static const OUString aSW_EXPORT_IDENTIFIER( RTL_CONSTASCII_USTRINGPARAM( "SwExportLastFilter" ) );
+    static const OUString aSD_EXPORT_IDENTIFIER( "SdExportLastFilter"  );
+    static const OUString aSI_EXPORT_IDENTIFIER( "SiExportLastFilter"  );
+    static const OUString aSW_EXPORT_IDENTIFIER( "SwExportLastFilter"  );
 
     const OUString* pRet = NULL;
 
@@ -279,7 +280,7 @@ OUString FileDialogHelper_Impl::handleHelpRequested( const FilePickerEvent& aEve
             break;
 
         default:
-            DBG_ERRORFILE( "invalid element id" );
+            SAL_WARN( "sfx2.dialog", "invalid element id" );
     }
 
     OUString aHelpText;
@@ -438,7 +439,7 @@ sal_Bool FileDialogHelper_Impl::CheckFilterOptionsCapability( const SfxFilter* _
                        if( aProps[nProperty].Name.equals( DEFINE_CONST_OUSTRING( "UIComponent") ) )
                        {
                            aProps[nProperty].Value >>= aServiceName;
-                        if( aServiceName.getLength() )
+                        if( !aServiceName.isEmpty() )
                             bResult = sal_True;
                     }
                 }
@@ -490,11 +491,11 @@ void FileDialogHelper_Impl::updateExportButton()
     uno::Reference < XFilePickerControlAccess > xCtrlAccess( mxFileDlg, UNO_QUERY );
     if ( xCtrlAccess.is() )
     {
-        OUString sEllipses( RTL_CONSTASCII_USTRINGPARAM( "..." ) );
+        OUString sEllipses( "..."  );
         OUString sOldLabel( xCtrlAccess->getLabel( CommonFilePickerElementIds::PUSHBUTTON_OK ) );
 
         // initialize button label; we need the label with the mnemonic char
-        if ( !maButtonLabel.getLength() || maButtonLabel.indexOf( MNEMONIC_CHAR ) == -1 )
+        if ( maButtonLabel.isEmpty() || maButtonLabel.indexOf( MNEMONIC_CHAR ) == -1 )
         {
             // cut the ellipses, if necessary
             sal_Int32 nIndex = sOldLabel.indexOf( sEllipses );
@@ -506,7 +507,7 @@ void FileDialogHelper_Impl::updateExportButton()
         OUString sLabel = maButtonLabel;
         // filter with options -> append ellipses on export button label
         if ( CheckFilterOptionsCapability( getCurentSfxFilter() ) )
-            sLabel += OUString( RTL_CONSTASCII_USTRINGPARAM( "..." ) );
+            sLabel += OUString( "..."  );
 
         if ( sOldLabel != sLabel )
         {
@@ -516,7 +517,7 @@ void FileDialogHelper_Impl::updateExportButton()
             }
             catch( const IllegalArgumentException& )
             {
-                DBG_ERRORFILE( "FileDialogHelper_Impl::updateExportButton: caught an exception!" );
+                SAL_WARN( "sfx2.dialog", "FileDialogHelper_Impl::updateExportButton: caught an exception!" );
             }
         }
     }
@@ -536,7 +537,7 @@ void FileDialogHelper_Impl::updateSelectionBox()
         Sequence< ::rtl::OUString > aCtrlList = xCtrlInfo->getSupportedControls();
         sal_uInt32 nCount = aCtrlList.getLength();
         for ( sal_uInt32 nCtrl = 0; nCtrl < nCount; ++nCtrl )
-            if ( aCtrlList[ nCtrl ].equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("SelectionBox")) )
+            if ( aCtrlList[ nCtrl ] == "SelectionBox" )
             {
                 bSelectionBoxFound = sal_False;
                 break;
@@ -602,7 +603,7 @@ void FileDialogHelper_Impl::updatePreviewState( sal_Bool _bUpdatePreviewWindow )
     {
         uno::Reference< XFilePickerControlAccess > xCtrlAccess( mxFileDlg, UNO_QUERY );
 
-        // check, wether or not we have to display a preview
+        // check, whether or not we have to display a preview
         if ( xCtrlAccess.is() )
         {
             try
@@ -626,7 +627,7 @@ void FileDialogHelper_Impl::updatePreviewState( sal_Bool _bUpdatePreviewWindow )
             }
             catch( const Exception& )
             {
-                DBG_ERRORFILE( "FileDialogHelper_Impl::updatePreviewState: caught an exception!" );
+                SAL_WARN( "sfx2.dialog", "FileDialogHelper_Impl::updatePreviewState: caught an exception!" );
             }
         }
     }
@@ -699,7 +700,7 @@ void FileDialogHelper_Impl::updateVersions()
 }
 
 // -----------------------------------------------------------------------
-IMPL_LINK( FileDialogHelper_Impl, TimeOutHdl_Impl, Timer*, EMPTYARG )
+IMPL_LINK_NOARG(FileDialogHelper_Impl, TimeOutHdl_Impl)
 {
     if ( !mbHasPreview )
         return 0;
@@ -786,7 +787,7 @@ ErrCode FileDialogHelper_Impl::getGraphic( const OUString& rURL,
     // select graphic filter from dialog filter selection
     OUString aCurFilter( getFilter() );
 
-    sal_uInt16 nFilter = aCurFilter.getLength() && mpGraphicFilter->GetImportFormatCount()
+    sal_uInt16 nFilter = !aCurFilter.isEmpty() && mpGraphicFilter->GetImportFormatCount()
                     ? mpGraphicFilter->GetImportFormatNumber( aCurFilter )
                     : GRFILTER_FORMAT_DONTKNOW;
 
@@ -835,7 +836,7 @@ ErrCode FileDialogHelper_Impl::getGraphic( Graphic& rGraphic ) const
             aPath = aPathSeq[0];
         }
 
-        if ( aPath.getLength() )
+        if ( !aPath.isEmpty() )
             nRet = getGraphic( aPath, rGraphic );
         else
             nRet = ERRCODE_IO_GENERAL;
@@ -1053,7 +1054,7 @@ FileDialogHelper_Impl::FileDialogHelper_Impl(
                 break;
 
             default:
-                DBG_ERRORFILE( "FileDialogHelper::ctor with unknown type" );
+                SAL_WARN( "sfx2.dialog", "FileDialogHelper::ctor with unknown type" );
                 break;
         }
 
@@ -1071,26 +1072,26 @@ FileDialogHelper_Impl::FileDialogHelper_Impl(
         else
         {
             aInitArguments[0] <<= NamedValue(
-                                    ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "TemplateDescription" ) ),
+                                    ::rtl::OUString( "TemplateDescription"  ),
                                     makeAny( nTemplateDescription )
                                 );
 
             ::rtl::OUString sStandardDirTemp = ::rtl::OUString( sStandardDir );
 
             aInitArguments[1] <<= NamedValue(
-                                    ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "StandardDir" ) ),
+                                    ::rtl::OUString( "StandardDir"  ),
                                     makeAny( sStandardDirTemp )
                                 );
 
             aInitArguments[2] <<= NamedValue(
-                                    ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "BlackList" ) ),
+                                    ::rtl::OUString( "BlackList"  ),
                                     makeAny( rBlackList )
                                 );
 
 
             if ( mpPreferredParentWindow )
                 aInitArguments[3] <<= NamedValue(
-                                        ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ParentWindow" ) ),
+                                        ::rtl::OUString( "ParentWindow"  ),
                                         makeAny( VCLUnoHelper::GetInterface( mpPreferredParentWindow ) )
                                     );
         }
@@ -1193,7 +1194,7 @@ void SAL_CALL PickerThread_Impl::run()
     catch( const RuntimeException& )
     {
         SetReturnValue( ExecutableDialogResults::CANCEL );
-        DBG_ERRORFILE( "RuntimeException caught" );
+        SAL_WARN( "sfx2.dialog", "RuntimeException caught" );
     }
 }
 
@@ -1207,7 +1208,7 @@ void FileDialogHelper_Impl::setControlHelpIds( const sal_Int16* _pControlId, con
     // forward these ids to the file picker
     try
     {
-        const ::rtl::OUString sHelpIdPrefix( RTL_CONSTASCII_USTRINGPARAM( INET_HID_SCHEME ) );
+        const ::rtl::OUString sHelpIdPrefix( INET_HID_SCHEME  );
         // the ids for the single controls
         uno::Reference< XFilePickerControlAccess > xControlAccess( mxFileDlg, UNO_QUERY );
         if ( xControlAccess.is() )
@@ -1276,7 +1277,7 @@ void FileDialogHelper_Impl::postExecute( sal_Int16 _nResult )
 // ------------------------------------------------------------------------
 void FileDialogHelper_Impl::implInitializeFileName( )
 {
-    if ( maFileName.getLength() )
+    if ( !maFileName.isEmpty() )
     {
         INetURLObject aObj( maPath );
         aObj.Append( maFileName );
@@ -1337,7 +1338,7 @@ sal_Int16 FileDialogHelper_Impl::implDoExecute()
         }
         catch( const Exception& )
         {
-            DBG_ERRORFILE( "FileDialogHelper_Impl::implDoExecute: caught an exception!" );
+            SAL_WARN( "sfx2.dialog", "FileDialogHelper_Impl::implDoExecute: caught an exception!" );
         }
     }
 
@@ -1366,28 +1367,24 @@ void FileDialogHelper_Impl::implStartExecute()
         }
         catch( const Exception& )
         {
-            DBG_ERRORFILE( "FileDialogHelper_Impl::implDoExecute: caught an exception!" );
+            SAL_WARN( "sfx2.dialog", "FileDialogHelper_Impl::implDoExecute: caught an exception!" );
         }
     }
 }
 
 // ------------------------------------------------------------------------
-void lcl_saveLastURLs(SvStringsDtor*&                                    rpURLList ,
+void lcl_saveLastURLs(std::vector<rtl::OUString>& rpURLList,
                       ::comphelper::SequenceAsVector< ::rtl::OUString >& lLastURLs )
 {
     lLastURLs.clear();
-    sal_uInt16 c = rpURLList->Count();
-    sal_uInt16 i = 0;
-    for (i=0; i<c; ++i)
-        lLastURLs.push_back(*(rpURLList->GetObject(i)));
+    for(std::vector<rtl::OUString>::iterator i = rpURLList.begin(); i != rpURLList.end(); ++i)
+        lLastURLs.push_back(*i);
 }
 
 // ------------------------------------------------------------------------
-void FileDialogHelper_Impl::implGetAndCacheFiles(const uno::Reference< XInterface >& xPicker  ,
-                                                       SvStringsDtor*&               rpURLList,
-                                                 const SfxFilter*                    pFilter  )
+void FileDialogHelper_Impl::implGetAndCacheFiles(const uno::Reference< XInterface >& xPicker, std::vector<rtl::OUString>& rpURLList, const SfxFilter* pFilter)
 {
-    rpURLList = NULL;
+    rpURLList.clear();
 
     rtl::OUString sExtension;
     if (pFilter)
@@ -1401,14 +1398,10 @@ void FileDialogHelper_Impl::implGetAndCacheFiles(const uno::Reference< XInterfac
     uno::Reference< XFilePicker2 > xPickNew(xPicker, UNO_QUERY);
     if (xPickNew.is())
     {
-                             rpURLList = new SvStringsDtor;
         Sequence< OUString > lFiles    = xPickNew->getSelectedFiles();
         ::sal_Int32          nFiles    = lFiles.getLength();
-        for (::sal_Int32 i = 0; i < nFiles; i++)
-        {
-            String* pURL = new String(lFiles[i]);
-            rpURLList->Insert( pURL, rpURLList->Count() );
-        }
+        for(sal_Int32 i = 0; i < nFiles; ++i)
+            rpURLList.push_back(lFiles[i]);
     }
 
     // b) the olde way ... non optional.
@@ -1419,15 +1412,10 @@ void FileDialogHelper_Impl::implGetAndCacheFiles(const uno::Reference< XInterfac
         ::sal_Int32          nFiles = lFiles.getLength();
         if ( nFiles == 1 )
         {
-                    rpURLList = new SvStringsDtor;
-            String* pURL      = new String(lFiles[0]);
-            rpURLList->Insert( pURL, 0 );
+            rpURLList.push_back(lFiles[0]);
         }
-        else
-        if ( nFiles > 1 )
+        else if ( nFiles > 1 )
         {
-            rpURLList = new SvStringsDtor;
-
             INetURLObject aPath( lFiles[0] );
             aPath.setFinalSlash();
 
@@ -1438,8 +1426,7 @@ void FileDialogHelper_Impl::implGetAndCacheFiles(const uno::Reference< XInterfac
                 else
                     aPath.setName( lFiles[i] );
 
-                String* pURL = new String(aPath.GetMainURL( INetURLObject::NO_DECODE ) );
-                rpURLList->Insert( pURL, rpURLList->Count() );
+                rpURLList.push_back(aPath.GetMainURL(INetURLObject::NO_DECODE));
             }
         }
     }
@@ -1448,7 +1435,7 @@ void FileDialogHelper_Impl::implGetAndCacheFiles(const uno::Reference< XInterfac
 }
 
 // ------------------------------------------------------------------------
-ErrCode FileDialogHelper_Impl::execute( SvStringsDtor*& rpURLList,
+ErrCode FileDialogHelper_Impl::execute( std::vector<rtl::OUString>& rpURLList,
                                         SfxItemSet *&   rpSet,
                                         String&         rFilter )
 {
@@ -1495,7 +1482,7 @@ ErrCode FileDialogHelper_Impl::execute( SvStringsDtor*& rpURLList,
             aSecOpt.IsOptionSet( SvtSecurityOptions::E_DOCWARN_RECOMMENDPASSWORD ) );
     }
 
-    rpURLList = NULL;
+    rpURLList.clear();
 
     if ( ! mxFileDlg.is() )
         return ERRCODE_ABORT;
@@ -1566,10 +1553,10 @@ ErrCode FileDialogHelper_Impl::execute( SvStringsDtor*& rpURLList,
 
         // fill the rpURLList
         implGetAndCacheFiles( mxFileDlg, rpURLList, pCurrentFilter );
-        if ( rpURLList == NULL || rpURLList->GetObject(0) == NULL )
+        if ( rpURLList.empty() )
             return ERRCODE_ABORT;
 
-        // check, wether or not we have to display a password box
+        // check, whether or not we have to display a password box
         if ( pCurrentFilter && mbHasPassword && mbIsPwdEnabled && xCtrlAccess.is() )
         {
             try
@@ -1579,7 +1566,7 @@ ErrCode FileDialogHelper_Impl::execute( SvStringsDtor*& rpURLList,
                 if ( ( aValue >>= bPassWord ) && bPassWord )
                 {
                     // ask for a password
-                    rtl::OUString aDocName(*(rpURLList->GetObject(0)));
+                    rtl::OUString aDocName(rpURLList[0]);
                     ErrCode errCode = RequestPassword(pCurrentFilter, aDocName, rpSet);
                     if (errCode != ERRCODE_NONE)
                         return errCode;
@@ -1621,7 +1608,7 @@ OUString FileDialogHelper_Impl::getPath() const
     if ( mxFileDlg.is() )
         aPath = mxFileDlg->getDisplayDirectory();
 
-    if ( !aPath.getLength() )
+    if ( aPath.isEmpty() )
         aPath = maPath;
 
     return aPath;
@@ -1665,7 +1652,7 @@ void FileDialogHelper_Impl::verifyPath()
     }
     INetURLObject url(maPath);
     if (url.GetProtocol() != INET_PROT_FILE
-        || !(url.getName(0, true, INetURLObject::DECODE_WITH_CHARSET)).equalsAscii("tmp"))
+        || url.getName(0, true, INetURLObject::DECODE_WITH_CHARSET) != "tmp")
     {
         return;
     }
@@ -1716,7 +1703,7 @@ void FileDialogHelper_Impl::verifyPath()
 // ------------------------------------------------------------------------
 void FileDialogHelper_Impl::displayFolder( const ::rtl::OUString& _rPath )
 {
-    if ( ! _rPath.getLength() )
+    if ( _rPath.isEmpty() )
         // nothing to do
         return;
 
@@ -1760,7 +1747,7 @@ void FileDialogHelper_Impl::setFilter( const OUString& rFilter )
 
     maCurFilter = rFilter;
 
-    if ( rFilter.getLength() && mpMatcher )
+    if ( !rFilter.isEmpty() && mpMatcher )
     {
         const SfxFilter* pFilter = mpMatcher->GetFilter4FilterName(
                                         rFilter, m_nMustFlags, m_nDontFlags );
@@ -1770,7 +1757,7 @@ void FileDialogHelper_Impl::setFilter( const OUString& rFilter )
 
     uno::Reference< XFilterManager > xFltMgr( mxFileDlg, UNO_QUERY );
 
-    if ( maCurFilter.getLength() && xFltMgr.is() )
+    if ( !maCurFilter.isEmpty() && xFltMgr.is() )
     {
         try
         {
@@ -1812,7 +1799,7 @@ void FileDialogHelper_Impl::addFilters( const String& rFactory,
 
     uno::Reference< XMultiServiceFactory > xSMGR = ::comphelper::getProcessServiceFactory();
     uno::Reference< XContainerQuery > xFilterCont(
-        xSMGR->createInstance(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.document.FilterFactory"))),
+        xSMGR->createInstance(::rtl::OUString("com.sun.star.document.FilterFactory")),
         UNO_QUERY);
     if ( ! xFilterCont.is() )
         return;
@@ -1837,7 +1824,7 @@ void FileDialogHelper_Impl::addFilters( const String& rFactory,
     }
     catch( const uno::Exception& )
     {
-        DBG_ERRORFILE( "Could not get filters from the configuration!" );
+        SAL_WARN( "sfx2.dialog", "Could not get filters from the configuration!" );
     }
 
     TSortedFilterList         aIter   (xResult);
@@ -1855,7 +1842,7 @@ void FileDialogHelper_Impl::addFilters( const String& rFactory,
         ::sfx2::appendFiltersForSave( aIter, xFltMgr, sFirstFilter, *this, rFactory );
 
     // set our initial selected filter (if we do not already have one)
-    if ( !maSelectFilter.getLength() )
+    if ( maSelectFilter.isEmpty() )
         maSelectFilter = sFirstFilter;
 }
 
@@ -1872,16 +1859,12 @@ void FileDialogHelper_Impl::addFilter( const OUString& rFilterName,
     {
         xFltMgr->appendFilter( rFilterName, rExtension );
 
-        if ( !maSelectFilter.getLength() )
+        if ( maSelectFilter.isEmpty() )
             maSelectFilter = rFilterName;
     }
     catch( const IllegalArgumentException& )
     {
-#ifdef DBG_UTIL
-        rtl::OStringBuffer aMsg(RTL_CONSTASCII_STRINGPARAM("Could not append Filter"));
-        aMsg.append(rtl::OUStringToOString(rFilterName, RTL_TEXTENCODING_UTF8));
-        DBG_ERRORFILE( aMsg.getStr() );
-#endif
+        SAL_WARN( "sfx2.dialog", "Could not append Filter" << rFilterName );
     }
 }
 
@@ -1934,7 +1917,7 @@ void FileDialogHelper_Impl::addGraphicFilter()
     }
     catch( const IllegalArgumentException& )
     {
-        DBG_ERRORFILE( "Could not append Filter" );
+        SAL_WARN( "sfx2.dialog", "Could not append Filter" );
     }
 
     // Now add the filter
@@ -1963,7 +1946,7 @@ void FileDialogHelper_Impl::addGraphicFilter()
         }
         catch( const IllegalArgumentException& )
         {
-            DBG_ERRORFILE( "Could not append Filter" );
+            SAL_WARN( "sfx2.dialog", "Could not append Filter" );
         }
     }
 }
@@ -2036,7 +2019,7 @@ void FileDialogHelper_Impl::saveConfig()
         if ( ! mbIsSaveDlg )
         {
             OUString aPath = getPath();
-            if ( aPath.getLength() &&
+            if ( !aPath.isEmpty() &&
                  utl::LocalFileHelper::IsLocalFile( aPath ) )
             {
                 aUserData.SetToken( 1, ' ', aPath );
@@ -2051,7 +2034,7 @@ void FileDialogHelper_Impl::saveConfig()
                 aValue = xDlg->getValue( ExtendedFilePickerElementIds::CHECKBOX_SELECTION, 0 );
                 sal_Bool bSelection = sal_True;
                 aValue >>= bSelection;
-                if ( aUserData.GetTokenCount(' ') < 3 )
+                if ( comphelper::string::getTokenCount(aUserData, ' ') < 3 )
                     aUserData.Append(' ');
                 aUserData.SetToken( 2, ' ', String::CreateFromInt32( (sal_Int32) bSelection ) );
                 bWriteConfig = sal_True;
@@ -2135,10 +2118,10 @@ void FileDialogHelper_Impl::loadConfig()
                     xDlg->setValue( ExtendedFilePickerElementIds::CHECKBOX_PREVIEW, 0, aValue );
                 }
 
-                if ( !maPath.getLength() )
+                if ( maPath.isEmpty() )
                     displayFolder( getInitPath( aUserData, 2 ) );
 
-                if ( ! maCurFilter.getLength() )
+                if ( maCurFilter.isEmpty() )
                 {
                     String aFilter = aUserData.GetToken( 3, ' ' );
                     aFilter = DecodeSpaces_Impl( aFilter );
@@ -2151,7 +2134,7 @@ void FileDialogHelper_Impl::loadConfig()
             catch( const IllegalArgumentException& ){}
         }
 
-        if ( !maPath.getLength() )
+        if ( maPath.isEmpty() )
             displayFolder( SvtPathOptions().GetGraphicPath() );
     }
     else
@@ -2170,7 +2153,7 @@ void FileDialogHelper_Impl::loadConfig()
         if ( ! aUserData.Len() )
             aUserData = DEFINE_CONST_UNICODE( STD_CONFIG_STR );
 
-        if ( ! maPath.getLength() )
+        if ( maPath.isEmpty() )
             displayFolder( getInitPath( aUserData, 1 ) );
 
         if ( mbHasAutoExt )
@@ -2195,7 +2178,7 @@ void FileDialogHelper_Impl::loadConfig()
             catch( const IllegalArgumentException& ){}
         }
 
-        if ( !maPath.getLength() )
+        if ( maPath.isEmpty() )
             displayFolder( SvtPathOptions().GetWorkPath() );
     }
 }
@@ -2204,7 +2187,7 @@ void FileDialogHelper_Impl::loadConfig()
 void FileDialogHelper_Impl::setDefaultValues()
 {
     // when no filter is set, we set the curentFilter to <all>
-    if ( !maCurFilter.getLength() && maSelectFilter.getLength() )
+    if ( maCurFilter.isEmpty() && !maSelectFilter.isEmpty() )
     {
         uno::Reference< XFilterManager > xFltMgr( mxFileDlg, UNO_QUERY );
         try
@@ -2216,7 +2199,7 @@ void FileDialogHelper_Impl::setDefaultValues()
     }
 
     // when no path is set, we use the standard 'work' folder
-    if ( ! maPath.getLength() )
+    if ( maPath.isEmpty() )
     {
         OUString aWorkFolder = SvtPathOptions().GetWorkPath();
         try
@@ -2344,10 +2327,10 @@ FileDialogHelper::FileDialogHelper(
     ::rtl::OUString aWildcard;
     if ( aExtName.indexOf( (sal_Unicode)'*' ) != 0 )
     {
-        if ( aExtName.getLength() && aExtName.indexOf( (sal_Unicode)'.' ) != 0 )
-            aWildcard = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "*." ) );
+        if ( !aExtName.isEmpty() && aExtName.indexOf( (sal_Unicode)'.' ) != 0 )
+            aWildcard = ::rtl::OUString( "*."  );
         else
-            aWildcard = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "*" ) );
+            aWildcard = ::rtl::OUString( "*"  );
     }
 
     aWildcard += aExtName;
@@ -2382,7 +2365,7 @@ void FileDialogHelper::SetContext( Context _eNewContext )
 }
 
 // ------------------------------------------------------------------------
-IMPL_LINK( FileDialogHelper, ExecuteSystemFilePicker, void*, EMPTYARG )
+IMPL_LINK_NOARG(FileDialogHelper, ExecuteSystemFilePicker)
 {
     m_nError = mpImp->execute();
     if ( m_aDialogClosedLink.IsSet() )
@@ -2393,7 +2376,7 @@ IMPL_LINK( FileDialogHelper, ExecuteSystemFilePicker, void*, EMPTYARG )
 
 // ------------------------------------------------------------------------
 // rDirPath has to be a directory
-ErrCode FileDialogHelper::Execute( SvStringsDtor*& rpURLList,
+ErrCode FileDialogHelper::Execute( std::vector<rtl::OUString>& rpURLList,
                                    SfxItemSet *&   rpSet,
                                    String&         rFilter,
                                    const String&   rDirPath )
@@ -2414,12 +2397,8 @@ ErrCode FileDialogHelper::Execute( SfxItemSet *&   rpSet,
                                    String&         rFilter )
 {
     ErrCode nRet;
-    SvStringsDtor* pURLList;
-
-    nRet = mpImp->execute( pURLList, rpSet, rFilter );
-
-    delete pURLList;
-
+    std::vector<rtl::OUString> rURLList;
+    nRet = mpImp->execute(rURLList, rpSet, rFilter);
     return nRet;
 }
 
@@ -2561,23 +2540,10 @@ ErrCode FileDialogHelper::GetGraphic( Graphic& rGraphic ) const
 // ------------------------------------------------------------------------
 static int impl_isFolder( const OUString& rPath )
 {
-    uno::Reference< task::XInteractionHandler > xHandler;
-    try
-    {
-        uno::Reference< lang::XMultiServiceFactory > xFactory( ::comphelper::getProcessServiceFactory(), uno::UNO_QUERY_THROW );
-        xHandler.set( xFactory->createInstance( DEFINE_CONST_OUSTRING( "com.sun.star.task.InteractionHandler" ) ),
-                      uno::UNO_QUERY_THROW );
-    }
-    catch ( const Exception & )
-    {
-    }
-
-    ::rtl::Reference< ::comphelper::StillReadWriteInteraction > aHandler = new ::comphelper::StillReadWriteInteraction( xHandler );
-
     try
     {
         ::ucbhelper::Content aContent(
-            rPath, new ::ucbhelper::CommandEnvironment( static_cast< task::XInteractionHandler* > ( aHandler.get() ), uno::Reference< ucb::XProgressHandler >() ) );
+            rPath, uno::Reference< ucb::XCommandEnvironment > () );
         if ( aContent.isFolder() )
             return 1;
 
@@ -2616,7 +2582,7 @@ void FileDialogHelper::SetDisplayDirectory( const String& _rPath )
     {
         INetURLObject aObjPathName( _rPath );
         ::rtl::OUString sFolder( aObjPathName.GetMainURL( INetURLObject::NO_DECODE ) );
-        if ( sFolder.getLength() == 0 )
+        if ( sFolder.isEmpty() )
         {
             // _rPath is not a valid path -> fallback to home directory
             osl::Security aSecurity;
@@ -2705,7 +2671,7 @@ void SAL_CALL FileDialogHelper::DialogClosed( const DialogClosedEvent& _rEvent )
 ErrCode FileOpenDialog_Impl( sal_Int16 nDialogType,
                              sal_Int64 nFlags,
                              const String& rFact,
-                             SvStringsDtor *& rpURLList,
+                             std::vector<rtl::OUString>& rpURLList,
                              String& rFilter,
                              SfxItemSet *& rpSet,
                              const String* pPath,
@@ -2729,7 +2695,7 @@ ErrCode FileOpenDialog_Impl( sal_Int16 nDialogType,
 
 ErrCode RequestPassword(const SfxFilter* pCurrentFilter, rtl::OUString& aURL, SfxItemSet* pSet)
 {
-    uno::Reference < ::com::sun::star::task::XInteractionHandler > xInteractionHandler( ::comphelper::getProcessServiceFactory()->createInstance(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.uui.UUIInteractionHandler"))), UNO_QUERY );
+    uno::Reference < ::com::sun::star::task::XInteractionHandler > xInteractionHandler( ::comphelper::getProcessServiceFactory()->createInstance(::rtl::OUString("com.sun.star.comp.uui.UUIInteractionHandler")), UNO_QUERY );
     if( xInteractionHandler.is() )
     {
         // TODO: need a save way to distinguish MS filters from other filters
@@ -2757,8 +2723,8 @@ ErrCode RequestPassword(const SfxFilter* pCurrentFilter, rtl::OUString& aURL, Sf
                     if ( aEncryptionKey.getLength() )
                     {
                         ::comphelper::SequenceAsHashMap aHashData;
-                        aHashData[ ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "STD97EncryptionKey" ) ) ] <<= aEncryptionKey;
-                        aHashData[ ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "STD97UniqueID" ) ) ] <<= aUniqueID;
+                        aHashData[ ::rtl::OUString( "STD97EncryptionKey"  ) ] <<= aEncryptionKey;
+                        aHashData[ ::rtl::OUString( "STD97UniqueID"  ) ] <<= aUniqueID;
 
                         pSet->Put( SfxUnoAnyItem( SID_ENCRYPTIONDATA, uno::makeAny( aHashData.getAsConstNamedValueList() ) ) );
                     }
@@ -2777,7 +2743,7 @@ ErrCode RequestPassword(const SfxFilter* pCurrentFilter, rtl::OUString& aURL, Sf
             if ( bMSType )
             {
                 // the empty password has 0 as Hash
-                sal_Int32 nHash = SfxMedium::CreatePasswordToModifyHash( pPasswordRequest->getPasswordToModify(), ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.text.TextDocument" ) ).equals( pCurrentFilter->GetServiceName() ) );
+                sal_Int32 nHash = SfxMedium::CreatePasswordToModifyHash( pPasswordRequest->getPasswordToModify(), ::rtl::OUString( "com.sun.star.text.TextDocument"  ).equals( pCurrentFilter->GetServiceName() ) );
                 if ( nHash )
                     pSet->Put( SfxUnoAnyItem( SID_MODIFYPASSWORDINFO, uno::makeAny( nHash ) ) );
             }
