@@ -126,7 +126,11 @@ namespace sfx2
         //................................................................
         void lcl_showDocumentMacrosDisabledError( const Reference< XInteractionHandler >& rxHandler, sal_Bool& rbAlreadyShown )
         {
+#ifdef MACOSX
+            lcl_showGeneralSfxErrorOnce( rxHandler, ERRCODE_SFX_DOCUMENT_MACRO_DISABLED_MAC, rbAlreadyShown );
+#else
             lcl_showGeneralSfxErrorOnce( rxHandler, ERRCODE_SFX_DOCUMENT_MACRO_DISABLED, rbAlreadyShown );
+#endif
         }
 
         //................................................................
@@ -241,7 +245,7 @@ namespace sfx2
                 if ( aURLReferer.removeSegment() )
                     aLocation = aURLReferer.GetMainURL( INetURLObject::NO_DECODE );
 
-                if ( aLocation.getLength() && xSignatures->isLocationTrusted( aLocation ) )
+                if ( !aLocation.isEmpty() && xSignatures->isLocationTrusted( aLocation ) )
                 {
                     return allowMacroExecution();
                 }
@@ -333,6 +337,7 @@ namespace sfx2
     sal_Bool DocumentMacroMode::hasMacroLibrary() const
     {
         sal_Bool bHasMacroLib = sal_False;
+#ifndef DISABLE_SCRIPTING
         try
         {
             Reference< XEmbeddedScripts > xScripts( m_pData->m_rDocumentAccess.getEmbeddedDocumentScripts() );
@@ -404,7 +409,7 @@ namespace sfx2
         {
             DBG_UNHANDLED_EXCEPTION();
         }
-
+#endif
         return bHasMacroLib;
     }
 
