@@ -67,15 +67,12 @@
 #include "docvor.hrc"
 #include <sfx2/docfilt.hxx>
 #include <sfx2/filedlghelper.hxx>
-#include <sfx2/docfilt.hxx>
 #include <sfx2/fcontnr.hxx>
 #include <svtools/localresaccess.hxx>
 #include <svtools/addresstemplate.hxx>
 #include <comphelper/processfactory.hxx>
-#define _SVSTDARR_STRINGSDTOR
 #include <svl/svstdarr.hxx>
 
-static const char cDelim = ':';
 sal_Bool SfxOrganizeListBox_Impl::bDropMoveOk = sal_True;
 
 using namespace ::com::sun::star;
@@ -156,7 +153,7 @@ friend class SfxOrganizeListBox_Impl;
     SfxOrganizeMgr          aMgr;
     sfx2::FileDialogHelper* pFileDlg;
 
-    SvStringsDtor*          GetAllFactoryURLs_Impl() const;
+    std::vector<rtl::OUString> GetAllFactoryURLs_Impl() const;
     sal_Bool                GetServiceName_Impl( String& rFactoryURL, String& rFileURL ) const;
     long                    Dispatch_Impl( sal_uInt16 nId, Menu* _pMenu );
     String                  GetPath_Impl( sal_Bool bOpen, const String& rFileName );
@@ -173,12 +170,11 @@ friend class SfxOrganizeListBox_Impl;
     DECL_LINK( AddFiles_Impl, Button * );
     DECL_LINK( OnAddressTemplateClicked, Button * );
 
-    DECL_LINK( ImportHdl, sfx2::FileDialogHelper* );
-    DECL_LINK( ExportHdl, sfx2::FileDialogHelper* );
-    DECL_LINK( AddFilesHdl, sfx2::FileDialogHelper* );
+    DECL_LINK(ImportHdl, void *);
+    DECL_LINK(ExportHdl, void *);
+    DECL_LINK(AddFilesHdl, void *);
 
     sal_Bool        DontDelete_Impl( SvLBoxEntry* pEntry );
-    void        OkHdl( Button* );
 
 public:
     SfxOrganizeDlg_Impl( SfxTemplateOrganizeDlg* pParent, SfxDocumentTemplates* pTempl );
@@ -698,9 +694,9 @@ sal_Bool SfxOrganizeListBox_Impl::MoveOrCopyContents(SvLBox *pSourceBox,
             // the general reference point
             while(GetModel()->GetDepth(pParentIter) != nTLevel)
                 pParentIter = GetParent(pParentIter);
-            if(pParentIter->HasChildsOnDemand() &&
-                !GetModel()->HasChilds(pParentIter))
-                RequestingChilds(pParentIter);
+            if(pParentIter->HasChildrenOnDemand() &&
+                !GetModel()->HasChildren(pParentIter))
+                RequestingChildren(pParentIter);
             SvLBoxEntry *pChildIter = 0;
 
             sal_uInt16 i = 0;
@@ -713,16 +709,16 @@ sal_Bool SfxOrganizeListBox_Impl::MoveOrCopyContents(SvLBox *pSourceBox,
                 // If possible, fill in Items onDemand
                 ++i;
                 if(i < 2 && p[i+1] != INDEX_IGNORE &&
-                   pChildIter->HasChildsOnDemand() &&
-                   !GetModel()->HasChilds(pChildIter))
-                    RequestingChilds(pChildIter);
+                   pChildIter->HasChildrenOnDemand() &&
+                   !GetModel()->HasChildren(pChildIter))
+                    RequestingChildren(pChildIter);
                 pParentIter = pChildIter;
             }
             rIdx = p[i];
             pNewParent = pParentIter;
             if(!IsExpanded(pNewParent) &&
-               pNewParent->HasChildsOnDemand() &&
-               !GetModel()->HasChilds(pNewParent))
+               pNewParent->HasChildrenOnDemand() &&
+               !GetModel()->HasChildren(pNewParent))
             {
                 bOk = sal_False;
                 if(!bCopy)
@@ -886,7 +882,7 @@ sal_Bool SfxOrganizeListBox_Impl::EditingEntry( SvLBoxEntry* pEntry, Selection&
     (SV-Handler)
 
     [Cross-references]
-    <SfxOrganizeListBox_Impl::EditedEntry(SvLBoxEntry* pEntry, const String& rText)>
+    <SfxOrganizeListBox_Impl::EditedEntry(SvLBoxEntry* pEntry, const rtl::OUString& rText)>
 */
 
 {
@@ -901,7 +897,7 @@ sal_Bool SfxOrganizeListBox_Impl::EditingEntry( SvLBoxEntry* pEntry, Selection&
 
 //-------------------------------------------------------------------------
 
-sal_Bool SfxOrganizeListBox_Impl::EditedEntry(SvLBoxEntry* pEntry, const String& rText)
+sal_Bool SfxOrganizeListBox_Impl::EditedEntry(SvLBoxEntry* pEntry, const rtl::OUString& rText)
 
 /*  [Description]
 
@@ -923,7 +919,7 @@ sal_Bool SfxOrganizeListBox_Impl::EditedEntry(SvLBoxEntry* pEntry, const String&
     delete pDlg->pSuspend;
     pDlg->pSuspend = NULL;
     SvLBoxEntry* pParent = GetParent(pEntry);
-    if( !rText.Len() )
+    if( rText.isEmpty() )
     {
         ErrorBox aBox( this, SfxResId( MSG_ERROR_EMPTY_NAME ) );
         aBox.GrabFocus();
@@ -1124,20 +1120,20 @@ SfxObjectShellRef SfxOrganizeListBox_Impl::GetObjectShell(const Path &rPath)
 
 //-------------------------------------------------------------------------
 
-void SfxOrganizeListBox_Impl::RequestingChilds( SvLBoxEntry* pEntry )
+void SfxOrganizeListBox_Impl::RequestingChildren( SvLBoxEntry* pEntry )
 
 /*  [Description]
 
-    Sent to the Childs of an entry that is going to be inserted.
+    Sent to the children of an entry that is going to be inserted.
     (SV-Handler)
 
     [Parameter]
 
-    SvLBoxEntry* pEntry     the entry whose Childs is requested
+    SvLBoxEntry* pEntry     the entry whose children is requested
 */
 
 {
-    if ( !GetModel()->HasChilds( pEntry ) )
+    if ( !GetModel()->HasChildren( pEntry ) )
     {
         WaitObject aWaitCursor( this );
 
@@ -1167,8 +1163,8 @@ void SfxOrganizeListBox_Impl::RequestingChilds( SvLBoxEntry* pEntry )
                 const sal_uInt16 nCount = aRef->GetContentCount(aPath[nDocLevel+1]);
                 String aText;
                 Bitmap aClosedBmp, aOpenedBmp;
-                const bool bCanHaveChilds =
-                    aRef->CanHaveChilds(aPath[nDocLevel+1],
+                const bool bCanHaveChildren =
+                    aRef->CanHaveChildren(aPath[nDocLevel+1],
                                         aPath[nDocLevel+2]);
                 for(sal_uInt16 i = 0; i < nCount; ++i)
                 {
@@ -1183,7 +1179,7 @@ void SfxOrganizeListBox_Impl::RequestingChilds( SvLBoxEntry* pEntry )
 
                     SvLBoxEntry *pNew = SvTreeListBox::InsertEntry(
                         aText, aOpenedImage, aClosedImage,
-                        pEntry, bCanHaveChilds);
+                        pEntry, bCanHaveChildren);
                     pNew->SetUserData(bDeletable ? &bDeletable : 0);
                 }
             }
@@ -1277,7 +1273,7 @@ SvLBoxEntry* SfxOrganizeListBox_Impl::InsertEntryByBmpType(
     const XubString& rText,
     BMPTYPE eBmpType,
     SvLBoxEntry* pParent,
-    sal_Bool bChildsOnDemand,
+    sal_Bool bChildrenOnDemand,
     sal_uIntPtr nPos,
     void* pUserData
 )
@@ -1302,7 +1298,7 @@ SvLBoxEntry* SfxOrganizeListBox_Impl::InsertEntryByBmpType(
             OSL_FAIL( "SfxOrganizeListBox_Impl::InsertEntryByBmpType(): something forgotten?!" );
     }
 
-    pEntry = SvTreeListBox::InsertEntry( rText, *pExp, *pCol, pParent, bChildsOnDemand, nPos, pUserData );
+    pEntry = SvTreeListBox::InsertEntry( rText, *pExp, *pCol, pParent, bChildrenOnDemand, nPos, pUserData );
 
     return pEntry;
 }
@@ -1683,8 +1679,17 @@ sal_Bool SfxOrganizeDlg_Impl::DontDelete_Impl( SvLBoxEntry* pEntry )
         return sal_True;
     }
 
+    //If delete is pressed on e.g. a style entry go up the chain to find the
+    //owning template
+    while (nDepth > 1)
+    {
+        pEntry = pFocusBox->GetParent(pEntry);
+        --nDepth;
+    }
+    SvLBoxEntry *pTemplateEntry = pEntry;
+
     sal_uInt16 nRegion = 0, nIndex = 0;
-    GetIndices_Impl( pFocusBox, pEntry, nRegion, nIndex );
+    GetIndices_Impl( pFocusBox, pTemplateEntry, nRegion, nIndex );
     const SfxDocumentTemplates* pTemplates = aMgr.GetTemplates();
     if ( !pTemplates || !pTemplates->HasUserContents( nRegion, nIndex ) )
         return sal_True;
@@ -1692,11 +1697,11 @@ sal_Bool SfxOrganizeDlg_Impl::DontDelete_Impl( SvLBoxEntry* pEntry )
     return sal_False;
 }
 
-SvStringsDtor* SfxOrganizeDlg_Impl::GetAllFactoryURLs_Impl( ) const
+std::vector<rtl::OUString> SfxOrganizeDlg_Impl::GetAllFactoryURLs_Impl( ) const
 {
     SvtModuleOptions aModOpt;
     const ::com::sun::star::uno::Sequence < ::rtl::OUString >& aServiceNames = aModOpt.GetAllServiceNames() ;
-    SvStringsDtor* pList = new SvStringsDtor;
+    std::vector<rtl::OUString> aList;
     sal_Int32 nCount = aServiceNames.getLength();
     for( sal_Int32 i=0; i<nCount; ++i )
     {
@@ -1704,12 +1709,11 @@ SvStringsDtor* SfxOrganizeDlg_Impl::GetAllFactoryURLs_Impl( ) const
         {
             SvtModuleOptions::EFactory eFac = SvtModuleOptions::E_WRITER;
             SvtModuleOptions::ClassifyFactoryByName( aServiceNames[i], eFac );
-            String* pURL = new String( aModOpt.GetFactoryEmptyDocumentURL( eFac ) );
-            pList->Insert( pURL, pList->Count() );
+            aList.push_back(aModOpt.GetFactoryEmptyDocumentURL(eFac));
         }
     }
 
-    return pList;
+    return aList;
 }
 
 sal_Bool SfxOrganizeDlg_Impl::GetServiceName_Impl( String& rName, String& rFileURL ) const
@@ -1771,14 +1775,13 @@ long SfxOrganizeDlg_Impl::Dispatch_Impl( sal_uInt16 nId, Menu* _pMenu )
             {
                 if(0 == pFocusBox->GetModel()->GetDepth(pEntry))
                 {
-                    const String aNoName( SfxResId(STR_NONAME) );
+                    const rtl::OUString aNoName(SFX2_RESSTR(STR_NONAME));
                     SvLBoxEntry* pParent = pFocusBox->GetParent(pEntry);
-                    String aName(aNoName);
-                    sal_uInt16 n = 1;
+                    rtl::OUString aName(aNoName);
+                    sal_Int32 n = 1;
                     while(!pFocusBox->IsUniqName_Impl(aName, pParent))
                     {
-                        aName = aNoName;
-                        aName += String::CreateFromInt32( n++ );
+                        aName = aNoName + rtl::OUString::valueOf(n++);
                     }
                     aMgr.InsertDir( pFocusBox, aName,
                             (sal_uInt16)pFocusBox->GetModel()->GetRelPos(pEntry)+1);
@@ -1995,17 +1998,6 @@ IMPL_LINK( SfxOrganizeDlg_Impl, AccelSelect_Impl, Accelerator *, pAccel )
         Dispatch_Impl( pAccel->GetCurItemId(), NULL ) : 0;
 }
 
-//-------------------------------------------------------------------------
-
-void SfxOrganizeDlg_Impl::OkHdl(Button *pButton)
-{
-    if(pFocusBox && pFocusBox->IsEditingActive())
-        pFocusBox->EndEditing(sal_False);
-    pButton->Click();
-}
-
-
-
 IMPL_LINK( SfxOrganizeDlg_Impl, MenuActivate_Impl, Menu *, pMenu )
 
 /*  [Description]
@@ -2069,20 +2061,17 @@ IMPL_LINK( SfxOrganizeDlg_Impl, MenuActivate_Impl, Menu *, pMenu )
     pMenu->EnableItem( ID_DEFAULT_TEMPLATE, bEnable );
 
     bEnable = sal_True;
-    SvStringsDtor* pList = GetAllFactoryURLs_Impl();
-    sal_uInt16 nCount = pList->Count();
-    if ( nCount > 0 )
+    std::vector<rtl::OUString> aList(GetAllFactoryURLs_Impl());
+    if (!aList.empty())
     {
         PopupMenu* pSubMenu = new PopupMenu;
         sal_uInt16 nItemId = ID_RESET_DEFAULT_TEMPLATE + 1;
-        for ( sal_uInt16 i = 0; i < nCount; ++i )
+        for(std::vector<rtl::OUString>::const_iterator i = aList.begin(); i != aList.end(); ++i)
         {
-            String aObjFacURL( *pList->GetObject(i) );
-            String aTitle = SvFileInformationManager::GetDescription(
-                INetURLObject(aObjFacURL) );
-            pSubMenu->InsertItem( nItemId, aTitle,
-                SvFileInformationManager::GetImage(INetURLObject(aObjFacURL), false) );
-            pSubMenu->SetItemCommand( nItemId++, aObjFacURL );
+            INetURLObject aObj(*i);
+            String aTitle = SvFileInformationManager::GetDescription(aObj);
+            pSubMenu->InsertItem(nItemId, aTitle, SvFileInformationManager::GetImage(aObj, false));
+            pSubMenu->SetItemCommand(nItemId++, *i);
             DBG_ASSERT( nItemId <= ID_RESET_DEFAULT_TEMPLATE_END, "menu item id overflow" );
         }
         pMenu->SetPopupMenu( ID_RESET_DEFAULT_TEMPLATE, pSubMenu );
@@ -2090,7 +2079,6 @@ IMPL_LINK( SfxOrganizeDlg_Impl, MenuActivate_Impl, Menu *, pMenu )
     else
         bEnable = sal_False;
 
-    delete pList;
     pMenu->EnableItem( ID_RESET_DEFAULT_TEMPLATE, bEnable );
 
     return 1;
@@ -2248,7 +2236,7 @@ IMPL_LINK( SfxOrganizeDlg_Impl, AddFiles_Impl, Button *, pButton )
 
 //-------------------------------------------------------------------------
 
-IMPL_LINK( SfxOrganizeDlg_Impl, ImportHdl, sfx2::FileDialogHelper *, EMPTYARG )
+IMPL_LINK_NOARG(SfxOrganizeDlg_Impl, ImportHdl)
 {
     DBG_ASSERT( pFileDlg, "SfxOrganizeDlg_Impl::ImportHdl(): no file dialog" );
 
@@ -2285,7 +2273,7 @@ IMPL_LINK( SfxOrganizeDlg_Impl, ImportHdl, sfx2::FileDialogHelper *, EMPTYARG )
 
 //-------------------------------------------------------------------------
 
-IMPL_LINK( SfxOrganizeDlg_Impl, ExportHdl, sfx2::FileDialogHelper *, EMPTYARG )
+IMPL_LINK_NOARG(SfxOrganizeDlg_Impl, ExportHdl)
 {
     DBG_ASSERT( pFileDlg, "SfxOrganizeDlg_Impl::ImportHdl(): no file dialog" );
     ::com::sun::star::uno::Sequence< ::rtl::OUString > aPaths;
@@ -2336,7 +2324,7 @@ IMPL_LINK( SfxOrganizeDlg_Impl, ExportHdl, sfx2::FileDialogHelper *, EMPTYARG )
 
 //-------------------------------------------------------------------------
 
-IMPL_LINK( SfxOrganizeDlg_Impl, AddFilesHdl, sfx2::FileDialogHelper *, EMPTYARG )
+IMPL_LINK_NOARG(SfxOrganizeDlg_Impl, AddFilesHdl)
 {
     if ( ERRCODE_NONE == pFileDlg->GetError() )
     {
