@@ -266,19 +266,19 @@ sal_Int32 getNextActionOffset( MetaAction * pCurrAct )
     case META_TEXT_ACTION: {
         MetaTextAction * pAct = static_cast<MetaTextAction *>(pCurrAct);
         return (pAct->GetLen() == (sal_uInt16)STRING_LEN
-                ? pAct->GetText().Len() - pAct->GetIndex() : pAct->GetLen());
+                ? pAct->GetText().getLength() - pAct->GetIndex() : pAct->GetLen());
     }
     case META_TEXTARRAY_ACTION: {
         MetaTextArrayAction * pAct =
             static_cast<MetaTextArrayAction *>(pCurrAct);
         return (pAct->GetLen() == (sal_uInt16)STRING_LEN
-                ? pAct->GetText().Len() - pAct->GetIndex() : pAct->GetLen());
+                ? pAct->GetText().getLength() - pAct->GetIndex() : pAct->GetLen());
     }
     case META_STRETCHTEXT_ACTION: {
         MetaStretchTextAction * pAct =
             static_cast<MetaStretchTextAction *>(pCurrAct);
         return (pAct->GetLen() == (sal_uInt16)STRING_LEN
-                ? pAct->GetText().Len() - pAct->GetIndex() : pAct->GetLen());
+                ? pAct->GetText().getLength() - pAct->GetIndex() : pAct->GetLen());
     }
     case META_FLOATTRANSPARENT_ACTION: {
         MetaFloatTransparentAction * pAct =
