@@ -1062,6 +1062,14 @@ bool SlideImpl::applyInitialShapeAttributes(
                 // this up first.
                 const DocTreeNodeSupplier& rNodeSupplier( pAttrShape->getTreeNodeSupplier() );
 
+                if( rNodeSupplier.getNumberOfTreeNodes(
+                        DocTreeNode::NODETYPE_LOGICAL_PARAGRAPH ) <= nParaIndex )
+                {
+                    OSL_FAIL( "SlideImpl::applyInitialShapeAttributes(): shape found does not "
+                                "provide a subset for requested paragraph index" );
+                    continue;
+                }
+
                 pAttrShape = pAttrShape->getSubset(
                     rNodeSupplier.getTreeNode(
                         nParaIndex,
@@ -1080,7 +1088,7 @@ bool SlideImpl::applyInitialShapeAttributes(
             for( ::std::size_t j=0; j<nShapePropSize; ++j )
             {
                 bool bVisible=false;
-                if( rShapeProps[j].Name.equalsIgnoreAsciiCaseAscii("visibility") &&
+                if( rShapeProps[j].Name.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("visibility")) &&
                     extractValue( bVisible,
                                   rShapeProps[j].Value,
                                   pShape,
