@@ -27,11 +27,11 @@
 
 package installer::ziplist;
 
-use installer::existence;
+use File::Spec::Functions qw(rel2abs);
+
 use installer::exiter;
 use installer::globals;
 use installer::logger;
-use installer::parameter;
 use installer::remover;
 use installer::systemactions;
 
@@ -383,7 +383,7 @@ sub remove_multiples_from_ziplist
             $itemname = $1;
         }
 
-        if (! installer::existence::exists_in_array($itemname, \@itemarray))
+        if (! grep {$_ eq $itemname} @itemarray)
         {
             push(@itemarray, $itemname);
         }
@@ -454,7 +454,7 @@ sub getinfofromziplist
 # Replacing variables in include path
 ####################################################
 
-sub replace_all_variables_in_pathes
+sub replace_all_variables_in_paths
 {
     my ( $patharrayref, $variableshashref ) = @_;
 
@@ -481,7 +481,7 @@ sub replace_all_variables_in_pathes
 # Replacing minor in include path
 ####################################################
 
-sub replace_minor_in_pathes
+sub replace_minor_in_paths
 {
     my ( $patharrayref ) = @_;
 
@@ -500,7 +500,7 @@ sub replace_minor_in_pathes
 # Replacing packagetype in include path
 ####################################################
 
-sub replace_packagetype_in_pathes
+sub replace_packagetype_in_paths
 {
     my ( $patharrayref ) = @_;
 
@@ -518,7 +518,7 @@ sub replace_packagetype_in_pathes
 }
 
 ####################################################
-# Removing ending separators in pathes
+# Removing ending separators in paths
 ####################################################
 
 sub remove_ending_separator
@@ -542,11 +542,11 @@ sub remove_ending_separator
 # Replacing languages in include path
 ####################################################
 
-sub replace_languages_in_pathes
+sub replace_languages_in_paths
 {
     my ( $patharrayref, $languagesref ) = @_;
 
-    installer::logger::include_header_into_logfile("Replacing languages in include pathes:");
+    installer::logger::include_header_into_logfile("Replacing languages in include paths:");
 
     my @patharray = ();
     my $infoline = "";
@@ -570,13 +570,13 @@ sub replace_languages_in_pathes
 
                 installer::remover::remove_leading_and_ending_whitespaces(\$newline);
 
-                # Is it necessary to refresh the global array, containing all files of all include pathes?
+                # Is it necessary to refresh the global array, containing all files of all include paths?
                 if ( -d $newdir )
                 {
                     # Checking if $newdir is empty
                     if ( ! installer::systemactions::is_empty_dir($newdir) )
                     {
-                        $installer::globals::refresh_includepathes = 1;
+                        $installer::globals::refresh_includepaths = 1;
                         $infoline = "Directory $newdir exists and is not empty. Refreshing global file array is required.\n";
                         push( @installer::globals::logfileinfo, $infoline);
                     }
@@ -610,7 +610,7 @@ sub list_all_files_from_include_path
 {
     my ( $patharrayref) = @_;
 
-    installer::logger::include_header_into_logfile("Include pathes:");
+    installer::logger::include_header_into_logfile("Include paths:");
 
     for ( my $i = 0; $i <= $#{$patharrayref}; $i++ )
     {
@@ -673,7 +673,7 @@ sub set_default_productversion_if_required
 }
 
 ####################################################
-# Removing .. in pathes
+# Removing .. in paths
 ####################################################
 
 sub simplify_path
@@ -696,17 +696,17 @@ sub simplify_path
 }
 
 ####################################################
-# Removing ending separators in pathes
+# Removing ending separators in paths
 ####################################################
 
-sub resolve_relative_pathes
+sub resolve_relative_paths
 {
     my ( $patharrayref ) = @_;
 
-    for ( my $i = 0; $i <= $#{$patharrayref}; $i++ )
+    for my $path ( @{$patharrayref} )
     {
-        installer::parameter::make_path_absolute(\${$patharrayref}[$i]);
-        simplify_path(\${$patharrayref}[$i]);
+        $path = rel2abs($path);
+        simplify_path(\$path);
     }
 }
 
@@ -755,6 +755,8 @@ sub overwrite_branding
     $variableshashref->{'PROGRESSSIZE'} = $ENV{'PROGRESSSIZE'} , if( defined $ENV{'PROGRESSSIZE'}  && $ENV{'PROGRESSSIZE'} ne "" );
     $variableshashref->{'PROGRESSPOSITION'} = $ENV{'PROGRESSPOSITION'} , if( defined $ENV{'PROGRESSPOSITION'}  && $ENV{'PROGRESSPOSITION'} ne "" );
     $variableshashref->{'PROGRESSFRAMECOLOR'} = $ENV{'PROGRESSFRAMECOLOR'} , if( defined $ENV{'PROGRESSFRAMECOLOR'}  && $ENV{'PROGRESSFRAMECOLOR'} ne "" );
+    $variableshashref->{'PROGRESSTEXTCOLOR'} = $ENV{'PROGRESSTEXTCOLOR'} , if( defined $ENV{'PROGRESSTEXTCOLOR'}  && $ENV{'PROGRESSTEXTCOLOR'} ne "" );
+    $variableshashref->{'PROGRESSTEXTBASELINE'} = $ENV{'PROGRESSTEXTBASELINE'} , if( defined $ENV{'PROGRESSTEXTBASELINE'}  && $ENV{'PROGRESSTEXTBASELINE'} ne "" );
 }
 
 ###########################################################
