@@ -65,13 +65,13 @@ namespace stoc_bootstrap
 Sequence< OUString > defreg_getSupportedServiceNames()
 {
     Sequence< OUString > seqNames(1);
-    seqNames.getArray()[0] = OUString(RTL_CONSTASCII_USTRINGPARAM(SERVICENAME));
+    seqNames.getArray()[0] = OUString(SERVICENAME);
     return seqNames;
 }
 
 OUString defreg_getImplementationName()
 {
-    return OUString(RTL_CONSTASCII_USTRINGPARAM(IMPLNAME));
+    return OUString(IMPLNAME);
 }
 }
 
@@ -276,7 +276,7 @@ OUString NestedKeyImpl::computeName(const OUString& name)
                 return m_defaultKey->getResolvedName(name);
         }
 
-        if ( resLocalName.getLength() > 0 && m_pRegistry->m_defaultReg->isValid() )
+        if ( !resLocalName.isEmpty() && m_pRegistry->m_defaultReg->isValid() )
         {
             Reference<XRegistryKey> localRoot(m_pRegistry->m_localReg->getRootKey());
             Reference<XRegistryKey> defaultRoot(m_pRegistry->m_defaultReg->getRootKey());
@@ -289,7 +289,7 @@ OUString NestedKeyImpl::computeName(const OUString& name)
             {
                 count--;
 
-                if (resLocalName.getLength() == 0 || resDefaultName.getLength() == 0)
+                if (resLocalName.isEmpty() || resDefaultName.isEmpty())
                     throw InvalidRegistryException();
 
                 resLocalName = localRoot->getResolvedName(resDefaultName);
@@ -683,7 +683,7 @@ Reference< XRegistryKey > SAL_CALL NestedKeyImpl::openKey( const OUString& aKeyN
 
     OUString resolvedName = computeName(aKeyName);
 
-    if ( resolvedName.getLength() == 0 )
+    if ( resolvedName.isEmpty() )
         throw InvalidRegistryException();
 
     Reference<XRegistryKey> localKey, defaultKey;
@@ -719,7 +719,7 @@ Reference< XRegistryKey > SAL_CALL NestedKeyImpl::createKey( const OUString& aKe
 
     OUString resolvedName = computeName(aKeyName);
 
-    if ( resolvedName.getLength() == 0 )
+    if ( resolvedName.isEmpty() )
         throw InvalidRegistryException();
 
     if ( m_localKey.is() && m_localKey->isValid() )
@@ -788,7 +788,7 @@ void SAL_CALL NestedKeyImpl::deleteKey( const OUString& rKeyName )
     {
         OUString resolvedName = computeName(rKeyName);
 
-        if ( resolvedName.getLength() == 0 )
+        if ( resolvedName.isEmpty() )
         {
             throw InvalidRegistryException();
         }
@@ -969,7 +969,7 @@ sal_Bool SAL_CALL NestedKeyImpl::createLink( const OUString& aLinkName, const OU
 
         resolvedName = computeName(linkName);
 
-        if ( resolvedName.getLength() == 0 )
+        if ( resolvedName.isEmpty() )
         {
             throw InvalidRegistryException();
         }
@@ -980,7 +980,7 @@ sal_Bool SAL_CALL NestedKeyImpl::createLink( const OUString& aLinkName, const OU
         if ( lastIndex == 0 )
             resolvedName = m_name + aLinkName;
         else
-            resolvedName = m_name + OUString( RTL_CONSTASCII_USTRINGPARAM("/") ) + aLinkName;
+            resolvedName = m_name + OUString( "/" ) + aLinkName;
     }
 
     if ( m_localKey.is() && m_localKey->isValid() )
@@ -1023,7 +1023,7 @@ void SAL_CALL NestedKeyImpl::deleteLink( const OUString& rLinkName )
 
         resolvedName = computeName(linkName);
 
-        if ( resolvedName.getLength() == 0 )
+        if ( resolvedName.isEmpty() )
         {
             throw InvalidRegistryException();
         }
@@ -1034,7 +1034,7 @@ void SAL_CALL NestedKeyImpl::deleteLink( const OUString& rLinkName )
         if ( lastIndex == 0 )
             resolvedName = m_name + rLinkName;
         else
-            resolvedName = m_name + OUString( RTL_CONSTASCII_USTRINGPARAM("/") ) + rLinkName;
+            resolvedName = m_name + OUString( "/" ) + rLinkName;
     }
 
     if ( m_localKey.is() && m_localKey->isValid() &&
@@ -1067,7 +1067,7 @@ OUString SAL_CALL NestedKeyImpl::getLinkTarget( const OUString& rLinkName )
 
         resolvedName = computeName(linkName);
 
-        if ( resolvedName.getLength() == 0 )
+        if ( resolvedName.isEmpty() )
         {
             throw InvalidRegistryException();
         }
@@ -1078,7 +1078,7 @@ OUString SAL_CALL NestedKeyImpl::getLinkTarget( const OUString& rLinkName )
         if ( lastIndex == 0 )
             resolvedName = m_name + rLinkName;
         else
-            resolvedName = m_name + OUString( RTL_CONSTASCII_USTRINGPARAM("/") ) + rLinkName;
+            resolvedName = m_name + OUString( "/" ) + rLinkName;
     }
 
     OUString linkTarget;
@@ -1112,7 +1112,7 @@ OUString SAL_CALL NestedKeyImpl::getResolvedName( const OUString& aKeyName )
 
     OUString resolvedName = computeName(aKeyName);
 
-    if ( resolvedName.getLength() == 0 )
+    if ( resolvedName.isEmpty() )
     {
         throw InvalidRegistryException();
     }
@@ -1176,8 +1176,8 @@ Any RegistryEnumueration::nextElement(  )
     }
     else
     {
-        throw NoSuchElementException( OUString( RTL_CONSTASCII_USTRINGPARAM(
-            "NestedRegistry: no nextElement() !" ) ),Reference< XInterface > () );
+        throw NoSuchElementException( OUString(
+            "NestedRegistry: no nextElement() !" ),Reference< XInterface > () );
     }
     return a;
 }
@@ -1266,7 +1266,7 @@ void SAL_CALL NestedRegistryImpl::open( const OUString&, sal_Bool, sal_Bool )
     throw(InvalidRegistryException, RuntimeException)
 {
     throw InvalidRegistryException(
-            OUString(RTL_CONSTASCII_USTRINGPARAM("the 'open' method is not specified for a nested registry")),
+            OUString("the 'open' method is not specified for a nested registry"),
             Reference< XInterface >() );
 }
 
@@ -1302,7 +1302,7 @@ void SAL_CALL NestedRegistryImpl::close(  )
     }
 /*
     throw InvalidRegistryException(
-            OUString(RTL_CONSTASCII_USTRINGPARAM("the 'close' method is not specified for a nested registry")),
+            OUString("the 'close' method is not specified for a nested registry"),
             Reference< XInterface >() );
 */
 }
@@ -1312,7 +1312,7 @@ void SAL_CALL NestedRegistryImpl::destroy(  )
     throw(InvalidRegistryException, RuntimeException)
 {
     throw InvalidRegistryException(
-            OUString(RTL_CONSTASCII_USTRINGPARAM("the 'destroy' method is not specified for a nested registry")),
+            OUString("the 'destroy' method is not specified for a nested registry"),
             Reference< XInterface >() );
 }
 
@@ -1380,7 +1380,8 @@ void SAL_CALL NestedRegistryImpl::mergeKey( const OUString& aKeyName, const OUSt
 namespace stoc_bootstrap
 {
 //*************************************************************************
-Reference<XInterface> SAL_CALL NestedRegistry_CreateInstance( const Reference<XComponentContext>& )
+Reference<XInterface> SAL_CALL NestedRegistry_CreateInstance(
+    SAL_UNUSED_PARAMETER const Reference<XComponentContext>& )
     throw(Exception)
 {
     Reference<XInterface>   xRet;
