@@ -103,10 +103,10 @@ sal_Bool SfxUndoAction::Merge( SfxUndoAction * )
 
 //------------------------------------------------------------------------
 
-XubString SfxUndoAction::GetComment() const
+rtl::OUString SfxUndoAction::GetComment() const
 {
     DBG_CHKTHIS(SfxUndoAction, 0);
-    return XubString();
+    return rtl::OUString();
 }
 
 //------------------------------------------------------------------------
@@ -658,7 +658,10 @@ bool SfxUndoManager::ImplAddUndoAction_NoNotify( SfxUndoAction *pAction, bool bT
         {
             i_guard.markForDeletion( m_pData->pActUndoArray->aUndoActions[0].pAction );
             m_pData->pActUndoArray->aUndoActions.Remove(0);
-            --m_pData->pActUndoArray->nCurUndoAction;
+            if (m_pData->pActUndoArray->nCurUndoAction > 0)
+            {
+                --m_pData->pActUndoArray->nCurUndoAction;
+            }
         }
     }
 
@@ -692,17 +695,15 @@ size_t SfxUndoManager::GetUndoActionCount( bool const i_currentLevel ) const
 
 //------------------------------------------------------------------------
 
-XubString SfxUndoManager::GetUndoActionComment( size_t nNo, bool const i_currentLevel ) const
+rtl::OUString SfxUndoManager::GetUndoActionComment( size_t nNo, bool const i_currentLevel ) const
 {
     UndoManagerGuard aGuard( *m_pData );
 
-    String sComment;
+    rtl::OUString sComment;
     const SfxUndoArray* pUndoArray = i_currentLevel ? m_pData->pActUndoArray : m_pData->pUndoArray;
     DBG_ASSERT( nNo < pUndoArray->nCurUndoAction, "svl::SfxUndoManager::GetUndoActionComment: illegal index!" );
     if( nNo < pUndoArray->nCurUndoAction )
-    {
         sComment = pUndoArray->aUndoActions[ pUndoArray->nCurUndoAction - 1 - nNo ].pAction->GetComment();
-    }
     return sComment;
 }
 
@@ -853,7 +854,7 @@ size_t SfxUndoManager::ImplGetRedoActionCount_Lock( bool const i_currentLevel )
 
 //------------------------------------------------------------------------
 
-XubString SfxUndoManager::GetRedoActionComment( size_t nNo, bool const i_currentLevel ) const
+rtl::OUString SfxUndoManager::GetRedoActionComment( size_t nNo, bool const i_currentLevel ) const
 {
     UndoManagerGuard aGuard( *m_pData );
     const SfxUndoArray* pUndoArray = i_currentLevel ? m_pData->pActUndoArray : m_pData->pUndoArray;
@@ -1160,11 +1161,11 @@ size_t SfxUndoManager::ImplLeaveListAction( const bool i_merge, UndoManagerGuard
     }
 
     // if the undo array has no comment, try to get it from its children
-    if ( pListAction->GetComment().Len() == 0 )
+    if ( pListAction->GetComment().isEmpty() )
     {
         for( size_t n = 0; n < pListAction->aUndoActions.size(); n++ )
         {
-            if( pListAction->aUndoActions[n].pAction->GetComment().Len() )
+            if (!pListAction->aUndoActions[n].pAction->GetComment().isEmpty())
             {
                 pListAction->SetComment( pListAction->aUndoActions[n].pAction->GetComment() );
                 break;
@@ -1295,7 +1296,7 @@ sal_uInt16 SfxListUndoAction::GetId() const
 
 //------------------------------------------------------------------------
 
-XubString SfxListUndoAction::GetComment() const
+rtl::OUString SfxListUndoAction::GetComment() const
 {
     return aComment;
 }
@@ -1455,12 +1456,11 @@ void SfxLinkUndoAction::Repeat(SfxRepeatTarget&r)
 
 //------------------------------------------------------------------------
 
-XubString SfxLinkUndoAction::GetComment() const
+rtl::OUString SfxLinkUndoAction::GetComment() const
 {
     if ( pAction )
         return pAction->GetComment();
-    else
-        return XubString();
+    return rtl::OUString();
 }
 
 
