@@ -95,9 +95,6 @@ public:
     void            SetHelpAgentRetryLimit( sal_Int32 _nTrials )        { nHelpAgentRetryLimit = _nTrials; SetModified(); }
     sal_Int32       GetHelpAgentRetryLimit( ) const         { return nHelpAgentRetryLimit; }
 
-    sal_Int32       getAgentIgnoreURLCounter( const ::rtl::OUString& _rURL );
-    void            decAgentIgnoreURLCounter( const ::rtl::OUString& _rURL );
-    void            resetAgentIgnoreURLCounter( const ::rtl::OUString& _rURL );
     void            resetAgentIgnoreURLCounter();
 
     void            SetWelcomeScreen( sal_Bool b )          { bWelcomeScreen = b; SetModified(); }
@@ -217,7 +214,7 @@ void  SvtHelpOptions_Impl::Load(const uno::Sequence< ::rtl::OUString>& rProperty
                             bHelpAgentEnabled = bTmp;
                             break;
                         default:
-                            DBG_ERRORFILE( "Wrong Member!" );
+                            SAL_WARN( "svtools.config", "Wrong Member!" );
                             break;
                     }
                 }
@@ -236,7 +233,7 @@ void  SvtHelpOptions_Impl::Load(const uno::Sequence< ::rtl::OUString>& rProperty
                             sHelpStyleSheet = aTmpStr;
                         break;
                         default:
-                            DBG_ERRORFILE( "Wrong Member!" );
+                            SAL_WARN( "svtools.config", "Wrong Member!" );
                             break;
                     }
                 }
@@ -253,13 +250,13 @@ void  SvtHelpOptions_Impl::Load(const uno::Sequence< ::rtl::OUString>& rProperty
                             break;
 
                         default:
-                            DBG_ERRORFILE( "Wrong Member!" );
+                            SAL_WARN( "svtools.config", "Wrong Member!" );
                             break;
                     }
                 }
                 else
                 {
-                    DBG_ERRORFILE( "Wrong Type!" );
+                    SAL_WARN( "svtools.config", "Wrong Type!" );
                 }
             }
         }
@@ -434,7 +431,7 @@ void SvtHelpOptions_Impl::implSaveURLCounters()
             sNewNodeName = sNodeNameBase;
             if (!getUniqueSetElementName(sIgnoreListNodePath, sNewNodeName))
             {
-                DBG_ERRORFILE( "SvtHelpOptions_Impl::implSaveURLCounters: could not get a free name!" );
+                SAL_WARN( "svtools.config", "SvtHelpOptions_Impl::implSaveURLCounters: could not get a free name!" );
                 continue;
             }
             AddNode(sIgnoreListNodePath, sNewNodeName);
@@ -558,51 +555,6 @@ SvtHelpOptions::SvtHelpOptions()
 
 // -----------------------------------------------------------------------
 
-sal_Int32 SvtHelpOptions_Impl::getAgentIgnoreURLCounter( const ::rtl::OUString& _rURL )
-{
-    ::osl::MutexGuard aGuard(aIgnoreCounterSafety);
-    ConstMapString2IntIterator aMapPos = aURLIgnoreCounters.find(_rURL);
-    if (aURLIgnoreCounters.end() == aMapPos)
-        return GetHelpAgentRetryLimit();
-    return aMapPos->second;
-}
-
-// -----------------------------------------------------------------------
-
-void SvtHelpOptions_Impl::decAgentIgnoreURLCounter( const ::rtl::OUString& _rURL )
-{
-    ::osl::MutexGuard aGuard(aIgnoreCounterSafety);
-    MapString2IntIterator aMapPos = aURLIgnoreCounters.find(_rURL);
-    if (aURLIgnoreCounters.end() == aMapPos)
-    {   // nothing known about this URL 'til now
-        sal_Int32 nLimit = GetHelpAgentRetryLimit();
-        sal_Int32 nIgnoreAgain = nLimit > 0 ? nLimit - 1 : 0;
-        aURLIgnoreCounters[_rURL] = nIgnoreAgain;
-    }
-    else
-    {
-        sal_Int32& rCounter = aMapPos->second;
-        if (rCounter)
-            --rCounter;
-    }
-    SetModified();
-}
-
-// -----------------------------------------------------------------------
-
-void SvtHelpOptions_Impl::resetAgentIgnoreURLCounter( const ::rtl::OUString& _rURL )
-{
-    ::osl::MutexGuard aGuard(aIgnoreCounterSafety);
-    MapString2IntIterator aMapPos = aURLIgnoreCounters.find(_rURL);
-    if (aURLIgnoreCounters.end() != aMapPos)
-    {
-        aURLIgnoreCounters.erase(aMapPos);
-        SetModified();
-    }
-}
-
-// -----------------------------------------------------------------------
-
 void SvtHelpOptions_Impl::resetAgentIgnoreURLCounter()
 {
     ::osl::MutexGuard aGuard(aIgnoreCounterSafety);
@@ -674,27 +626,6 @@ sal_Bool SvtHelpOptions::IsHelpAgentAutoStartMode() const
 
 // -----------------------------------------------------------------------
 
-sal_Int32 SvtHelpOptions::getAgentIgnoreURLCounter( const ::rtl::OUString& _rURL )
-{
-    return pImp->getAgentIgnoreURLCounter( _rURL );
-}
-
-// -----------------------------------------------------------------------
-
-void SvtHelpOptions::decAgentIgnoreURLCounter( const ::rtl::OUString& _rURL )
-{
-    pImp->decAgentIgnoreURLCounter( _rURL );
-}
-
-// -----------------------------------------------------------------------
-
-void SvtHelpOptions::resetAgentIgnoreURLCounter( const ::rtl::OUString& _rURL )
-{
-    pImp->resetAgentIgnoreURLCounter( _rURL );
-}
-
-// -----------------------------------------------------------------------
-
 void SvtHelpOptions::resetAgentIgnoreURLCounter()
 {
     pImp->resetAgentIgnoreURLCounter();
@@ -712,11 +643,6 @@ sal_Bool SvtHelpOptions::IsWelcomeScreen() const
     return pImp->IsWelcomeScreen();
 }
 
-String SvtHelpOptions::GetLocale() const
-{
-    return pImp->GetLocale();
-}
-
 String SvtHelpOptions::GetSystem() const
 {
     return pImp->GetSystem();
