@@ -26,14 +26,16 @@
  *
  ************************************************************************/
 
+#include "sal/config.h"
 
 #include <svtools/fileview.hxx>
-#include <svtools/svtdata.hxx>
+#include <svtools/svtresid.hxx>
 #include <svtools/imagemgr.hxx>
 #include <svtools/headbar.hxx>
 #include <svtools/svtabbx.hxx>
 #include <svtools/svtools.hrc>
 #include "fileview.hrc"
+#include "fileview.hxx"
 #include "contentenumeration.hxx"
 #include <svtools/AccessibleBrowseBoxObjType.hxx>
 #include <com/sun/star/util/DateTime.hpp>
@@ -59,7 +61,6 @@
 #include <algorithm>
 #include <memory>
 #include <tools/urlobj.hxx>
-#include <tools/datetime.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/string.hxx>
 #include <unotools/localfilehelper.hxx>
@@ -97,7 +98,7 @@ using ::rtl::OUString;
 #define COLUMN_SIZE         3
 #define COLUMN_DATE         4
 
-#define aSeparatorStr  "----------------------------------"
+#define SEPARATOR_STR  "----------------------------------"
 
 #define ROW_HEIGHT                17    // the height of a row has to be a little higher than the bitmap
 #define QUICK_SEARCH_TIMEOUT    1500    // time in mSec before the quicksearch string will be reseted
@@ -112,6 +113,9 @@ namespace
     {
     public:
         virtual void onTimeout( CallbackTimer* _pInstigator ) = 0;
+
+    protected:
+        ~ITimeoutHandler() {}
     };
 
     //====================================================================
@@ -145,15 +149,14 @@ namespace
 void FilterMatch::createWildCardFilterList(const String& _rFilterList,::std::vector< WildCard >& _rFilters)
 {
     if( _rFilterList.Len() )
-    {// filter is given
-        xub_StrLen nCount = _rFilterList.GetTokenCount();
-        _rFilters.reserve( nCount );
+    {
+        // filter is given
         xub_StrLen nIndex = 0;
         OUString sToken;
         do
         {
             sToken = _rFilterList.GetToken( 0, ';', nIndex );
-            if ( sToken.getLength() )
+            if ( !sToken.isEmpty() )
             {
                 _rFilters.push_back( WildCard( sToken.toAsciiUpperCase() ) );
             }
@@ -184,6 +187,7 @@ private:
     sal_Bool                mbAutoResize            : 1;
     sal_Bool                mbEnableDelete          : 1;
     sal_Bool                mbEnableRename          : 1;
+    bool                    mbShowHeader;
 
     void            DeleteEntries();
     void            DoQuickSearch( const xub_Unicode& rChar );
@@ -199,7 +203,7 @@ public:
 
     virtual void    Resize();
     virtual void    KeyInput( const KeyEvent& rKEvt );
-    virtual sal_Bool    EditedEntry( SvLBoxEntry* pEntry, const XubString& rNewText );
+    virtual sal_Bool EditedEntry( SvLBoxEntry* pEntry, const rtl::OUString& rNewText );
 
     void            ClearAll();
     HeaderBar*      GetHeaderBar() const { return mpHeaderBar; }
@@ -211,7 +215,7 @@ public:
 
     Reference< XCommandEnvironment >    GetCommandEnvironment() const { return mxCmdEnv; }
 
-    DECL_LINK( ResetQuickSearch_Impl, Timer * );
+    DECL_LINK(ResetQuickSearch_Impl, void *);
 
     virtual PopupMenu*  CreateContextMenu( void );
     virtual void        ExcecuteContextMenuAction( sal_uInt16 nSelectedPopentry );
@@ -658,7 +662,7 @@ inline void SvtFileView_Impl::EndEditing( bool _bCancel )
 
 // functions -------------------------------------------------------------
 
-OUString CreateExactSizeText_Impl( sal_Int64 nSize )
+OUString CreateExactSizeText( sal_Int64 nSize )
 {
     double fSize( ( double ) nSize );
     int nDec;
@@ -670,25 +674,25 @@ OUString CreateExactSizeText_Impl( sal_Int64 nSize )
 
     if ( nSize < 10000 )
     {
-        aUnitStr += String( SvtResId( STR_SVT_BYTES ) );
+        aUnitStr += SVT_RESSTR(STR_SVT_BYTES );
         nDec = 0;
     }
     else if ( nSize < nMega )
     {
         fSize /= 1024;
-        aUnitStr += String( SvtResId( STR_SVT_KB ) );
+        aUnitStr += SVT_RESSTR(STR_SVT_KB);
         nDec = 1;
     }
     else if ( nSize < nGiga )
     {
         fSize /= nMega;
-        aUnitStr += String( SvtResId( STR_SVT_MB ) );
+        aUnitStr += SVT_RESSTR(STR_SVT_MB);
         nDec = 2;
     }
     else
     {
         fSize /= nGiga;
-        aUnitStr += String( SvtResId( STR_SVT_GB ) );
+        aUnitStr += SVT_RESSTR(STR_SVT_GB);
         nDec = 3;
     }
 
@@ -712,34 +716,38 @@ ViewTabListBox_Impl::ViewTabListBox_Impl( Window* pParentWin,
 
     mpHeaderBar         ( NULL ),
     mpParent            ( pParent ),
-    msAccessibleDescText( SvtResId( STR_SVT_ACC_DESC_FILEVIEW ) ),
-    msFolder            ( SvtResId( STR_SVT_ACC_DESC_FOLDER ) ),
-    msFile              ( SvtResId( STR_SVT_ACC_DESC_FILE ) ),
+    msAccessibleDescText( SVT_RESSTR(STR_SVT_ACC_DESC_FILEVIEW) ),
+    msFolder            ( SVT_RESSTR(STR_SVT_ACC_DESC_FOLDER) ),
+    msFile              ( SVT_RESSTR(STR_SVT_ACC_DESC_FILE) ),
     mnSearchIndex       ( 0 ),
     mbResizeDisabled    ( sal_False ),
     mbAutoResize        ( sal_False ),
     mbEnableDelete      ( sal_True ),
-    mbEnableRename      ( sal_True )
-
+    mbEnableRename      ( sal_True ),
+    mbShowHeader        ( (nFlags & FILEVIEW_SHOW_NONE) == 0 )
 {
-    sal_Bool bViewHeader = true;
     Size aBoxSize = pParentWin->GetSizePixel();
     mpHeaderBar = new HeaderBar( pParentWin, WB_BUTTONSTYLE | WB_BOTTOMBORDER );
     mpHeaderBar->SetPosSizePixel( Point( 0, 0 ), mpHeaderBar->CalcWindowSizePixel() );
 
     HeaderBarItemBits nBits = ( HIB_LEFT | HIB_VCENTER | HIB_CLICKABLE );
-    if ((nFlags & FILEVIEW_SHOW_NONE) == FILEVIEW_SHOW_NONE)
-        bViewHeader = false;
+    if (nFlags & FILEVIEW_SHOW_ONLYTITLE)
+    {
+        long pTabs[] = { 2, 20, 600 };
+        SetTabs(&pTabs[0], MAP_PIXEL);
+
+        mpHeaderBar->InsertItem(COLUMN_TITLE, SVT_RESSTR(STR_SVT_FILEVIEW_COLUMN_TITLE), 600, nBits | HIB_UPARROW);
+    }
     else
     {
-        if (nFlags & FILEVIEW_SHOW_TITLE)
-            mpHeaderBar->InsertItem(COLUMN_TITLE, String(SvtResId(STR_SVT_FILEVIEW_COLUMN_TITLE)), 600, nBits | HIB_UPARROW);
-        if (nFlags & FILEVIEW_SHOW_ALL)
-            mpHeaderBar->InsertItem(COLUMN_TYPE, String(SvtResId(STR_SVT_FILEVIEW_COLUMN_TYPE)), 140, nBits);
-        if (nFlags & FILEVIEW_SHOW_SIZE)
-            mpHeaderBar->InsertItem(COLUMN_SIZE, String(SvtResId(STR_SVT_FILEVIEW_COLUMN_SIZE)), 80, nBits);
-        if (nFlags & FILEVIEW_SHOW_DATE)
-            mpHeaderBar->InsertItem(COLUMN_DATE, String(SvtResId(STR_SVT_FILEVIEW_COLUMN_DATE)), 500, nBits);
+        long pTabs[] = { 5, 20, 180, 320, 400, 600 };
+        SetTabs(&pTabs[0], MAP_PIXEL);
+        SetTabJustify(2, AdjustRight); // column "Size"
+
+        mpHeaderBar->InsertItem(COLUMN_TITLE, SVT_RESSTR(STR_SVT_FILEVIEW_COLUMN_TITLE), 180, nBits | HIB_UPARROW);
+        mpHeaderBar->InsertItem(COLUMN_TYPE, SVT_RESSTR(STR_SVT_FILEVIEW_COLUMN_TYPE), 140, nBits);
+        mpHeaderBar->InsertItem(COLUMN_SIZE, SVT_RESSTR(STR_SVT_FILEVIEW_COLUMN_SIZE), 80, nBits);
+        mpHeaderBar->InsertItem(COLUMN_DATE, SVT_RESSTR(STR_SVT_FILEVIEW_COLUMN_DATE), 500, nBits);
     }
 
     Size aHeadSize = mpHeaderBar->GetSizePixel();
@@ -748,9 +756,11 @@ ViewTabListBox_Impl::ViewTabListBox_Impl( Window* pParentWin,
     InitHeaderBar( mpHeaderBar );
     SetHighlightRange();
     SetEntryHeight( ROW_HEIGHT );
+    if (nFlags & FILEVIEW_MULTISELECTION)
+        SetSelectionMode( MULTIPLE_SELECTION );
 
     Show();
-    if( bViewHeader )
+    if( mbShowHeader )
         mpHeaderBar->Show();
 
     maResetQuickSearch.SetTimeout( QUICK_SEARCH_TIMEOUT );
@@ -776,7 +786,7 @@ ViewTabListBox_Impl::~ViewTabListBox_Impl()
 
 // -----------------------------------------------------------------------
 
-IMPL_LINK( ViewTabListBox_Impl, ResetQuickSearch_Impl, Timer*, EMPTYARG )
+IMPL_LINK_NOARG(ViewTabListBox_Impl, ResetQuickSearch_Impl)
 {
     ::osl::MutexGuard aGuard( maMutex );
 
@@ -796,9 +806,13 @@ void ViewTabListBox_Impl::Resize()
     if ( mbResizeDisabled || !aBoxSize.Width() )
         return;
 
-    Size aBarSize = mpHeaderBar->GetSizePixel();
-    aBarSize.Width() = mbAutoResize ? aBoxSize.Width() : GetSizePixel().Width();
-    mpHeaderBar->SetSizePixel( aBarSize );
+    Size aBarSize;
+    if ( mbShowHeader )
+    {
+        aBarSize = mpHeaderBar->GetSizePixel();
+        aBarSize.Width() = mbAutoResize ? aBoxSize.Width() : GetSizePixel().Width();
+        mpHeaderBar->SetSizePixel( aBarSize );
+    }
 
     if ( mbAutoResize )
     {
@@ -1033,7 +1047,7 @@ void ViewTabListBox_Impl::DeleteEntries()
 
 // -----------------------------------------------------------------------
 sal_Bool ViewTabListBox_Impl::EditedEntry( SvLBoxEntry* pEntry,
-                                 const XubString& rNewText )
+                                 const rtl::OUString& rNewText )
 {
     sal_Bool bRet = sal_False;
 
@@ -1043,7 +1057,7 @@ sal_Bool ViewTabListBox_Impl::EditedEntry( SvLBoxEntry* pEntry,
     if ( pData )
         aURL = OUString( pData->maURL );
 
-    if ( ! aURL.getLength() )
+    if ( aURL.isEmpty() )
         return bRet;
 
     try
@@ -1073,7 +1087,7 @@ sal_Bool ViewTabListBox_Impl::EditedEntry( SvLBoxEntry* pEntry,
         if ( canRename )
         {
             Any aValue;
-            aValue <<= OUString( rNewText );
+            aValue <<= rNewText;
             aContent.setPropertyValue( aPropName, aValue );
             mpParent->EntryRenamed( aURL, rNewText );
 
@@ -1211,7 +1225,7 @@ SvtFileView::SvtFileView( Window* pParent, const ResId& rResId,
 
     Control( pParent, rResId )
 {
-    sal_Int8 nFlags = FILEVIEW_SHOW_ALL;
+    sal_Int8 nFlags = 0;
     if ( bOnlyFolder )
         nFlags |= FILEVIEW_ONLYFOLDER;
     if ( bMultiSelection )
@@ -1225,13 +1239,6 @@ SvtFileView::SvtFileView( Window* pParent, const ResId& rResId,
     mpImp->mpView->ForbidEmptyText();
     SetSortColumn( true );
 
-    long pTabs[] = { 5, 20, 180, 320, 400, 600 };
-    mpImp->mpView->SetTabs( &pTabs[0], MAP_PIXEL );
-    mpImp->mpView->SetTabJustify( 2, AdjustRight ); // column "Size"
-
-    if ( bMultiSelection )
-        mpImp->mpView->SetSelectionMode( MULTIPLE_SELECTION );
-
     HeaderBar* pHeaderBar = mpImp->mpView->GetHeaderBar();
     pHeaderBar->SetSelectHdl( LINK( this, SvtFileView, HeaderSelect_Impl ) );
     pHeaderBar->SetEndDragHdl( LINK( this, SvtFileView, HeaderEndDrag_Impl ) );
@@ -1244,26 +1251,10 @@ SvtFileView::SvtFileView( Window* pParent, const ResId& rResId, sal_uInt8 nFlags
     Reference< XInteractionHandler > xInteractionHandler = Reference< XInteractionHandler > (
         ::comphelper::getProcessServiceFactory()->createInstance( OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.uui.InteractionHandler") ) ), UNO_QUERY );
     Reference < XCommandEnvironment > xCmdEnv = new ::ucbhelper::CommandEnvironment( xInteractionHandler, Reference< XProgressHandler >() );
-    mpImp = new SvtFileView_Impl( this, xCmdEnv, nFlags,
-                                  ( nFlags & FILEVIEW_ONLYFOLDER ) == FILEVIEW_ONLYFOLDER );
-    SetSortColumn( true );
 
-    if ( ( nFlags & FILEVIEW_SHOW_ALL ) == FILEVIEW_SHOW_ALL )
-    {
-        long pTabs[] = { 5, 20, 180, 320, 400, 600 };
-        mpImp->mpView->SetTabs( &pTabs[0], MAP_PIXEL );
-        mpImp->mpView->SetTabJustify( 2, AdjustRight ); // column "Size"
-    }
-    else
-    {
-        // show only title
-        long pTabs[] = { 2, 20, 600 };
-        mpImp->mpView->SetTabs( &pTabs[0], MAP_PIXEL );
-    }
-    if ( ( nFlags & FILEVIEW_SHOW_NONE ) == FILEVIEW_SHOW_NONE )
-        SetSortColumn( false );
-    if ( ( nFlags & FILEVIEW_MULTISELECTION ) == FILEVIEW_MULTISELECTION )
-        mpImp->mpView->SetSelectionMode( MULTIPLE_SELECTION );
+    mpImp = new SvtFileView_Impl( this, xCmdEnv, nFlags, nFlags & FILEVIEW_ONLYFOLDER );
+
+    SetSortColumn( (nFlags & FILEVIEW_SHOW_NONE) == 0 );
 
     HeaderBar *pHeaderBar = mpImp->mpView->GetHeaderBar();
     pHeaderBar->SetSelectHdl( LINK( this, SvtFileView, HeaderSelect_Impl ) );
@@ -1302,23 +1293,13 @@ String SvtFileView::GetCurrentURL() const
 }
 // -----------------------------------------------------------------------------
 
-sal_Bool SvtFileView::CreateNewFolder( const String& rNewFolder )
+void SvtFileView::CreatedFolder( const String& rUrl, const String& rNewFolder )
 {
-    sal_Bool bRet = sal_False;
-    INetURLObject aObj( mpImp->maViewURL );
-    aObj.insertName( rNewFolder, false, INetURLObject::LAST_SEGMENT, true, INetURLObject::ENCODE_ALL );
-    String sURL = aObj.GetMainURL( INetURLObject::NO_DECODE );
-    if ( ::utl::UCBContentHelper::MakeFolder( sURL, sal_True ) )
-    {
-        String sTitle = aObj.getName( INetURLObject::LAST_SEGMENT, true, INetURLObject::DECODE_WITH_CHARSET );
-        String sEntry = mpImp->FolderInserted( sURL, sTitle );
-        SvLBoxEntry* pEntry = mpImp->mpView->InsertEntry( sEntry, mpImp->maFolderImage, mpImp->maFolderImage );
-        SvtContentEntry* pUserData = new SvtContentEntry( sURL, sal_True );
-        pEntry->SetUserData( pUserData );
-        mpImp->mpView->MakeVisible( pEntry );
-        bRet = sal_True;
-    }
-    return bRet;
+    String sEntry = mpImp->FolderInserted( rUrl, rNewFolder );
+    SvLBoxEntry* pEntry = mpImp->mpView->InsertEntry( sEntry, mpImp->maFolderImage, mpImp->maFolderImage );
+    SvtContentEntry* pUserData = new SvtContentEntry( rUrl, sal_True );
+    pEntry->SetUserData( pUserData );
+    mpImp->mpView->MakeVisible( pEntry );
 }
 
 // -----------------------------------------------------------------------
@@ -1356,7 +1337,7 @@ sal_Bool SvtFileView::GetParentURL( String& rParentURL ) const
     }
     catch( Exception const & )
     {
-        // perhaps an unkown url protocol (e.g. "private:newdoc")
+        // perhaps an unknown url protocol (e.g. "private:newdoc")
     }
 
     return bRet;
@@ -1883,10 +1864,10 @@ FileViewResult SvtFileView_Impl::GetFolderContent_Impl(
         if ( ::svt::SUCCESS == eResult )
         {
             implEnumerationSuccess();
-            m_pContentEnumerator = NULL;
+            m_pContentEnumerator.clear();
             return eSuccess;
         }
-        m_pContentEnumerator = NULL;
+        m_pContentEnumerator.clear();
         return eFailure;
     }
 
@@ -1960,7 +1941,7 @@ FileViewResult SvtFileView_Impl::GetFolderContent_Impl(
         return eStillRunning;
     }
 
-    DBG_ERRORFILE( "SvtFileView_Impl::GetFolderContent_Impl: unreachable!" );
+    SAL_WARN( "svtools.contnr", "SvtFileView_Impl::GetFolderContent_Impl: unreachable!" );
     return eFailure;
 }
 
@@ -1983,7 +1964,7 @@ void SvtFileView_Impl::FilterFolderContent_Impl( const OUString &rFilter )
     }
 
     if ( !bHideTransFile &&
-        ( !rFilter.getLength() || ( rFilter.compareToAscii( ALL_FILES_FILTER ) == COMPARE_EQUAL ) ) )
+        ( rFilter.isEmpty() || ( rFilter.compareToAscii( ALL_FILES_FILTER ) == COMPARE_EQUAL ) ) )
         // when replacing names, there is always something to filter (no view of ".nametranslation.table")
         return;
 
@@ -2144,7 +2125,7 @@ void SvtFileView_Impl::CancelRunningAsyncAction()
     m_pContentEnumerator->cancel();
     m_bRunningAsyncAction = false;
 
-    m_pContentEnumerator = NULL;
+    m_pContentEnumerator.clear();
     if ( m_pCancelAsyncTimer.is() && m_pCancelAsyncTimer->isTicking() )
         m_pCancelAsyncTimer->stop();
     m_pCancelAsyncTimer = NULL;
@@ -2174,7 +2155,7 @@ void SvtFileView_Impl::enumerationDone( ::svt::EnumerationResult _eResult )
     SolarMutexGuard aSolarGuard;
     ::osl::MutexGuard aGuard( maMutex );
 
-    m_pContentEnumerator = NULL;
+    m_pContentEnumerator.clear();
     if ( m_pCancelAsyncTimer.is() && m_pCancelAsyncTimer->isTicking() )
         m_pCancelAsyncTimer->stop();
     m_pCancelAsyncTimer = NULL;
@@ -2241,7 +2222,7 @@ void SvtFileView_Impl::CreateDisplayText_Impl()
         aValue += aTab;
         // folders don't have a size
         if ( ! (*aIt)->mbIsFolder )
-            aValue += CreateExactSizeText_Impl( (*aIt)->maSize );
+            aValue += CreateExactSizeText( (*aIt)->maSize );
         aValue += aTab;
         // set the date, but volumes have no date
         if ( ! (*aIt)->mbIsFolder || ! (*aIt)->mbIsVolume )
@@ -2290,7 +2271,6 @@ void SvtFileView_Impl::CreateVector_Impl( const Sequence < OUString > &rList )
         // get the title
         pEntry->SetNewTitle( aValue.getToken( 0, '\t', nIndex ) );
         aDisplayText = pEntry->GetTitle();
-        // #83004# --------------------
         ReplaceTabWithString( aDisplayText );
         aDisplayText += aTab;
 
@@ -2308,7 +2288,7 @@ void SvtFileView_Impl::CreateVector_Impl( const Sequence < OUString > &rList )
             OUString aSize = aValue.getToken( 0, '\t', nIndex );
             aDisplayText += aSize;
 
-            if ( aSize.getLength() )
+            if ( !aSize.isEmpty() )
                 pEntry->maSize = aSize.toInt64();
         }
         aDisplayText += aTab;
@@ -2319,9 +2299,9 @@ void SvtFileView_Impl::CreateVector_Impl( const Sequence < OUString > &rList )
             OUString aDate = aValue.getToken( 0, '\t', nIndex );
             aDisplayText += aDate;
 
-            if ( aDate.getLength() )
+            if ( !aDate.isEmpty() )
             {
-                DBG_ERRORFILE( "Don't know, how to convert date" );
+                SAL_WARN( "svtools.contnr", "Don't know, how to convert date" );
                 ;// convert date string to date
             }
         }
@@ -2334,7 +2314,7 @@ void SvtFileView_Impl::CreateVector_Impl( const Sequence < OUString > &rList )
         if ( nIndex >= 0 )
         {
             OUString aBool = aValue.getToken( 0, '\t', nIndex );
-            if ( aBool.getLength() )
+            if ( !aBool.isEmpty() )
                 pEntry->mbIsFolder = aBool.toBoolean();
         }
         // get the image url
@@ -2347,9 +2327,9 @@ void SvtFileView_Impl::CreateVector_Impl( const Sequence < OUString > &rList )
         pEntry->maDisplayText = aDisplayText;
 
         // detect the image
-        if( aValue != rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(aSeparatorStr) ) )
+        if( aValue != SEPARATOR_STR )
         {
-            INetURLObject aObj( pEntry->maImageURL.getLength() ? pEntry->maImageURL : pEntry->maTargetURL );
+            INetURLObject aObj( !pEntry->maImageURL.isEmpty() ? pEntry->maImageURL : pEntry->maTargetURL );
             pEntry->maImage = SvFileInformationManager::GetImage( aObj, sal_False );
         }
         maContent.push_back( pEntry );
@@ -2426,7 +2406,7 @@ sal_Bool CompareSortingData_Impl( SortingData_Impl* const aOne, SortingData_Impl
         switch ( gnColumn )
         {
             case COLUMN_TITLE:
-                // compare case insensitiv first
+                // compare case insensitive first
                 nComp = pCollatorWrapper->compareString( aOne->GetLowerTitle(), aTwo->GetLowerTitle() );
 
                 if ( nComp == 0 )
@@ -2568,7 +2548,6 @@ String SvtFileView_Impl::FolderInserted( const OUString& rURL, const OUString& r
 
     // title, type, size, date
     aValue = pData->GetTitle();
-    // #83004# --------------------
     ReplaceTabWithString( aValue );
     aValue += aTab;
     aValue += pData->maType;
@@ -2657,7 +2636,7 @@ namespace svtools {
 QueryDeleteDlg_Impl::QueryDeleteDlg_Impl
 (
     Window* pParent,
-    const String& rName      // Eintragsname
+    const String& rName      // entry name
 ) :
 
     ModalDialog( pParent, SvtResId( DLG_SVT_QUERYDELETE ) ),
@@ -2679,7 +2658,7 @@ QueryDeleteDlg_Impl::QueryDeleteDlg_Impl
     _aAllButton.SetClickHdl( aLink );
     _aNoButton.SetClickHdl( aLink );
 
-    // Anzeige der spezifizierten Texte
+    // display specified texts
 
     WinBits nTmpStyle = _aEntry.GetStyle();
     nTmpStyle |= WB_PATHELLIPSIS;
