@@ -51,6 +51,10 @@ GIFReader::GIFReader( SvStream& rStm ) :
             nLastPos        ( rStm.Tell() ),
             nLogWidth100    ( 0UL ),
             nLogHeight100   ( 0UL ),
+            nGlobalWidth    ( 0 ),
+            nGlobalHeight   ( 0 ),
+            nImageWidth     ( 0 ),
+            nImageHeight    ( 0 ),
             nLoops          ( 1 ),
             eActAction      ( GLOBAL_HEADER_READING ),
             bGCTransparent  ( sal_False ),
@@ -257,8 +261,8 @@ sal_Bool GIFReader::ReadExtension()
                     // Appl.-Extension hat Laenge 11
                     if ( cSize == 0x0b )
                     {
-                        rtl::OString aAppId = read_uInt8s_AsOString(rIStm, 8);
-                        rtl::OString aAppCode = read_uInt8s_AsOString(rIStm, 3);
+                        rtl::OString aAppId = read_uInt8s_ToOString(rIStm, 8);
+                        rtl::OString aAppCode = read_uInt8s_ToOString(rIStm, 3);
                         rIStm >> cSize;
 
                         // NetScape-Extension
@@ -446,7 +450,7 @@ void GIFReader::FillImages( HPBYTE pBytes, sal_uLong nCount )
         {
             if( bInterlaced )
             {
-                long nT1;
+                long nT1, nT2;
 
                 // falls Interlaced, werden die Zeilen kopiert
                 if( nLastInterCount )
@@ -484,7 +488,7 @@ void GIFReader::FillImages( HPBYTE pBytes, sal_uLong nCount )
 
                 if( nT1 >= nImageHeight )
                 {
-                    long nT2 = nImageY - ( ( nImageHeight + 7 ) >> 3 );
+                    nT2 = nImageY - ( ( nImageHeight + 7 ) >> 3 );
                     nT1 = ( nT2 << 3 ) + 4;
                     nLastInterCount = 3;
 
