@@ -44,7 +44,6 @@
 // - defines -
 // -----------
 
-#define MAX_PRINTER_EXT             1024
 #define MAP( cVal0, cVal1, nFrac )  ((sal_uInt8)((((long)(cVal0)<<20L)+nFrac*((long)(cVal1)-(cVal0)))>>20L))
 #define WATERMARK_LUM_OFFSET        50
 #define WATERMARK_CON_OFFSET        -70
@@ -236,7 +235,7 @@ void GraphicManager::ImplRegisterObj( const GraphicObject& rObj, Graphic& rSubst
 void GraphicManager::ImplUnregisterObj( const GraphicObject& rObj )
 {
     mpCache->ReleaseGraphicObject( rObj );
-    for( GraphicObjectList_impl::iterator it = maObjList.begin(); it < maObjList.end(); ++it )
+    for( GraphicObjectList_impl::iterator it = maObjList.begin(); it != maObjList.end(); ++it )
     {
         if ( *it == &rObj ) {
             maObjList.erase( it );
