@@ -50,9 +50,6 @@
 
 #include "tableundo.hxx"
 #include "cell.hxx"
-#include "svx/svdotable.hxx"
-#include "svx/svdoutl.hxx"
-#include "svx/unoshtxt.hxx"
 #include "svx/unoshprp.hxx"
 #include "svx/unoshape.hxx"
 #include "editeng/editobj.hxx"
@@ -582,16 +579,6 @@ SfxStyleSheet* Cell::GetStyleSheet() const
 
 // -----------------------------------------------------------------------------
 
-SfxStyleSheetPool* Cell::GetStyleSheetPool() const
-{
-    if( mpProperties && mpProperties->GetStyleSheet() )
-        return dynamic_cast< SfxStyleSheetPool* >( &mpProperties->GetStyleSheet()->GetPool() );
-    else
-        return 0;
-}
-
-// -----------------------------------------------------------------------------
-
 const Rectangle& Cell::GetCurrentBoundRect() const
 {
     return maCellRect;
@@ -767,10 +754,10 @@ OUString SAL_CALL Cell::getImplementationName(  ) throw (RuntimeException)
 
 sal_Bool SAL_CALL Cell::supportsService( const OUString& ServiceName ) throw (RuntimeException)
 {
-    if( ServiceName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.table.cell" ) ) == 0 )
+    if( ServiceName == "com.sun.star.table.cell" )
         return sal_True;
 
-    if( ServiceName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.drawing.cell" ) ) == 0 )
+    if( ServiceName == "com.sun.star.drawing.cell" )
         return sal_True;
 
     return SvxUnoTextBase::supportsService( ServiceName );
@@ -1075,12 +1062,6 @@ Any SAL_CALL Cell::getPropertyValue( const OUString& PropertyName ) throw(Unknow
     {
         switch( pMap->nWID )
         {
-/*
-        case OWN_ATTR_HASLEVELS:
-        {
-            return Any( hasLevels() );
-        }
-*/
         case OWN_ATTR_STYLE:
         {
             return Any( Reference< XStyle >( dynamic_cast< SfxUnoStyleSheet* >( GetStyleSheet() ) ) );
@@ -1293,12 +1274,6 @@ PropertyState SAL_CALL Cell::getPropertyState( const OUString& PropertyName ) th
                 eState = PropertyState_DEFAULT_VALUE;
             }
         }
-/*
-        case OWN_ATTR_HASLEVELS:
-        {
-            return PropertyState_DIRECT_VALUE;
-        }
-*/
         case OWN_ATTR_STYLE:
         {
             return PropertyState_DIRECT_VALUE;
@@ -1324,9 +1299,6 @@ PropertyState SAL_CALL Cell::getPropertyState( const OUString& PropertyName ) th
             case SFX_ITEM_DEFAULT:
                 eState = PropertyState_DEFAULT_VALUE;
                 break;
-    //      case SFX_ITEM_UNKNOWN:
-    //      case SFX_ITEM_DONTCARE:
-    //      case SFX_ITEM_DISABLED:
             default:
                 eState = PropertyState_AMBIGUOUS_VALUE;
                 break;
@@ -1361,7 +1333,7 @@ PropertyState SAL_CALL Cell::getPropertyState( const OUString& PropertyName ) th
                 case XATTR_FILLFLOATTRANSPARENCE:
                     {
                         NameOrIndex* pItem = (NameOrIndex*)rSet.GetItem((sal_uInt16)pMap->nWID);
-                        if( ( pItem == NULL ) )
+                        if( pItem == NULL )
                             eState = PropertyState_DEFAULT_VALUE;
                     }
                     break;
@@ -1425,7 +1397,6 @@ void SAL_CALL Cell::setPropertyToDefault( const OUString& PropertyName ) throw(U
             mpProperties->ClearObjectItem( XATTR_FILLBMP_TILE );
             break;
         }
-//      case OWN_ATTR_HASLEVELS:
         case OWN_ATTR_STYLE:
             break;
 
@@ -1465,10 +1436,6 @@ Any SAL_CALL Cell::getPropertyDefault( const OUString& aPropertyName ) throw(Unk
         case OWN_ATTR_FILLBMP_MODE:
             return Any(  BitmapMode_NO_REPEAT );
 
-/*
-        case OWN_ATTR_HASLEVELS:
-            return Any( sal_False );
-*/
         case OWN_ATTR_STYLE:
         {
             Reference< XStyle > xStyle;
