@@ -34,6 +34,8 @@
 #include <tools/shl.hxx>
 #include <tools/globname.hxx>
 #include <svx/svxids.hrc>
+#include <rtl/random.h>
+
 #include <com/sun/star/i18n/WordType.hdl>
 #include <com/sun/star/i18n/ForbiddenCharacters.hdl>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
@@ -59,6 +61,7 @@
 #include <editeng/forbiddencharacterstable.hxx>
 #include <svx/svdmodel.hxx>
 #include <editeng/pbinitem.hxx>
+#include <editeng/rsiditem.hxx>
 #include <unotools/charclass.hxx>
 #include <unotools/localedatawrapper.hxx>
 
@@ -90,7 +93,7 @@
 #include <ndole.hxx>
 #include <ndgrf.hxx>
 #include <rolbck.hxx>           // Undo attr
-#include <doctxm.hxx>           // for the directories
+#include <doctxm.hxx>           // for the index stuff
 #include <grfatr.hxx>
 #include <poolfmt.hxx>          // pool template ids
 #include <mvsave.hxx>           // for server functionality
@@ -139,13 +142,6 @@
 using namespace ::com::sun::star;
 using ::rtl::OUString;
 
-// Page descriptors
-SV_IMPL_PTRARR(SwPageDescs,SwPageDescPtr);
-// Directories
-SV_IMPL_PTRARR( SwTOXTypes, SwTOXTypePtr )
-// Field types
-SV_IMPL_PTRARR( SwFldTypes, SwFldTypePtr)
-
 /* IInterface */
 sal_Int32 SwDoc::acquire()
 {
@@ -251,7 +247,7 @@ void SwDoc::set(/*[in]*/ DocumentSettingId id, /*[in]*/ bool value)
                 mbOldNumbering = value;
 
                 const SwNumRuleTbl& rNmTbl = GetNumRuleTbl();
-                for( sal_uInt16 n = 0; n < rNmTbl.Count(); ++n )
+                for( sal_uInt16 n = 0; n < rNmTbl.size(); ++n )
                     rNmTbl[n]->SetInvalidRule(sal_True);
 
                 UpdateNumRule();
@@ -456,6 +452,33 @@ void SwDoc::setLinkUpdateMode( /*[in]*/sal_uInt16 eMode )
     nLinkUpdMode = eMode;
 }
 
+sal_uInt32 SwDoc::getRsid() const
+{
+    return nRsid;
+}
+
+void SwDoc::setRsid( sal_uInt32 nVal )
+{
+    // Increase the rsid with a random number smaller than 2^17. This way we
+    // expect to be able to edit a document 2^12 times before rsid overflows.
+    sal_uInt32 nIncrease = 0;
+    static rtlRandomPool aPool = rtl_random_createPool();
+    rtl_random_getBytes( aPool, &nIncrease, sizeof ( nIncrease ) );
+    nIncrease &= ( 1<<17 ) - 1;
+    nIncrease++; // make sure the new rsid is not the same
+    nRsid = nVal + nIncrease;
+}
+
+sal_uInt32 SwDoc::getRsidRoot() const
+{
+    return nRsidRoot;
+}
+
+void SwDoc::setRsidRoot( sal_uInt32 nVal )
+{
+    nRsidRoot = nVal;
+}
+
 SwFldUpdateFlags SwDoc::getFieldUpdateFlags( /*[in]*/bool bGlobalSettings ) const
 {
     SwFldUpdateFlags eRet = eFldUpdMode;
@@ -723,7 +746,7 @@ bool SwDoc::SplitNode( const SwPosition &rPos, bool bChkTableStart )
     if (GetIDocumentUndoRedo().DoesUndo())
     {
         GetIDocumentUndoRedo().ClearRedo();
-        // insert from the Undo object (currently only for TextNode)
+        // insert the Undo object (currently only for TextNode)
         if( pNode->IsTxtNode() )
         {
             pUndo = new SwUndoSplitNode( this, rPos, bChkTableStart );
@@ -731,6 +754,15 @@ bool SwDoc::SplitNode( const SwPosition &rPos, bool bChkTableStart )
         }
     }
 
+    // Update the rsid of the old and the new node unless
+    // the old node is split at the beginning or at the end
+    SwTxtNode *pTxtNode =  rPos.nNode.GetNode().GetTxtNode();
+    xub_StrLen nPos = rPos.nContent.GetIndex();
+    if( pTxtNode && nPos && nPos != pTxtNode->Len() )
+    {
+        UpdateParRsid( pTxtNode );
+    }
+
     //JP 28.01.97: Special case for SplitNode at table start:
     //             If it is at the beginning of a Doc/Fly/Footer/... or right at after a table
     //             then insert a paragraph before it.
@@ -756,7 +788,7 @@ bool SwDoc::SplitNode( const SwPosition &rPos, bool bChkTableStart )
                     pNd = 0;
                 else
                 {
-                    // Only if the table has line breaks!
+                    // Only if the table has page breaks!
                     const SwFrmFmt* pFrmFmt = pTblNd->GetTable().GetFrmFmt();
                     if( SFX_ITEM_SET != pFrmFmt->GetItemState(RES_PAGEDESC, sal_False) &&
                         SFX_ITEM_SET != pFrmFmt->GetItemState( RES_BREAK, sal_False ) )
@@ -774,7 +806,7 @@ bool SwDoc::SplitNode( const SwPosition &rPos, bool bChkTableStart )
                     ((SwPosition&)rPos).nNode = pTblNd->GetIndex()-1;
                     ((SwPosition&)rPos).nContent.Assign( pTxtNd, 0 );
 
-                    // only add page breaks/templates to the body area
+                    // only add page breaks/styles to the body area
                     if( nPrevPos > GetNodes().GetEndOfExtras().GetIndex() )
                     {
                         SwFrmFmt* pFrmFmt = pTblNd->GetTable().GetFrmFmt();
@@ -1063,6 +1095,41 @@ SwFieldType *SwDoc::GetSysFldType( const sal_uInt16 eWhich ) const
     return 0;
 }
 
+// Set the rsid from nStt to nEnd of pTxtNode to the current session number
+bool SwDoc::UpdateRsid( SwTxtNode *pTxtNode, xub_StrLen nStt, xub_StrLen nEnd )
+{
+    if ( !pTxtNode )
+    {
+        return false;
+    }
+
+    SvxRsidItem aRsid( nRsid, RES_CHRATR_RSID );
+    SwTxtAttr* pAttr = MakeTxtAttr( *this, aRsid, nStt, nEnd );
+    return pTxtNode->InsertHint( pAttr, INS_DEFAULT );
+}
+
+// Set the rsid of the next nLen symbols of rRg to the current session number
+bool SwDoc::UpdateRsid( const SwPaM &rRg, const xub_StrLen nLen )
+{
+    const SwPosition* pPos = rRg.GetPoint();
+    SwTxtNode *pTxtNode = pPos->nNode.GetNode().GetTxtNode();
+    xub_StrLen nInsPos = pPos->nContent.GetIndex();
+
+    return UpdateRsid( pTxtNode, nInsPos - nLen, nInsPos );
+}
+
+bool SwDoc::UpdateParRsid( SwTxtNode *pTxtNode, sal_uInt32 nVal )
+{
+    if ( !pTxtNode )
+    {
+        return false;
+    }
+
+    SvxRsidItem aRsid( nVal ? nVal : nRsid, RES_PARATR_RSID );
+    return pTxtNode->SetAttr( aRsid );
+}
+
+
 /*************************************************************************
  *             void SetDocStat( const SwDocStat& rStat );
  *************************************************************************/
@@ -1105,9 +1172,11 @@ sal_uInt16 _PostItFld::GetPageNo(
     const std::set< sal_Int32 > &rPossiblePages,
     /* out */ sal_uInt16& rVirtPgNo, /* out */ sal_uInt16& rLineNo )
 {
-    //Problem: If a PostItFld is contained in more than one Node that is represented by more than one layout instance,
+    //Problem: If a PostItFld is contained in a Node that is represented
+    //by more than one layout instance,
     //we have to decide whether it should be printed once or n-times.
-    //Probably only once. For the page number we don't select a random one, but the PostIt's first occurence in the selected area.
+    //Probably only once. For the page number we don't select a random one,
+    //but the PostIt's first occurence in the selected area.
     rVirtPgNo = 0;
     sal_uInt16 nPos = GetCntnt();
     SwIterator<SwTxtFrm,SwTxtNode> aIter( GetFld()->GetTxtNode() );
@@ -1301,7 +1370,7 @@ void SwDoc::CalculatePagesForPrinting(
 
         // please note
     }
-    if (aPageRange.getLength() == 0)    // empty string -> print all
+    if (aPageRange.isEmpty())    // empty string -> print all
     {
         // set page range to print to 'all pages'
         aPageRange = OUString::valueOf( (sal_Int32)1 );
@@ -1473,7 +1542,7 @@ void SwDoc::CalculatePagePairsForProspectPrinting(
     const sal_Int32 nContent = rOptions.getIntValue( "PrintContent", 0 );
     if (nContent == 1)
         aPageRange = rOptions.getStringValue( "PageRange", rtl::OUString() );
-    if (aPageRange.getLength() == 0)    // empty string -> print all
+    if (aPageRange.isEmpty())    // empty string -> print all
     {
         // set page range to print to 'all pages'
         aPageRange = OUString::valueOf( (sal_Int32)1 );
@@ -1743,7 +1812,7 @@ const SwFmtRefMark* SwDoc::GetRefMark( sal_uInt16 nIndex ) const
 // Return the names of all set references in the Doc
 //JP 24.06.96: If the array pointer is 0, then just return whether a RefMark is set in the Doc
 // OS 25.06.96: From now on we always return the reference count
-sal_uInt16 SwDoc::GetRefMarks( SvStringsDtor* pNames ) const
+sal_uInt16 SwDoc::GetRefMarks( std::vector<rtl::OUString>* pNames ) const
 {
     const SfxPoolItem* pItem;
     const SwTxtRefMark* pTxtRef;
@@ -1757,8 +1826,8 @@ sal_uInt16 SwDoc::GetRefMarks( SvStringsDtor* pNames ) const
         {
             if( pNames )
             {
-                String* pTmp = new String( ((SwFmtRefMark*)pItem)->GetRefName() );
-                pNames->Insert( pTmp, nCount );
+                String pTmp(((SwFmtRefMark*)pItem)->GetRefName());
+                pNames->insert(pNames->begin() + nCount, pTmp);
             }
             nCount ++;
         }
@@ -1826,7 +1895,7 @@ void SwDoc::ClearSwLayouterEntries()
 void SwDoc::SetModified()
 {
     ClearSwLayouterEntries();
-    // We return the status for the link according to the old and new value of the flags
+    // give the old and new modified state to the link
     //  Bit 0:  -> old state
     //  Bit 1:  -> new state
     long nCall = mbModified ? 3 : 2;
@@ -1845,7 +1914,7 @@ void SwDoc::SetModified()
 
 void SwDoc::ResetModified()
 {
-    // We return the status for the link according to the old and new value of the flags
+    // give the old and new modified state to the link
     //  Bit 0:  -> old state
     //  Bit 1:  -> new state
     long nCall = mbModified ? 1 : 0;
@@ -2306,11 +2375,11 @@ sal_Bool SwDoc::ConvertFieldsToText()
     GetIDocumentUndoRedo().StartUndo( UNDO_UI_REPLACE, NULL );
 
     const SwFldTypes* pMyFldTypes = GetFldTypes();
-    sal_uInt16 nCount = pMyFldTypes->Count();
+    sal_uInt16 nCount = pMyFldTypes->size();
     //go backward, field types are removed
     for(sal_uInt16 nType = nCount;  nType > 0;  --nType)
     {
-        const SwFieldType *pCurType = pMyFldTypes->GetObject(nType - 1);
+        const SwFieldType *pCurType = (*pMyFldTypes)[nType - 1];
 
         if ( RES_POSTITFLD == pCurType->Which() )
             continue;
@@ -2575,7 +2644,7 @@ bool SwDoc::ContainsHiddenChars() const
     for( sal_uLong n = GetNodes().Count(); n; )
     {
         SwNode* pNd = GetNodes()[ --n ];
-        if ( ND_TEXTNODE == pNd->GetNodeType() &&
+        if ( pNd->IsTxtNode() &&
              ((SwTxtNode*)pNd)->HasHiddenCharAttribute( false ) )
             return true;
     }
@@ -2608,6 +2677,7 @@ void SwDoc::ChkCondColls()
 uno::Reference< script::vba::XVBAEventProcessor >
 SwDoc::GetVbaEventProcessor()
 {
+#ifndef DISABLE_SCRIPTING
     if( !mxVbaEvents.is() && pDocShell && ooo::vba::isAlienWordDoc( *pDocShell ) )
     {
         try
@@ -2621,6 +2691,7 @@ SwDoc::GetVbaEventProcessor()
         {
         }
     }
+#endif
     return mxVbaEvents;
 }
 
@@ -2635,4 +2706,16 @@ void SwDoc::setExternalData(::sw::tExternalDataType eType,
     return m_externalData[eType];
 }
 
+sal_uInt16 SwNumRuleTbl::GetPos(const SwNumRule* pRule) const
+{
+    const_iterator it = std::find(begin(), end(), pRule);
+    return it == end() ? USHRT_MAX : it - begin();
+}
+
+SwNumRuleTbl::~SwNumRuleTbl()
+{
+    for(const_iterator it = begin(); it != end(); ++it)
+        delete *it;
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
