@@ -40,24 +40,28 @@
 #include <sfx2/app.hxx>
 #include <svx/dialmgr.hxx>
 #include <svx/dialogs.hrc>
-
-#define READ_OLDVERS        // erstmal noch alte Versionen lesen
+#include <swtable.hxx>
+#include <swtblfmt.hxx>
+#include <com/sun/star/text/VertOrientation.hpp>
 #include <swtypes.hxx>
 #include <doc.hxx>
 #include <poolfmt.hxx>
 #include <tblafmt.hxx>
 #include <cellatr.hxx>
 #include <SwStyleNameMapper.hxx>
+#include <hintids.hxx>
+#include <fmtornt.hxx>
+#include <editsh.hxx>
 
 using ::editeng::SvxBorderLine;
 
-// bis SO5PF
+// until SO5PF
 const sal_uInt16 AUTOFORMAT_ID_X        = 9501;
 const sal_uInt16 AUTOFORMAT_ID_358      = 9601;
 const sal_uInt16 AUTOFORMAT_DATA_ID_X   = 9502;
 
-// ab SO5
-//! in nachfolgenden Versionen muss der Betrag dieser IDs groesser sein
+// from SO5
+//! In follow-up versions these IDs' values need to increase
 const sal_uInt16 AUTOFORMAT_ID_504      = 9801;
 const sal_uInt16 AUTOFORMAT_DATA_ID_504 = 9802;
 
@@ -80,27 +84,88 @@ const sal_uInt16 AUTOFORMAT_DATA_ID_680DR25 = 10022;
 const sal_uInt16 AUTOFORMAT_ID_300OVRLN      = 10031;
 const sal_uInt16 AUTOFORMAT_DATA_ID_300OVRLN = 10032;
 
+// --- Bug fix to fdo#31005: Table Autoformats does not save/apply all properties (Writer and Calc)
+const sal_uInt16 AUTOFORMAT_ID_31005      = 10041;
+const sal_uInt16 AUTOFORMAT_DATA_ID_31005 = 10042;
+
 // current version
-const sal_uInt16 AUTOFORMAT_ID          = AUTOFORMAT_ID_300OVRLN;
-const sal_uInt16 AUTOFORMAT_DATA_ID     = AUTOFORMAT_DATA_ID_300OVRLN;
-
-
-#ifdef READ_OLDVERS
-const sal_uInt16 AUTOFORMAT_OLD_ID      = 8201;
-const sal_uInt16 AUTOFORMAT_OLD_ID1     = 8301;
-const sal_uInt16 AUTOFORMAT_OLD_DATA_ID = 8202;
-#endif
-
+const sal_uInt16 AUTOFORMAT_ID          = AUTOFORMAT_ID_31005;
+const sal_uInt16 AUTOFORMAT_DATA_ID     = AUTOFORMAT_DATA_ID_31005;
+const sal_uInt16 AUTOFORMAT_FILE_VERSION= SOFFICE_FILEFORMAT_50;
 
 SwBoxAutoFmt* SwTableAutoFmt::pDfltBoxAutoFmt = 0;
 
 #define sAutoTblFmtName "autotbl.fmt"
 
-// SwTable Auto-Format-Tabelle
-SV_IMPL_PTRARR( _SwTableAutoFmtTbl, SwTableAutoFmt* )
+namespace
+{
+    /// Begins a writer-specific data block. Call before serializing any writer-specific properties.
+    sal_uInt64 BeginSwBlock(SvStream& rStream)
+    {
+        // We need to write down the offset of the end of the writer-specific data, so that
+        // calc can skip it. We'll only have that value after writing the data, so we
+        // write a placeholder value first, write the data, then jump back and write the
+        // real offset.
+
+        // Note that we explicitly use sal_uInt64 instead of sal_Size (which can be 32
+        // or 64 depending on platform) to ensure 64-bit portability on this front. I don't
+        // actually know if autotbl.fmt as a whole is portable, since that requires all serialization
+        // logic to be written with portability in mind.
+        sal_uInt64 whereToWriteEndOfSwBlock = rStream.Tell();
+
+        sal_uInt64 endOfSwBlock = 0;
+        rStream << endOfSwBlock;
+
+        return whereToWriteEndOfSwBlock;
+    }
+
+    /// Ends a writer-specific data block. Call after serializing writer-specific properties.
+    /// Closes a corresponding BeginSwBlock call.
+    void EndSwBlock(SvStream& rStream, sal_uInt64 whereToWriteEndOfSwBlock)
+    {
+        sal_uInt64 endOfSwBlock = rStream.Tell();
+        rStream.Seek(whereToWriteEndOfSwBlock);
+        rStream << endOfSwBlock;
+        rStream.Seek(endOfSwBlock);
+    }
+
+    /**
+    Helper class for writer-specific blocks. Begins a writer-specific block on construction,
+    and closes it on destruction.
+
+    See also: BeginSwBlock and EndSwBlock.
+    */
+    class WriterSpecificAutoFormatBlock : ::boost::noncopyable
+    {
+    public:
+        WriterSpecificAutoFormatBlock(SvStream &rStream) : _rStream(rStream)
+        {
+            _whereToWriteEndOfBlock = BeginSwBlock(rStream);
+        }
+
+        ~WriterSpecificAutoFormatBlock()
+        {
+            EndSwBlock(_rStream, _whereToWriteEndOfBlock);
+        }
+
+    private:
+        SvStream &_rStream;
+        sal_uInt64 _whereToWriteEndOfBlock;
+    };
+
+    /// Checks whether a writer-specific block exists (i.e. size is not zero)
+    sal_Bool WriterSpecificBlockExists(SvStream &stream)
+    {
+        sal_uInt64 endOfSwBlock = 0;
+        stream >> endOfSwBlock;
+
+        // end-of-block pointing to itself indicates a zero-size block.
+        return endOfSwBlock != stream.Tell();
+    }
+}
 
 
-//  Struct mit Versionsnummern der Items
+// Struct with version numbers of the Items
 
 struct SwAfVersions
 {
@@ -120,6 +185,8 @@ public:
     sal_uInt16 nBrushVersion;
 
     sal_uInt16 nAdjustVersion;
+    sal_uInt16 m_nTextOrientationVersion;
+    sal_uInt16 m_nVerticalAlignmentVersion;
 
     sal_uInt16 nHorJustifyVersion;
     sal_uInt16 nVerJustifyVersion;
@@ -150,6 +217,8 @@ SwAfVersions::SwAfVersions() :
     nLineVersion(0),
     nBrushVersion(0),
     nAdjustVersion(0),
+    m_nTextOrientationVersion(0),
+    m_nVerticalAlignmentVersion(0),
     nHorJustifyVersion(0),
     nVerJustifyVersion(0),
     nOrientationVersion(0),
@@ -179,6 +248,12 @@ void SwAfVersions::Load( SvStream& rStream, sal_uInt16 nVer )
         rStream >> nLineVersion;
     rStream >> nBrushVersion;
     rStream >> nAdjustVersion;
+    if (nVer >= AUTOFORMAT_ID_31005 && WriterSpecificBlockExists(rStream))
+    {
+        rStream >> m_nTextOrientationVersion;
+        rStream >> m_nVerticalAlignmentVersion;
+    }
+
     rStream >> nHorJustifyVersion;
     rStream >> nVerJustifyVersion;
     rStream >> nOrientationVersion;
@@ -221,6 +296,8 @@ SwBoxAutoFmt::SwBoxAutoFmt()
     aBLTR( 0 ),
     aBackground( RES_BACKGROUND ),
     aAdjust( SVX_ADJUST_LEFT, RES_PARATR_ADJUST ),
+    m_aTextOrientation(FRMDIR_ENVIRONMENT, RES_FRAMEDIR),
+    m_aVerticalAlignment(0, com::sun::star::text::VertOrientation::NONE, com::sun::star::text::RelOrientation::FRAME),
     aHorJustify( SVX_HOR_JUSTIFY_STANDARD, 0),
     aVerJustify( SVX_VER_JUSTIFY_STANDARD, 0),
     aStacked( 0 ),
@@ -262,6 +339,8 @@ SwBoxAutoFmt::SwBoxAutoFmt( const SwBoxAutoFmt& rNew )
     aBLTR( rNew.aBLTR ),
     aBackground( rNew.aBackground ),
     aAdjust( rNew.aAdjust ),
+    m_aTextOrientation(rNew.m_aTextOrientation),
+    m_aVerticalAlignment(rNew.m_aVerticalAlignment),
     aHorJustify( rNew.aHorJustify ),
     aVerJustify( rNew.aVerJustify ),
     aStacked( rNew.aStacked ),
@@ -301,6 +380,8 @@ SwBoxAutoFmt& SwBoxAutoFmt::operator=( const SwBoxAutoFmt& rNew )
     aShadowed = rNew.aShadowed;
     aColor = rNew.aColor;
     SetAdjust( rNew.aAdjust );
+    m_aTextOrientation = rNew.m_aTextOrientation;
+    m_aVerticalAlignment = rNew.m_aVerticalAlignment;
     aBox = rNew.aBox;
     aTLBR = rNew.aTLBR;
     aBLTR = rNew.aBLTR;
@@ -377,8 +458,15 @@ sal_Bool SwBoxAutoFmt::Load( SvStream& rStream, const SwAfVersions& rVersions, s
     SetAdjust( *(SvxAdjustItem*)pNew );
     delete pNew;
 
+    if (nVer >= AUTOFORMAT_DATA_ID_31005 && WriterSpecificBlockExists(rStream))
+    {
+        READ(m_aTextOrientation, SvxFrameDirectionItem, rVersions.m_nTextOrientationVersion);
+        READ(m_aVerticalAlignment, SwFmtVertOrient, rVersions.m_nVerticalAlignmentVersion);
+    }
+
     READ( aHorJustify,  SvxHorJustifyItem , rVersions.nHorJustifyVersion)
     READ( aVerJustify,  SvxVerJustifyItem   , rVersions.nVerJustifyVersion)
+
     READ( aOrientation, SvxOrientationItem  , rVersions.nOrientationVersion)
     READ( aMargin, SvxMarginItem       , rVersions.nMarginVersion)
 
@@ -401,11 +489,11 @@ sal_Bool SwBoxAutoFmt::Load( SvStream& rStream, const SwAfVersions& rVersions, s
         sal_uInt16 eSys, eLge;
         // --- from 680/dr25 on: store strings as UTF-8
         CharSet eCharSet = (nVer >= AUTOFORMAT_ID_680DR25) ? RTL_TEXTENCODING_UTF8 : rStream.GetStreamCharSet();
-        rStream.ReadByteString( sNumFmtString, eCharSet )
-                >> eSys >> eLge;
+        sNumFmtString = rStream.ReadUniOrByteString( eCharSet );
+        rStream >> eSys >> eLge;
         eSysLanguage = (LanguageType) eSys;
         eNumFmtLanguage = (LanguageType) eLge;
-        if ( eSysLanguage == LANGUAGE_SYSTEM )      // von alten Versionen (Calc)
+        if ( eSysLanguage == LANGUAGE_SYSTEM )      // from old versions (Calc)
             eSysLanguage = static_cast<LanguageType>(::GetAppLanguage());
     }
 
@@ -415,109 +503,93 @@ sal_Bool SwBoxAutoFmt::Load( SvStream& rStream, const SwAfVersions& rVersions, s
     return 0 == rStream.GetError();
 }
 
-#ifdef READ_OLDVERS
-
-sal_Bool SwBoxAutoFmt::LoadOld( SvStream& rStream, sal_uInt16 aLoadVer[] )
-{
-    SfxPoolItem* pNew;
-    READ( aFont,        SvxFontItem         , 0)
-
-    if( rStream.GetStreamCharSet() == aFont.GetCharSet() )
-        aFont.SetCharSet(::osl_getThreadTextEncoding());
-
-    READ( aHeight,      SvxFontHeightItem   , 1)
-    READ( aWeight,      SvxWeightItem       , 2)
-    READ( aPosture,     SvxPostureItem      , 3)
-    READ( aUnderline,   SvxUnderlineItem    , 4)
-    READ( aCrossedOut,  SvxCrossedOutItem   , 5)
-    READ( aContour,     SvxContourItem      , 6)
-    READ( aShadowed,    SvxShadowedItem     , 7)
-    READ( aColor,       SvxColorItem        , 8)
-
-    pNew = aAdjust.Create(rStream, aLoadVer[ 9 ] );
-    SetAdjust( *(SvxAdjustItem*)pNew );
-    delete pNew;
-
-    READ( aBox,         SvxBoxItem          , 10)
-    READ( aBackground,  SvxBrushItem        , 11)
-
-    return 0 == rStream.GetError();
-}
-
-#endif
-
-
-sal_Bool SwBoxAutoFmt::Save( SvStream& rStream ) const
+sal_Bool SwBoxAutoFmt::Save( SvStream& rStream, sal_uInt16 fileVersion ) const
 {
     SvxOrientationItem aOrientation( aRotateAngle.GetValue(), aStacked.GetValue(), 0 );
 
-    aFont.Store( rStream, aFont.GetVersion(SOFFICE_FILEFORMAT_40)  );
-    aHeight.Store( rStream, aHeight.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aWeight.Store( rStream, aWeight.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aPosture.Store( rStream, aPosture.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aCJKFont.Store( rStream, aCJKFont.GetVersion(SOFFICE_FILEFORMAT_40)  );
-    aCJKHeight.Store( rStream, aCJKHeight.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aCJKWeight.Store( rStream, aCJKWeight.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aCJKPosture.Store( rStream, aCJKPosture.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aCTLFont.Store( rStream, aCTLFont.GetVersion(SOFFICE_FILEFORMAT_40)  );
-    aCTLHeight.Store( rStream, aCTLHeight.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aCTLWeight.Store( rStream, aCTLWeight.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aCTLPosture.Store( rStream, aCTLPosture.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aUnderline.Store( rStream, aUnderline.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aOverline.Store( rStream, aOverline.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aCrossedOut.Store( rStream, aCrossedOut.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aContour.Store( rStream, aContour.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aShadowed.Store( rStream, aShadowed.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aColor.Store( rStream, aColor.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aBox.Store( rStream, aBox.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aTLBR.Store( rStream, aTLBR.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aBLTR.Store( rStream, aBLTR.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aBackground.Store( rStream, aBackground.GetVersion(SOFFICE_FILEFORMAT_40) );
+    aFont.Store( rStream, aFont.GetVersion(fileVersion)  );
+    aHeight.Store( rStream, aHeight.GetVersion(fileVersion) );
+    aWeight.Store( rStream, aWeight.GetVersion(fileVersion) );
+    aPosture.Store( rStream, aPosture.GetVersion(fileVersion) );
+    aCJKFont.Store( rStream, aCJKFont.GetVersion(fileVersion)  );
+    aCJKHeight.Store( rStream, aCJKHeight.GetVersion(fileVersion) );
+    aCJKWeight.Store( rStream, aCJKWeight.GetVersion(fileVersion) );
+    aCJKPosture.Store( rStream, aCJKPosture.GetVersion(fileVersion) );
+    aCTLFont.Store( rStream, aCTLFont.GetVersion(fileVersion)  );
+    aCTLHeight.Store( rStream, aCTLHeight.GetVersion(fileVersion) );
+    aCTLWeight.Store( rStream, aCTLWeight.GetVersion(fileVersion) );
+    aCTLPosture.Store( rStream, aCTLPosture.GetVersion(fileVersion) );
+    aUnderline.Store( rStream, aUnderline.GetVersion(fileVersion) );
+    aOverline.Store( rStream, aOverline.GetVersion(fileVersion) );
+    aCrossedOut.Store( rStream, aCrossedOut.GetVersion(fileVersion) );
+    aContour.Store( rStream, aContour.GetVersion(fileVersion) );
+    aShadowed.Store( rStream, aShadowed.GetVersion(fileVersion) );
+    aColor.Store( rStream, aColor.GetVersion(fileVersion) );
+    aBox.Store( rStream, aBox.GetVersion(fileVersion) );
+    aTLBR.Store( rStream, aTLBR.GetVersion(fileVersion) );
+    aBLTR.Store( rStream, aBLTR.GetVersion(fileVersion) );
+    aBackground.Store( rStream, aBackground.GetVersion(fileVersion) );
 
-    aAdjust.Store( rStream, aAdjust.GetVersion(SOFFICE_FILEFORMAT_40) );
+    aAdjust.Store( rStream, aAdjust.GetVersion(fileVersion) );
+    if (fileVersion >= SOFFICE_FILEFORMAT_50)
+    {
+        WriterSpecificAutoFormatBlock block(rStream);
 
-    aHorJustify.Store( rStream, aHorJustify.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aVerJustify.Store( rStream, aVerJustify.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aOrientation.Store( rStream, aOrientation.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aMargin.Store( rStream, aMargin.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aLinebreak.Store( rStream, aLinebreak.GetVersion(SOFFICE_FILEFORMAT_40) );
-    // Calc Rotation ab SO5
-    aRotateAngle.Store( rStream, aRotateAngle.GetVersion(SOFFICE_FILEFORMAT_40) );
-    aRotateMode.Store( rStream, aRotateMode.GetVersion(SOFFICE_FILEFORMAT_40) );
+        m_aTextOrientation.Store(rStream, m_aTextOrientation.GetVersion(fileVersion));
+        m_aVerticalAlignment.Store(rStream, m_aVerticalAlignment.GetVersion(fileVersion));
+    }
+
+    aHorJustify.Store( rStream, aHorJustify.GetVersion(fileVersion) );
+    aVerJustify.Store( rStream, aVerJustify.GetVersion(fileVersion) );
+    aOrientation.Store( rStream, aOrientation.GetVersion(fileVersion) );
+    aMargin.Store( rStream, aMargin.GetVersion(fileVersion) );
+    aLinebreak.Store( rStream, aLinebreak.GetVersion(fileVersion) );
+    // Calc Rotation from SO5
+    aRotateAngle.Store( rStream, aRotateAngle.GetVersion(fileVersion) );
+    aRotateMode.Store( rStream, aRotateMode.GetVersion(fileVersion) );
 
     // --- from 680/dr25 on: store strings as UTF-8
-    rStream.WriteByteString( sNumFmtString, RTL_TEXTENCODING_UTF8 )
-        << (sal_uInt16)eSysLanguage << (sal_uInt16)eNumFmtLanguage;
+    write_lenPrefixed_uInt8s_FromOUString<sal_uInt16>(rStream, sNumFmtString,
+        RTL_TEXTENCODING_UTF8);
+    rStream << (sal_uInt16)eSysLanguage << (sal_uInt16)eNumFmtLanguage;
 
     return 0 == rStream.GetError();
 }
 
 
-sal_Bool SwBoxAutoFmt::SaveVerionNo( SvStream& rStream ) const
+sal_Bool SwBoxAutoFmt::SaveVersionNo( SvStream& rStream, sal_uInt16 fileVersion ) const
 {
-    rStream << aFont.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aHeight.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aWeight.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aPosture.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aUnderline.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aOverline.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aCrossedOut.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aContour.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aShadowed.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aColor.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aBox.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aTLBR.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aBackground.GetVersion( SOFFICE_FILEFORMAT_40 );
+    rStream << aFont.GetVersion( fileVersion );
+    rStream << aHeight.GetVersion( fileVersion );
+    rStream << aWeight.GetVersion( fileVersion );
+    rStream << aPosture.GetVersion( fileVersion );
+    rStream << aUnderline.GetVersion( fileVersion );
+    rStream << aOverline.GetVersion( fileVersion );
+    rStream << aCrossedOut.GetVersion( fileVersion );
+    rStream << aContour.GetVersion( fileVersion );
+    rStream << aShadowed.GetVersion( fileVersion );
+    rStream << aColor.GetVersion( fileVersion );
+    rStream << aBox.GetVersion( fileVersion );
+    rStream << aTLBR.GetVersion( fileVersion );
+    rStream << aBackground.GetVersion( fileVersion );
 
-    rStream << aAdjust.GetVersion( SOFFICE_FILEFORMAT_40 );
+    rStream << aAdjust.GetVersion( fileVersion );
 
-    rStream << aHorJustify.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aVerJustify.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << SvxOrientationItem(SVX_ORIENTATION_STANDARD, 0).GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aMargin.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aLinebreak.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aRotateAngle.GetVersion( SOFFICE_FILEFORMAT_40 );
-    rStream << aRotateMode.GetVersion( SOFFICE_FILEFORMAT_40 );
+    if (fileVersion >= SOFFICE_FILEFORMAT_50)
+    {
+        WriterSpecificAutoFormatBlock block(rStream);
+
+        rStream << m_aTextOrientation.GetVersion(fileVersion);
+        rStream << m_aVerticalAlignment.GetVersion(fileVersion);
+    }
+
+    rStream << aHorJustify.GetVersion( fileVersion );
+    rStream << aVerJustify.GetVersion( fileVersion );
+    rStream << SvxOrientationItem(SVX_ORIENTATION_STANDARD, 0).GetVersion( fileVersion );
+    rStream << aMargin.GetVersion( fileVersion );
+    rStream << aLinebreak.GetVersion( fileVersion );
+    rStream << aRotateAngle.GetVersion( fileVersion );
+    rStream << aRotateMode.GetVersion( fileVersion );
 
     rStream << (sal_uInt16)0;       // NumberFormat
 
@@ -527,7 +599,15 @@ sal_Bool SwBoxAutoFmt::SaveVerionNo( SvStream& rStream ) const
 
 
 SwTableAutoFmt::SwTableAutoFmt( const String& rName )
-    : aName( rName ), nStrResId( USHRT_MAX )
+    : aName( rName )
+    , nStrResId( USHRT_MAX )
+    , m_aBreak( SVX_BREAK_NONE, RES_BREAK )
+    , m_aKeepWithNextPara( sal_False, RES_KEEP )
+    , m_aRepeatHeading( 0 )
+    , m_bLayoutSplit( sal_True )
+    , m_bRowSplit( sal_True )
+    , m_bCollapsingBorders(sal_True)
+    , m_aShadow( RES_SHADOW )
 {
     bInclFont = sal_True;
     bInclJustify = sal_True;
@@ -541,6 +621,9 @@ SwTableAutoFmt::SwTableAutoFmt( const String& rName )
 
 
 SwTableAutoFmt::SwTableAutoFmt( const SwTableAutoFmt& rNew )
+    : m_aBreak( rNew.m_aBreak )
+    , m_aKeepWithNextPara( sal_False, RES_KEEP )
+    , m_aShadow( RES_SHADOW )
 {
     for( sal_uInt8 n = 0; n < 16; ++n )
         aBoxAutoFmt[ n ] = 0;
@@ -555,9 +638,9 @@ SwTableAutoFmt& SwTableAutoFmt::operator=( const SwTableAutoFmt& rNew )
             delete aBoxAutoFmt[ n ];
 
         SwBoxAutoFmt* pFmt = rNew.aBoxAutoFmt[ n ];
-        if( pFmt )      // ist gesetzt -> kopieren
+        if( pFmt )      // if is set -> copy
             aBoxAutoFmt[ n ] = new SwBoxAutoFmt( *pFmt );
-        else            // sonst default
+        else            // else default
             aBoxAutoFmt[ n ] = 0;
     }
 
@@ -570,6 +653,15 @@ SwTableAutoFmt& SwTableAutoFmt::operator=( const SwTableAutoFmt& rNew )
     bInclValueFormat = rNew.bInclValueFormat;
     bInclWidthHeight = rNew.bInclWidthHeight;
 
+    m_aBreak = rNew.m_aBreak;
+    m_aPageDesc = rNew.m_aPageDesc;
+    m_aKeepWithNextPara = rNew.m_aKeepWithNextPara;
+    m_aRepeatHeading = rNew.m_aRepeatHeading;
+    m_bLayoutSplit = rNew.m_bLayoutSplit;
+    m_bRowSplit = rNew.m_bRowSplit;
+    m_bCollapsingBorders = rNew.m_bCollapsingBorders;
+    m_aShadow = rNew.m_aShadow;
+
     return *this;
 }
 
@@ -585,26 +677,26 @@ SwTableAutoFmt::~SwTableAutoFmt()
 
 void SwTableAutoFmt::SetBoxFmt( const SwBoxAutoFmt& rNew, sal_uInt8 nPos )
 {
-    OSL_ENSURE( nPos < 16, "falscher Bereich" );
+    OSL_ENSURE( nPos < 16, "wrong area" );
 
     SwBoxAutoFmt* pFmt = aBoxAutoFmt[ nPos ];
-    if( pFmt )      // ist gesetzt -> kopieren
+    if( pFmt )      // if is set -> copy
         *aBoxAutoFmt[ nPos ] = rNew;
-    else            // sonst neu setzen
+    else            // else set anew
         aBoxAutoFmt[ nPos ] = new SwBoxAutoFmt( rNew );
 }
 
 
 const SwBoxAutoFmt& SwTableAutoFmt::GetBoxFmt( sal_uInt8 nPos ) const
 {
-    OSL_ENSURE( nPos < 16, "falscher Bereich" );
+    OSL_ENSURE( nPos < 16, "wrong area" );
 
     SwBoxAutoFmt* pFmt = aBoxAutoFmt[ nPos ];
-    if( pFmt )      // ist gesetzt -> kopieren
+    if( pFmt )      // if is set -> copy
         return *pFmt;
-    else            // sonst den default returnen
+    else            // else return the default
     {
-        // falls noch nicht vorhanden:
+        // If it doesn't exist yet:
         if( !pDfltBoxAutoFmt )
             pDfltBoxAutoFmt = new SwBoxAutoFmt;
         return *pDfltBoxAutoFmt;
@@ -613,15 +705,15 @@ const SwBoxAutoFmt& SwTableAutoFmt::GetBoxFmt( sal_uInt8 nPos ) const
 
 
 
-SwBoxAutoFmt& SwTableAutoFmt::UpdateFromSet( sal_uInt8 nPos,
-                                            const SfxItemSet& rSet,
-                                            UpdateFlags eFlags,
-                                            SvNumberFormatter* pNFmtr )
+void SwTableAutoFmt::UpdateFromSet( sal_uInt8 nPos,
+                                    const SfxItemSet& rSet,
+                                    UpdateFlags eFlags,
+                                    SvNumberFormatter* pNFmtr)
 {
-    OSL_ENSURE( nPos < 16, "falscher Bereich" );
+    OSL_ENSURE( nPos < 16, "wrong area" );
 
     SwBoxAutoFmt* pFmt = aBoxAutoFmt[ nPos ];
-    if( !pFmt )     // ist gesetzt -> kopieren
+    if( !pFmt )     // if is set -> copy
     {
         pFmt = new SwBoxAutoFmt;
         aBoxAutoFmt[ nPos ] = pFmt;
@@ -656,6 +748,8 @@ SwBoxAutoFmt& SwTableAutoFmt::UpdateFromSet( sal_uInt8 nPos,
 //        pFmt->SetTLBR( (SvxLineItem&)rSet.Get( RES_... ) );
 //        pFmt->SetBLTR( (SvxLineItem&)rSet.Get( RES_... ) );
         pFmt->SetBackground( (SvxBrushItem&)rSet.Get( RES_BACKGROUND ) );
+        pFmt->SetTextOrientation(static_cast<const SvxFrameDirectionItem&>(rSet.Get(RES_FRAMEDIR)));
+        pFmt->SetVerticalAlignment(static_cast<const SwFmtVertOrient&>(rSet.Get(RES_VERT_ORIENT)));
 
         const SwTblBoxNumFormat* pNumFmtItem;
         const SvNumberformat* pNumFormat = 0;
@@ -667,19 +761,18 @@ SwBoxAutoFmt& SwTableAutoFmt::UpdateFromSet( sal_uInt8 nPos,
                                     static_cast<LanguageType>(::GetAppLanguage()));
         else
         {
-            // defaulten
+            // default
             pFmt->SetValueFormat( aEmptyStr, LANGUAGE_SYSTEM,
                                   static_cast<LanguageType>(::GetAppLanguage() ));
         }
     }
-    // den Rest koennen wir nicht, StarCalc spezifisch
 
-    return *pFmt;
+    // we cannot handle the rest, that's specific to StarCalc
 }
 
 
-void SwTableAutoFmt::UpdateToSet( sal_uInt8 nPos, SfxItemSet& rSet,
-                UpdateFlags eFlags, SvNumberFormatter* pNFmtr ) const
+void SwTableAutoFmt::UpdateToSet(sal_uInt8 nPos, SfxItemSet& rSet,
+                                 UpdateFlags eFlags, SvNumberFormatter* pNFmtr) const
 {
     const SwBoxAutoFmt& rChg = GetBoxFmt( nPos );
 
@@ -744,6 +837,9 @@ void SwTableAutoFmt::UpdateToSet( sal_uInt8 nPos, SfxItemSet& rSet,
         if( IsBackground() )
             rSet.Put( rChg.GetBackground() );
 
+        rSet.Put(rChg.GetTextOrientation());
+        rSet.Put(rChg.GetVerticalAlignment());
+
         if( IsValueFormat() && pNFmtr )
         {
             String sFmt; LanguageType eLng, eSys;
@@ -762,9 +858,65 @@ void SwTableAutoFmt::UpdateToSet( sal_uInt8 nPos, SfxItemSet& rSet,
         }
     }
 
-    // den Rest koennen wir nicht, StarCalc spezifisch
+    // we cannot handle the rest, that's specific to StarCalc
 }
 
+void SwTableAutoFmt::RestoreTableProperties(SwTable &table) const
+{
+    SwTableFmt *pFormat = table.GetTableFmt();
+    if (!pFormat)
+        return;
+
+    SwDoc *pDoc = pFormat->GetDoc();
+    if (!pDoc)
+        return;
+
+    SfxItemSet rSet(pDoc->GetAttrPool(), aTableSetRange);
+
+    rSet.Put(m_aBreak);
+    rSet.Put(m_aPageDesc);
+    rSet.Put(SwFmtLayoutSplit(m_bLayoutSplit));
+    rSet.Put(SfxBoolItem(RES_COLLAPSING_BORDERS, m_bCollapsingBorders));
+    rSet.Put(m_aKeepWithNextPara);
+    rSet.Put(m_aShadow);
+
+    pFormat->SetFmtAttr(rSet);
+
+    SwEditShell *pShell = pDoc->GetEditShell();
+    pDoc->SetRowSplit(*pShell->getShellCrsr(false), SwFmtRowSplit(m_bRowSplit));
+
+    table.SetRowsToRepeat(m_aRepeatHeading);
+}
+
+void SwTableAutoFmt::StoreTableProperties(const SwTable &table)
+{
+    SwTableFmt *pFormat = table.GetTableFmt();
+    if (!pFormat)
+        return;
+
+    SwDoc *pDoc = pFormat->GetDoc();
+    if (!pDoc)
+        return;
+
+    SwEditShell *pShell = pDoc->GetEditShell();
+    SwFmtRowSplit *pRowSplit = 0;
+    pDoc->GetRowSplit(*pShell->getShellCrsr(false), pRowSplit);
+    m_bRowSplit = pRowSplit ? pRowSplit->GetValue() : sal_False;
+    delete pRowSplit;
+    pRowSplit = 0;
+
+    const SfxItemSet &rSet = pFormat->GetAttrSet();
+
+    m_aBreak = static_cast<const SvxFmtBreakItem&>(rSet.Get(RES_BREAK));
+    m_aPageDesc = static_cast<const SwFmtPageDesc&>(rSet.Get(RES_PAGEDESC));
+    const SwFmtLayoutSplit &layoutSplit = static_cast<const SwFmtLayoutSplit&>(rSet.Get(RES_LAYOUT_SPLIT));
+    m_bLayoutSplit = layoutSplit.GetValue();
+    m_bCollapsingBorders = static_cast<const SfxBoolItem&>(rSet.Get(RES_COLLAPSING_BORDERS)).GetValue();
+
+    m_aKeepWithNextPara = static_cast<const SvxFmtKeepItem&>(rSet.Get(RES_KEEP));
+    m_aRepeatHeading = table.GetRowsToRepeat();
+    m_aShadow = static_cast<const SvxShadowItem&>(rSet.Get(RES_SHADOW));
+}
 
 sal_Bool SwTableAutoFmt::Load( SvStream& rStream, const SwAfVersions& rVersions )
 {
@@ -779,7 +931,7 @@ sal_Bool SwTableAutoFmt::Load( SvStream& rStream, const SwAfVersions& rVersions
         sal_Bool b;
         // --- from 680/dr25 on: store strings as UTF-8
         CharSet eCharSet = (nVal >= AUTOFORMAT_ID_680DR25) ? RTL_TEXTENCODING_UTF8 : rStream.GetStreamCharSet();
-        rStream.ReadByteString( aName, eCharSet );
+        aName = rStream.ReadUniOrByteString( eCharSet );
         if( AUTOFORMAT_DATA_ID_552 <= nVal )
         {
             rStream >> nStrResId;
@@ -799,9 +951,22 @@ sal_Bool SwTableAutoFmt::Load( SvStream& rStream, const SwAfVersions& rVersions
         rStream >> b; bInclValueFormat = b;
         rStream >> b; bInclWidthHeight = b;
 
+        if (nVal >= AUTOFORMAT_DATA_ID_31005 && WriterSpecificBlockExists(rStream))
+        {
+            SfxPoolItem* pNew = 0;
+
+            READ(m_aBreak, SvxFmtBreakItem, AUTOFORMAT_FILE_VERSION);
+            READ(m_aPageDesc, SwFmtPageDesc, AUTOFORMAT_FILE_VERSION);
+            READ(m_aKeepWithNextPara, SvxFmtKeepItem, AUTOFORMAT_FILE_VERSION);
+
+            rStream >> m_aRepeatHeading >> m_bLayoutSplit >> m_bRowSplit >> m_bCollapsingBorders;
+
+            READ(m_aShadow, SvxShadowItem, AUTOFORMAT_FILE_VERSION);
+        }
+
         bRet = 0 == rStream.GetError();
 
-        for( sal_uInt8 i = 0; i < 16; ++i )
+        for( sal_uInt8 i = 0; bRet && i < 16; ++i )
         {
             SwBoxAutoFmt* pFmt = new SwBoxAutoFmt;
             bRet = pFmt->Load( rStream, rVersions, nVal );
@@ -817,50 +982,14 @@ sal_Bool SwTableAutoFmt::Load( SvStream& rStream, const SwAfVersions& rVersions
     return bRet;
 }
 
-#ifdef READ_OLDVERS
-
-sal_Bool SwTableAutoFmt::LoadOld( SvStream& rStream, sal_uInt16 aLoadVer[] )
-{
-    sal_Bool    bRet = sal_True;
-    sal_uInt16  nVal = 0;
-    rStream >> nVal;
-    bRet = 0 == rStream.GetError();
-
-    if( bRet && ( AUTOFORMAT_OLD_DATA_ID == nVal ))
-    {
-        sal_Bool b;
-        rStream.ReadByteString( aName, rStream.GetStreamCharSet() );
-        rStream >> b; bInclFont = b;
-        rStream >> b; bInclJustify = b;
-        rStream >> b; bInclFrame = b;
-        rStream >> b; bInclBackground = b;
-        bRet = (rStream.GetError() == 0);
-
-        for( int i = 0; i < 16; i++)
-        {
-            SwBoxAutoFmt* pFmt = new SwBoxAutoFmt;
-            bRet = pFmt->LoadOld( rStream, aLoadVer );
-            if( bRet )
-                aBoxAutoFmt[ i ] = pFmt;
-            else
-            {
-                delete pFmt;
-                break;
-            }
-        }
-    }
-    return bRet;
-}
-#endif
-
-
-sal_Bool SwTableAutoFmt::Save( SvStream& rStream ) const
+sal_Bool SwTableAutoFmt::Save( SvStream& rStream, sal_uInt16 fileVersion ) const
 {
     sal_uInt16 nVal = AUTOFORMAT_DATA_ID;
     sal_Bool b;
     rStream << nVal;
     // --- from 680/dr25 on: store strings as UTF-8
-    rStream.WriteByteString( aName, RTL_TEXTENCODING_UTF8 );
+    write_lenPrefixed_uInt8s_FromOUString<sal_uInt16>(rStream, aName,
+        RTL_TEXTENCODING_UTF8 );
     rStream << nStrResId;
     rStream << ( b = bInclFont );
     rStream << ( b = bInclJustify );
@@ -869,25 +998,76 @@ sal_Bool SwTableAutoFmt::Save( SvStream& rStream ) const
     rStream << ( b = bInclValueFormat );
     rStream << ( b = bInclWidthHeight );
 
+    {
+        WriterSpecificAutoFormatBlock block(rStream);
+
+        m_aBreak.Store(rStream, m_aBreak.GetVersion(fileVersion));
+        m_aPageDesc.Store(rStream, m_aPageDesc.GetVersion(fileVersion));
+        m_aKeepWithNextPara.Store(rStream, m_aKeepWithNextPara.GetVersion(fileVersion));
+        rStream << m_aRepeatHeading << m_bLayoutSplit << m_bRowSplit << m_bCollapsingBorders;
+        m_aShadow.Store(rStream, m_aShadow.GetVersion(fileVersion));
+    }
+
     sal_Bool bRet = 0 == rStream.GetError();
 
     for( int i = 0; bRet && i < 16; ++i )
     {
         SwBoxAutoFmt* pFmt = aBoxAutoFmt[ i ];
-        if( !pFmt )     // nicht gesetzt -> default schreiben
+        if( !pFmt )     // if not set -> write default
         {
-            // falls noch nicht vorhanden:
+            // If it doesn't exist yet:
             if( !pDfltBoxAutoFmt )
                 pDfltBoxAutoFmt = new SwBoxAutoFmt;
             pFmt = pDfltBoxAutoFmt;
         }
-        bRet = pFmt->Save( rStream );
+        bRet = pFmt->Save( rStream, fileVersion );
     }
     return bRet;
 }
 
 
+struct SwTableAutoFmtTbl::Impl
+{
+    boost::ptr_vector<SwTableAutoFmt> m_AutoFormats;
+};
+
+size_t SwTableAutoFmtTbl::size() const
+{
+    return m_pImpl->m_AutoFormats.size();
+}
+
+SwTableAutoFmt const& SwTableAutoFmtTbl::operator[](size_t const i) const
+{
+    return m_pImpl->m_AutoFormats[i];
+}
+SwTableAutoFmt      & SwTableAutoFmtTbl::operator[](size_t const i)
+{
+    return m_pImpl->m_AutoFormats[i];
+}
+
+void
+SwTableAutoFmtTbl::InsertAutoFmt(size_t const i, SwTableAutoFmt *const pFmt)
+{
+    m_pImpl->m_AutoFormats.insert(m_pImpl->m_AutoFormats.begin() + i, pFmt);
+}
+
+void SwTableAutoFmtTbl::EraseAutoFmt(size_t const i)
+{
+    m_pImpl->m_AutoFormats.erase(m_pImpl->m_AutoFormats.begin() + i);
+}
+
+void SwTableAutoFmtTbl::MoveAutoFmt(size_t const target, size_t source)
+{
+    m_pImpl->m_AutoFormats.transfer(m_pImpl->m_AutoFormats.begin() + target,
+            m_pImpl->m_AutoFormats.begin() + source, m_pImpl->m_AutoFormats);
+}
+
+SwTableAutoFmtTbl::~SwTableAutoFmtTbl()
+{
+}
+
 SwTableAutoFmtTbl::SwTableAutoFmtTbl()
+    : m_pImpl(new Impl)
 {
     String sNm;
     SwTableAutoFmt* pNew = new SwTableAutoFmt(
@@ -905,13 +1085,13 @@ SwTableAutoFmtTbl::SwTableAutoFmtTbl()
     for( i = 0; i < 4; ++i )
         pNew->SetBoxFmt( aNew, i );
 
-    // 70% Grau
+    // 70% gray
     aBrushItem.SetColor( RGB_COLORDATA( 0x4d, 0x4d, 0x4d ) );
     aNew.SetBackground( aBrushItem );
     for( i = 4; i <= 12; i += 4 )
         pNew->SetBoxFmt( aNew, i );
 
-    // 20% Grau
+    // 20% gray
     aBrushItem.SetColor( RGB_COLORDATA( 0xcc, 0xcc, 0xcc ) );
     aNew.SetBackground( aBrushItem );
     aColor.SetColor( COL_BLACK );
@@ -942,7 +1122,7 @@ SwTableAutoFmtTbl::SwTableAutoFmtTbl()
         ((SwBoxAutoFmt&)pNew->GetBoxFmt( i )).SetBox( aBox );
     }
 
-    Insert( pNew, Count() );
+    m_pImpl->m_AutoFormats.push_back(pNew);
 }
 
 sal_Bool SwTableAutoFmtTbl::Load()
@@ -953,7 +1133,7 @@ sal_Bool SwTableAutoFmtTbl::Load()
     SvtPathOptions aOpt;
     if( aOpt.SearchFile( sNm, SvtPathOptions::PATH_USERCONFIG ))
     {
-        SfxMedium aStream( sNm, STREAM_STD_READ, sal_True );
+        SfxMedium aStream( sNm, STREAM_STD_READ );
         bRet = Load( *aStream.GetInStream() );
     }
     else
@@ -967,7 +1147,7 @@ sal_Bool SwTableAutoFmtTbl::Save() const
     String sNm( aPathOpt.GetUserConfigPath() );
     sNm += INET_PATH_TOKEN;
     sNm.AppendAscii( RTL_CONSTASCII_STRINGPARAM( sAutoTblFmtName ));
-    SfxMedium aStream(sNm, STREAM_STD_WRITE, sal_True );
+    SfxMedium aStream(sNm, STREAM_STD_WRITE );
     return Save( *aStream.GetOutStream() ) && aStream.Commit();
 }
 
@@ -976,7 +1156,7 @@ sal_Bool SwTableAutoFmtTbl::Load( SvStream& rStream )
     sal_Bool bRet = 0 == rStream.GetError();
     if (bRet)
     {
-        // Achtung hier muss ein allgemeiner Header gelesen werden
+        // Attention: We need to read a general Header here
         sal_uInt16 nVal = 0;
         rStream >> nVal;
         bRet = 0 == rStream.GetError();
@@ -985,18 +1165,20 @@ sal_Bool SwTableAutoFmtTbl::Load( SvStream& rStream )
         {
             SwAfVersions aVersions;
 
+            // Default version is 5.0, unless we detect an old format ID.
+            sal_uInt16 nFileVers = SOFFICE_FILEFORMAT_50;
+            if(nVal < AUTOFORMAT_ID_31005)
+                nFileVers = SOFFICE_FILEFORMAT_40;
+
             if( nVal == AUTOFORMAT_ID_358 ||
                     (AUTOFORMAT_ID_504 <= nVal && nVal <= AUTOFORMAT_ID) )
             {
-                sal_uInt16 nFileVers = SOFFICE_FILEFORMAT_40;
                 sal_uInt8 nChrSet, nCnt;
                 long nPos = rStream.Tell();
                 rStream >> nCnt >> nChrSet;
-//              if( 4 <= nCnt )
-//                  rStream >> nFileVers;
                 if( rStream.Tell() != sal_uLong(nPos + nCnt) )
                 {
-                    OSL_ENSURE( !this, "Der Header enthaelt mehr/neuere Daten" );
+                    OSL_ENSURE( !this, "The Header contains more or newer Data" );
                     rStream.Seek( nPos + nCnt );
                 }
                 rStream.SetStreamCharSet( (CharSet)nChrSet );
@@ -1006,7 +1188,7 @@ sal_Bool SwTableAutoFmtTbl::Load( SvStream& rStream )
             if( nVal == AUTOFORMAT_ID_358 || nVal == AUTOFORMAT_ID_X ||
                     (AUTOFORMAT_ID_504 <= nVal && nVal <= AUTOFORMAT_ID) )
             {
-                aVersions.Load( rStream, nVal );        // Item-Versionen
+                aVersions.Load( rStream, nVal );        // Item versions
 
                 SwTableAutoFmt* pNew;
                 sal_uInt16 nAnz = 0;
@@ -1020,7 +1202,7 @@ sal_Bool SwTableAutoFmtTbl::Load( SvStream& rStream )
                     bRet = pNew->Load( rStream, aVersions );
                     if( bRet )
                     {
-                        Insert( pNew, Count() );
+                        m_pImpl->m_AutoFormats.push_back(pNew);
                     }
                     else
                     {
@@ -1029,37 +1211,10 @@ sal_Bool SwTableAutoFmtTbl::Load( SvStream& rStream )
                     }
                 }
             }
-#ifdef READ_OLDVERS
-            else if( AUTOFORMAT_OLD_ID == nVal || AUTOFORMAT_OLD_ID1 == nVal )
+            else
             {
-                SwTableAutoFmt* pNew;
-                sal_uInt16 nAnz = 0;
-                rStream >> nAnz;
-
-                sal_uInt16 aArr[ 12 ];
-                memset( aArr, 0, 12 * sizeof( sal_uInt16 ) );
-                if( AUTOFORMAT_OLD_ID1 == nVal )
-                    for( sal_uInt16 n = 0; n < 12; ++n )
-                        rStream >> aArr[ n ];
-
-                bRet = 0 == rStream.GetError();
-
-                for( sal_uInt16 i = 0; i < nAnz; ++i )
-                {
-                    pNew = new SwTableAutoFmt( aEmptyStr );
-                    bRet = pNew->LoadOld( rStream, aArr );
-                    if( bRet )
-                    {
-                        Insert( pNew, Count() );
-                    }
-                    else
-                    {
-                        delete pNew;
-                        break;
-                    }
-                }
+                bRet = false;
             }
-#endif
         }
     }
     return bRet;
@@ -1071,27 +1226,27 @@ sal_Bool SwTableAutoFmtTbl::Save( SvStream& rStream ) const
     sal_Bool bRet = 0 == rStream.GetError();
     if (bRet)
     {
-        rStream.SetVersion( SOFFICE_FILEFORMAT_40 );
+        rStream.SetVersion(AUTOFORMAT_FILE_VERSION);
 
-        // Achtung hier muss ein allgemeiner Header gespeichert werden
+        // Attention: We need to save a general Header here
         sal_uInt16 nVal = AUTOFORMAT_ID;
         rStream << nVal
-                << (sal_uInt8)2         // Anzahl von Zeichen des Headers incl. diesem
+                << (sal_uInt8)2 // Character count of the Header including this value
                 << (sal_uInt8)GetStoreCharSet( ::osl_getThreadTextEncoding() );
 
         bRet = 0 == rStream.GetError();
 
-        //-----------------------------------------------------------
-        // die VersionsNummer fuer alle Attribute schreiben
-        (*this)[ 0 ]->GetBoxFmt( 0 ).SaveVerionNo( rStream );
+        // Write this version number for all attributes
+        m_pImpl->m_AutoFormats[0].GetBoxFmt(0).SaveVersionNo(
+                rStream, AUTOFORMAT_FILE_VERSION);
 
-        rStream << (sal_uInt16)(Count() - 1);
+        rStream << static_cast<sal_uInt16>(m_pImpl->m_AutoFormats.size() - 1);
         bRet = 0 == rStream.GetError();
 
-        for( sal_uInt16 i = 1; bRet && i < Count(); ++i )
+        for (sal_uInt16 i = 1; bRet && i < m_pImpl->m_AutoFormats.size(); ++i)
         {
-            SwTableAutoFmt* pFmt = (*this)[ i ];
-            bRet = pFmt->Save( rStream );
+            SwTableAutoFmt const& rFmt = m_pImpl->m_AutoFormats[i];
+            bRet = rFmt.Save(rStream, AUTOFORMAT_FILE_VERSION);
         }
     }
     rStream.Flush();
