@@ -290,7 +290,7 @@ void SwAutoFormat::_SetRedlineTxt( sal_uInt16 nActionId )
     sal_uInt16 nSeqNo = 0;
     if( STR_AUTOFMTREDL_END > nActionId )
     {
-        sTxt = *ViewShell::GetShellRes()->GetAutoFmtNameLst()[ nActionId ];
+        sTxt = ViewShell::GetShellRes()->GetAutoFmtNameLst()[ nActionId ];
         switch( nActionId )
         {
         case STR_AUTOFMTREDL_SET_NUMBULET:
@@ -592,28 +592,28 @@ sal_Bool SwAutoFormat::DoUnderline()
         editeng::SvxBorderLine aLine;
         switch( eState )
         {
-        case 1:         // einfach, 0,05 pt
-            aLine.SetStyle( editeng::SOLID );
+        case 1:         // single, 0,05 pt
+            aLine.SetBorderLineStyle(table::BorderLineStyle::SOLID);
             aLine.SetWidth( DEF_LINE_WIDTH_0 );
             break;
-        case 2:         // einfach, 1,0 pt
-            aLine.SetStyle( editeng::SOLID );
+        case 2:         // single, 1,0 pt
+            aLine.SetBorderLineStyle(table::BorderLineStyle::SOLID);
             aLine.SetWidth( DEF_LINE_WIDTH_1 );
             break;
-        case 3:         // doppelt, 1,1 pt
-            aLine.SetStyle( editeng::DOUBLE );
+        case 3:         // double, 1,1 pt
+            aLine.SetBorderLineStyle(table::BorderLineStyle::DOUBLE);
             aLine.SetWidth( DEF_LINE_WIDTH_0 );
             break;
-        case 4:         // doppelt, 4,5 pt
-            aLine.SetStyle( editeng::THICKTHIN_SMALLGAP );
+        case 4:         // double, 4,5 pt
+            aLine.SetBorderLineStyle(table::BorderLineStyle::THICKTHIN_SMALLGAP);
             aLine.SetWidth( DEF_LINE_WIDTH_1  );
             break;
-        case 5:         // doppelt, 6,0 pt
-            aLine.SetStyle( editeng::THINTHICK_SMALLGAP );
+        case 5:         // double, 6,0 pt
+            aLine.SetBorderLineStyle(table::BorderLineStyle::THINTHICK_SMALLGAP);
             aLine.SetWidth( DEF_LINE_WIDTH_2 );
             break;
-        case 6:         // doppelt, 9,0 pt
-            aLine.SetStyle( editeng::DOUBLE );
+        case 6:         // double, 9,0 pt
+            aLine.SetBorderLineStyle(table::BorderLineStyle::DOUBLE);
             aLine.SetWidth( DEF_LINE_WIDTH_2 );
             break;
         }
@@ -840,7 +840,7 @@ sal_uInt16 SwAutoFormat::GetDigitLevel( const SwTxtNode& rNd, xub_StrLen& rPos,
             sal_Bool bIsUpper =
                 0 != ( i18n::KCharacterType::UPPER &
                                         rCC.getCharacterType( rTxt, nPos ));
-            sal_Unicode cLow = rCC.toLower( rTxt, nPos, 1 ).GetChar(0), cNumTyp;
+            sal_Unicode cLow = rCC.lowercase(rTxt, nPos, 1)[0], cNumTyp;
             int eTmpScan;
 
             // roemische Zeichen sind "mdclxvi". Da man aber eher mal eine
@@ -1832,7 +1832,7 @@ void SwAutoFormat::BuildHeadLine( sal_uInt16 nLvl )
 {
     if( aFlags.bWithRedlining )
     {
-        String sTxt( *ViewShell::GetShellRes()->GetAutoFmtNameLst()[
+        String sTxt(ViewShell::GetShellRes()->GetAutoFmtNameLst()[
                                     STR_AUTOFMTREDL_SET_TMPL_HEADLINE ] );
         sTxt.SearchAndReplace( String::CreateFromAscii(
                                     RTL_CONSTASCII_STRINGPARAM( "$(ARG1)" )),
