@@ -55,7 +55,7 @@
 sal_uInt16 SwEditShell::GetFldTypeCount(sal_uInt16 nResId, sal_Bool bUsed ) const
 {
     const SwFldTypes* pFldTypes = GetDoc()->GetFldTypes();
-    const sal_uInt16 nSize = pFldTypes->Count();
+    const sal_uInt16 nSize = pFldTypes->size();
 
     if(nResId == USHRT_MAX)
     {
@@ -91,7 +91,7 @@ sal_uInt16 SwEditShell::GetFldTypeCount(sal_uInt16 nResId, sal_Bool bUsed ) cons
 SwFieldType* SwEditShell::GetFldType(sal_uInt16 nFld, sal_uInt16 nResId, sal_Bool bUsed ) const
 {
     const SwFldTypes* pFldTypes = GetDoc()->GetFldTypes();
-    const sal_uInt16 nSize = pFldTypes->Count();
+    const sal_uInt16 nSize = pFldTypes->size();
 
     if(nResId == USHRT_MAX && nFld < nSize)
     {
@@ -150,7 +150,7 @@ void SwEditShell::RemoveFldType(sal_uInt16 nFld, sal_uInt16 nResId)
     }
 
     const SwFldTypes* pFldTypes = GetDoc()->GetFldTypes();
-    const sal_uInt16 nSize = pFldTypes->Count();
+    const sal_uInt16 nSize = pFldTypes->size();
     sal_uInt16 nIdx = 0;
     for( sal_uInt16 i = 0; i < nSize; ++i )
         // Gleiche ResId -> Index erhoehen
@@ -168,10 +168,10 @@ void SwEditShell::RemoveFldType(sal_uInt16 nFld, sal_uInt16 nResId)
 void SwEditShell::RemoveFldType(sal_uInt16 nResId, const String& rStr)
 {
     const SwFldTypes* pFldTypes = GetDoc()->GetFldTypes();
-    const sal_uInt16 nSize = pFldTypes->Count();
+    const sal_uInt16 nSize = pFldTypes->size();
     const CharClass& rCC = GetAppCharClass();
 
-    String aTmp( rCC.lower( rStr ));
+    String aTmp( rCC.lowercase( rStr ));
 
     for(sal_uInt16 i = 0; i < nSize; ++i)
     {
@@ -179,7 +179,7 @@ void SwEditShell::RemoveFldType(sal_uInt16 nResId, const String& rStr)
         SwFieldType* pFldType = (*pFldTypes)[i];
         if( pFldType->Which() == nResId )
         {
-            if( aTmp.Equals( rCC.lower( pFldType->GetName() ) ))
+            if( aTmp.Equals( rCC.lowercase( pFldType->GetName() ) ))
             {
                 GetDoc()->RemoveFldType(i);
                 return;
@@ -432,13 +432,13 @@ void SwEditShell::ChgDBData(const SwDBData& rNewData)
     GetDoc()->ChgDBData(rNewData);
 }
 
-void SwEditShell::GetAllUsedDB( SvStringsDtor& rDBNameList,
-                                SvStringsDtor* pAllDBNames )
+void SwEditShell::GetAllUsedDB( std::vector<String>& rDBNameList,
+                                std::vector<String>* pAllDBNames )
 {
     GetDoc()->GetAllUsedDB( rDBNameList, pAllDBNames );
 }
 
-void SwEditShell::ChangeDBFields( const SvStringsDtor& rOldNames,
+void SwEditShell::ChangeDBFields( const std::vector<String>& rOldNames,
                                     const String& rNewName )
 {
     GetDoc()->ChangeDBFields( rOldNames, rNewName );
@@ -509,7 +509,7 @@ void SwEditShell::ChangeAuthorityData(const SwAuthEntry* pNewData)
 sal_Bool SwEditShell::IsAnyDatabaseFieldInDoc()const
 {
     const SwFldTypes * pFldTypes = GetDoc()->GetFldTypes();
-    const sal_uInt16 nSize = pFldTypes->Count();
+    const sal_uInt16 nSize = pFldTypes->size();
     for(sal_uInt16 i = 0; i < nSize; ++i)
     {
         SwFieldType& rFldType = *((*pFldTypes)[i]);
