@@ -49,6 +49,7 @@
 #include <shellres.hxx>
 #include <calc.hxx>
 #include <comcore.hrc>
+#include <docary.hxx>
 
 #include <math.h>
 
@@ -79,8 +80,7 @@ sal_uInt16 lcl_GetLanguageOfFormat( sal_uInt16 nLng, sal_uLong nFmt,
  --------------------------------------------------------------------*/
 // Array der Feldname
 
-SvStringsDtor* SwFieldType::pFldNames = 0;
-
+std::vector<String>* SwFieldType::pFldNames = 0;
 
     sal_uInt16 aTypeTab[] = {
     /* RES_DBFLD            */      TYP_DBFLD,
@@ -133,13 +133,12 @@ const String& SwFieldType::GetTypeStr(sal_uInt16 nTypeId)
     if( !pFldNames )
         _GetFldName();
 
-    if( nTypeId < SwFieldType::pFldNames->Count() )
-        return *SwFieldType::pFldNames->GetObject( nTypeId );
+    if( nTypeId < SwFieldType::pFldNames->size() )
+        return (*SwFieldType::pFldNames)[nTypeId];
     else
         return aEmptyStr;
 }
 
-
 /*---------------------------------------------------
  Jedes Feld referenziert einen Feldtypen, der fuer
  jedes Dokument einmalig ist.
@@ -151,9 +150,14 @@ SwFieldType::SwFieldType( sal_uInt16 nWhichId )
 {
 }
 
-const String& SwFieldType::GetName() const
+namespace
 {
-    return aEmptyStr;
+    rtl::OUString aEmptyOUStr;
+}
+
+const rtl::OUString& SwFieldType::GetName() const
+{
+    return aEmptyOUStr;
 }
 
 bool SwFieldType::QueryValue( uno::Any&, sal_uInt16 ) const
@@ -267,14 +271,14 @@ String SwField::GetFieldName() const
     Beschreibung: Parameter setzen auslesen
  --------------------------------------------------------------------*/
 
-const String& SwField::GetPar1() const
+const rtl::OUString& SwField::GetPar1() const
 {
-    return aEmptyStr;
+    return aEmptyOUStr;
 }
 
-String SwField::GetPar2() const
+rtl::OUString SwField::GetPar2() const
 {
-    return aEmptyStr;
+    return rtl::OUString();
 }
 
 String SwField::GetFormula() const
@@ -282,10 +286,10 @@ String SwField::GetFormula() const
     return GetPar2();
 }
 
-void SwField::SetPar1(const String& )
+void SwField::SetPar1(const rtl::OUString& )
 {}
 
-void SwField::SetPar2(const String& )
+void SwField::SetPar2(const rtl::OUString& )
 {}
 
 sal_uInt16 SwField::GetSubType() const
@@ -760,4 +764,16 @@ String SwField::GetDescription() const
     return SW_RES(STR_FIELD);
 }
 
+sal_uInt16 SwFldTypes::GetPos(const SwFieldType* pFieldType) const
+{
+    const_iterator it = std::find(begin(), end(), pFieldType);
+    return it == end() ? USHRT_MAX : it - begin();
+}
+
+SwFldTypes::~SwFldTypes()
+{
+    for(const_iterator it = begin(); it != end(); ++it)
+        delete *it;
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
