@@ -32,7 +32,6 @@
 #include <rtl/string.h>
 #include <rtl/memory.h>
 
-#include <rtl/string.h>
 #include <svx/svdogrp.hxx>
 #include <svx/svdundo.hxx>
 #include <svx/svdpage.hxx>
@@ -118,7 +117,7 @@ void SwSdrUndo::RedoImpl(::sw::UndoRedoContext & rContext)
     rContext.SetSelections(0, pMarkList);
 }
 
-String SwSdrUndo::GetComment() const
+rtl::OUString SwSdrUndo::GetComment() const
 {
     return pSdrUndo->GetComment();
 }
