@@ -26,7 +26,6 @@
  *
  ************************************************************************/
 
-
 #include <rtl/ustrbuf.hxx>
 #include <swtypes.hxx>
 #include <hintids.hxx>
@@ -47,7 +46,6 @@
 #include <sfx2/linkmgr.hxx>
 #include <docary.hxx>
 #include <paratr.hxx>
-#include <tools/urlobj.hxx>
 #include <pam.hxx>
 #include <tools/cachestr.hxx>
 #include <shellio.hxx>
@@ -107,8 +105,6 @@
 #include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
 #include <fmtflcnt.hxx>
-#define _SVSTDARR_USHORTS
-#define _SVSTDARR_XUB_STRLEN
 #include <svl/svstdarr.hxx>
 #include <editeng/brshitem.hxx>
 #include <fmtclds.hxx>
@@ -553,7 +549,7 @@ static char const*const g_ServicesParagraphEnum[] =
 };
 
 static const size_t g_nServicesParagraphEnum(
-    SAL_N_ELEMENTS(g_ServicesParagraphEnum));
+    sizeof(g_ServicesParagraphEnum)/sizeof(g_ServicesParagraphEnum[0]));
 
 sal_Bool SAL_CALL
 SwXParagraphEnumeration::supportsService(const OUString& rServiceName)
@@ -889,7 +885,7 @@ throw (uno::RuntimeException)
             m_pImpl->m_rDoc.DeleteAndJoin(aCursor);
         }
 
-        if (rText.getLength())
+        if (!rText.isEmpty())
         {
             SwUnoCursorHelper::DocInsertStringSplitCR(
                     m_pImpl->m_rDoc, aCursor, rText, bForceExpandHints);
@@ -938,7 +934,7 @@ static char const*const g_ServicesTextRange[] =
 };
 
 static const size_t g_nServicesTextRange(
-    SAL_N_ELEMENTS(g_ServicesTextRange));
+    sizeof(g_ServicesTextRange)/sizeof(g_ServicesTextRange[0]));
 
 sal_Bool SAL_CALL SwXTextRange::supportsService(const OUString& rServiceName)
 throw (uno::RuntimeException)
@@ -1315,7 +1311,7 @@ throw (uno::RuntimeException)
 {
     SolarMutexGuard g;
 
-    if (!rServiceName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.text.TextContent")))
+    if ( rServiceName != "com.sun.star.text.TextContent" )
     {
         throw uno::RuntimeException();
     }
@@ -1670,7 +1666,7 @@ static char const*const g_ServicesTextRanges[] =
 };
 
 static const size_t g_nServicesTextRanges(
-    SAL_N_ELEMENTS(g_ServicesTextRanges));
+    sizeof(g_ServicesTextRanges)/sizeof(g_ServicesTextRanges[0]));
 
 sal_Bool SAL_CALL SwXTextRanges::supportsService(const OUString& rServiceName)
 throw (uno::RuntimeException)
@@ -1731,7 +1727,7 @@ void SwUnoCursorHelper::SetString(SwCursor & rCursor, const OUString& rString)
     {
         pDoc->DeleteAndJoin(rCursor);
     }
-    if (rString.getLength())
+    if (!rString.isEmpty())
     {
         String aText(rString);
         const bool bSuccess( SwUnoCursorHelper::DocInsertStringSplitCR(
@@ -1895,9 +1891,9 @@ SwXParaFrameEnumeration::SwXParaFrameEnumeration(
             SwPosFlyFrms aFlyFrms;
             //get all frames that are bound at paragraph or at character
             rPaM.GetDoc()->GetAllFlyFmts(aFlyFrms, m_pImpl->GetCursor(), sal_False, sal_True);
-            for(sal_uInt16 i = 0; i < aFlyFrms.Count(); i++)
+            for(SwPosFlyFrms::iterator it = aFlyFrms.begin(); it != aFlyFrms.end(); ++it)
             {
-                SwPosFlyFrm* pPosFly = aFlyFrms[i];
+                SwPosFlyFrm* pPosFly = *it;
                 SwFrmFmt *const pFrmFmt =
                     const_cast<SwFrmFmt*>(&pPosFly->GetFmt());
                 // create SwDepend for frame and insert into array
@@ -1967,7 +1963,7 @@ static char const*const g_ServicesParaFrameEnum[] =
 };
 
 static const size_t g_nServicesParaFrameEnum(
-    SAL_N_ELEMENTS(g_ServicesParaFrameEnum));
+    sizeof(g_ServicesParaFrameEnum)/sizeof(g_ServicesParaFrameEnum[0]));
 
 sal_Bool SAL_CALL
 SwXParaFrameEnumeration::supportsService(const OUString& rServiceName)
