@@ -88,7 +88,7 @@ class SwTestAccountSettingsDialog : public SfxModalDialog
     bool                m_bStop;
 
     void                Test();
-    DECL_LINK(StopHdl, PushButton*);
+    DECL_LINK(StopHdl, void *);
     DECL_STATIC_LINK(SwTestAccountSettingsDialog, TestHdl, void*);
 public:
     SwTestAccountSettingsDialog(SwMailConfigPage* pParent);
@@ -129,9 +129,9 @@ class SwAuthenticationSettingsDialog : public SfxModalDialog
 
     SwMailMergeConfigItem& rConfigItem;
 
-    DECL_LINK( OKHdl_Impl, OKButton*);
+    DECL_LINK(OKHdl_Impl, void *);
     DECL_LINK( CheckBoxHdl_Impl, CheckBox*);
-    DECL_LINK( RadioButtonHdl_Impl, RadioButton*);
+    DECL_LINK(RadioButtonHdl_Impl, void *);
 
 
 public:
@@ -236,14 +236,14 @@ IMPL_LINK(SwMailConfigPage, ReplyToHdl, CheckBox*, pBox)
     return 0;
 }
 
-IMPL_LINK(SwMailConfigPage, AuthenticationHdl, PushButton*, EMPTYARG)
+IMPL_LINK_NOARG(SwMailConfigPage, AuthenticationHdl)
 {
     SwAuthenticationSettingsDialog aDlg(this, *m_pConfigItem);
     aDlg.Execute();
     return 0;
 }
 
-IMPL_LINK(SwMailConfigPage, TestHdl, PushButton*, EMPTYARG)
+IMPL_LINK_NOARG(SwMailConfigPage, TestHdl)
 {
     SwTestAccountSettingsDialog(this).Execute();
     return 0;
@@ -317,7 +317,7 @@ SwTestAccountSettingsDialog::~SwTestAccountSettingsDialog()
 {
 }
 
-IMPL_LINK(SwTestAccountSettingsDialog, StopHdl, PushButton*, EMPTYARG)
+IMPL_LINK_NOARG(SwTestAccountSettingsDialog, StopHdl)
 {
     m_bStop = true;
     return 0;
@@ -374,7 +374,7 @@ void SwTestAccountSettingsDialog::Test()
                         new SwConnectionContext(
                             m_pParent->m_pConfigItem->GetInServerName(),
                             m_pParent->m_pConfigItem->GetInServerPort(),
-                            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Insecure")));
+                            ::rtl::OUString("Insecure"));
                 xInMailService->connect(xConnectionContext, xAuthenticator);
             }
             if(m_bStop)
@@ -382,7 +382,7 @@ void SwTestAccountSettingsDialog::Test()
             uno::Reference<XAuthenticator> xAuthenticator;
             if(m_pParent->m_pConfigItem->IsAuthentication() &&
                     !m_pParent->m_pConfigItem->IsSMTPAfterPOP() &&
-                    m_pParent->m_pConfigItem->GetMailUserName().getLength())
+                    !m_pParent->m_pConfigItem->GetMailUserName().isEmpty())
                 xAuthenticator =
                     new SwAuthenticator(
                         m_pParent->m_pConfigItem->GetMailUserName(),
@@ -404,7 +404,7 @@ void SwTestAccountSettingsDialog::Test()
                     new SwConnectionContext(
                         m_pParent->m_aServerED.GetText(),
                         sal::static_int_cast< sal_Int16, sal_Int64 >(m_pParent->m_aPortNF.GetValue()),
-                        m_pParent->m_aSecureCB.IsChecked() ? OUString(RTL_CONSTASCII_USTRINGPARAM("Ssl")) : OUString(RTL_CONSTASCII_USTRINGPARAM("Insecure")));
+                        m_pParent->m_aSecureCB.IsChecked() ? OUString("Ssl") : OUString("Insecure"));
             xMailService->connect(xConnectionContext, xAuthenticator);
             bIsLoggedIn = xMailService->isConnected();
             if( xInMailService.is() )
@@ -522,7 +522,7 @@ SwAuthenticationSettingsDialog::~SwAuthenticationSettingsDialog()
 {
 }
 
-IMPL_LINK( SwAuthenticationSettingsDialog, OKHdl_Impl, OKButton*, EMPTYARG)
+IMPL_LINK_NOARG(SwAuthenticationSettingsDialog, OKHdl_Impl)
 {
     rConfigItem.SetAuthentication( m_aAuthenticationCB.IsChecked() );
     rConfigItem.SetSMTPAfterPOP(m_aSMTPAfterPOPRB.IsChecked());
@@ -548,7 +548,7 @@ IMPL_LINK( SwAuthenticationSettingsDialog, CheckBoxHdl_Impl, CheckBox*, pBox)
     return 0;
 }
 
-IMPL_LINK( SwAuthenticationSettingsDialog, RadioButtonHdl_Impl, RadioButton*, EMPTYARG)
+IMPL_LINK_NOARG(SwAuthenticationSettingsDialog, RadioButtonHdl_Impl)
 {
     sal_Bool bSeparate = m_aSeparateAuthenticationRB.IsChecked();
     sal_Bool bIsEnabled = m_aSeparateAuthenticationRB.IsEnabled();
