@@ -40,6 +40,7 @@
 #include <mmoutputpage.hxx>
 #include <mmconfigitem.hxx>
 #include <comphelper/processfactory.hxx>
+#include <comphelper/string.hxx>
 #include "com/sun/star/mail/XSmtpService.hpp"
 #include "com/sun/star/mail/MailServiceType.hpp"
 #include <rtl/ref.hxx>
@@ -107,7 +108,7 @@ SwMailMergeChildWin::~SwMailMergeChildWin()
 {
 }
 
-IMPL_LINK( SwMailMergeChildWin, BackHdl, ToolBox *, EMPTYARG )
+IMPL_LINK_NOARG(SwMailMergeChildWin, BackHdl)
 {
     GetBindings().GetDispatcher()->Execute(FN_MAILMERGE_WIZARD, SFX_CALLMODE_ASYNCHRON);
     return 0;
@@ -241,7 +242,7 @@ void SwMailDispatcherListener_Impl::DeleteAttachments( uno::Reference< mail::XMa
             {
                 ::rtl::OUString sURL;
                 xTransferableProperties->getPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("URL")) ) >>= sURL;
-                if(sURL.getLength())
+                if(!sURL.isEmpty())
                     SWUnoHelper::UCB_DeleteFile( sURL );
             }
         }
@@ -425,7 +426,7 @@ void lcl_Move(Control& rCtrl, long nYOffset)
     rCtrl.SetPosPixel(aPos);
 }
 
-IMPL_LINK( SwSendMailDialog, DetailsHdl_Impl, PushButton*, EMPTYARG )
+IMPL_LINK_NOARG(SwSendMailDialog, DetailsHdl_Impl)
 {
     long nMove = 0;
     if(m_aStatusLB.IsVisible())
@@ -471,7 +472,7 @@ IMPL_LINK( SwSendMailDialog, StopHdl_Impl, PushButton*, pButton )
     return 0;
 }
 
-IMPL_LINK( SwSendMailDialog, CloseHdl_Impl, PushButton*, EMPTYARG )
+IMPL_LINK_NOARG(SwSendMailDialog, CloseHdl_Impl)
 {
     ModelessDialog::Show( sal_False );
     return 0;
@@ -578,7 +579,7 @@ void  SwSendMailDialog::IterateMails()
         pMessage->addRecipient( pCurrentMailDescriptor->sEMail );
         pMessage->SetSenderName( m_pConfigItem->GetMailDisplayName() );
         pMessage->SetSenderAddress( m_pConfigItem->GetMailAddress() );
-        if(pCurrentMailDescriptor->sAttachmentURL.getLength())
+        if(!pCurrentMailDescriptor->sAttachmentURL.isEmpty())
         {
             mail::MailAttachment aAttach;
             aAttach.Data =
@@ -597,10 +598,10 @@ void  SwSendMailDialog::IterateMails()
         pMessage->setBody( xBody );
 
         //CC and BCC are tokenized by ';'
-        if(pCurrentMailDescriptor->sCC.getLength())
+        if(!pCurrentMailDescriptor->sCC.isEmpty())
         {
             String sTokens( pCurrentMailDescriptor->sCC );
-            sal_uInt16 nTokens = sTokens.GetTokenCount( ';' );
+            sal_uInt16 nTokens = comphelper::string::getTokenCount(sTokens, ';');
             xub_StrLen nPos = 0;
             for( sal_uInt16 nToken = 0; nToken < nTokens; ++nToken)
             {
@@ -609,10 +610,10 @@ void  SwSendMailDialog::IterateMails()
                     pMessage->addCcRecipient( sTmp );
             }
         }
-        if(pCurrentMailDescriptor->sBCC.getLength())
+        if(!pCurrentMailDescriptor->sBCC.isEmpty())
         {
             String sTokens( pCurrentMailDescriptor->sBCC );
-            sal_uInt16 nTokens = sTokens.GetTokenCount( ';' );
+            sal_uInt16 nTokens = comphelper::string::getTokenCount(sTokens, ';');
             xub_StrLen nPos = 0;
             for( sal_uInt16 nToken = 0; nToken < nTokens; ++nToken)
             {
