@@ -38,8 +38,6 @@
 #include <svl/macitem.hxx>
 #include <sfx2/fcontnr.hxx>
 #include <sfx2/docfile.hxx>
-#define _SVSTDARR_STRINGS
-#include <svl/svstdarr.hxx>
 #include <svl/urihelper.hxx>
 #include <unotools/transliterationwrapper.hxx>
 #include <poolfmt.hxx>
@@ -83,9 +81,7 @@ struct TextBlockInfo_Impl
     String sLongName;
     String sGroupName;
 };
-typedef TextBlockInfo_Impl* TextBlockInfo_ImplPtr;
-SV_DECL_PTRARR_DEL( TextBlockInfoArr, TextBlockInfo_ImplPtr, 0, 4 )
-SV_IMPL_PTRARR( TextBlockInfoArr, TextBlockInfo_ImplPtr )
+typedef boost::ptr_vector<TextBlockInfo_Impl> TextBlockInfoArr;
 SV_IMPL_REF( SwDocShell )
 
 /*------------------------------------------------------------------------
@@ -138,13 +134,14 @@ void SwGlossaryHdl::SetCurGroup(const String &rGrp, sal_Bool bApi, sal_Bool bAlw
             String sCurBase = aTemp.getBase();
             aTemp.removeSegment();
             const String sCurEntryPath = aTemp.GetMainURL(INetURLObject::NO_DECODE);
-            const SvStrings* pPathArr = rStatGlossaries.GetPathArray();
+            const std::vector<String> & rPathArr =
+                rStatGlossaries.GetPathArray();
             sal_uInt16 nCurrentPath = USHRT_MAX;
-            for(sal_uInt16 nPath = 0; nPath < pPathArr->Count(); nPath++)
+            for (size_t nPath = 0; nPath < rPathArr.size(); ++nPath)
             {
-                if(sCurEntryPath == *(*pPathArr)[nPath])
+                if (sCurEntryPath == rPathArr[nPath])
                 {
-                    nCurrentPath = nPath;
+                    nCurrentPath = static_cast<sal_uInt16>(nPath);
                     break;
                 }
             }
@@ -467,17 +464,17 @@ sal_Bool SwGlossaryHdl::Expand( const String& rShortName,
                         pData->sTitle = sTitle;
                         pData->sLongName = sLongName;
                         pData->sGroupName = sGroupName;
-                        aFoundArr.Insert(pData, aFoundArr.Count());
+                        aFoundArr.push_back(pData);
                     }
                 }
             }
         }
-        if( aFoundArr.Count() )  // one was found
+        if( !aFoundArr.empty() )  // one was found
         {
             pGlossaries->PutGroupDoc(pGlossary);
-            if(1 == aFoundArr.Count())
+            if(1 == aFoundArr.size())
             {
-                TextBlockInfo_Impl* pData = aFoundArr.GetObject(0);
+                TextBlockInfo_Impl* pData = &aFoundArr.front();
                 pGlossary = (SwTextBlocks *)pGlossaries->GetGroupDoc(pData->sGroupName);
                 nFound = pGlossary->GetIndex( aShortName );
             }
@@ -488,9 +485,9 @@ sal_Bool SwGlossaryHdl::Expand( const String& rShortName,
 
                 AbstractSwSelGlossaryDlg* pDlg = pFact->CreateSwSelGlossaryDlg( 0, aShortName, DLG_SEL_GLOS );
                 OSL_ENSURE(pDlg, "Dialogdiet fail!");
-                for(sal_uInt16 i = 0; i < aFoundArr.Count(); ++i)
+                for(sal_uInt16 i = 0; i < aFoundArr.size(); ++i)
                 {
-                    TextBlockInfo_Impl* pData = aFoundArr.GetObject(i);
+                    TextBlockInfo_Impl* pData = &aFoundArr[i];
                     pDlg->InsertGlos(pData->sTitle, pData->sLongName);
                 }
                 pDlg->SelectEntryPos(0);
@@ -500,7 +497,7 @@ sal_Bool SwGlossaryHdl::Expand( const String& rShortName,
                 delete pDlg;
                 if(LISTBOX_ENTRY_NOTFOUND != nRet)
                 {
-                    TextBlockInfo_Impl* pData = aFoundArr.GetObject(nRet);
+                    TextBlockInfo_Impl* pData = &aFoundArr[nRet];
                     pGlossary = (SwTextBlocks *)pGlossaries->GetGroupDoc(pData->sGroupName);
                     nFound = pGlossary->GetIndex( aShortName );
                 }
@@ -545,7 +542,7 @@ sal_Bool SwGlossaryHdl::Expand( const String& rShortName,
     // API-programs would hang.
     // Moreover the event macro must also not be called in an action
         pWrtShell->StartUndo(UNDO_INSGLOSSARY);
-        if( aStartMacro.GetMacName().Len() )
+        if( aStartMacro.HasMacro() )
             pWrtShell->ExecMacro( aStartMacro );
         if(pWrtShell->HasSelection())
             pWrtShell->DelLeft();
@@ -556,7 +553,7 @@ sal_Bool SwGlossaryHdl::Expand( const String& rShortName,
 
         pWrtShell->InsertGlossary(*pGlossary, aShortName);
         pWrtShell->EndAllAction();
-        if( aEndMacro.GetMacName().Len() )
+        if( aEndMacro.HasMacro() )
         {
             pWrtShell->ExecMacro( aEndMacro );
         }
@@ -591,7 +588,7 @@ sal_Bool SwGlossaryHdl::InsertGlossary(const String &rName)
     // otherwise the possible Shell change gets delayed and
     // API-programs would hang.
     // Moreover the event macro must also not be called in an action
-    if( aStartMacro.GetMacName().Len() )
+    if( aStartMacro.HasMacro() )
         pWrtShell->ExecMacro( aStartMacro );
     if( pWrtShell->HasSelection() )
         pWrtShell->DelRight();
@@ -602,7 +599,7 @@ sal_Bool SwGlossaryHdl::InsertGlossary(const String &rName)
 
     pWrtShell->InsertGlossary(*pGlos, rName);
     pWrtShell->EndAllAction();
-    if( aEndMacro.GetMacName().Len() )
+    if( aEndMacro.HasMacro() )
     {
         pWrtShell->ExecMacro( aEndMacro );
     }
@@ -629,9 +626,9 @@ void SwGlossaryHdl::SetMacros(const String& rShortName,
                                   : rStatGlossaries.GetGroupDoc( aCurGrp );
     SvxMacroTableDtor aMacroTbl;
     if( pStart )
-        aMacroTbl.Insert( SW_EVENT_START_INS_GLOSSARY, new SvxMacro(*pStart));
+        aMacroTbl.Insert( SW_EVENT_START_INS_GLOSSARY, *pStart);
     if( pEnd )
-        aMacroTbl.Insert( SW_EVENT_END_INS_GLOSSARY, new SvxMacro(*pEnd));
+        aMacroTbl.Insert( SW_EVENT_END_INS_GLOSSARY, *pEnd);
     sal_uInt16 nIdx = pGlos->GetIndex( rShortName );
     if( !pGlos->SetMacroTable( nIdx, aMacroTbl ) && pGlos->GetError() )
         ErrorHandler::HandleError( pGlos->GetError() );
@@ -778,7 +775,7 @@ sal_Bool SwGlossaryHdl::ImportGlossaries( const String& rName )
     if( rName.Len() )
     {
         const SfxFilter* pFilter = 0;
-        SfxMedium* pMed = new SfxMedium( rName, STREAM_READ, sal_True, 0, 0 );
+        SfxMedium* pMed = new SfxMedium( rName, STREAM_READ, 0, 0 );
         SfxFilterMatcher aMatcher( String::CreateFromAscii("swriter") );
         pMed->UseInteractionHandler( sal_True );
         if( !aMatcher.GuessFilter( *pMed, &pFilter, sal_False ) )
