@@ -935,8 +935,9 @@ bool SwPostItMgr::LayoutByPage(std::list<SwSidebarWin*> &aVisiblePostItList,cons
     long            lTopBorder      = rBorder.Top() + 5;
     long            lBottomBorder   = rBorder.Bottom() - 5;
     const long      lVisibleHeight  = lBottomBorder - lTopBorder; //rBorder.GetHeight() ;
+    long            lSpaceUsed = 0;
     long            lTranslatePos   = 0;
-    bool            bDone           = false;
+    int             loop = 0;
     bool            bScrollbars     = false;
 
     // do all neccessary resizings
@@ -965,8 +966,7 @@ bool SwPostItMgr::LayoutByPage(std::list<SwSidebarWin*> &aVisiblePostItList,cons
     //start the real layout so nothing overlaps anymore
     if (aVisiblePostItList.size()>1)
     {
-        long lSpaceUsed = 0;
-        int  loop = 0;
+        bool bDone = false;
         // if no window is moved anymore we are finished
         while (!bDone)
         {
@@ -1146,7 +1146,7 @@ void SwPostItMgr::Delete(String aAuthor)
     SwRewriter aRewriter;
     String aUndoString = SW_RES(STR_DELETE_AUTHOR_NOTES);
     aUndoString += aAuthor;
-    aRewriter.AddRule(UNDO_ARG1, aUndoString);
+    aRewriter.AddRule(UndoArg1, aUndoString);
     mpWrtShell->StartUndo( UNDO_DELETE, &aRewriter );
 
     std::vector<SwFmtFld*> aTmp;
@@ -1174,7 +1174,7 @@ void SwPostItMgr::Delete()
     mpWrtShell->StartAllAction();
     SetActiveSidebarWin(0);
     SwRewriter aRewriter;
-    aRewriter.AddRule(UNDO_ARG1, SW_RES(STR_DELETE_ALL_NOTES) );
+    aRewriter.AddRule(UndoArg1, SW_RES(STR_DELETE_ALL_NOTES) );
     mpWrtShell->StartUndo( UNDO_DELETE, &aRewriter );
 
     std::vector<SwFmtFld*> aTmp;
@@ -1582,7 +1582,7 @@ Color SwPostItMgr::GetColorDark(sal_uInt16 aAuthorIndex)
             COL_AUTHOR4_NORMAL,     COL_AUTHOR5_NORMAL,     COL_AUTHOR6_NORMAL,
             COL_AUTHOR7_NORMAL,     COL_AUTHOR8_NORMAL,     COL_AUTHOR9_NORMAL };
 
-        return Color( aArrayNormal[ aAuthorIndex % (SAL_N_ELEMENTS(aArrayNormal))]);
+        return Color( aArrayNormal[ aAuthorIndex % (sizeof( aArrayNormal )/ sizeof( aArrayNormal[0] ))]);
     }
     else
         return Color(COL_WHITE);
@@ -1597,7 +1597,7 @@ Color SwPostItMgr::GetColorLight(sal_uInt16 aAuthorIndex)
             COL_AUTHOR4_LIGHT,      COL_AUTHOR5_LIGHT,      COL_AUTHOR6_LIGHT,
             COL_AUTHOR7_LIGHT,      COL_AUTHOR8_LIGHT,      COL_AUTHOR9_LIGHT };
 
-        return Color( aArrayLight[ aAuthorIndex % (SAL_N_ELEMENTS(aArrayLight))]);
+        return Color( aArrayLight[ aAuthorIndex % (sizeof( aArrayLight )/ sizeof( aArrayLight[0] ))]);
     }
     else
         return Color(COL_WHITE);
@@ -1612,7 +1612,7 @@ Color SwPostItMgr::GetColorAnchor(sal_uInt16 aAuthorIndex)
             COL_AUTHOR4_DARK,       COL_AUTHOR5_DARK,       COL_AUTHOR6_DARK,
             COL_AUTHOR7_DARK,       COL_AUTHOR8_DARK,       COL_AUTHOR9_DARK };
 
-        return Color( aArrayAnchor[  aAuthorIndex % (SAL_N_ELEMENTS(aArrayAnchor))]);
+        return Color( aArrayAnchor[  aAuthorIndex % (sizeof( aArrayAnchor )  / sizeof( aArrayAnchor[0] ))]);
     }
     else
         return Color(COL_WHITE);
