@@ -26,8 +26,9 @@
  *
  ************************************************************************/
 
+#include "sal/config.h"
 
-
+#include <officecfg/Office/Common.hxx>
 #include <tools/gen.hxx>
 #include <sfx2/imgmgr.hxx>
 #include <sfx2/viewfrm.hxx>
@@ -35,7 +36,6 @@
 #include <svx/ruler.hxx>
 #include <svl/zforlist.hxx>
 #include <svl/stritem.hxx>
-#include <unotools/undoopt.hxx>
 
 #include "swtypes.hxx"
 #include "cmdid.h"
@@ -74,7 +74,6 @@ SwInputWindow::SwInputWindow( Window* pParent, SfxBindings* pBind )
     pView(0),
     pBindings(pBind),
     aAktTableName(aEmptyStr)
-    , m_nActionCount(0)
     , m_bDoesUndo(true)
     , m_bResetUndo(false)
     , m_bCallUndo(false)
@@ -158,10 +157,6 @@ void SwInputWindow::CleanupUglyHackWithUndo()
         {
             pWrtShell->Undo();
         }
-        if (0 == m_nActionCount)
-        {
-            SW_MOD()->GetUndoOptions().SetUndoCount(0);
-        }
         m_bResetUndo = false; // #i117122# once is enough :)
     }
 }
@@ -246,10 +241,9 @@ void SwInputWindow::ShowWin()
             if( bIsTable )
             {
                 m_bResetUndo = true;
-                m_nActionCount = SW_MOD()->GetUndoOptions().GetUndoCount();
-                if (0 == m_nActionCount) { // deactivated? turn it on...
-                    SW_MOD()->GetUndoOptions().SetUndoCount(1);
-                }
+                SAL_WARN_IF(
+                    officecfg::Office::Common::Undo::Steps::get() <= 0,
+                    "sw", "/org.openoffice.Office.Common/Undo/Steps <= 0");
 
                 m_bDoesUndo = pWrtShell->DoesUndo();
                 if( !m_bDoesUndo )
@@ -348,7 +342,7 @@ static const char * const aStrArr[] = {
     return 0;
 }
 
-IMPL_LINK( SwInputWindow, DropdownClickHdl, ToolBox*, EMPTYARG )
+IMPL_LINK_NOARG(SwInputWindow, DropdownClickHdl)
 {
     sal_uInt16 nCurID = GetCurItemId();
     EndSelection(); // setzt CurItemId zurueck !
@@ -496,7 +490,7 @@ void SwInputWindow::SetFormula( const String& rFormula, sal_Bool bDelFlag )
     bDelSel = bDelFlag;
 }
 
-IMPL_LINK( SwInputWindow, ModifyHdl, InputEdit*, EMPTYARG )
+IMPL_LINK_NOARG(SwInputWindow, ModifyHdl)
 {
     if (bIsTable && m_bResetUndo)
     {
