@@ -513,8 +513,7 @@ void SwFrameShell::Execute(SfxRequest &rReq)
             if(pArgs && SFX_ITEM_SET == pArgs->GetItemState(GetPool().GetWhich(nSlot), sal_False, &pItem))
             {
                 aMgr.SetAttrSet( *pArgs );
-                if(SID_ATTR_ULSPACE == nSlot && SID_ATTR_ULSPACE == nSlot)
-                    bCopyToFmt = sal_True;
+                bCopyToFmt = sal_True;
             }
         }
         break;
@@ -1096,12 +1095,15 @@ void SwFrameShell::ExecFrameStyle(SfxRequest& rReq)
 
                     if(aBorderLine.GetOutWidth() == 0)
                     {
-                        aBorderLine.SetStyle( ::editeng::SOLID );
+                        aBorderLine.SetBorderLineStyle(
+                                table::BorderLineStyle::SOLID);
                         aBorderLine.SetWidth( DEF_LINE_WIDTH_0 );
                     }
                     //Distance nur setzen, wenn der Request vom Controller kommt
 
+#ifndef DISABLE_SCRIPTING
                     if(!StarBASIC::IsRunning())
+#endif
                     {
                         aNewBox.SetDistance( rBoxItem.GetDistance() );
                     }
@@ -1228,7 +1230,7 @@ void lcl_FrmGetMaxLineWidth(const SvxBorderLine* pBorderLine, SvxBorderLine& rBo
     if(pBorderLine->GetWidth() > rBorderLine.GetWidth())
         rBorderLine.SetWidth(pBorderLine->GetWidth());
 
-    rBorderLine.SetStyle(pBorderLine->GetStyle());
+    rBorderLine.SetBorderLineStyle(pBorderLine->GetBorderLineStyle());
     rBorderLine.SetColor(pBorderLine->GetColor());
 }
 
