@@ -52,6 +52,8 @@
 
 #include <IDocumentSettingAccess.hxx>
 
+#include <basegfx/tools/zoomtools.hxx>
+
 //Das SetVisArea der DocShell darf nicht vom InnerResizePixel gerufen werden.
 //Unsere Einstellungen muessen aber stattfinden.
 #ifndef WB_RIGHT_ALIGNED
@@ -831,16 +833,14 @@ void SwView::CalcAndSetBorderPixel( SvBorder &rToFill, sal_Bool /*bInner*/ )
 
     const StyleSettings &rSet = GetEditWin().GetSettings().GetStyleSettings();
     const long nTmp = rSet.GetScrollBarSize();
-    if( pVScrollbar->IsVisible(sal_False) )
+    if( pVScrollbar->IsVisible(sal_True) )
     {
         if(bRightVRuler)
             rToFill.Left() = nTmp;
         else
             rToFill.Right()  = nTmp;
     }
-    //#i32913# in browse mode the visibility of the horizontal scrollbar
-    // depends on the content (fixed width tables may require a scrollbar)
-    if ( pHScrollbar->IsVisible(pWrtShell->GetViewOptions()->getBrowseMode()) )
+    if ( pHScrollbar->IsVisible(sal_True) )
         rToFill.Bottom() = nTmp;
 
     SetBorderPixel( rToFill );
@@ -870,13 +870,10 @@ void ViewResizePixel( const Window &rRef,
     const sal_Bool bVLineal = pVLineal && pVLineal->IsVisible();
     const long nVLinSzWidth = bVLineal ?
                         pVLineal->GetSizePixel().Width() : 0;
-    long nHBSzHeight2= rHScrollbar.IsVisible( sal_False ) || !rHScrollbar.IsAuto() ?
-                       rRef.GetSettings().GetStyleSettings().GetScrollBarSize() : 0;
-    long nHBSzHeight =
-                rHScrollbar.IsVisible(sal_True) ||  (rHScrollbar.IsVisible( sal_False ) && !rHScrollbar.IsAuto()) ?
-                                nHBSzHeight2:0;
-    long nVBSzWidth = rVScrollbar.IsVisible(sal_True) ||  (rVScrollbar.IsVisible( sal_False ) && !rVScrollbar.IsAuto()) ?
-                         rRef.GetSettings().GetStyleSettings().GetScrollBarSize() : 0;
+
+    long nScrollBarSize = rRef.GetSettings().GetStyleSettings().GetScrollBarSize();
+    long nHBSzHeight = rHScrollbar.IsVisible(true) ? nScrollBarSize : 0;
+    long nVBSzWidth = rVScrollbar.IsVisible(true) ? nScrollBarSize : 0;
 
     if(pVLineal)
     {
@@ -920,7 +917,7 @@ void ViewResizePixel( const Window &rRef,
             aPos.X() += nVBSzWidth;
         }
 
-        Size  aSize( rSize.Width(), nHBSzHeight2 );
+        Size  aSize( rSize.Width(), nHBSzHeight );
         if ( nVBSzWidth )
             aSize.Width() -= nVBSzWidth;
         rHScrollbar.SetPosSizePixel( aPos, aSize );
@@ -968,15 +965,10 @@ void ViewResizePixel( const Window &rRef,
         aPos.Y() += aImgSz.Height();
         pPageDownBtn->SetPosSizePixel( aPos, aImgSz );
 
-
-        if( rHScrollbar.IsVisible( sal_False ) )
-        {
-            aScrollFillPos.X() = aPos.X();
-
-            rScrollBarBox.SetPosSizePixel( aScrollFillPos,
-                                         Size( nHBSzHeight, nVBSzWidth) );
-        }
+        aScrollFillPos.X() = aPos.X();
     }
+
+    rScrollBarBox.SetPosSizePixel( aScrollFillPos, Size( nHBSzHeight, nVBSzWidth) );
 }
 
 void SwView::ShowAtResize()
@@ -1076,36 +1068,27 @@ void SwView::OuterResizePixel( const Point &rOfst, const Size &rSize )
     bInOuterResizePixel = sal_True;
 
 // feststellen, ob Scrollbars angezeigt werden duerfen
-    sal_Bool bBrowse = pWrtShell->GetViewOptions()->getBrowseMode();
-    sal_Bool bShowH = sal_False,
-         bShowV = sal_False,
-         bAuto  = sal_False,
-         bHAuto = bBrowse;
-    switch( GetScrollingMode() )
+    sal_Bool bShowH = sal_True,
+         bShowV = sal_True,
+         bAuto  = sal_True,
+         bHAuto = sal_True;
+
+    const SwViewOption *pVOpt = pWrtShell->GetViewOptions();
+    if ( !pVOpt->IsReadonly() || pVOpt->IsStarOneSetting() )
     {
-    case SCROLLING_DEFAULT:
-        {
-            const SwViewOption *pVOpt = pWrtShell->GetViewOptions();
-            if ( !pVOpt->IsReadonly() || pVOpt->IsStarOneSetting() )
-            {
-                bShowH = pVOpt->IsViewHScrollBar();
-                bShowV = pVOpt->IsViewVScrollBar();
-                bAuto = bHAuto = sal_True;
-                break;
-            }
-        }
-        /* kein break hier */
-    case SCROLLING_AUTO:
-        bAuto = bHAuto = sal_True;
-        bShowH = bShowV = sal_True;
-        break;
-    case SCROLLING_YES:
-        bShowH = bShowV = sal_True;
-        break;
-    case SCROLLING_NO:
-        bShowH = bShowV = bHAuto = sal_False;
-        break;
+        bShowH = pVOpt->IsViewHScrollBar();
+        bShowV = pVOpt->IsViewVScrollBar();
     }
+
+    if (!mbHScrollbarEnabled)
+    {
+        bHAuto = bShowH = false;
+    }
+    if (!mbVScrollbarEnabled)
+    {
+        bAuto = bShowV = false;
+    }
+
     SwDocShell* pDocSh = GetDocShell();
     sal_Bool bIsPreview = pDocSh->IsPreview();
     if( bIsPreview )
@@ -1307,11 +1290,11 @@ sal_Bool SwView::HandleWheelCommands( const CommandEvent& rCEvt )
     const CommandWheelData* pWData = rCEvt.GetWheelData();
     if( pWData && COMMAND_WHEEL_ZOOM == pWData->GetMode() )
     {
-        sal_uInt16 nFact = pWrtShell->GetViewOptions()->GetZoom();
+        long nFact = pWrtShell->GetViewOptions()->GetZoom();
         if( 0L > pWData->GetDelta() )
-            nFact = static_cast< sal_uInt16 >(Max( 20, nFact - 10 ));
+            nFact = Max( (long) 20, basegfx::zoomtools::zoomOut( nFact ));
         else
-            nFact = static_cast< sal_uInt16 >(Min( 600, nFact + 10 ));
+            nFact = Min( (long) 600, basegfx::zoomtools::zoomIn( nFact ));
 
         SetZoom( SVX_ZOOM_PERCENT, nFact );
         bOk = sal_True;
