@@ -100,7 +100,7 @@ static bool check( bool b , char const * message )
 namespace {
 
 bool checkEmpty(rtl::OUString const & string, char const * message) {
-    bool ok = string.getLength() == 0;
+    bool ok = string.isEmpty();
     if (!ok) {
         fprintf(
             stderr, "%s failed: %s\n", message,
@@ -592,13 +592,11 @@ static sal_Bool performTest(
                 bRet &= check(v0 == 33, "transportPolySequence, element 0");
                 rtl::OUString v1;
                 tps3.member[1] >>= v1;
-                bRet &= check(
-                    v1.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("ABC")),
-                    "transportPolySequence, element 1");
+                bRet &= check( v1 == "ABC", "transportPolySequence, element 1" );
                 bRet &= check(
                     xLBT->getNullPolyLong().member == 0, "getNullPolyLong");
                 bRet &= check(
-                    xLBT->getNullPolyString().member.getLength() == 0,
+                    xLBT->getNullPolyString().member.isEmpty(),
                     "getNullPolyString");
                 bRet &= check(
                     xLBT->getNullPolyType().member == Type(),
@@ -1068,8 +1066,10 @@ uno_Sequence* cloneSequence(const uno_Sequence* val, const Type& type)
         Type _tElem(pTdElem->pWeakRef);
         for (int i = 0; i < val->nElements; i++)
         {
+            sal_Int8 *pValBuf = (sal_Int8 *)(&val->elements + i * pTdElem->nSize);
+
             uno_Sequence* seq = cloneSequence(
-                *(uno_Sequence**) (&val->elements + i * pTdElem->nSize),
+                *(uno_Sequence**) (pValBuf),
                 _tElem);
             *((uno_Sequence**) pBufCur) = seq;
             pBufCur += pTdElem->nSize;
@@ -1181,16 +1181,13 @@ sal_Int32 TestBridgeImpl::run( const Sequence< OUString > & rArgs )
             i = 1;
         }
         bool noCurrentContext = false;
-        if (i < rArgs.getLength()
-            && rArgs[i].equalsAsciiL(
-                RTL_CONSTASCII_STRINGPARAM("noCurrentContext")))
+        if ( i < rArgs.getLength() && rArgs[i] == "noCurrentContext" )
         {
             noCurrentContext = true;
             ++i;
         }
         bool stress = false;
-        if (i < rArgs.getLength()
-            && rArgs[i].equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("stress")))
+        if ( i < rArgs.getLength() && rArgs[i] == "stress" )
         {
             stress = true;
             ++i;
@@ -1302,7 +1299,8 @@ extern "C"
 {
 //==================================================================================================
 SAL_DLLPUBLIC_EXPORT void * SAL_CALL component_getFactory(
-    const sal_Char * pImplName, void * pServiceManager, void * )
+    const sal_Char * pImplName, void * pServiceManager,
+    SAL_UNUSED_PARAMETER void * )
 {
     void * pRet = 0;
 
