@@ -41,7 +41,6 @@ namespace skeletonmaker { namespace cpp {
 
 void generateIncludes(std::ostream & o,
          const boost::unordered_set< OString, OStringHash >& interfaces,
-         const AttributeInfo& /*properties*/,
          OString propertyhelper, bool serviceobject,
          bool supportxcomponent)
 {
@@ -155,8 +154,8 @@ void generateCompHelperDefinition(std::ostream & o,
     short nbrackets = generateNamespace(o, implname, true, nm);
 
     o << "::rtl::OUString SAL_CALL _getImplementationName() {\n"
-      << "    return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(\n"
-      << "        \"" << implname << "\"));\n}\n\n";
+      << "    return ::rtl::OUString(\n"
+      << "        \"" << implname << "\");\n}\n\n";
 
     o << "css::uno::Sequence< ::rtl::OUString > SAL_CALL "
         "_getSupportedServiceNames()\n{\n    css::uno::Sequence< "
@@ -166,9 +165,8 @@ void generateCompHelperDefinition(std::ostream & o,
     short i=0;
     while (iter != services.end())
     {
-        o << "    s[" << i++ << "] = ::rtl::OUString("
-          << "RTL_CONSTASCII_USTRINGPARAM(\n        \""
-          << (*iter).replace('/','.') << "\"));\n";
+        o << "    s[" << i++ << "] = ::rtl::OUString(\""
+          << (*iter).replace('/','.') << "\");\n";
         ++iter;
     }
     o << "    return s;\n}\n\n";
@@ -333,7 +331,7 @@ void generateXAddInBodies(std::ostream& o, const OString & classname)
         "::rtl::OUString(),\n                                           "
         "sDISPLAYNAME);\n            if (sDisplayName.equals(aDisplayName))\n"
         "                return functions[i];\n        }\n    }\n"
-        "     catch ( css::uno::RuntimeException & e ) {\n        throw e;\n    }\n"
+        "     catch ( const css::uno::RuntimeException & e ) {\n        throw e;\n    }\n"
         "     catch ( css::uno::Exception & ) {\n    }\n    return ret;\n}\n\n";
 
     o << "::rtl::OUString SAL_CALL " << classname << "getDisplayFunctionName(const "
@@ -406,7 +404,7 @@ void generateXCompatibilityNamesBodies(std::ostream& o, const OString & classnam
         "                } while ( nIndex >= 0 );\n\n                "
         "seqLocalizedNames[i].Locale = aLocale;\n                "
         "seqLocalizedNames[i].Name = sCompatibilityName;\n            }"
-        "\n        }\n    }\n    catch ( css::uno::RuntimeException & e ) {\n        "
+        "\n        }\n    }\n    catch ( const css::uno::RuntimeException & e ) {\n        "
         "throw e;\n    }\n    catch ( css::uno::Exception & ) {\n    }\n\n"
         "    return seqLocalizedNames;\n}\n\n";
 }
@@ -525,21 +523,20 @@ void generateAddinConstructorAndHelper(std::ostream& o,
 
         o << "        css::uno::Reference< css::lang::XMultiServiceFactory > xProvider"
             "(\n             m_xContext->getServiceManager()->createInstanceWithContext"
-            "(\n                 ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(\n    "
-            "                 \"com.sun.star.configuration.ConfigurationProvider\")),"
+            "(\n                 ::rtl::OUString(\n    "
+            "                 \"com.sun.star.configuration.ConfigurationProvider\"),"
             "\n                 m_xContext ), css::uno::UNO_QUERY );\n\n";
 
         o << "        ::rtl::OUString sReadOnlyView(\n"
-            "            RTL_CONSTASCII_USTRINGPARAM(\n"
-            "                \"com.sun.star.configuration.ConfigurationAccess\"));\n\n";
+            "                \"com.sun.star.configuration.ConfigurationAccess\");\n\n";
 
-        o << "        ::rtl::OUStringBuffer sPath(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(\n"
-            "             \"/org.openoffice.Office.CalcAddIns/AddInInfo/\")));\n"
+        o << "        ::rtl::OUStringBuffer sPath(::rtl::OUString(\n"
+            "             \"/org.openoffice.Office.CalcAddIns/AddInInfo/\"));\n"
             "        sPath.appendAscii(sADDIN_SERVICENAME);\n"
             "        sPath.appendAscii(\"/AddInFunctions\");\n\n"
             "        // create arguments: nodepath\n"
             "        css::beans::PropertyValue aArgument;\n"
-            "        aArgument.Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(\"nodepath\"));\n"
+            "        aArgument.Name = ::rtl::OUString(\"nodepath\");\n"
             "        aArgument.Value <<= sPath.makeStringAndClear();\n\n"
             "        css::uno::Sequence< css::uno::Any > aArguments(1);\n"
             "        aArguments[0] <<= aArgument;\n\n";
@@ -554,8 +551,8 @@ void generateAddinConstructorAndHelper(std::ostream& o,
 
         o << "        // extend arguments to create a view for all locales to get "
             "simple\n        // access to the compatibilityname property\n"
-            "        aArgument.Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(\"locale\"));\n"
-            "        aArgument.Value <<= ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(\"*\"));\n"
+            "        aArgument.Name = ::rtl::OUString(\"locale\");\n"
+            "        aArgument.Value <<= ::rtl::OUString(\"*\");\n"
             "        aArguments.realloc(2);\n"
             "        aArguments[1] <<= aArgument;\n\n"
             "        // create view for all locales\n"
@@ -572,15 +569,15 @@ void generateAddinConstructorAndHelper(std::ostream& o,
             "throw (css::uno::RuntimeException)\n{\n"
             "    ::rtl::OUString ret;\n    try {\n        "
             "::rtl::OUStringBuffer buf(funcName);\n"
-            "        if (paramName.getLength() > 0) {\n"
+            "        if (!paramName.isEmpty()) {\n"
             "            buf.appendAscii(\"/Parameters/\");\n"
             "            buf.append(paramName);\n        }\n\n"
             "        css::uno::Reference< css::beans::XPropertySet > xPropSet(\n"
             "            m_xHAccess->getByHierarchicalName(\n"
             "                buf.makeStringAndClear()), css::uno::UNO_QUERY);\n"
             "        xPropSet->getPropertyValue(\n            "
-            "::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(propName))) >>= ret;\n    }\n"
-            "     catch ( css::uno::RuntimeException & e ) {\n        throw e;\n    }\n"
+            "::rtl::OUString(propName)) >>= ret;\n    }\n"
+            "     catch ( const css::uno::RuntimeException & e ) {\n        throw e;\n    }\n"
             "     catch ( css::uno::Exception & ) {\n    }\n    return ret;\n";
     }
     o <<"}\n\n";
@@ -924,14 +921,14 @@ void generateQueryInterface(std::ostream& o,
                             OString const & classname,
                             OString const & propertyhelper)
 {
-    if (propertyhelper.getLength() == 0)
+    if (propertyhelper.isEmpty())
         return;
 
     o << "css::uno::Any " << classname
       << "::queryInterface(css::uno::Type const & type) throw ("
         "css::uno::RuntimeException)\n{\n    ";
 
-    if (propertyhelper.getLength() >= 1)
+    if (!propertyhelper.isEmpty())
         o << "return ";
     else
         o << "css::uno::Any a(";
@@ -949,7 +946,7 @@ void generateQueryInterface(std::ostream& o,
             o << ">";
     }
 
-    if (propertyhelper.getLength() >= 1) {
+    if (!propertyhelper.isEmpty()) {
         o << "::queryInterface(type);\n";
     } else {
         o << "::queryInterface(type));\n";
@@ -968,8 +965,7 @@ void generateQueryInterface(std::ostream& o,
 
 void generateSkeleton(ProgramOptions const & options,
                       TypeManager const & manager,
-                      std::vector< OString > const & types,
-                      OString const & /*delegate*/)
+                      std::vector< OString > const & types)
 {
     // special handling of calc add-ins
     if (options.componenttype == 2) {
@@ -1030,8 +1026,8 @@ void generateSkeleton(ProgramOptions const & options,
             printLicenseHeader(*pofs, compFileName);
         }
 
-        generateIncludes(*pofs, interfaces, properties, propertyhelper,
-                         serviceobject, supportxcomponent);
+        generateIncludes(*pofs, interfaces, propertyhelper, serviceobject,
+                         supportxcomponent);
 
         if (options.componenttype == 3) {
             *pofs << "#include \"com/sun/star/frame/XFrame.hpp\"\n";
@@ -1087,7 +1083,7 @@ void generateSkeleton(ProgramOptions const & options,
             delete pofs;
             OSL_VERIFY(makeValidTypeFile(compFileName, tmpFileName, sal_False));
         }
-    } catch(CannotDumpException& e) {
+    } catch(const CannotDumpException& e) {
 
         std::cerr << "ERROR: " << e.m_message.getStr() << "\n";
         if ( !standardout ) {
@@ -1160,7 +1156,7 @@ void generateCalcAddin(ProgramOptions const & options,
     OString propertyhelper = checkPropertyHelper(
         options, manager, services, interfaces, attributes, propinterfaces);
 
-    if (propertyhelper.getLength() > 0)
+    if (!propertyhelper.isEmpty())
         std::cerr << "WARNING: interfaces specifying calc add-in functions "
             "shouldn't support attributes!\n";
 
@@ -1192,8 +1188,8 @@ void generateCalcAddin(ProgramOptions const & options,
             printLicenseHeader(*pofs, compFileName);
         }
 
-        generateIncludes(*pofs, interfaces, properties, propertyhelper,
-                         serviceobject, supportxcomponent);
+        generateIncludes(*pofs, interfaces, propertyhelper, serviceobject,
+                         supportxcomponent);
 
         *pofs <<
             "#include \"com/sun/star/beans/PropertyValue.hpp\"\n"
@@ -1251,7 +1247,7 @@ void generateCalcAddin(ProgramOptions const & options,
             delete pofs;
             OSL_VERIFY(makeValidTypeFile(compFileName, tmpFileName, sal_False));
         }
-    } catch(CannotDumpException& e) {
+    } catch(const CannotDumpException& e) {
 
         std::cerr << "ERROR: " << e.m_message.getStr() << "\n";
         if ( !standardout ) {
