@@ -28,10 +28,8 @@
 
 
 #include <unotools/historyoptions.hxx>
-#include <unotools/historyoptions_const.hxx>
 #include <unotools/configmgr.hxx>
 #include <unotools/configitem.hxx>
-#include <tools/debug.hxx>
 #include <com/sun/star/uno/Any.hxx>
 #include <com/sun/star/uno/Sequence.hxx>
 
@@ -54,12 +52,6 @@
 
 #include <comphelper/processfactory.hxx>
 
-#include <unotools/loghelper.hxx>
-
-//_________________________________________________________________________________________________________________
-// namespaces
-//_________________________________________________________________________________________________________________
-
 using namespace ::std     ;
 using namespace ::utl     ;
 using namespace ::rtl     ;
@@ -69,20 +61,27 @@ using namespace ::com::sun::star::beans ;
 
 namespace css = ::com::sun::star;
 
-//_________________________________________________________________________________________________________________
-// const
-//_________________________________________________________________________________________________________________
-
 namespace {
     static const ::sal_Int32 s_nOffsetURL               = 0;
     static const ::sal_Int32 s_nOffsetFilter            = 1;
     static const ::sal_Int32 s_nOffsetTitle             = 2;
     static const ::sal_Int32 s_nOffsetPassword          = 3;
-}
 
-//_________________________________________________________________________________________________________________
-// private declarations!
-//_________________________________________________________________________________________________________________
+    const char s_sCommonHistory[] = "org.openoffice.Office.Common/History";
+    const char s_sHistories[] = "org.openoffice.Office.Histories/Histories";
+    const char s_sPickListSize[] = "PickListSize";
+    const char s_sURLHistorySize[] = "Size";
+    const char s_sHelpBookmarksSize[] = "HelpBookmarkSize";
+    const char s_sPickList[] = "PickList";
+    const char s_sURLHistory[] = "URLHistory";
+    const char s_sHelpBookmarks[] = "HelpBookmarks";
+    const char s_sItemList[] = "ItemList";
+    const char s_sOrderList[] = "OrderList";
+    const char s_sHistoryItemRef[] = "HistoryItemRef";
+    const char s_sFilter[] = "Filter";
+    const char s_sTitle[] = "Title";
+    const char s_sPassword[] = "Password";
+}
 
 struct IMPL_THistoryItem
 {
@@ -123,7 +122,6 @@ public:
     ~SvtHistoryOptions_Impl();
 
     sal_uInt32 GetSize( EHistoryType eHistory );
-    void SetSize( EHistoryType eHistory, sal_uInt32 nSize );
     void Clear( EHistoryType eHistory );
     Sequence< Sequence< PropertyValue > > GetList( EHistoryType eHistory );
     void                                  AppendItem(       EHistoryType eHistory ,
@@ -150,14 +148,14 @@ SvtHistoryOptions_Impl::SvtHistoryOptions_Impl()
         m_xCfg = Reference< css::container::XNameAccess > (
             ::comphelper::ConfigurationHelper::openConfig(
             ::comphelper::getProcessServiceFactory(),
-            s_sHistories,
+            rtl::OUString(s_sHistories),
             ::comphelper::ConfigurationHelper::E_STANDARD),
             css::uno::UNO_QUERY );
 
         m_xCommonXCU = Reference< css::container::XNameAccess > (
             ::comphelper::ConfigurationHelper::openConfig(
             ::comphelper::getProcessServiceFactory(),
-            s_sCommonHistory,
+            rtl::OUString(s_sCommonHistory),
             ::comphelper::ConfigurationHelper::E_STANDARD),
             css::uno::UNO_QUERY );
     }
@@ -166,7 +164,7 @@ SvtHistoryOptions_Impl::SvtHistoryOptions_Impl()
         m_xCfg.clear();
         m_xCommonXCU.clear();
 
-        LogHelper::logIt(ex);
+        SAL_WARN("unotools", "Caught unexpected: " << ex.Message);
     }
 }
 
@@ -195,15 +193,15 @@ sal_uInt32 SvtHistoryOptions_Impl::GetSize( EHistoryType eHistory )
         switch( eHistory )
         {
         case ePICKLIST:
-            xListAccess->getPropertyValue(s_sPickListSize) >>= nSize;
+            xListAccess->getPropertyValue(rtl::OUString(s_sPickListSize)) >>= nSize;
             break;
 
         case eHISTORY:
-            xListAccess->getPropertyValue(s_sURLHistorySize) >>= nSize;
+            xListAccess->getPropertyValue(rtl::OUString(s_sURLHistorySize)) >>= nSize;
             break;
 
         case eHELPBOOKMARKS:
-            xListAccess->getPropertyValue(s_sHelpBookmarksSize) >>= nSize;
+            xListAccess->getPropertyValue(rtl::OUString(s_sHelpBookmarksSize)) >>= nSize;
             break;
 
         default:
@@ -212,62 +210,12 @@ sal_uInt32 SvtHistoryOptions_Impl::GetSize( EHistoryType eHistory )
     }
     catch(const css::uno::Exception& ex)
     {
-        LogHelper::logIt(ex);
+        SAL_WARN("unotools", "Caught unexpected: " << ex.Message);
     }
 
     return nSize;
 }
 
-//*****************************************************************************************************************
-//  public method
-//  Attention: We return the max. size of our internal lists - That is the capacity not the size!
-//*****************************************************************************************************************
-void SvtHistoryOptions_Impl::SetSize( EHistoryType eHistory, sal_uInt32 nSize )
-{
-    css::uno::Reference< css::beans::XPropertySet > xListAccess(m_xCommonXCU, css::uno::UNO_QUERY);
-    if (! xListAccess.is ())
-        return;
-
-    try
-    {
-        switch( eHistory )
-        {
-        case ePICKLIST:
-            if(nSize!=GetSize(ePICKLIST))
-            {
-                xListAccess->setPropertyValue(s_sPickListSize, css::uno::makeAny(nSize));
-                ::comphelper::ConfigurationHelper::flush(m_xCommonXCU);
-            }
-            break;
-
-        case eHISTORY:
-            if(nSize!=GetSize(eHISTORY))
-            {
-                xListAccess->setPropertyValue(s_sURLHistorySize, css::uno::makeAny(nSize));
-                ::comphelper::ConfigurationHelper::flush(m_xCommonXCU);
-            }
-            break;
-
-        case eHELPBOOKMARKS:
-            if(nSize!=GetSize(eHELPBOOKMARKS))
-            {
-                xListAccess->setPropertyValue(s_sHelpBookmarksSize, css::uno::makeAny(nSize));
-                ::comphelper::ConfigurationHelper::flush(m_xCommonXCU);
-            }
-            break;
-
-        default:
-            break;
-        }
-
-        impl_truncateList (eHistory, nSize);
-    }
-    catch(const css::uno::Exception& ex)
-    {
-        LogHelper::logIt(ex);
-    }
-}
-
 //*****************************************************************************************************************
 void SvtHistoryOptions_Impl::impl_truncateList ( EHistoryType eHistory, sal_uInt32 nSize )
 {
@@ -281,15 +229,15 @@ void SvtHistoryOptions_Impl::impl_truncateList ( EHistoryType eHistory, sal_uInt
         switch( eHistory )
         {
         case ePICKLIST:
-            m_xCfg->getByName(s_sPickList) >>= xList;
+            m_xCfg->getByName(rtl::OUString(s_sPickList)) >>= xList;
             break;
 
         case eHISTORY:
-            m_xCfg->getByName(s_sURLHistory) >>= xList;
+            m_xCfg->getByName(rtl::OUString(s_sURLHistory)) >>= xList;
             break;
 
         case eHELPBOOKMARKS:
-            m_xCfg->getByName(s_sHelpBookmarks) >>= xList;
+            m_xCfg->getByName(rtl::OUString(s_sHelpBookmarks)) >>= xList;
             break;
 
         default:
@@ -301,8 +249,8 @@ void SvtHistoryOptions_Impl::impl_truncateList ( EHistoryType eHistory, sal_uInt
         if ( ! xList.is())
             return;
 
-        xList->getByName(s_sOrderList) >>= xOrderList;
-        xList->getByName(s_sItemList)  >>= xItemList;
+        xList->getByName(rtl::OUString(s_sOrderList)) >>= xOrderList;
+        xList->getByName(rtl::OUString(s_sItemList))  >>= xItemList;
 
         const sal_uInt32 nLength = xOrderList->getElementNames().getLength();
         if (nSize < nLength)
@@ -312,7 +260,7 @@ void SvtHistoryOptions_Impl::impl_truncateList ( EHistoryType eHistory, sal_uInt
                 ::rtl::OUString sTmp;
                 const ::rtl::OUString sRemove = ::rtl::OUString::valueOf((sal_Int32)i);
                 xOrderList->getByName(sRemove) >>= xSet;
-                xSet->getPropertyValue(s_sHistoryItemRef) >>= sTmp;
+                xSet->getPropertyValue(rtl::OUString(s_sHistoryItemRef)) >>= sTmp;
                 xItemList->removeByName(sTmp);
                 xOrderList->removeByName(sRemove);
             }
@@ -322,7 +270,7 @@ void SvtHistoryOptions_Impl::impl_truncateList ( EHistoryType eHistory, sal_uInt
     }
     catch(const css::uno::Exception& ex)
     {
-        LogHelper::logIt(ex);
+        SAL_WARN("unotools", "Caught unexpected: " << ex.Message);
     }
 }
 
@@ -342,19 +290,19 @@ void SvtHistoryOptions_Impl::Clear( EHistoryType eHistory )
         {
         case ePICKLIST:
             {
-                m_xCfg->getByName(s_sPickList) >>= xListAccess;
+                m_xCfg->getByName(rtl::OUString(s_sPickList)) >>= xListAccess;
                 break;
             }
 
         case eHISTORY:
             {
-                m_xCfg->getByName(s_sURLHistory) >>= xListAccess;
+                m_xCfg->getByName(rtl::OUString(s_sURLHistory)) >>= xListAccess;
                 break;
             }
 
         case eHELPBOOKMARKS:
             {
-                m_xCfg->getByName(s_sHelpBookmarks) >>= xListAccess;
+                m_xCfg->getByName(rtl::OUString(s_sHelpBookmarks)) >>= xListAccess;
                 break;
             }
 
@@ -365,14 +313,14 @@ void SvtHistoryOptions_Impl::Clear( EHistoryType eHistory )
         if (xListAccess.is())
         {
             // clear ItemList
-            xListAccess->getByName(s_sItemList)  >>= xNode  ;
+            xListAccess->getByName(rtl::OUString(s_sItemList))  >>= xNode  ;
             lOrders = xNode->getElementNames();
             const sal_Int32 nLength = lOrders.getLength();
             for(sal_Int32 i=0; i<nLength; ++i)
                 xNode->removeByName(lOrders[i]);
 
             // clear OrderList
-            xListAccess->getByName(s_sOrderList) >>= xNode ;
+            xListAccess->getByName(rtl::OUString(s_sOrderList)) >>= xNode ;
             lOrders = xNode->getElementNames();
             for(sal_Int32 j=0; j<nLength; ++j)
                 xNode->removeByName(lOrders[j]);
@@ -382,7 +330,7 @@ void SvtHistoryOptions_Impl::Clear( EHistoryType eHistory )
     }
     catch(const css::uno::Exception& ex)
     {
-        LogHelper::logIt(ex);
+        SAL_WARN("unotools", "Caught unexpected: " << ex.Message);
     }
 }
 
@@ -414,19 +362,19 @@ Sequence< Sequence< PropertyValue > > SvtHistoryOptions_Impl::GetList( EHistoryT
         {
         case ePICKLIST:
             {
-                m_xCfg->getByName(s_sPickList) >>= xListAccess;
+                m_xCfg->getByName(rtl::OUString(s_sPickList)) >>= xListAccess;
                 break;
             }
 
         case eHISTORY:
             {
-                m_xCfg->getByName(s_sURLHistory) >>= xListAccess;
+                m_xCfg->getByName(rtl::OUString(s_sURLHistory)) >>= xListAccess;
                 break;
             }
 
         case eHELPBOOKMARKS:
             {
-                m_xCfg->getByName(s_sHelpBookmarks) >>= xListAccess;
+                m_xCfg->getByName(rtl::OUString(s_sHelpBookmarks)) >>= xListAccess;
                 break;
             }
 
@@ -436,8 +384,8 @@ Sequence< Sequence< PropertyValue > > SvtHistoryOptions_Impl::GetList( EHistoryT
 
         if (xListAccess.is())
         {
-            xListAccess->getByName(s_sItemList)  >>= xItemList;
-            xListAccess->getByName(s_sOrderList) >>= xOrderList;
+            xListAccess->getByName(rtl::OUString(s_sItemList))  >>= xItemList;
+            xListAccess->getByName(rtl::OUString(s_sOrderList)) >>= xOrderList;
 
             const sal_Int32 nLength = xOrderList->getElementNames().getLength();
             Sequence< Sequence< PropertyValue > > aRet(nLength);
@@ -449,13 +397,13 @@ Sequence< Sequence< PropertyValue > > SvtHistoryOptions_Impl::GetList( EHistoryT
                 {
                     ::rtl::OUString sUrl;
                     xOrderList->getByName(::rtl::OUString::valueOf(nItem)) >>= xSet;
-                    xSet->getPropertyValue(s_sHistoryItemRef) >>= sUrl;
+                    xSet->getPropertyValue(rtl::OUString(s_sHistoryItemRef)) >>= sUrl;
 
                     xItemList->getByName(sUrl) >>= xSet;
                     seqProperties[s_nOffsetURL  ].Value <<= sUrl;
-                    xSet->getPropertyValue(s_sFilter)   >>= seqProperties[s_nOffsetFilter   ].Value;
-                    xSet->getPropertyValue(s_sTitle)    >>= seqProperties[s_nOffsetTitle    ].Value;
-                    xSet->getPropertyValue(s_sPassword) >>= seqProperties[s_nOffsetPassword ].Value;
+                    xSet->getPropertyValue(rtl::OUString(s_sFilter))   >>= seqProperties[s_nOffsetFilter   ].Value;
+                    xSet->getPropertyValue(rtl::OUString(s_sTitle))    >>= seqProperties[s_nOffsetTitle    ].Value;
+                    xSet->getPropertyValue(rtl::OUString(s_sPassword)) >>= seqProperties[s_nOffsetPassword ].Value;
                     aRet[nCount++] = seqProperties;
                 }
                 catch(const css::uno::Exception& ex)
@@ -467,7 +415,7 @@ Sequence< Sequence< PropertyValue > > SvtHistoryOptions_Impl::GetList( EHistoryT
                     // ignore such corrupted individual items here, so that at
                     // least newly added items are successfully reported back
                     // from this function:
-                    LogHelper::logIt(ex);
+                    SAL_WARN("unotools", "Caught unexpected: " << ex.Message);
                 }
             }
             assert(nCount <= nLength);
@@ -477,7 +425,7 @@ Sequence< Sequence< PropertyValue > > SvtHistoryOptions_Impl::GetList( EHistoryT
     }
     catch(const css::uno::Exception& ex)
     {
-        LogHelper::logIt(ex);
+        SAL_WARN("unotools", "Caught unexpected: " << ex.Message);
     }
 
     return seqReturn;
@@ -502,19 +450,19 @@ void SvtHistoryOptions_Impl::AppendItem(       EHistoryType eHistory ,
     {
     case ePICKLIST:
         {
-            m_xCfg->getByName(s_sPickList) >>= xListAccess;
+            m_xCfg->getByName(rtl::OUString(s_sPickList)) >>= xListAccess;
             nMaxSize = GetSize(ePICKLIST);
         }
         break;
     case eHISTORY:
         {
-            m_xCfg->getByName(s_sURLHistory) >>= xListAccess;
+            m_xCfg->getByName(rtl::OUString(s_sURLHistory)) >>= xListAccess;
             nMaxSize = GetSize(eHISTORY);
         }
         break;
     case eHELPBOOKMARKS:
         {
-            m_xCfg->getByName(s_sHelpBookmarks) >>= xListAccess;
+            m_xCfg->getByName(rtl::OUString(s_sHelpBookmarks)) >>= xListAccess;
             nMaxSize = GetSize(eHELPBOOKMARKS);
         }
         break;
@@ -531,10 +479,11 @@ void SvtHistoryOptions_Impl::AppendItem(       EHistoryType eHistory ,
 
     try
     {
-        xListAccess->getByName(s_sItemList)  >>= xItemList;
-        xListAccess->getByName(s_sOrderList) >>= xOrderList;
+        xListAccess->getByName(rtl::OUString(s_sItemList))  >>= xItemList;
+        xListAccess->getByName(rtl::OUString(s_sOrderList)) >>= xOrderList;
         sal_Int32 nLength = xOrderList->getElementNames().getLength();
 
+        rtl::OUString sHistoryItemRef(s_sHistoryItemRef);
         // The item to be appended is already existing!
         if (xItemList->hasByName(sURL))
         {
@@ -542,13 +491,13 @@ void SvtHistoryOptions_Impl::AppendItem(       EHistoryType eHistory ,
             {
                 ::rtl::OUString sTmp;
                 xOrderList->getByName(::rtl::OUString::valueOf(i)) >>= xSet;
-                xSet->getPropertyValue(s_sHistoryItemRef) >>= sTmp;
+                xSet->getPropertyValue(sHistoryItemRef) >>= sTmp;
 
                 if(sURL == sTmp)
                 {
                     ::rtl::OUString sFind;
                     xOrderList->getByName( ::rtl::OUString::valueOf(i) ) >>= xSet;
-                    xSet->getPropertyValue(s_sHistoryItemRef) >>= sFind;
+                    xSet->getPropertyValue(sHistoryItemRef) >>= sFind;
                     for (sal_Int32 j=i-1; j>=0; --j)
                     {
                         css::uno::Reference< css::beans::XPropertySet > xPrevSet;
@@ -557,11 +506,11 @@ void SvtHistoryOptions_Impl::AppendItem(       EHistoryType eHistory ,
                         xOrderList->getByName( ::rtl::OUString::valueOf(j) )     >>= xNextSet;
 
                         ::rtl::OUString sTemp;
-                        xNextSet->getPropertyValue(s_sHistoryItemRef) >>= sTemp;
-                        xPrevSet->setPropertyValue(s_sHistoryItemRef, css::uno::makeAny(sTemp));
+                        xNextSet->getPropertyValue(sHistoryItemRef) >>= sTemp;
+                        xPrevSet->setPropertyValue(sHistoryItemRef, css::uno::makeAny(sTemp));
                     }
                     xOrderList->getByName( ::rtl::OUString::valueOf((sal_Int32)0) ) >>= xSet;
-                    xSet->setPropertyValue(s_sHistoryItemRef, css::uno::makeAny(sFind));
+                    xSet->setPropertyValue(sHistoryItemRef, css::uno::makeAny(sFind));
 
                     ::comphelper::ConfigurationHelper::flush(m_xCfg);
                     break;
@@ -582,8 +531,24 @@ void SvtHistoryOptions_Impl::AppendItem(       EHistoryType eHistory ,
             {
                 ::rtl::OUString sRemove;
                 xOrderList->getByName(::rtl::OUString::valueOf(nLength-1)) >>= xSet;
-                xSet->getPropertyValue(s_sHistoryItemRef) >>= sRemove;
-                xItemList->removeByName(sRemove);
+                xSet->getPropertyValue(sHistoryItemRef) >>= sRemove;
+                try
+                {
+                    xItemList->removeByName(sRemove);
+                }
+                catch (css::container::NoSuchElementException &)
+                {
+                    // <https://bugs.freedesktop.org/show_bug.cgi?id=46074>
+                    // "FILEOPEN: No Recent Documents..." discusses a problem
+                    // with corrupted /org.openoffice.Office/Histories/Histories
+                    // configuration items; to work around that problem, simply
+                    // ignore such corrupted individual items here, so that at
+                    // least newly added items are successfully added:
+                    if (!sRemove.isEmpty())
+                    {
+                        throw;
+                    }
+                }
             }
             if ( nLength != nMaxSize )
             {
@@ -597,27 +562,27 @@ void SvtHistoryOptions_Impl::AppendItem(       EHistoryType eHistory ,
                 xOrderList->getByName( ::rtl::OUString::valueOf(j) )   >>= xPrevSet;
                 xOrderList->getByName( ::rtl::OUString::valueOf(j-1) ) >>= xNextSet;
                 ::rtl::OUString sTemp;
-                xNextSet->getPropertyValue(s_sHistoryItemRef) >>= sTemp;
-                xPrevSet->setPropertyValue(s_sHistoryItemRef, css::uno::makeAny(sTemp));
+                xNextSet->getPropertyValue(sHistoryItemRef) >>= sTemp;
+                xPrevSet->setPropertyValue(sHistoryItemRef, css::uno::makeAny(sTemp));
             }
             xOrderList->getByName( ::rtl::OUString::valueOf((sal_Int32)0) ) >>= xSet;
-            xSet->setPropertyValue(s_sHistoryItemRef, css::uno::makeAny(sURL));
+            xSet->setPropertyValue(sHistoryItemRef, css::uno::makeAny(sURL));
 
             // Append the item to ItemList.
             xFac = css::uno::Reference< css::lang::XSingleServiceFactory >(xItemList, css::uno::UNO_QUERY);
             xInst = xFac->createInstance();
             xItemList->insertByName(sURL, css::uno::makeAny(xInst));
             xSet = css::uno::Reference< css::beans::XPropertySet >(xInst, css::uno::UNO_QUERY);
-            xSet->setPropertyValue(s_sFilter, css::uno::makeAny(sFilter));
-            xSet->setPropertyValue(s_sTitle, css::uno::makeAny(sTitle));
-            xSet->setPropertyValue(s_sPassword, css::uno::makeAny(sPassword));
+            xSet->setPropertyValue(rtl::OUString(s_sFilter), css::uno::makeAny(sFilter));
+            xSet->setPropertyValue(rtl::OUString(s_sTitle), css::uno::makeAny(sTitle));
+            xSet->setPropertyValue(rtl::OUString(s_sPassword), css::uno::makeAny(sPassword));
 
             ::comphelper::ConfigurationHelper::flush(m_xCfg);
         }
     }
     catch(const css::uno::Exception& ex)
     {
-        LogHelper::logIt(ex);
+        SAL_WARN("unotools", "Caught unexpected: " << ex.Message);
     }
 }
 
@@ -675,15 +640,6 @@ sal_uInt32 SvtHistoryOptions::GetSize( EHistoryType eHistory ) const
     return m_pDataContainer->GetSize( eHistory );
 }
 
-//*****************************************************************************************************************
-// public method
-//*****************************************************************************************************************
-void SvtHistoryOptions::SetSize( EHistoryType eHistory, sal_uInt32 nSize )
-{
-    MutexGuard aGuard( GetOwnStaticMutex() );
-    m_pDataContainer->SetSize( eHistory, nSize );
-}
-
 //*****************************************************************************************************************
 // public method
 //*****************************************************************************************************************
