@@ -795,7 +795,7 @@ sal_Bool AquaSalGraphics::drawNativeControl(ControlType nType,
             {
                 aTrackDraw.bounds = rc;
                 aTrackDraw.min   = pSLVal->mnMin;
-                aTrackDraw.max   = pSLVal->mnMax;;
+                aTrackDraw.max   = pSLVal->mnMax;
                 aTrackDraw.value = pSLVal->mnCur;
                 aTrackDraw.reserved = 0;
                 aTrackDraw.attributes = kThemeTrackShowThumb;
@@ -1215,24 +1215,6 @@ sal_Bool AquaSalGraphics::drawNativeControl(ControlType nType,
     return bOK;
 }
 
-/*
- * DrawNativeControlText()
- *
- *  OPTIONAL.  Draws the requested text for the control described by nPart/nState.
- *     Used if text not drawn by DrawNativeControl().
- *
- *  rControlRegion: The bounding region of the complete control in VCL frame coordinates.
- *  aValue:     An optional value (tristate/numerical/string)
- *  aCaption:   A caption or title string (like button text etc)
- */
-sal_Bool AquaSalGraphics::drawNativeControlText( ControlType /*nType*/, ControlPart /*nPart*/, const Rectangle& /*rControlRegion*/,
-                                               ControlState /*nState*/, const ImplControlValue& /*aValue*/,
-                                               const rtl::OUString& )
-{
-    return( sal_False );
-}
-
-
 /*
  * GetNativeControlRegion()
  *
