@@ -176,20 +176,6 @@ StatusBar::StatusBar( Window* pParent, WinBits nStyle ) :
 
 // -----------------------------------------------------------------------
 
-StatusBar::StatusBar( Window* pParent, const ResId& rResId ) :
-    Window( WINDOW_STATUSBAR )
-{
-    rResId.SetRT( RSC_STATUSBAR );
-    WinBits nStyle = ImplInitRes( rResId );
-    ImplInit( pParent, nStyle );
-    ImplLoadRes( rResId );
-
-    if ( !(nStyle & WB_HIDE) )
-        Show();
-}
-
-// -----------------------------------------------------------------------
-
 StatusBar::~StatusBar()
 {
     // Alle Items loeschen
@@ -887,7 +873,7 @@ void StatusBar::RequestHelp( const HelpEvent& rHEvt )
             String aCommand = GetItemCommand( nItemId );
             rtl::OString aHelpId( GetHelpId( nItemId ) );
 
-            if ( aCommand.Len() || aHelpId.getLength() )
+            if ( aCommand.Len() || !aHelpId.isEmpty() )
             {
                 // Wenn eine Hilfe existiert, dann ausloesen
                 Help* pHelp = Application::GetHelp();
@@ -895,7 +881,7 @@ void StatusBar::RequestHelp( const HelpEvent& rHEvt )
                 {
                     if ( aCommand.Len() )
                         pHelp->Start( aCommand, this );
-                    else if ( aHelpId.getLength() )
+                    else if ( !aHelpId.isEmpty() )
                         pHelp->Start( rtl::OStringToOUString( aHelpId, RTL_TEXTENCODING_UTF8 ), this );
                 }
                 return;
@@ -1032,68 +1018,6 @@ void StatusBar::InsertItem( sal_uInt16 nItemId, sal_uLong nWidth,
 
 // -----------------------------------------------------------------------
 
-void StatusBar::RemoveItem( sal_uInt16 nItemId )
-{
-    sal_uInt16 nPos = GetItemPos( nItemId );
-    if ( nPos != STATUSBAR_ITEM_NOTFOUND )
-    {
-        delete (*mpItemList)[ nPos ];
-        mpItemList->erase( mpItemList->begin() + nPos );
-
-        mbFormat = sal_True;
-        if ( ImplIsItemUpdate() )
-            Invalidate();
-
-        ImplCallEventListeners( VCLEVENT_STATUSBAR_ITEMREMOVED, (void*) sal_IntPtr(nItemId) );
-    }
-}
-
-// -----------------------------------------------------------------------
-
-void StatusBar::ShowItem( sal_uInt16 nItemId )
-{
-    sal_uInt16 nPos = GetItemPos( nItemId );
-
-    if ( nPos != STATUSBAR_ITEM_NOTFOUND )
-    {
-        ImplStatusItem* pItem = (*mpItemList)[ nPos ];
-        if ( !pItem->mbVisible )
-        {
-            pItem->mbVisible = sal_True;
-
-            mbFormat = sal_True;
-            if ( ImplIsItemUpdate() )
-                Invalidate();
-
-            ImplCallEventListeners( VCLEVENT_STATUSBAR_SHOWITEM, (void*) sal_IntPtr(nItemId) );
-        }
-    }
-}
-
-// -----------------------------------------------------------------------
-
-void StatusBar::HideItem( sal_uInt16 nItemId )
-{
-    sal_uInt16 nPos = GetItemPos( nItemId );
-
-    if ( nPos != STATUSBAR_ITEM_NOTFOUND )
-    {
-        ImplStatusItem* pItem = (*mpItemList)[ nPos ];
-        if ( pItem->mbVisible )
-        {
-            pItem->mbVisible = sal_False;
-
-            mbFormat = sal_True;
-            if ( ImplIsItemUpdate() )
-                Invalidate();
-
-            ImplCallEventListeners( VCLEVENT_STATUSBAR_HIDEITEM, (void*) sal_IntPtr(nItemId) );
-        }
-    }
-}
-
-// -----------------------------------------------------------------------
-
 sal_Bool StatusBar::IsItemVisible( sal_uInt16 nItemId ) const
 {
     sal_uInt16 nPos = GetItemPos( nItemId );
@@ -1106,54 +1030,6 @@ sal_Bool StatusBar::IsItemVisible( sal_uInt16 nItemId ) const
 
 // -----------------------------------------------------------------------
 
-void StatusBar::ShowItems()
-{
-    if ( !mbVisibleItems )
-    {
-        mbVisibleItems = sal_True;
-        if ( !mbProgressMode )
-            Invalidate();
-
-        ImplCallEventListeners( VCLEVENT_STATUSBAR_SHOWALLITEMS );
-    }
-}
-
-// -----------------------------------------------------------------------
-
-void StatusBar::HideItems()
-{
-    if ( mbVisibleItems )
-    {
-        mbVisibleItems = sal_False;
-        if ( !mbProgressMode )
-            Invalidate();
-
-        ImplCallEventListeners( VCLEVENT_STATUSBAR_HIDEALLITEMS );
-    }
-}
-
-// -----------------------------------------------------------------------
-
-void StatusBar::CopyItems( const StatusBar& rStatusBar )
-{
-    // Alle Items entfernen
-    for ( size_t i = 0, n = mpItemList->size(); i < n; ++i ) {
-        delete (*mpItemList)[ i ];
-    }
-    mpItemList->clear();
-
-    // Items kopieren
-    for ( size_t i = 0, n = rStatusBar.mpItemList->size(); i < n; ++i ) {
-        mpItemList->push_back( new ImplStatusItem( *(*rStatusBar.mpItemList)[ i ] ) );
-    }
-
-    mbFormat = sal_True;
-    if ( ImplIsItemUpdate() )
-        Invalidate();
-}
-
-// -----------------------------------------------------------------------
-
 void StatusBar::Clear()
 {
     // Alle Item loeschen
@@ -1275,42 +1151,6 @@ Point StatusBar::GetItemTextPos( sal_uInt16 nItemId ) const
 
 // -----------------------------------------------------------------------
 
-sal_uLong StatusBar::GetItemWidth( sal_uInt16 nItemId ) const
-{
-    sal_uInt16 nPos = GetItemPos( nItemId );
-
-    if ( nPos != STATUSBAR_ITEM_NOTFOUND )
-        return (*mpItemList)[ nPos ]->mnWidth;
-
-    return 0;
-}
-
-// -----------------------------------------------------------------------
-
-StatusBarItemBits StatusBar::GetItemBits( sal_uInt16 nItemId ) const
-{
-    sal_uInt16 nPos = GetItemPos( nItemId );
-
-    if ( nPos != STATUSBAR_ITEM_NOTFOUND )
-        return (*mpItemList)[ nPos ]->mnBits;
-
-    return 0;
-}
-
-// -----------------------------------------------------------------------
-
-long StatusBar::GetItemOffset( sal_uInt16 nItemId ) const
-{
-    sal_uInt16 nPos = GetItemPos( nItemId );
-
-    if ( nPos != STATUSBAR_ITEM_NOTFOUND )
-        return (*mpItemList)[ nPos ]->mnOffset;
-
-    return 0;
-}
-
-// -----------------------------------------------------------------------
-
 void StatusBar::SetItemText( sal_uInt16 nItemId, const XubString& rText )
 {
     sal_uInt16 nPos = GetItemPos( nItemId );
@@ -1409,18 +1249,6 @@ void StatusBar::SetItemData( sal_uInt16 nItemId, void* pNewData )
 
 // -----------------------------------------------------------------------
 
-void* StatusBar::GetItemData( sal_uInt16 nItemId ) const
-{
-    sal_uInt16 nPos = GetItemPos( nItemId );
-
-    if ( nPos != STATUSBAR_ITEM_NOTFOUND )
-        return (*mpItemList)[ nPos ]->mpUserData;
-
-    return NULL;
-}
-
-// -----------------------------------------------------------------------
-
 void StatusBar::SetHelpText( sal_uInt16 nItemId, const XubString& rText )
 {
     sal_uInt16 nPos = GetItemPos( nItemId );
@@ -1438,14 +1266,14 @@ const XubString& StatusBar::GetHelpText( sal_uInt16 nItemId ) const
     if ( nPos != STATUSBAR_ITEM_NOTFOUND )
     {
         ImplStatusItem* pItem = (*mpItemList)[ nPos ];
-        if ( !pItem->maHelpText.Len() && ( pItem->maHelpId.getLength() || pItem->maCommand.Len() ))
+        if ( !pItem->maHelpText.Len() && ( !pItem->maHelpId.isEmpty() || pItem->maCommand.Len() ))
         {
             Help* pHelp = Application::GetHelp();
             if ( pHelp )
             {
                 if ( pItem->maCommand.Len() )
                     pItem->maHelpText = pHelp->GetHelpText( pItem->maCommand, this );
-                if ( !pItem->maHelpText.Len() && pItem->maHelpId.getLength() )
+                if ( !pItem->maHelpText.Len() && !pItem->maHelpId.isEmpty() )
                     pItem->maHelpText = pHelp->GetHelpText( rtl::OStringToOUString( pItem->maHelpId, RTL_TEXTENCODING_UTF8 ), this );
             }
         }
@@ -1501,7 +1329,7 @@ rtl::OString StatusBar::GetHelpId( sal_uInt16 nItemId ) const
     if ( nPos != STATUSBAR_ITEM_NOTFOUND )
     {
         ImplStatusItem* pItem = (*mpItemList)[ nPos ];
-        if ( pItem->maHelpId.getLength() )
+        if ( !pItem->maHelpId.isEmpty() )
             aRet = pItem->maHelpId;
         else
             aRet = ::rtl::OUStringToOString( pItem->maCommand, RTL_TEXTENCODING_UTF8 );
@@ -1510,42 +1338,6 @@ rtl::OString StatusBar::GetHelpId( sal_uInt16 nItemId ) const
     return aRet;
 }
 
-// -----------------------------------------------------------------------
-
-void StatusBar::ImplCalcBorder( )
-{
-    mnCalcHeight = mnDY;
-    // subtract border
-    if( IsTopBorder() )
-    {
-        mnCalcHeight -= 2;
-        mnTextY += 2;
-        mnItemY += 2;
-    }
-    if ( IsBottomBorder() )
-        mnCalcHeight -= 2;
-    mbFormat = sal_True;
-    Invalidate();
-}
-
-void StatusBar::SetBottomBorder( sal_Bool bBottomBorder )
-{
-    if ( mbBottomBorder != bBottomBorder )
-    {
-        mbBottomBorder = bBottomBorder;
-        ImplCalcBorder();
-    }
-}
-
-void StatusBar::SetTopBorder( sal_Bool bTopBorder )
-{
-    if ( mpImplData->mbTopBorder != static_cast<bool>(bTopBorder) )
-    {
-        mpImplData->mbTopBorder = static_cast<bool>(bTopBorder);
-        ImplCalcBorder();
-    }
-}
-
 sal_Bool StatusBar::IsTopBorder() const
 {
     return mpImplData->mbTopBorder;
@@ -1619,23 +1411,6 @@ void StatusBar::EndProgressMode()
 
 // -----------------------------------------------------------------------
 
-void StatusBar::ResetProgressMode()
-{
-    if ( mbProgressMode )
-    {
-        mnPercent = 0;
-        maPrgsTxt.Erase();
-        if ( IsReallyVisible() )
-        {
-            Invalidate();
-            Update();
-            Flush();
-        }
-    }
-}
-
-// -----------------------------------------------------------------------
-
 void StatusBar::SetText( const XubString& rText )
 {
     if ( (!mbVisibleItems || (GetStyle() & WB_RIGHT)) && !mbProgressMode &&
