@@ -281,7 +281,7 @@ sal_Bool KDESalGraphics::drawNativeControl( ControlType type, ControlPart part,
         OSL_ASSERT( value.getType() != CTRL_SPINBUTTONS );
         const SpinbuttonValue* pSpinVal = static_cast<const SpinbuttonValue *>(&value);
         Rectangle aButtonRect( pSpinVal->maUpperRect);
-        aButtonRect.Union( pSpinVal->maLowerRect );;
+        aButtonRect.Union( pSpinVal->maLowerRect );
         widgetRect = QRect( aButtonRect.Left(), aButtonRect.Top(),
                             aButtonRect.Right(), aButtonRect.Bottom() );
     }
@@ -306,7 +306,7 @@ sal_Bool KDESalGraphics::drawNativeControl( ControlType type, ControlPart part,
         draw( QStyle::CE_PushButton, &option, m_image,
               vclStateValue2StateFlag(nControlState, value) );
     }
-    else if ( (type == CTRL_MENUBAR))
+    else if (type == CTRL_MENUBAR)
     {
         if (part == PART_MENU_ITEM)
         {
@@ -369,6 +369,7 @@ sal_Bool KDESalGraphics::drawNativeControl( ControlType type, ControlPart part,
             // paints the whole menu item, so translate position (and it'll be clipped);
             // it is also necessary to fill the background transparently first, as this
             // is painted after menuitem highlight, otherwise there would be a grey area
+            assert( value.getType() == CTRL_MENU_POPUP );
             const MenupopupValue* menuVal = static_cast<const MenupopupValue*>(&value);
             QRect menuItemRect( region2QRect( menuVal->maItemRect ));
             QRect rect( menuItemRect.topLeft() - widgetRect.topLeft(),
