@@ -87,11 +87,11 @@ WinSalFrame* ImplFindSalObjectFrame( HWND hWnd )
     if ( pObject )
     {
         // Dazugehoerenden Frame suchen
-        HWND hWnd = ::GetParent( pObject->mhWnd );
+        HWND hWnd2 = ::GetParent( pObject->mhWnd );
         pFrame = GetSalData()->mpFirstFrame;
         while ( pFrame )
         {
-            if ( pFrame->mhWnd == hWnd )
+            if ( pFrame->mhWnd == hWnd2 )
                 break;
 
             pFrame = pFrame->mpNextFrame;
@@ -825,20 +825,6 @@ void WinSalObject::GrabFocus()
         ::SetFocus( mhWndChild );
 }
 
-// -----------------------------------------------------------------------
-
-void WinSalObject::SetBackground()
-{
-}
-
-// -----------------------------------------------------------------------
-
-void WinSalObject::SetBackground( SalColor )
-{
-}
-
-// -----------------------------------------------------------------------
-
 const SystemEnvData* WinSalObject::GetSystemData() const
 {
     return &maSysData;
