@@ -262,13 +262,13 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
                     // Binary filter takes BiDirection into account ( but I have no idea about that here )
                     // or even what it is. But... here's where to handle it if it becomes an issue
                         pPropMap->Insert( PROP_FRM_DIRECTION, false, uno::makeAny( VERT_TOP_RIGHT ));
-                        OSL_TRACE("Have inserted textDirection %d", nIntValue );
+                        SAL_INFO( "writerfilter", "Have inserted textDirection " << nIntValue );
                         break;
                     case 3:  // btLr
                         // We have to fake this text direction
                          pPropMap->Insert( PROP_FRM_DIRECTION, false, uno::makeAny( HORI_LEFT_TOP ));
                          pPropMap->Insert( PROP_CHAR_ROTATION, false, uno::makeAny( sal_Int16( 900 ) ));
-                        OSL_TRACE("Have inserted textDirection %d", nIntValue );
+                        SAL_INFO( "writerfilter", "Have inserted textDirection " << nIntValue );
                         break;
                     case 4: // lrTbV
                         pPropMap->Insert( PROP_FRM_DIRECTION, false, uno::makeAny( HORI_LEFT_TOP ));
@@ -442,7 +442,7 @@ void DomainMapperTableManager::endOfRowAction()
     double nFullWidth = m_nTableWidth;
     //the positions have to be distibuted in a range of 10000
     const double nFullWidthRelative = 10000.;
-    if( pTableGrid->size() == nGrids )
+    if( pTableGrid->size() == nGrids && m_nCell > 0 )
     {
         uno::Sequence< text::TableColumnSeparator > aSeparators( m_nCell - 1 );
         text::TableColumnSeparator* pSeparators = aSeparators.getArray();
@@ -477,7 +477,7 @@ void DomainMapperTableManager::endOfRowAction()
 #endif
         insertRowProps(pPropMap);
     }
-    else if (m_bImplicitMerges)
+    else if (m_bImplicitMerges && pTableGrid->size())
     {
         // More grid than cells definitions? Then take the last ones.
         // This feature is used by the RTF implicit horizontal cell merges.
@@ -486,8 +486,9 @@ void DomainMapperTableManager::endOfRowAction()
 
         sal_Int16 nSum = 0;
         sal_uInt32 nPos = 0;
+        sal_uInt32 nSizeTableGrid = pTableGrid->size();
         // Ignoring the i=0 case means we assume that the width of the last cell matches the table width
-        for (int i = m_nCell; i > 1; i--)
+        for (sal_uInt32 i = m_nCell; i > 1 && nSizeTableGrid >= i; i--)
         {
             nSum += (*pTableGrid.get())[pTableGrid->size() - i]; // Size of the current cell
             pSeparators[nPos].Position = nSum * nFullWidthRelative / nFullWidth; // Relative position
@@ -530,7 +531,7 @@ void lcl_CopyTextProperties(PropertyMapPtr pToFill,
     if( !pStyleSheetEntry )
         return;
     //fill base style properties first, recursively
-    if( pStyleSheetEntry->sBaseStyleIdentifier.getLength())
+    if( !pStyleSheetEntry->sBaseStyleIdentifier.isEmpty())
     {
         const StyleSheetEntryPtr pParentStyleSheet =
             pStyleSheetTable->FindStyleSheetByISTD(pStyleSheetEntry->sBaseStyleIdentifier);
