@@ -27,6 +27,7 @@
 
 #include <rtfcontrolwords.hxx>
 #include <sal/macros.h>
+#include <string.h>
 
 namespace writerfilter {
 namespace rtftok {
@@ -39,6 +40,7 @@ RTFSymbol aRTFControlWords[] = {
     {":", CONTROL_SYMBOL, RTF_SUBENTRY},
     {"\\", CONTROL_SYMBOL, RTF_BACKSLASH},
     {"\n", CONTROL_SYMBOL, RTF_PAR},
+    {"\r", CONTROL_SYMBOL, RTF_PAR},
     {"\r\n", CONTROL_SYMBOL, RTF_PAR},
     {"_", CONTROL_SYMBOL, RTF_NOBRKHYPH},
     {"{", CONTROL_SYMBOL, RTF_LBRACE},
@@ -1855,6 +1857,11 @@ RTFSymbol aRTFControlWords[] = {
 };
 int nRTFControlWords = SAL_N_ELEMENTS(aRTFControlWords);
 
+bool RTFSymbol::operator<(const RTFSymbol& rOther) const
+{
+    return strcmp(sKeyword, rOther.sKeyword) < 0;
+}
+
 } // namespace rtftok
 } // namespace writerfilter
 
