@@ -141,9 +141,16 @@ RTFSprms::RTFSprms(const RTFSprms& rSprms)
         m_aSprms.push_back(std::make_pair(i->first, RTFValue::Pointer_t(i->second->Clone())));
 }
 
-std::vector< std::pair<Id, RTFValue::Pointer_t> >* RTFSprms::operator->()
+RTFSprms& RTFSprms::operator=(const RTFSprms& rOther)
 {
-    return &m_aSprms;
+    RTFSprms aTmp(rOther);
+    swap(aTmp);
+    return *this;
+}
+
+void RTFSprms::swap(RTFSprms& rOther)
+{
+    m_aSprms.swap(rOther.m_aSprms);
 }
 
 } // namespace rtftok
