@@ -60,21 +60,21 @@ namespace treeview {
         TVDom( TVDom* arent = 0 )
             : kind( other ),
               parent( arent ),
-              childs( 0 )
+              children( 0 )
         {
         }
 
         ~TVDom()
         {
-            for( unsigned i = 0; i < childs.size(); ++i )
-                delete childs[i];
+            for( unsigned i = 0; i < children.size(); ++i )
+                delete children[i];
         }
 
 
         TVDom* newChild()
         {
-            childs.push_back( new TVDom( this ) );
-            return childs.back();
+            children.push_back( new TVDom( this ) );
+            return children.back();
         }
 
 
@@ -135,7 +135,7 @@ namespace treeview {
 
         rtl::OUString getTargetURL()
         {
-            if( ! targetURL.getLength() )
+            if( targetURL.isEmpty() )
             {
                 sal_Int32 len;
                 for ( const TVDom* p = this;; p = p->parent )
@@ -166,7 +166,7 @@ namespace treeview {
         rtl::OUString  targetURL;
 
         TVDom *parent;
-        std::vector< TVDom* > childs;
+        std::vector< TVDom* > children;
     };
 
 }
@@ -185,11 +185,11 @@ using namespace com::sun::star::deployment;
 
 
 ConfigData::ConfigData()
-    : prodName(RTL_CONSTASCII_USTRINGPARAM("%PRODUCTNAME")),
-      prodVersion(RTL_CONSTASCII_USTRINGPARAM("%PRODUCTVERSION")),
-      vendName(RTL_CONSTASCII_USTRINGPARAM("%VENDORNAME")),
-      vendVersion(RTL_CONSTASCII_USTRINGPARAM("%VENDORVERSION")),
-      vendShort(RTL_CONSTASCII_USTRINGPARAM("%VENDORSHORT"))
+    : prodName("%PRODUCTNAME"),
+      prodVersion("%PRODUCTVERSION"),
+      vendName("%VENDORNAME"),
+      vendVersion("%VENDORVERSION"),
+      vendShort("%VENDORSHORT")
 {
 }
 
@@ -268,11 +268,11 @@ TVBase::queryInterface(
     throw( RuntimeException )
 {
     Any aRet = cppu::queryInterface( rType,
-                                     SAL_STATIC_CAST( XTypeProvider*, this ),
-                                     SAL_STATIC_CAST( XNameAccess*, this ),
-                                     SAL_STATIC_CAST( XHierarchicalNameAccess*, this ),
-                                     SAL_STATIC_CAST( XChangesNotifier*, this ),
-                                     SAL_STATIC_CAST( XComponent*, this ) );
+                                     (static_cast< XTypeProvider* >(this)),
+                                     (static_cast< XNameAccess* >(this)),
+                                     (static_cast< XHierarchicalNameAccess* >(this)),
+                                     (static_cast< XChangesNotifier* >(this)),
+                                     (static_cast< XComponent* >(this)) );
 
     return aRet.hasValue() ? aRet : OWeakObject::queryInterface( rType );
 }
@@ -307,8 +307,8 @@ TVRead::TVRead( const ConfigData& configData,TVDom* tvDom )
     if( tvDom->isLeaf() )
     {
         TargetURL = ( tvDom->getTargetURL() + configData.appendix );
-        if( tvDom->anchor.getLength() )
-            TargetURL += ( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "#" )) +
+        if( !tvDom->anchor.isEmpty() )
+            TargetURL += ( rtl::OUString( "#" ) +
                            tvDom->anchor );
     }
     else
@@ -363,9 +363,9 @@ TVRead::getElementNames( )
 {
     Sequence< rtl::OUString > seq( 3 );
 
-    seq[0] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Title" ));
-    seq[1] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "TargetURL" ));
-    seq[2] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Children" ));
+    seq[0] = rtl::OUString( "Title" );
+    seq[1] = rtl::OUString( "TargetURL" );
+    seq[2] = rtl::OUString( "Children" );
 
     return seq;
 }
@@ -491,9 +491,9 @@ extern "C" void data_handler( void *userData,
 
 TVChildTarget::TVChildTarget( const ConfigData& configData,TVDom* tvDom )
 {
-    Elements.resize( tvDom->childs.size() );
+    Elements.resize( tvDom->children.size() );
     for( unsigned i = 0; i < Elements.size(); ++i )
-        Elements[i] = new TVRead( configData,tvDom->childs[i] );
+        Elements[i] = new TVRead( configData,tvDom->children[i] );
 }
 
 
@@ -504,8 +504,7 @@ TVChildTarget::TVChildTarget( const Reference< XMultiServiceFactory >& xMSF )
 {
     ConfigData configData = init( xMSF );
 
-    if( ! configData.locale.getLength()  ||
-        ! configData.system.getLength() )
+    if( configData.locale.isEmpty() || configData.system.isEmpty() )
         return;
 
     sal_uInt64  ret,len = 0;
@@ -541,9 +540,9 @@ TVChildTarget::TVChildTarget( const Reference< XMultiServiceFactory >& xMSF )
 
     // now TVDom holds the relevant information
 
-    Elements.resize( tvDom.childs.size() );
+    Elements.resize( tvDom.children.size() );
     for( unsigned i = 0; i < Elements.size(); ++i )
-        Elements[i] = new TVRead( configData,tvDom.childs[i] );
+        Elements[i] = new TVRead( configData,tvDom.children[i] );
 }
 
 
@@ -665,9 +664,9 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
     rtl::OUString system( getKey( xHierAccess,"Help/System" ) );
     sal_Bool showBasic( getBooleanKey(xHierAccess,"Help/ShowBasic") );
     rtl::OUString instPath( getKey( xHierAccess,"Path/Current/Help" ) );
-    if( ! instPath.getLength() )
+    if( instPath.isEmpty() )
       // try to determine path from default
-      instPath = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "$(instpath)/help" ));
+      instPath = rtl::OUString( "$(instpath)/help" );
 
     // replace anything like $(instpath);
     subst( xSMgr,instPath );
@@ -685,21 +684,21 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
     try
     {
         uno::Reference< lang::XMultiServiceFactory > xConfigProvider(
-              xSMgr ->createInstance(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.configuration.ConfigurationProvider"))), uno::UNO_QUERY_THROW);
+              xSMgr ->createInstance(::rtl::OUString("com.sun.star.configuration.ConfigurationProvider")), uno::UNO_QUERY_THROW);
 
         uno::Sequence < uno::Any > lParams(1);
         beans::PropertyValue                       aParam ;
-        aParam.Name    = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("nodepath"));
-        aParam.Value <<= ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/org.openoffice.Setup/Product"));
+        aParam.Name    = ::rtl::OUString("nodepath");
+        aParam.Value <<= ::rtl::OUString("/org.openoffice.Setup/Product");
         lParams[0] = uno::makeAny(aParam);
 
         // open it
         uno::Reference< uno::XInterface > xCFG( xConfigProvider->createInstanceWithArguments(
-                    ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.configuration.ConfigurationAccess")),
+                    ::rtl::OUString("com.sun.star.configuration.ConfigurationAccess"),
                     lParams) );
 
         uno::Reference< container::XNameAccess > xDirectAccess(xCFG, uno::UNO_QUERY);
-        uno::Any aRet = xDirectAccess->getByName(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ooSetupExtension")));
+        uno::Any aRet = xDirectAccess->getByName(::rtl::OUString("ooSetupExtension"));
 
         aRet >>= setupextension;
     }
@@ -708,7 +707,7 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
     }
 
     rtl::OUString productVersion( setupversion +
-                                  rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( " " )) +
+                                  rtl::OUString( " " ) +
                                   setupextension );
     rtl::OUString locale( getKey( xHierAccess,"L10N/ooLocale" ) );
 
@@ -718,7 +717,7 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
     osl::FileBase::RC errFile = osl::FileBase::getFileURLFromSystemPath( instPath,url );
     if( errFile != osl::FileBase::E_None ) return configData;
     if( url.lastIndexOf( sal_Unicode( '/' ) ) != url.getLength() - 1 )
-        url += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "/" ));
+        url += rtl::OUString( "/" );
     rtl::OUString ret;
     sal_Int32 idx;
     osl::DirectoryItem aDirItem;
@@ -731,8 +730,8 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
         ret = locale.copy( 0,idx );
     else
         {
-        locale = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "en-US" ));
-        ret = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("en"));
+        locale = rtl::OUString( "en-US" );
+        ret = rtl::OUString("en");
         }
     url = url + ret;
 
@@ -742,7 +741,7 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
     TreeFileIterator aTreeIt( locale );
     rtl::OUString aTreeFile;
     sal_Int32 nFileSize;
-    while( (aTreeFile = aTreeIt.nextTreeFile( nFileSize ) ).getLength() > 0 )
+    while( !(aTreeFile = aTreeIt.nextTreeFile( nFileSize ) ).isEmpty() )
     {
         configData.vFileLen.push_back( nFileSize );
         configData.vFileURL.push_back( aTreeFile );
@@ -805,11 +804,11 @@ ConfigData TVChildTarget::init( const Reference< XMultiServiceFactory >& xSMgr )
        configData.system = system;
     configData.locale = locale;
     configData.appendix =
-        rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "?Language=" )) +
+        rtl::OUString( "?Language=" ) +
         configData.locale +
-        rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "&System=" )) +
+        rtl::OUString( "&System=" ) +
         configData.system +
-        rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "&UseDB=no" )) ;
+        rtl::OUString( "&UseDB=no" ) ;
 
     return configData;
 }
@@ -831,7 +830,7 @@ TVChildTarget::getConfiguration(const Reference< XMultiServiceFactory >& m_xSMgr
         try
         {
             rtl::OUString sProviderService =
-                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.configuration.ConfigurationProvider" ));
+                rtl::OUString( "com.sun.star.configuration.ConfigurationProvider" );
             sProvider =
                 Reference< XMultiServiceFactory >(
                     m_xSMgr->createInstance( sProviderService ),
@@ -858,7 +857,7 @@ TVChildTarget::getHierAccess( const Reference< XMultiServiceFactory >& sProvider
     {
         Sequence< Any > seq(1);
         rtl::OUString sReaderService =
-            rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.configuration.ConfigurationAccess" ));
+            rtl::OUString( "com.sun.star.configuration.ConfigurationAccess" );
 
         seq[0] <<= rtl::OUString::createFromAscii( file );
 
@@ -935,7 +934,7 @@ void TVChildTarget::subst( const Reference< XMultiServiceFactory >& m_xSMgr,
         {
             xCfgMgr =
                 Reference< XConfigManager >(
-                    m_xSMgr->createInstance( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.config.SpecialConfigManager" )) ),
+                    m_xSMgr->createInstance( rtl::OUString( "com.sun.star.config.SpecialConfigManager" ) ),
                     UNO_QUERY );
         }
         catch( const com::sun::star::uno::Exception& )
@@ -954,9 +953,9 @@ void TVChildTarget::subst( const Reference< XMultiServiceFactory >& m_xSMgr,
 //===================================================================
 // class ExtensionIteratorBase
 
-static rtl::OUString aSlash(RTL_CONSTASCII_USTRINGPARAM("/"));
-static rtl::OUString aHelpFilesBaseName(RTL_CONSTASCII_USTRINGPARAM("help"));
-static rtl::OUString aHelpMediaType(RTL_CONSTASCII_USTRINGPARAM( "application/vnd.sun.star.help"));
+static rtl::OUString aSlash("/");
+static rtl::OUString aHelpFilesBaseName("help");
+static rtl::OUString aHelpMediaType("application/vnd.sun.star.help");
 
 ExtensionIteratorBase::ExtensionIteratorBase( const rtl::OUString& aLanguage )
         : m_eState( USER_EXTENSIONS )
@@ -973,19 +972,19 @@ void ExtensionIteratorBase::init()
     if (xProps.is())
     {
         xProps->getPropertyValue(
-            ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("DefaultContext") ) ) >>= m_xContext;
+            ::rtl::OUString( "DefaultContext" ) ) >>= m_xContext;
         OSL_ASSERT( m_xContext.is() );
     }
     if( !m_xContext.is() )
     {
         throw RuntimeException(
-            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "ExtensionIteratorBase::init(), no XComponentContext" )),
+            ::rtl::OUString( "ExtensionIteratorBase::init(), no XComponentContext" ),
             Reference< XInterface >() );
     }
 
     Reference< XMultiComponentFactory > xSMgr( m_xContext->getServiceManager(), UNO_QUERY );
     m_xSFA = Reference< ucb::XSimpleFileAccess >(
-        xSMgr->createInstanceWithContext( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.ucb.SimpleFileAccess" )),
+        xSMgr->createInstanceWithContext( rtl::OUString( "com.sun.star.ucb.SimpleFileAccess" ),
         m_xContext ), UNO_QUERY_THROW );
 
     m_bUserPackagesLoaded = false;
@@ -1056,7 +1055,7 @@ Reference< deployment::XPackage > ExtensionIteratorBase::implGetNextUserHelpPack
     if( !m_bUserPackagesLoaded )
     {
         Reference< XPackageManager > xUserManager =
-            thePackageManagerFactory::get( m_xContext )->getPackageManager( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("user")) );
+            thePackageManagerFactory::get( m_xContext )->getPackageManager( rtl::OUString("user") );
         m_aUserPackagesSeq = xUserManager->getDeployedPackages
             ( Reference< task::XAbortChannel >(), Reference< ucb::XCommandEnvironment >() );
 
@@ -1086,7 +1085,7 @@ Reference< deployment::XPackage > ExtensionIteratorBase::implGetNextSharedHelpPa
     if( !m_bSharedPackagesLoaded )
     {
         Reference< XPackageManager > xSharedManager =
-            thePackageManagerFactory::get( m_xContext )->getPackageManager( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("shared")) );
+            thePackageManagerFactory::get( m_xContext )->getPackageManager( rtl::OUString("shared") );
         m_aSharedPackagesSeq = xSharedManager->getDeployedPackages
             ( Reference< task::XAbortChannel >(), Reference< ucb::XCommandEnvironment >() );
 
@@ -1116,7 +1115,7 @@ Reference< deployment::XPackage > ExtensionIteratorBase::implGetNextBundledHelpP
     if( !m_bBundledPackagesLoaded )
     {
         Reference< XPackageManager > xBundledManager =
-            thePackageManagerFactory::get( m_xContext )->getPackageManager( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("bundled")) );
+            thePackageManagerFactory::get( m_xContext )->getPackageManager( rtl::OUString("bundled") );
         m_aBundledPackagesSeq = xBundledManager->getDeployedPackages
             ( Reference< task::XAbortChannel >(), Reference< ucb::XCommandEnvironment >() );
 
@@ -1183,7 +1182,7 @@ rtl::OUString TreeFileIterator::nextTreeFile( sal_Int32& rnFileSize )
 {
     rtl::OUString aRetFile;
 
-    while( !aRetFile.getLength() && m_eState != END_REACHED )
+    while( aRetFile.isEmpty() && m_eState != END_REACHED )
     {
         switch( m_eState )
         {
@@ -1240,18 +1239,18 @@ rtl::OUString TreeFileIterator::expandURL( const rtl::OUString& aURL )
         Reference< XMultiComponentFactory > xSMgr( m_xContext->getServiceManager(), UNO_QUERY );
 
         xFac = Reference< uri::XUriReferenceFactory >(
-            xSMgr->createInstanceWithContext( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-            "com.sun.star.uri.UriReferenceFactory")), m_xContext ) , UNO_QUERY );
+            xSMgr->createInstanceWithContext( rtl::OUString(
+            "com.sun.star.uri.UriReferenceFactory"), m_xContext ) , UNO_QUERY );
         if( !xFac.is() )
         {
             throw RuntimeException(
-                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Databases::expand(), could not instatiate UriReferenceFactory." )),
+                ::rtl::OUString( "Databases::expand(), could not instatiate UriReferenceFactory." ),
                 Reference< XInterface >() );
         }
 
         xMacroExpander = Reference< util::XMacroExpander >(
             m_xContext->getValueByName(
-            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "/singletons/com.sun.star.util.theMacroExpander" )) ),
+            ::rtl::OUString( "/singletons/com.sun.star.util.theMacroExpander" ) ),
             UNO_QUERY_THROW );
      }
 
