@@ -84,7 +84,7 @@ void lcl_setRoleAtLabeledSequence(
     {
         uno::Reference< beans::XPropertySet > xProp( xValues, uno::UNO_QUERY );
         if( xProp.is())
-            xProp->setPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM( "Role" )), uno::makeAny( rRole ));
+            xProp->setPropertyValue(OUString( "Role" ), uno::makeAny( rRole ));
     }
 }
 
@@ -339,7 +339,7 @@ void SchXMLChartContext::StartElement( const uno::Reference< xml::sax::XAttribut
         }
     }
 
-    if( aOldChartTypeName.getLength()<= 0 )
+    if( aOldChartTypeName.isEmpty() )
     {
         OSL_FAIL( "need a charttype to create a diagram" );
         //set a fallback value:
@@ -363,9 +363,9 @@ void SchXMLChartContext::StartElement( const uno::Reference< xml::sax::XAttribut
         {
             try
             {
-                xDocProp->getPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "BaseDiagram" ))) >>= aOldChartTypeName;
+                xDocProp->getPropertyValue( ::rtl::OUString( "BaseDiagram" )) >>= aOldChartTypeName;
                 maChartTypeServiceName =  SchXMLTools::GetNewChartTypeName( aOldChartTypeName );
-                xDocProp->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "RefreshAddInAllowed" )) , uno::makeAny( sal_False) );
+                xDocProp->setPropertyValue( rtl::OUString( "RefreshAddInAllowed" ) , uno::makeAny( sal_False) );
             }
             catch(const uno::Exception&)
             {
@@ -445,8 +445,8 @@ struct NewDonutSeries
             {
                 aPointStyle.msSeriesStyleNameForDonuts = m_aSeriesStyles[nPointIndex];
             }
-            if( aPointStyle.msSeriesStyleNameForDonuts.getLength()
-                || aPointStyle.msStyleName.getLength() )
+            if( !aPointStyle.msSeriesStyleNameForDonuts.isEmpty()
+                || !aPointStyle.msStyleName.isEmpty() )
                 aRet.push_back( aPointStyle );
             ++aPointIt;
             ++nPointIndex;
@@ -581,8 +581,7 @@ bool lcl_SpecialHandlingForDonutChartNeeded(
     const SvXMLImport & rImport )
 {
     bool bResult = false;
-    if( rServiceName.equalsAsciiL(
-            RTL_CONSTASCII_STRINGPARAM( "com.sun.star.chart2.DonutChartType" )))
+    if( rServiceName == "com.sun.star.chart2.DonutChartType" )
     {
         bResult = SchXMLTools::isDocumentGeneratedWithOpenOfficeOlderThan2_3( rImport.GetModel() );
     }
@@ -622,24 +621,24 @@ void lcl_ApplyDataFromRectangularRangeToDiagram(
 
     uno::Sequence< beans::PropertyValue > aArgs( 3 );
     aArgs[0] = beans::PropertyValue(
-        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "CellRangeRepresentation" )),
+        ::rtl::OUString( "CellRangeRepresentation" ),
         -1, uno::makeAny( rRectangularRange ),
         beans::PropertyState_DIRECT_VALUE );
     aArgs[1] = beans::PropertyValue(
-        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "DataRowSource" )),
+        ::rtl::OUString( "DataRowSource" ),
         -1, uno::makeAny( eDataRowSource ),
         beans::PropertyState_DIRECT_VALUE );
     aArgs[2] = beans::PropertyValue(
-        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "FirstCellAsLabel" )),
+        ::rtl::OUString( "FirstCellAsLabel" ),
         -1, uno::makeAny( bFirstCellAsLabel ),
         beans::PropertyState_DIRECT_VALUE );
 
-    if( sColTrans.getLength() || sRowTrans.getLength() )
+    if( !sColTrans.isEmpty() || !sRowTrans.isEmpty() )
     {
         aArgs.realloc( aArgs.getLength() + 1 );
         aArgs[ aArgs.getLength() - 1 ] = beans::PropertyValue(
-            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "SequenceMapping" )),
-            -1, uno::makeAny( sColTrans.getLength()
+            ::rtl::OUString( "SequenceMapping" ),
+            -1, uno::makeAny( !sColTrans.isEmpty()
                 ? lcl_getNumberSequenceFromString( sColTrans, bHasCateories && !xNewDoc->hasInternalDataProvider() )
                 : lcl_getNumberSequenceFromString( sRowTrans, bHasCateories && !xNewDoc->hasInternalDataProvider() ) ),
         beans::PropertyState_DIRECT_VALUE );
@@ -654,17 +653,17 @@ void lcl_ApplyDataFromRectangularRangeToDiagram(
             comphelper::MediaDescriptor aMediaDescriptor( xModel->getArgs() );
 
             comphelper::MediaDescriptor::const_iterator aIt(
-                aMediaDescriptor.find( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "HierarchicalDocumentName" ))));
+                aMediaDescriptor.find( rtl::OUString(  "HierarchicalDocumentName" )));
             if( aIt != aMediaDescriptor.end() )
             {
                 aChartOleObjectName = (*aIt).second.get< ::rtl::OUString >();
             }
         }
-        if( aChartOleObjectName.getLength() )
+        if( !aChartOleObjectName.isEmpty() )
         {
             aArgs.realloc( aArgs.getLength() + 1 );
             aArgs[ aArgs.getLength() - 1 ] = beans::PropertyValue(
-                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "ChartOleObjectName" )),
+                ::rtl::OUString( "ChartOleObjectName" ),
                 -1, uno::makeAny( aChartOleObjectName ),
                 beans::PropertyState_DIRECT_VALUE );
         }
@@ -676,11 +675,11 @@ void lcl_ApplyDataFromRectangularRangeToDiagram(
 
     aArgs.realloc( aArgs.getLength() + 2 );
     aArgs[ aArgs.getLength() - 2 ] = beans::PropertyValue(
-        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "HasCategories" )),
+        ::rtl::OUString( "HasCategories" ),
         -1, uno::makeAny( bHasCateories ),
         beans::PropertyState_DIRECT_VALUE );
     aArgs[ aArgs.getLength() - 1 ] = beans::PropertyValue(
-        ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("UseCategoriesAsX")),
+        ::rtl::OUString("UseCategoriesAsX"),
         -1, uno::makeAny( sal_False ),//categories in ODF files are not to be used as x values (independent from what is offered in our ui)
         beans::PropertyState_DIRECT_VALUE );
 
@@ -695,7 +694,7 @@ void SchXMLChartContext::EndElement()
 
     if( xProp.is())
     {
-        if( maMainTitle.getLength())
+        if( !maMainTitle.isEmpty())
         {
             uno::Reference< beans::XPropertySet > xTitleProp( xDoc->getTitle(), uno::UNO_QUERY );
             if( xTitleProp.is())
@@ -704,7 +703,7 @@ void SchXMLChartContext::EndElement()
                 {
                     uno::Any aAny;
                     aAny <<= maMainTitle;
-                    xTitleProp->setPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "String" )), aAny );
+                    xTitleProp->setPropertyValue( rtl::OUString(  "String" ), aAny );
                 }
                 catch(const beans::UnknownPropertyException&)
                 {
@@ -712,7 +711,7 @@ void SchXMLChartContext::EndElement()
                 }
             }
         }
-        if( maSubTitle.getLength())
+        if( !maSubTitle.isEmpty())
         {
             uno::Reference< beans::XPropertySet > xTitleProp( xDoc->getSubTitle(), uno::UNO_QUERY );
             if( xTitleProp.is())
@@ -721,7 +720,7 @@ void SchXMLChartContext::EndElement()
                 {
                     uno::Any aAny;
                     aAny <<= maSubTitle;
-                    xTitleProp->setPropertyValue( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "String" )), aAny );
+                    xTitleProp->setPropertyValue( rtl::OUString(  "String" ), aAny );
                 }
                 catch(const beans::UnknownPropertyException&)
                 {
@@ -740,13 +739,13 @@ void SchXMLChartContext::EndElement()
     if( xDiaProp.is())
     {
         if( maSeriesDefaultsAndStyles.maStackedDefault.hasValue())
-            xDiaProp->setPropertyValue(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Stacked")),maSeriesDefaultsAndStyles.maStackedDefault);
+            xDiaProp->setPropertyValue(::rtl::OUString("Stacked"),maSeriesDefaultsAndStyles.maStackedDefault);
         if( maSeriesDefaultsAndStyles.maPercentDefault.hasValue())
-            xDiaProp->setPropertyValue(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Percent")),maSeriesDefaultsAndStyles.maPercentDefault);
+            xDiaProp->setPropertyValue(::rtl::OUString("Percent"),maSeriesDefaultsAndStyles.maPercentDefault);
         if( maSeriesDefaultsAndStyles.maDeepDefault.hasValue())
-            xDiaProp->setPropertyValue(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Deep")),maSeriesDefaultsAndStyles.maDeepDefault);
+            xDiaProp->setPropertyValue(::rtl::OUString("Deep"),maSeriesDefaultsAndStyles.maDeepDefault);
         if( maSeriesDefaultsAndStyles.maStackedBarsConnectedDefault.hasValue())
-            xDiaProp->setPropertyValue(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("StackedBarsConnected")),maSeriesDefaultsAndStyles.maStackedBarsConnectedDefault);
+            xDiaProp->setPropertyValue(::rtl::OUString("StackedBarsConnected"),maSeriesDefaultsAndStyles.maStackedBarsConnectedDefault);
     }
 
     //the OOo 2.0 implementation and older has a bug with donuts
@@ -758,18 +757,18 @@ void SchXMLChartContext::EndElement()
         return;
 
     bool bHasOwnData = false;
-    if( m_aXLinkHRefAttributeToIndicateDataProvider.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "." ) ) ) //data comes from the chart itself
+    if( m_aXLinkHRefAttributeToIndicateDataProvider == "." ) //data comes from the chart itself
         bHasOwnData = true;
-    else if( m_aXLinkHRefAttributeToIndicateDataProvider.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ".." ) ) ) //data comes from the parent application
+    else if( m_aXLinkHRefAttributeToIndicateDataProvider == ".." ) //data comes from the parent application
         bHasOwnData = false;
-    else if( m_aXLinkHRefAttributeToIndicateDataProvider.getLength() ) //not supported so far to get the data by sibling objects -> fall back to chart itself if data are available
+    else if( !m_aXLinkHRefAttributeToIndicateDataProvider.isEmpty() ) //not supported so far to get the data by sibling objects -> fall back to chart itself if data are available
         bHasOwnData = m_bHasTableElement;
     else
         bHasOwnData = !m_bHasRangeAtPlotArea;
 
     if( xNewDoc->hasInternalDataProvider())
     {
-        if( !m_bHasTableElement && !m_aXLinkHRefAttributeToIndicateDataProvider.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "." ) ) )
+        if( !m_bHasTableElement && m_aXLinkHRefAttributeToIndicateDataProvider != "." )
         {
             //#i103147# ODF, workaround broken files with a missing table:cell-range-address at the plot-area
             bool bSwitchSuccessful = SchXMLTools::switchBackToDataProviderFromParent( xNewDoc, maLSequencesPerIndex );
@@ -783,7 +782,7 @@ void SchXMLChartContext::EndElement()
         xNewDoc->createInternalDataProvider( sal_False /* bCloneExistingData */ );
     }
     if( bHasOwnData )
-        msChartAddress = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "all" ));
+        msChartAddress = ::rtl::OUString( "all" );
 
     bool bSwitchRangesFromOuterToInternalIfNecessary = false;
     if( !bHasOwnData && mbAllRangeAddressesAvailable )
@@ -792,7 +791,7 @@ void SchXMLChartContext::EndElement()
         if( mbIsStockChart )
             MergeSeriesForStockChart();
     }
-    else if( msChartAddress.getLength() )
+    else if( !msChartAddress.isEmpty() )
     {
         //own data or only rectangular range available
 
@@ -817,7 +816,7 @@ void SchXMLChartContext::EndElement()
             try
             {
                 if( bOlderThan2_3 && xDiaProp.is() )//for older charts the hidden cells were removed by calc on the fly
-                    xDiaProp->setPropertyValue(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("IncludeHiddenCells")),uno::makeAny(false));
+                    xDiaProp->setPropertyValue(::rtl::OUString("IncludeHiddenCells"),uno::makeAny(false));
 
                 // note: mbRowHasLabels means the first row contains labels, that means we have "column-descriptions",
                 // (analogously mbColHasLabels means we have "row-descriptions")
@@ -830,7 +829,7 @@ void SchXMLChartContext::EndElement()
                 if(!bHasOwnData)
                 {
                     bHasOwnData = true;
-                    msChartAddress = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "all" ));
+                    msChartAddress = ::rtl::OUString( "all" );
                     if( !xNewDoc->hasInternalDataProvider() )
                     {
                         xNewDoc->createInternalDataProvider( sal_False /* bCloneExistingData */ );
@@ -915,7 +914,7 @@ void SchXMLChartContext::EndElement()
     }
 
     if( xProp.is())
-        xProp->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "RefreshAddInAllowed" )) , uno::makeAny( sal_True) );
+        xProp->setPropertyValue( rtl::OUString( "RefreshAddInAllowed" ) , uno::makeAny( sal_True) );
 }
 
 void SchXMLChartContext::MergeSeriesForStockChart()
@@ -939,12 +938,11 @@ void SchXMLChartContext::MergeSeriesForStockChart()
             uno::Sequence< uno::Reference< chart2::XChartType > > aChartTypes( xCTCnt->getChartTypes());
             for( sal_Int32 nCTIdx=0; nCTIdx<aChartTypes.getLength(); ++nCTIdx )
             {
-                if( aChartTypes[nCTIdx]->getChartType().equalsAsciiL(
-                        RTL_CONSTASCII_STRINGPARAM("com.sun.star.chart2.CandleStickChartType")))
+                if( aChartTypes[nCTIdx]->getChartType() == "com.sun.star.chart2.CandleStickChartType" )
                 {
                     xDSContainer.set( aChartTypes[nCTIdx], uno::UNO_QUERY_THROW );
                     uno::Reference< beans::XPropertySet > xCTProp( aChartTypes[nCTIdx], uno::UNO_QUERY_THROW );
-                    xCTProp->getPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Japanese" ))) >>= bHasJapaneseCandlestick;
+                    xCTProp->getPropertyValue( ::rtl::OUString( "Japanese" )) >>= bHasJapaneseCandlestick;
                     break;
                 }
             }
@@ -966,27 +964,27 @@ void SchXMLChartContext::MergeSeriesForStockChart()
                 if( bHasJapaneseCandlestick )
                 {
                     // open values
-                    lcl_setRoleAtFirstSequence( aSeriesSeq[ nSeriesIndex ], OUString(RTL_CONSTASCII_USTRINGPARAM( "values-first" )));
+                    lcl_setRoleAtFirstSequence( aSeriesSeq[ nSeriesIndex ], OUString( "values-first" ));
                     aNewSeries[i] = aSeriesSeq[ nSeriesIndex ];
                     // low values
                     lcl_MoveDataToCandleStickSeries(
                         uno::Reference< chart2::data::XDataSource >( aSeriesSeq[ ++nSeriesIndex ], uno::UNO_QUERY_THROW ),
-                        aNewSeries[i], OUString(RTL_CONSTASCII_USTRINGPARAM( "values-min" )));
+                        aNewSeries[i], OUString( "values-min" ));
                 }
                 else
                 {
                     // low values
-                    lcl_setRoleAtFirstSequence( aSeriesSeq[ nSeriesIndex ], OUString(RTL_CONSTASCII_USTRINGPARAM( "values-min" )));
+                    lcl_setRoleAtFirstSequence( aSeriesSeq[ nSeriesIndex ], OUString( "values-min" ));
                     aNewSeries[i] = aSeriesSeq[ nSeriesIndex ];
                 }
                 // high values
                 lcl_MoveDataToCandleStickSeries(
                     uno::Reference< chart2::data::XDataSource >( aSeriesSeq[ ++nSeriesIndex ], uno::UNO_QUERY_THROW ),
-                    aNewSeries[i], OUString(RTL_CONSTASCII_USTRINGPARAM( "values-max" )));
+                    aNewSeries[i], OUString( "values-max" ));
                 // close values
                 lcl_MoveDataToCandleStickSeries(
                     uno::Reference< chart2::data::XDataSource >( aSeriesSeq[ ++nSeriesIndex ], uno::UNO_QUERY_THROW ),
-                    aNewSeries[i], OUString(RTL_CONSTASCII_USTRINGPARAM( "values-last" )));
+                    aNewSeries[i], OUString( "values-last" ));
             }
             xDSContainer->setDataSeries( aNewSeries );
         }
@@ -1029,7 +1027,7 @@ SvXMLImportContext* SchXMLChartContext::CreateChildContext(
             {
                 if( xProp.is())
                 {
-                    xProp->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "HasMainTitle" )), aTrueBool );
+                    xProp->setPropertyValue( rtl::OUString( "HasMainTitle" ), aTrueBool );
                 }
                 uno::Reference< drawing::XShape > xTitleShape( xDoc->getTitle(), uno::UNO_QUERY );
                 pContext = new SchXMLTitleContext( mrImportHelper, GetImport(),
@@ -1042,7 +1040,7 @@ SvXMLImportContext* SchXMLChartContext::CreateChildContext(
             {
                 if( xProp.is())
                 {
-                    xProp->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "HasSubTitle" )), aTrueBool );
+                    xProp->setPropertyValue( rtl::OUString( "HasSubTitle" ), aTrueBool );
                 }
                 uno::Reference< drawing::XShape > xTitleShape( xDoc->getSubTitle(), uno::UNO_QUERY );
                 pContext = new SchXMLTitleContext( mrImportHelper, GetImport(),
@@ -1066,17 +1064,17 @@ SvXMLImportContext* SchXMLChartContext::CreateChildContext(
                 // (which is required in the ODF spec)
                 // Note: For stock charts and donut charts with special handling
                 // the mapping must not be applied!
-                if( !msChartAddress.getLength() && !mbIsStockChart &&
+                if( msChartAddress.isEmpty() && !mbIsStockChart &&
                     !lcl_SpecialHandlingForDonutChartNeeded(
                         maChartTypeServiceName, GetImport()))
                 {
-                    if( msColTrans.getLength() > 0 )
+                    if( !msColTrans.isEmpty() )
                     {
-                        OSL_ASSERT( msRowTrans.getLength() == 0 );
+                        OSL_ASSERT( msRowTrans.isEmpty() );
                         pTableContext->setColumnPermutation( lcl_getNumberSequenceFromString( msColTrans, true ));
                         msColTrans = OUString();
                     }
-                    else if( msRowTrans.getLength() > 0 )
+                    else if( !msRowTrans.isEmpty() )
                     {
                         pTableContext->setRowPermutation( lcl_getNumberSequenceFromString( msRowTrans, true ));
                         msRowTrans = OUString();
@@ -1135,8 +1133,7 @@ void SchXMLChartContext::InitChart(
     }
 
     //  Set the chart type via setting the diagram.
-    if( rChartTypeServiceName.getLength() &&
-        xDoc.is())
+    if( !rChartTypeServiceName.isEmpty() && xDoc.is())
     {
         uno::Reference< lang::XMultiServiceFactory > xFact( xDoc, uno::UNO_QUERY );
         if( xFact.is())
