@@ -26,10 +26,9 @@
  *
  ************************************************************************/
 
+#include "sal/config.h"
 
-#ifdef PRECOMPILED
-#include "filt_pch.hxx"
-#endif
+#include <officecfg/Office/Common.hxx>
 #include <xmloff/unointerfacetouniqueidentifiermapper.hxx>
 #include <osl/mutex.hxx>
 #include <tools/debug.hxx>
@@ -43,7 +42,6 @@
 #include <com/sun/star/uri/UriReferenceFactory.hpp>
 #include <com/sun/star/util/MeasureUnit.hpp>
 #include <comphelper/processfactory.hxx>
-#include <comphelper/configurationhelper.hxx>
 #include <xmloff/attrlist.hxx>
 #include <xmloff/nmspmap.hxx>
 #include <xmloff/xmluconv.hxx>
@@ -58,7 +56,6 @@
 #include "XMLStarBasicExportHandler.hxx"
 #include "XMLScriptExportHandler.hxx"
 #include <xmloff/SettingsExportHelper.hxx>
-#include <com/sun/star/container/XNameAccess.hpp>
 #include <com/sun/star/container/XIndexContainer.hpp>
 #include <com/sun/star/document/XEventsSupplier.hpp>
 #include <com/sun/star/document/XViewDataSupplier.hpp>
@@ -77,7 +74,6 @@
 #include "xmloff/XMLFilterServiceNames.h"
 #include "xmloff/XMLEmbeddedObjectExportFilter.hxx"
 #include "XMLBasicExportFilter.hxx"
-#include <osl/mutex.hxx>
 #include <rtl/logfile.hxx>
 #include <cppuhelper/implbase1.hxx>
 #include <comphelper/extract.hxx>
@@ -130,8 +126,6 @@ const sal_Char s_grddl_xsl[] = "http://FIXME";
 
 #define XML_USEPRETTYPRINTING       "UsePrettyPrinting"
 
-#define C2U(cChar) OUString( RTL_CONSTASCII_USTRINGPARAM(cChar) )
-
 struct XMLServiceMapEntry_Impl
 {
     const sal_Char *sModelService;
@@ -380,6 +374,9 @@ void SvXMLExport::_InitCtor()
         {
             mpNamespaceMap->Add(
                 GetXMLToken(XML_NP_TABLE_EXT), GetXMLToken(XML_N_TABLE_EXT), XML_NAMESPACE_TABLE_EXT);
+            mpNamespaceMap->Add(
+                GetXMLToken(XML_NP_CALC_EXT), GetXMLToken(XML_N_CALC_EXT), XML_NAMESPACE_CALC_EXT);
+
         }
     }
     if( (getExportFlags() & (EXPORT_MASTERSTYLES|EXPORT_CONTENT) ) != 0 )
@@ -421,8 +418,8 @@ void SvXMLExport::_InitCtor()
 
     mxAttrList = (xml::sax::XAttributeList*)mpAttrList;
 
-    msGraphicObjectProtocol = OUString( RTL_CONSTASCII_USTRINGPARAM( "vnd.sun.star.GraphicObject:" ) );
-    msEmbeddedObjectProtocol = OUString( RTL_CONSTASCII_USTRINGPARAM( "vnd.sun.star.EmbeddedObject:" ) );
+    msGraphicObjectProtocol = OUString(  "vnd.sun.star.GraphicObject:"  );
+    msEmbeddedObjectProtocol = OUString(  "vnd.sun.star.EmbeddedObject:"  );
 
     if (mxModel.is() && !mxEventListener.is())
     {
@@ -438,14 +435,10 @@ void SvXMLExport::_InitCtor()
     // cl: but only if we do export to current oasis format, old openoffice format *must* always be compatible
     if( (getExportFlags() & EXPORT_OASIS) != 0 )
     {
-        sal_Bool bTemp = sal_True;
-        if ( ::comphelper::ConfigurationHelper::readDirectKey(
-                getServiceFactory(),
-                C2U("org.openoffice.Office.Common/"), C2U("Save/Document"), C2U("SaveBackwardCompatibleODF"),
-                ::comphelper::ConfigurationHelper::E_READONLY ) >>= bTemp )
-        {
-            mpImpl->mbSaveBackwardCompatibleODF = bTemp;
-        }
+        mpImpl->mbSaveBackwardCompatibleODF =
+            officecfg::Office::Common::Save::Document::
+            SaveBackwardCompatibleODF::get(
+                mpImpl->mxComponentContext);
     }
 }
 
@@ -558,46 +551,6 @@ SvXMLExport::SvXMLExport(
         mpNumExport = new SvXMLNumFmtExport(*this, mxNumberFormatsSupplier);
 }
 
-SvXMLExport::SvXMLExport(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory >& xServiceFactory,
-    const OUString &rFileName,
-    const uno::Reference< xml::sax::XDocumentHandler > & rHandler,
-    const Reference< XModel >& rModel,
-    const Reference< document::XGraphicObjectResolver >& rEmbeddedGraphicObjects,
-    sal_Int16 const eDefaultFieldUnit)
-:   mpImpl( new SvXMLExport_Impl ),
-    mxServiceFactory(xServiceFactory),
-    mxModel( rModel ),
-    mxHandler( rHandler ),
-    mxExtHandler( rHandler, uno::UNO_QUERY ),
-    mxNumberFormatsSupplier (rModel, uno::UNO_QUERY),
-    mxGraphicResolver( rEmbeddedGraphicObjects ),
-    mpAttrList( new SvXMLAttributeList ),
-    msOrigFileName( rFileName ),
-    mpNamespaceMap( new SvXMLNamespaceMap ),
-    mpUnitConv( new SvXMLUnitConverter(getServiceFactory(),
-                util::MeasureUnit::MM_100TH,
-                SvXMLUnitConverter::GetMeasureUnit(eDefaultFieldUnit)) ),
-    mpNumExport(0L),
-    mpProgressBarHelper( NULL ),
-    mpEventExport( NULL ),
-    mpImageMapExport( NULL ),
-    mpXMLErrors( NULL ),
-    mbExtended( sal_False ),
-    meClass( XML_TOKEN_INVALID ),
-    mnExportFlags( 0 ),
-    mnErrorFlags( ERROR_NO ),
-    msWS( GetXMLToken(XML_WS) ),
-    mbSaveLinkedSections(sal_True)
-{
-    mpImpl->SetSchemeOf( msOrigFileName );
-    DBG_ASSERT( mxServiceFactory.is(), "got no service manager" );
-    _InitCtor();
-
-    if (mxNumberFormatsSupplier.is())
-        mpNumExport = new SvXMLNumFmtExport(*this, mxNumberFormatsSupplier);
-}
-
 SvXMLExport::~SvXMLExport()
 {
     delete mpXMLErrors;
@@ -614,9 +567,9 @@ SvXMLExport::~SvXMLExport()
             {
                 if (mpProgressBarHelper)
                 {
-                    OUString sProgressMax(RTL_CONSTASCII_USTRINGPARAM(XML_PROGRESSMAX));
-                    OUString sProgressCurrent(RTL_CONSTASCII_USTRINGPARAM(XML_PROGRESSCURRENT));
-                    OUString sRepeat(RTL_CONSTASCII_USTRINGPARAM(XML_PROGRESSREPEAT));
+                    OUString sProgressMax(XML_PROGRESSMAX);
+                    OUString sProgressCurrent(XML_PROGRESSCURRENT);
+                    OUString sRepeat(XML_PROGRESSREPEAT);
                     if (xPropertySetInfo->hasPropertyByName(sProgressMax) &&
                         xPropertySetInfo->hasPropertyByName(sProgressCurrent))
                     {
@@ -633,7 +586,7 @@ SvXMLExport::~SvXMLExport()
                 }
                 if (mpNumExport && (mnExportFlags & (EXPORT_AUTOSTYLES | EXPORT_STYLES)))
                 {
-                    OUString sWrittenNumberFormats(RTL_CONSTASCII_USTRINGPARAM(XML_WRITTENNUMBERSTYLES));
+                    OUString sWrittenNumberFormats(XML_WRITTENNUMBERSTYLES);
                     if (xPropertySetInfo->hasPropertyByName(sWrittenNumberFormats))
                     {
                         uno::Sequence<sal_Int32> aWasUsed;
@@ -683,7 +636,7 @@ void SAL_CALL SvXMLExport::setSourceDocument( const uno::Reference< lang::XCompo
         uno::Reference< beans::XPropertySetInfo > xPropertySetInfo = mxExportInfo->getPropertySetInfo();
         if (xPropertySetInfo.is())
         {
-            OUString sUsePrettyPrinting(RTL_CONSTASCII_USTRINGPARAM(XML_USEPRETTYPRINTING));
+            OUString sUsePrettyPrinting(XML_USEPRETTYPRINTING);
             if (xPropertySetInfo->hasPropertyByName(sUsePrettyPrinting))
             {
                 uno::Any aAny = mxExportInfo->getPropertyValue(sUsePrettyPrinting);
@@ -695,7 +648,7 @@ void SAL_CALL SvXMLExport::setSourceDocument( const uno::Reference< lang::XCompo
 
             if (mpNumExport && (mnExportFlags & (EXPORT_AUTOSTYLES | EXPORT_STYLES)))
             {
-                OUString sWrittenNumberFormats(RTL_CONSTASCII_USTRINGPARAM(XML_WRITTENNUMBERSTYLES));
+                OUString sWrittenNumberFormats(XML_WRITTENNUMBERSTYLES);
                 if (xPropertySetInfo->hasPropertyByName(sWrittenNumberFormats))
                 {
                     uno::Any aAny = mxExportInfo->getPropertyValue(sWrittenNumberFormats);
@@ -719,8 +672,7 @@ void SAL_CALL SvXMLExport::setSourceDocument( const uno::Reference< lang::XCompo
         try
         {
             Reference < XInterface > xIfc =
-                xFactory->createInstance(OUString(RTL_CONSTASCII_USTRINGPARAM(
-                                            "com.sun.star.xml.NamespaceMap")) );
+                xFactory->createInstance(OUString( "com.sun.star.xml.NamespaceMap") );
             if( xIfc.is() )
             {
                 Reference< XNameAccess > xNamespaceMap( xIfc, UNO_QUERY );
@@ -805,7 +757,7 @@ void SAL_CALL SvXMLExport::initialize( const uno::Sequence< uno::Any >& aArgumen
         uno::Reference< beans::XPropertySetInfo > xPropertySetInfo =
             mxExportInfo->getPropertySetInfo();
         OUString sPropName(
-                RTL_CONSTASCII_USTRINGPARAM("BaseURI" ) );
+                "BaseURI"  );
         if( xPropertySetInfo->hasPropertyByName(sPropName) )
         {
             uno::Any aAny = mxExportInfo->getPropertyValue(sPropName);
@@ -814,23 +766,23 @@ void SAL_CALL SvXMLExport::initialize( const uno::Sequence< uno::Any >& aArgumen
             mpImpl->SetSchemeOf( msOrigFileName );
         }
         OUString sRelPath;
-        sPropName = OUString( RTL_CONSTASCII_USTRINGPARAM("StreamRelPath" ) );
+        sPropName = OUString( "StreamRelPath"  );
         if( xPropertySetInfo->hasPropertyByName(sPropName) )
         {
             uno::Any aAny = mxExportInfo->getPropertyValue(sPropName);
             aAny >>= sRelPath;
         }
         OUString sName;
-        sPropName = OUString( RTL_CONSTASCII_USTRINGPARAM("StreamName" ) );
+        sPropName = OUString( "StreamName"  );
         if( xPropertySetInfo->hasPropertyByName(sPropName) )
         {
             uno::Any aAny = mxExportInfo->getPropertyValue(sPropName);
             aAny >>= sName;
         }
-        if( msOrigFileName.getLength() && sName.getLength() )
+        if( !msOrigFileName.isEmpty() && !sName.isEmpty() )
         {
             INetURLObject aBaseURL( msOrigFileName );
-            if( sRelPath.getLength() )
+            if( !sRelPath.isEmpty() )
                 aBaseURL.insertName( sRelPath );
             aBaseURL.insertName( sName );
             msOrigFileName = aBaseURL.GetMainURL(INetURLObject::DECODE_TO_IURI);
@@ -839,19 +791,19 @@ void SAL_CALL SvXMLExport::initialize( const uno::Sequence< uno::Any >& aArgumen
 
         // Written OpenDocument file format doesn't fit to the created text document (#i69627#)
         const ::rtl::OUString sOutlineStyleAsNormalListStyle(
-                RTL_CONSTASCII_USTRINGPARAM("OutlineStyleAsNormalListStyle") );
+                "OutlineStyleAsNormalListStyle" );
         if( xPropertySetInfo->hasPropertyByName( sOutlineStyleAsNormalListStyle ) )
         {
             uno::Any aAny = mxExportInfo->getPropertyValue( sOutlineStyleAsNormalListStyle );
             aAny >>= (mpImpl->mbOutlineStyleAsNormalListStyle);
         }
 
-        OUString sTargetStorage( RTL_CONSTASCII_USTRINGPARAM("TargetStorage") );
+        OUString sTargetStorage( "TargetStorage" );
         if( xPropertySetInfo->hasPropertyByName( sTargetStorage ) )
             mxExportInfo->getPropertyValue( sTargetStorage ) >>= mpImpl->mxTargetStorage;
 
         const ::rtl::OUString sExportTextNumberElement(
-                RTL_CONSTASCII_USTRINGPARAM("ExportTextNumberElement") );
+                "ExportTextNumberElement" );
         if( xPropertySetInfo->hasPropertyByName( sExportTextNumberElement ) )
         {
             uno::Any aAny = mxExportInfo->getPropertyValue( sExportTextNumberElement );
@@ -875,7 +827,7 @@ sal_Bool SAL_CALL SvXMLExport::filter( const uno::Sequence< beans::PropertyValue
     {
         const sal_uInt32 nTest =
             EXPORT_META|EXPORT_STYLES|EXPORT_CONTENT|EXPORT_SETTINGS;
-        if( (mnExportFlags & nTest) == nTest && !msOrigFileName.getLength() )
+        if( (mnExportFlags & nTest) == nTest && msOrigFileName.isEmpty() )
         {
             // evaluate descriptor only for flat files and if a base URI
             // has not been provided already
@@ -887,12 +839,12 @@ sal_Bool SAL_CALL SvXMLExport::filter( const uno::Sequence< beans::PropertyValue
                 const OUString& rPropName = pProps->Name;
                 const Any& rValue = pProps->Value;
 
-                if( rPropName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "FileName" ) ) )
+                if ( rPropName == "FileName" )
                 {
                     if( !(rValue >>= msOrigFileName ) )
                         return sal_False;
                 }
-                else if (rPropName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "FilterName" ) ) )
+                else if ( rPropName == "FilterName" )
                 {
                     if( !(rValue >>= msFilterName ) )
                         return sal_False;
@@ -973,10 +925,8 @@ uno::Sequence< OUString > SAL_CALL SvXMLExport::getSupportedServiceNames(  )
     throw(uno::RuntimeException)
 {
     uno::Sequence<OUString> aSeq(2);
-    aSeq[0] = OUString(
-        RTL_CONSTASCII_USTRINGPARAM("com.sun.star.document.ExportFilter"));
-    aSeq[1] = OUString(
-        RTL_CONSTASCII_USTRINGPARAM("com.sun.star.xml.XMLExportFilter"));
+    aSeq[0] = OUString( "com.sun.star.document.ExportFilter");
+    aSeq[1] = OUString( "com.sun.star.xml.XMLExportFilter");
     return aSeq;
 }
 
@@ -1178,8 +1128,8 @@ void SvXMLExport::ImplExportStyles( sal_Bool )
     // transfer style names (+ families) TO other components (if appropriate)
     if( ( ( mnExportFlags & EXPORT_CONTENT ) == 0 ) && mxExportInfo.is() )
     {
-        static OUString sStyleNames( RTL_CONSTASCII_USTRINGPARAM("StyleNames") );
-        static OUString sStyleFamilies( RTL_CONSTASCII_USTRINGPARAM("StyleFamilies") );
+        static OUString sStyleNames( "StyleNames" );
+        static OUString sStyleFamilies( "StyleFamilies" );
         uno::Reference< beans::XPropertySetInfo > xPropertySetInfo = mxExportInfo->getPropertySetInfo();
         if ( xPropertySetInfo->hasPropertyByName( sStyleNames ) && xPropertySetInfo->hasPropertyByName( sStyleFamilies ) )
         {
@@ -1196,8 +1146,8 @@ void SvXMLExport::ImplExportStyles( sal_Bool )
 void SvXMLExport::ImplExportAutoStyles( sal_Bool )
 {
     // transfer style names (+ families) FROM other components (if appropriate)
-    OUString sStyleNames( RTL_CONSTASCII_USTRINGPARAM("StyleNames") );
-    OUString sStyleFamilies( RTL_CONSTASCII_USTRINGPARAM("StyleFamilies") );
+    OUString sStyleNames( "StyleNames" );
+    OUString sStyleFamilies( "StyleFamilies" );
     if( ( ( mnExportFlags & EXPORT_STYLES ) == 0 )
         && mxExportInfo.is()
         && mxExportInfo->getPropertySetInfo()->hasPropertyByName( sStyleNames )
@@ -1280,7 +1230,7 @@ lcl_AddGrddl(SvXMLExport & rExport, const sal_Int32 /*nExportMode*/)
     if (EXPORT_SETTINGS != nExportMode) // meta, content, styles
     {
         rExport.AddAttribute( XML_NAMESPACE_GRDDL, XML_TRANSFORMATION,
-            OUString(RTL_CONSTASCII_USTRINGPARAM(s_grddl_xsl)) );
+            OUString(s_grddl_xsl) );
     }
 #endif
 }
@@ -1311,8 +1261,7 @@ sal_uInt32 SvXMLExport::exportDoc( enum ::xmloff::token::XMLTokenEnum eClass )
                 {
                     mxGraphicResolver = Reference< XGraphicObjectResolver >::query(
                         xFactory->createInstance(
-                            OUString(RTL_CONSTASCII_USTRINGPARAM(
-                                "com.sun.star.document.ExportGraphicObjectResolver"))));
+                            OUString( "com.sun.star.document.ExportGraphicObjectResolver")));
                     bOwnGraphicResolver = mxGraphicResolver.is();
                 }
 
@@ -1320,8 +1269,7 @@ sal_uInt32 SvXMLExport::exportDoc( enum ::xmloff::token::XMLTokenEnum eClass )
                 {
                     mxEmbeddedResolver = Reference< XEmbeddedObjectResolver >::query(
                         xFactory->createInstance(
-                            OUString(RTL_CONSTASCII_USTRINGPARAM(
-                                "com.sun.star.document.ExportEmbeddedObjectResolver"))));
+                            OUString( "com.sun.star.document.ExportEmbeddedObjectResolver")));
                     bOwnEmbeddedResolver = mxEmbeddedResolver.is();
                 }
             }
@@ -1351,7 +1299,7 @@ sal_uInt32 SvXMLExport::exportDoc( enum ::xmloff::token::XMLTokenEnum eClass )
                 Any aAny;
                 aAny <<= GetXMLToken( eClass );
                 xConvPropSet->setPropertyValue(
-                        OUString(RTL_CONSTASCII_USTRINGPARAM("Class")), aAny );
+                        OUString("Class"), aAny );
 
                 Reference< XPropertySet > xPropSet =
                     mxExportInfo.is()
@@ -1367,7 +1315,7 @@ sal_uInt32 SvXMLExport::exportDoc( enum ::xmloff::token::XMLTokenEnum eClass )
                 // get filter component
                 Reference< xml::sax::XDocumentHandler > xTmpDocHandler(
                     xFactory->createInstanceWithArguments(
-                    OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Oasis2OOoTransformer")),
+                    OUString("com.sun.star.comp.Oasis2OOoTransformer"),
                                 aArgs), UNO_QUERY);
                 OSL_ENSURE( xTmpDocHandler.is(),
                     "can't instantiate OASIS transformer component" );
@@ -1411,6 +1359,7 @@ sal_uInt32 SvXMLExport::exportDoc( enum ::xmloff::token::XMLTokenEnum eClass )
         switch( getDefaultVersion() )
         {
         case SvtSaveOptions::ODFVER_LATEST: pVersion = sXML_1_2; break;
+        case SvtSaveOptions::ODFVER_012_EXT_COMPAT: pVersion = sXML_1_2; break;
         case SvtSaveOptions::ODFVER_012: pVersion = sXML_1_2; break;
         case SvtSaveOptions::ODFVER_011: pVersion = sXML_1_1; break;
         case SvtSaveOptions::ODFVER_010: break;
@@ -1457,7 +1406,7 @@ sal_uInt32 SvXMLExport::exportDoc( enum ::xmloff::token::XMLTokenEnum eClass )
             // office:mimetype = ... (only for stream containing the content)
             if( eClass != XML_TOKEN_INVALID )
             {
-                OUString aTmp( RTL_CONSTASCII_USTRINGPARAM("application/vnd.oasis.opendocument.") );
+                OUString aTmp( "application/vnd.oasis.opendocument." );
                 aTmp += GetXMLToken( eClass );
                 AddAttribute( XML_NAMESPACE_OFFICE, XML_MIMETYPE, aTmp );
             }
@@ -1557,7 +1506,7 @@ void SvXMLExport::_ExportScripts()
     if ( mnExportFlags & EXPORT_EMBEDDED )
     {
         ::rtl::OUString aValue( GetNamespaceMap().GetPrefixByKey( XML_NAMESPACE_OOO ) );
-        aValue += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ":Basic" ) );
+        aValue += ::rtl::OUString(  ":Basic"  );
         AddAttribute( XML_NAMESPACE_SCRIPT, XML_LANGUAGE, aValue );
 
         SvXMLElementExport aElem( *this, XML_NAMESPACE_OFFICE, XML_SCRIPT, sal_True, sal_True );
@@ -1567,7 +1516,7 @@ void SvXMLExport::_ExportScripts()
         {
             Reference< beans::XPropertySet > xPSet( mxModel, UNO_QUERY );
             if ( xPSet.is() )
-                xPSet->getPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "BasicLibraries" ) ) );
+                xPSet->getPropertyValue( ::rtl::OUString(  "BasicLibraries"  ) );
         }
 
         Reference< document::XExporter > xExporter;
@@ -1578,7 +1527,7 @@ void SvXMLExport::_ExportScripts()
             Sequence < Any > aArgs( 1 );
             aArgs[0] <<= xHdl;
             xExporter.set( xMSF->createInstanceWithArguments(
-                OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.document.XMLOasisBasicExporter" ) ), aArgs ),
+                OUString(  "com.sun.star.document.XMLOasisBasicExporter"  ), aArgs ),
                 UNO_QUERY );
         }
 
@@ -1617,7 +1566,7 @@ void SvXMLExport::_ExportStyles( sal_Bool )
         // export (fill-)gradient-styles
         try
         {
-            uno::Reference< container::XNameAccess > xGradient( xFact->createInstance( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.drawing.GradientTable") ) ), uno::UNO_QUERY );
+            uno::Reference< container::XNameAccess > xGradient( xFact->createInstance( OUString("com.sun.star.drawing.GradientTable" ) ), uno::UNO_QUERY );
             if( xGradient.is() )
             {
                 XMLGradientStyleExport aGradientStyle( *this );
@@ -1650,7 +1599,7 @@ void SvXMLExport::_ExportStyles( sal_Bool )
         // export (fill-)hatch-styles
         try
         {
-            uno::Reference< container::XNameAccess > xHatch( xFact->createInstance( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.drawing.HatchTable") ) ), uno::UNO_QUERY );
+            uno::Reference< container::XNameAccess > xHatch( xFact->createInstance( OUString("com.sun.star.drawing.HatchTable" ) ), uno::UNO_QUERY );
             if( xHatch.is() )
             {
                 XMLHatchStyleExport aHatchStyle( *this );
@@ -1682,7 +1631,7 @@ void SvXMLExport::_ExportStyles( sal_Bool )
         // export (fill-)bitmap-styles
         try
         {
-            uno::Reference< container::XNameAccess > xBitmap( xFact->createInstance( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.drawing.BitmapTable") ) ), uno::UNO_QUERY );
+            uno::Reference< container::XNameAccess > xBitmap( xFact->createInstance( OUString("com.sun.star.drawing.BitmapTable" ) ), uno::UNO_QUERY );
             if( xBitmap.is() )
             {
                 XMLImageStyle aImageStyle;
@@ -1715,7 +1664,7 @@ void SvXMLExport::_ExportStyles( sal_Bool )
         // export transparency-gradient -styles
         try
         {
-            uno::Reference< container::XNameAccess > xTransGradient( xFact->createInstance( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.drawing.TransparencyGradientTable") ) ), uno::UNO_QUERY );
+            uno::Reference< container::XNameAccess > xTransGradient( xFact->createInstance( OUString("com.sun.star.drawing.TransparencyGradientTable" ) ), uno::UNO_QUERY );
             if( xTransGradient.is() )
             {
                 XMLTransGradientStyleExport aTransGradientstyle( *this );
@@ -1748,7 +1697,7 @@ void SvXMLExport::_ExportStyles( sal_Bool )
         // export marker-styles
         try
         {
-            uno::Reference< container::XNameAccess > xMarker( xFact->createInstance( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.drawing.MarkerTable") ) ), uno::UNO_QUERY );
+            uno::Reference< container::XNameAccess > xMarker( xFact->createInstance( OUString("com.sun.star.drawing.MarkerTable" ) ), uno::UNO_QUERY );
             if( xMarker.is() )
             {
                 XMLMarkerStyleExport aMarkerStyle( *this );
@@ -1781,7 +1730,7 @@ void SvXMLExport::_ExportStyles( sal_Bool )
         // export dash-styles
         try
         {
-            uno::Reference< container::XNameAccess > xDashes( xFact->createInstance( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.drawing.DashTable") ) ), uno::UNO_QUERY );
+            uno::Reference< container::XNameAccess > xDashes( xFact->createInstance( OUString("com.sun.star.drawing.DashTable" ) ), uno::UNO_QUERY );
             if( xDashes.is() )
             {
                 XMLDashStyleExport aDashStyle( *this );
@@ -1882,7 +1831,7 @@ void SvXMLExport::GetViewSettingsAndViews(uno::Sequence<beans::PropertyValue>& r
             sal_Int32 nOldLength(rProps.getLength());
             rProps.realloc(nOldLength + 1);
             beans::PropertyValue aProp;
-            aProp.Name = OUString(RTL_CONSTASCII_USTRINGPARAM("Views"));
+            aProp.Name = OUString("Views");
             aProp.Value <<= xIndexAccess;
             rProps[nOldLength] = aProp;
         }
@@ -2049,10 +1998,10 @@ ProgressBarHelper*  SvXMLExport::GetProgressBarHelper()
             uno::Reference< beans::XPropertySetInfo > xPropertySetInfo = mxExportInfo->getPropertySetInfo();
             if (xPropertySetInfo.is())
             {
-                OUString sProgressRange(RTL_CONSTASCII_USTRINGPARAM(XML_PROGRESSRANGE));
-                OUString sProgressMax(RTL_CONSTASCII_USTRINGPARAM(XML_PROGRESSMAX));
-                OUString sProgressCurrent(RTL_CONSTASCII_USTRINGPARAM(XML_PROGRESSCURRENT));
-                OUString sRepeat(RTL_CONSTASCII_USTRINGPARAM(XML_PROGRESSREPEAT));
+                OUString sProgressRange(XML_PROGRESSRANGE);
+                OUString sProgressMax(XML_PROGRESSMAX);
+                OUString sProgressCurrent(XML_PROGRESSCURRENT);
+                OUString sRepeat(XML_PROGRESSREPEAT);
                 if (xPropertySetInfo->hasPropertyByName(sProgressMax) &&
                     xPropertySetInfo->hasPropertyByName(sProgressCurrent) &&
                     xPropertySetInfo->hasPropertyByName(sProgressRange))
@@ -2077,7 +2026,7 @@ ProgressBarHelper*  SvXMLExport::GetProgressBarHelper()
                     if (aAny.getValueType() == getBooleanCppuType())
                         mpProgressBarHelper->SetRepeat(::cppu::any2bool(aAny));
                     else {
-                        DBG_ERRORFILE("why is it no boolean?");
+                        SAL_WARN( "xmloff.core", "why is it no boolean?" );
                     }
                 }
             }
@@ -2094,9 +2043,9 @@ XMLEventExport& SvXMLExport::GetEventExport()
         mpEventExport = new XMLEventExport(*this, NULL);
 
         // and register standard handlers + names
-        OUString sStarBasic(RTL_CONSTASCII_USTRINGPARAM("StarBasic"));
+        OUString sStarBasic("StarBasic");
         mpEventExport->AddHandler(sStarBasic, new XMLStarBasicExportHandler());
-        OUString sScript(RTL_CONSTASCII_USTRINGPARAM("Script"));
+        OUString sScript("Script");
         mpEventExport->AddHandler(sScript, new XMLScriptExportHandler());
         mpEventExport->AddTranslationTable(aStandardEventTable);
     }
@@ -2171,7 +2120,7 @@ sal_Bool SvXMLExport::ExportEmbeddedOwnObject( Reference< XComponent >& rComp )
                 sFilterService = OUString( pEntry->sFilterService,
                                            pEntry->nFilterServiceLen,
                                               RTL_TEXTENCODING_ASCII_US );
-                bIsChart = sModelService.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( XML_MODEL_SERVICE_CHART ));
+                bIsChart = sModelService == XML_MODEL_SERVICE_CHART;
                 break;
             }
             pEntry++;
@@ -2180,7 +2129,7 @@ sal_Bool SvXMLExport::ExportEmbeddedOwnObject( Reference< XComponent >& rComp )
 
     OSL_ENSURE( sFilterService.getLength(), "no export filter for own object" );
 
-    if( !sFilterService.getLength() )
+    if( sFilterService.isEmpty() )
         return sal_False;
 
     Reference < XDocumentHandler > xHdl =
@@ -2206,7 +2155,7 @@ sal_Bool SvXMLExport::ExportEmbeddedOwnObject( Reference< XComponent >& rComp )
                 new ::comphelper::PropertySetInfo( aInfoMap )));
 
         if( bIsChart )
-            xInfoProp->setPropertyValue( OUString( RTL_CONSTASCII_USTRINGPARAM("ExportTableNumberList")), makeAny( true ));
+            xInfoProp->setPropertyValue( OUString( "ExportTableNumberList"), makeAny( true ));
 
         aArgs.realloc( 2 );
         aArgs[1] <<= xInfoProp;
@@ -2239,7 +2188,7 @@ OUString SvXMLExport::GetRelativeReference(const OUString& rValue)
     // #i65474# handling of fragment URLs ("#....") is undefined
     // they are stored 'as is'
     uno::Reference< uri::XUriReference > xUriRef;
-    if(sValue.getLength() && sValue.getStr()[0] != '#')
+    if(!sValue.isEmpty() && sValue.getStr()[0] != '#')
     {
         try
         {
@@ -2427,17 +2376,11 @@ void SvXMLExport::SetError(
     SetError( nId, rMsgParams, sEmpty, NULL );
 }
 
-
-XMLErrors* SvXMLExport::GetErrors()
-{
-    return mpXMLErrors;
-}
-
 void SvXMLExport::DisposingModel()
 {
     mxModel.clear();
     // Shapes in Writer cannot be named via context menu (#i51726#)
-    meModelType = SvtModuleOptions::E_UNKNOWN_FACTORY;;
+    meModelType = SvtModuleOptions::E_UNKNOWN_FACTORY;
     mxEventListener.clear();
 }
 
@@ -2514,10 +2457,10 @@ SvXMLExport::AddAttributeXmlId(uno::Reference<uno::XInterface> const & i_xIfc)
     if ( xMeta.is() )
     {
         const beans::StringPair mdref( xMeta->getMetadataReference() );
-        if ( mdref.Second.getLength() )
+        if ( !mdref.Second.isEmpty() )
         {
             const ::rtl::OUString streamName( GetStreamName() );
-            if ( streamName.getLength() )
+            if ( !streamName.isEmpty() )
             {
                 if ( streamName.equals(mdref.First) )
                 {
@@ -2537,7 +2480,7 @@ SvXMLExport::AddAttributeXmlId(uno::Reference<uno::XInterface> const & i_xIfc)
                 // a) just omit styles.xml ids -- they are unlikely anyway...
                 // b) somehow find out whether we are currently exporting styles
                 //    or content, and prefix "s" or "c" => unique
-                if ( mdref.First.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("content.xml")) )
+                if ( mdref.First == "content.xml" )
                 {
                     AddAttribute( XML_NAMESPACE_XML, XML_ID, mdref.Second );
                 }
@@ -2564,7 +2507,7 @@ SvXMLExport::AddAttributesRDFa(
 
     const uno::Reference<rdf::XMetadatable> xMeta(
         i_xTextContent, uno::UNO_QUERY);
-    if (!xMeta.is() || !xMeta->getMetadataReference().Second.getLength())
+    if (!xMeta.is() || xMeta->getMetadataReference().Second.isEmpty())
     {
         return; // no xml:id => no RDFa
     }
@@ -2638,37 +2581,6 @@ SvXMLElementExport::SvXMLElementExport( SvXMLExport& rExp,
     StartElement( rExp, nPrefixKey, GetXMLToken(eLName), bIWSOutside );
 }
 
-SvXMLElementExport::SvXMLElementExport( SvXMLExport& rExp,
-                                        sal_Bool bDoSth,
-                                        sal_uInt16 nPrefixKey,
-                                        const sal_Char *pLName,
-                                        sal_Bool bIWSOutside,
-                                        sal_Bool bIWSInside ) :
-    rExport( rExp ),
-    bIgnWS( bIWSInside ),
-    bDoSomething( bDoSth )
-{
-    if( bDoSomething )
-    {
-        OUString sLName( OUString::createFromAscii(pLName) );
-        StartElement( rExp, nPrefixKey, sLName, bIWSOutside );
-    }
-}
-
-SvXMLElementExport::SvXMLElementExport( SvXMLExport& rExp,
-                                        sal_Bool bDoSth,
-                                        sal_uInt16 nPrefixKey,
-                                        const OUString& rLName,
-                                        sal_Bool bIWSOutside,
-                                        sal_Bool bIWSInside ) :
-    rExport( rExp ),
-    bIgnWS( bIWSInside ),
-    bDoSomething( bDoSth )
-{
-    if( bDoSomething )
-        StartElement( rExp, nPrefixKey, rLName, bIWSOutside );
-}
-
 SvXMLElementExport::SvXMLElementExport( SvXMLExport& rExp,
                                         sal_Bool bDoSth,
                                         sal_uInt16 nPrefixKey,
